asn_data = {
    "0": "-Reserved AS-",
    "1": "LVLT-1 - Level 3 Communications, Inc.",
    "2": "UDEL-DCN - University of Delaware",
    "3": "MIT-GATEWAYS - Massachusetts Institute of Technology",
    "4": "ISI- - University of Southern California",
    "5": "SYMBOLICS - Symbolics, Inc.",
    "6": "BULL-NETWORK for further information please visit http://www.bull.com",
    "7": "UK Defence Research Agency",
    "8": "RICE- - Rice University",
    "9": "CMU-ROUTER - Carnegie Mellon University",
    "10": "CSNET-EXT- - CSNET Coordination and Information Center (CSNET-CIC)",
    "11": "HARVARD - Harvard University",
    "12": "NYU-DOMAIN - New York University",
    "13": "DNIC--00013 - Headquarters, USAISC",
    "14": "COLUMBIA-GW - Columbia University",
    "15": "NET-DYNAMICS-EXP - DYNAMICS",
    "16": "LBL - Lawrence Berkeley National Laboratory",
    "17": "PURDUE - Purdue University",
    "18": "UTEX - University of Texas at Austin",
    "19": "CSS-DOMAIN - SMDC c/o Science Applications International Corporation",
    "20": "UR - University of Rochester",
    "21": "RAND - The RAND Corporation",
    "22": "DNIC--00022 - Navy Network Information Center (NNIC)",
    "23": "NISN-SIP- - National Aeronautics and Space Administration",
    "24": "AMES-N-GW - National Aeronautics and Space Administration",
    "25": "UCB - University of California at Berkeley",
    "26": "CORNELL - Cornell University",
    "27": "UMDNET - University of Maryland",
    "28": "DFVLR-SYS Deutsches Zentrum fuer Luft- und Raumfahrt",
    "29": "YALE- - Yale University",
    "30": "SRI-AICNET - SRI International",
    "31": "CIT - California Institute of Technology",
    "32": "STANFORD - Stanford University",
    "33": "HP-DIGITAL-33 - Hewlett-Packard Company",
    "34": "UDELNET - University of Delaware",
    "35": "MITRE--1 - The MITRE Corporation",
    "36": "EGP-TESTOR - SRI International",
    "37": "DNIC--00037 - Navy Network Information Center (NNIC)",
    "38": "UIUC - University of Illinois",
    "39": "DNIC--00039 - DoD Network Information Center",
    "40": "MIT-TEST - Massachusetts Institute of Technology",
    "41": "AMES - National Aeronautics and Space Administration",
    "42": "PCH PCH",
    "43": "BNL- - Brookhaven National Laboratory",
    "44": "S1-DOMAIN - Lawrence Livermore National Laboratory",
    "45": "LLL-TIS- - Lawrence Livermore National Laboratory",
    "46": "RUTGERS - Rutgers University",
    "47": "USC- - University of Southern California",
    "48": "DNIC--00048 - Navy Network Information Center (NNIC)",
    "49": "ICST- - National Bureau of Standards",
    "50": "ORNL-MSRNET - Oak Ridge National Laboratory",
    "51": "DNIC--00051 - Headquarters, USAISC",
    "52": "UCLA - University of California, Los Angeles",
    "53": "NORTHROP- - Northrop Grumman Corporation - Automation Sciences Laboratory",
    "54": "DNIC--00054 - Headquarters, USAISC",
    "55": "UPENN - University of Pennsylvania",
    "56": "DNIC--00056 - DoD Network Information Center",
    "57": "UMN-REI-UC - University of Minnesota",
    "58": "DREA- - Defence Research Establishment Atlantic",
    "59": "WISC-MADISON- - University of Wisconsin Madison",
    "60": "AINET-60 - Advanced Information Technology Services, LLC",
    "61": "DEC-MARLBORO- - 754th Electronic Systems Group",
    "62": "CYRS - CyrusOne LLC",
    "63": "LL-MI - Massachusetts Institute of Technology",
    "64": "MITRE--2 - The MITRE Corporation",
    "65": "AF-RN-65 - 754th Electronic Systems Group",
    "66": "DNIC--00066 - Headquarters, USAISC",
    "67": "SDC-PRC- - Unisys Corporation",
    "68": "LANL-INET- - Los Alamos National Laboratory",
    "69": "UPENN2 - University of Pennsylvania",
    "70": "NLM-GW - National Library of Medicine",
    "71": "HP-INTERNET- Hewlett Packard Europe S.A.S.",
    "72": "SCHLUMBERGER- Schlumberger Limited",
    "73": "WHINGTON- - University of Washington",
    "74": "XDRENET- - Defence Research Establishment",
    "75": "ANL- - Argonne National Laboratory",
    "76": "SDC-CAM- - Unisys Corporation",
    "77": "JHUAPL- - Johns Hopkins University Applied Physics Laboratory",
    "78": "SYNTEGRA - Syntegra (USA), Inc.",
    "79": "DSPO-HC- - Los Alamos National Laboratory",
    "80": "GE-CRD - General Electric Company",
    "81": "NCREN - MCNC",
    "82": "TWG-DEMO- - The Wollongong Group",
    "83": "DNIC--00083 - Headquarters, USAISC",
    "84": "DNIC--00084 - Navy Network Information Center (NNIC)",
    "85": "AERO-NET - The Aerospace Corporation",
    "86": "CSC-300-86 - Computer Sciences Corporation",
    "87": "INDIANA- - Indiana University",
    "88": "PRINCETON- - Princeton University",
    "89": "DNIC--00089 - Navy Network Information Center (NNIC)",
    "90": "SUN- - Sun Microsystems, Inc.",
    "91": "RPI- - Rensselaer Polytechnic Institute",
    "92": "CLARKSON- - Clarkson University",
    "93": "NTTA-93 - NTT America, Inc.",
    "94": "DNIC--00094 - Headquarters, USAISC",
    "95": "DNIC--00095 - DoD Network Information Center",
    "96": "DNIC--00096 - Headquarters, USAISC",
    "97": "NTTA-97 - NTT America, Inc.",
    "98": "ROCKEFELLER- - The Rockefeller University",
    "99": "INTEL-IWARP - Intel Corporation",
    "100": "FMC-CTC - FMC Central Engineering Laboratories",
    "101": "WH-NSF- - University of Washington",
    "102": "NSF-HQ- - National Science Foundation",
    "103": "NWU- - Northwestern University",
    "104": "COLORADO- - University of Colorado at Boulder",
    "105": "MOT-MCD- - Gould Computer Systems Division",
    "106": "GDAIS-N-106 - General Dynamics Advanced Information Systems, Inc.",
    "107": "ECSNET- - 754th Electronic Systems Group",
    "108": "XEROX- - Xerox Corporation",
    "109": "CISCO-EU-109 Cisco Systems Global N - ARIN Assigned",
    "110": "XAIT- - Xerox Advanced Information Technology",
    "111": "BOSTONU- - Boston University",
    "112": "ROOTSERV Root Server Technical Operations Assn",
    "113": "SCCNET- - Space Communications Company",
    "114": "NTTA-114 - NTT America, Inc.",
    "115": "DNIC--00115 - DoD Network Information Center",
    "116": "TELCORDIA - Telcordia Technologies",
    "117": "ALBM-NET- - Lockheed Austin Division",
    "118": "DNIC--00118 - Navy Network Information Center (NNIC)",
    "119": "AMS- - American Mathematical Society",
    "120": "MITRE-OMAHA - The MITRE Corporation",
    "121": "DNIC--00121 - DoD Network Information Center",
    "122": "U-PGH-NET- - UPMC",
    "123": "LOGAIRCOMNET- - 754th Electronic Systems Group",
    "124": "DNIC--00124 - DoD Network Information Center",
    "125": "HI-NET- - Honeywell International, Inc.",
    "126": "DNIC--00126 - DoD Network Information Center",
    "127": "JPL-127 - Jet Propulsion Laboratory",
    "128": "ADS- - Advanced Decision Systems",
    "129": "DNIC--00129 - DoD Network Information Center",
    "130": "CSOCNET- - Space Communications Division",
    "131": "UCSB-NET- - University of California, Santa Barbara",
    "132": "WPAFB-CSD-NET- - 754th Electronic Systems Group",
    "133": "AFIT- - 754th Electronic Systems Group",
    "134": "CORONA-GW- - Fleet Analysis Center",
    "135": "DNIC--00135 - DoD Network Information Center",
    "136": "AF-N-136 - 754th Electronic Systems Group",
    "137": "GARR GARR Italian academic and research network",
    "138": "DNIC--00138 - DoD Network Information Center",
    "139": "DNIC--00139 - Navy Network Information Center (NNIC)",
    "140": "DNIC--00140 - DoD Network Information Center",
    "141": "DNIC--00141 - Navy Network Information Center (NNIC)",
    "142": "DNIC--00142 - Headquarters, USAISC",
    "143": "OOG1- - 1881CS/XPC",
    "144": "ATT-INTERNET - Lucent Technologies/Bell Laboratories",
    "145": "VBNS - MCI Communications Corporation",
    "146": "HQEIS- - 754th Electronic Systems Group",
    "147": "DNIC--00147 - DoD Network Information Center",
    "148": "DNIC--00148 - Navy Network Information Center (NNIC)",
    "149": "DNIC--00149 - DoD Network Information Center",
    "150": "DNIC--00150 - Navy Network Information Center (NNIC)",
    "151": "IND-NTC- - Hewlett-Packard Company",
    "152": "SRI-ACCATT- - SRI International",
    "153": "CTNOSC-N-153 - Headquarters, USAISC",
    "154": "DNIC--00154 - Headquarters, USAISC",
    "155": "DNIC--00155 - DoD Network Information Center",
    "156": "NORTHETERN-GW- - Northeastern University",
    "157": "INTELLIAUTON - Silicon Graphics International Corp.",
    "158": "ERI- - Ericsson Network Systems, Inc.",
    "159": "OSUNET- - The Ohio State University",
    "160": "U-CHICAGO- - University of Chicago",
    "161": "TI- - Texas Instruments, Inc.",
    "162": "DNIC--00162 - Navy Network Information Center (NNIC)",
    "163": "IBM-RESEARCH- - IBM Almaden Research Center",
    "164": "DNIC--00164 - DoD Network Information Center",
    "165": "DNIC--00165 - DoD Network Information Center",
    "166": "IDA- - Institute for Defense Analyses",
    "167": "WESLEYAN- - Wesleyan University",
    "168": "UMS-AMHERST - University of Massachusetts",
    "169": "HANSCOM-NET- - 754th Electronic Systems Group",
    "170": "DNIC--00170 - DoD Network Information Center",
    "171": "SOX-RES - Southern Light Rail, Inc.",
    "172": "DNIC--00172 - Headquarters, USAISC",
    "173": "ERX-ECLNET Electrical Communications Laboratories",
    "174": "COGENT Cogent/PSI",
    "175": "PL- - 754th Electronic Systems Group",
    "176": "BCN- - Information Systems and Networks Corporation",
    "177": "UMICH--1 - University of Michigan",
    "178": "UMICH--2 - University of Michigan",
    "179": "UMICH--3 - University of Michigan",
    "180": "UMICH--4 - University of Michigan",
    "181": "MERIT--1 - Merit Network Inc.",
    "182": "MERIT--2 - Merit Network Inc.",
    "183": "MERIT--3 - Merit Network Inc.",
    "184": "MERIT--4 - Merit Network Inc.",
    "185": "MERIT--5 - Merit Network Inc.",
    "186": "CUA- - The Catholic University of America",
    "187": "DNSCT- - DNScast",
    "188": "SAIC- - Science Applications International Corporation",
    "189": "LVLT-189 - Level 3 Communications, Inc.",
    "190": "DNIC--00190 - Navy Network Information Center (NNIC)",
    "191": "DNIC--00191 - Navy Network Information Center (NNIC)",
    "192": "ROCHINSTTECH - Rochester Institute of Technology",
    "193": "FORD-N - Lockheed Martin Western Development Labs",
    "194": "NCAR- - University Corporation for Atmospheric Research",
    "195": "SDSC- - San Diego Supercomputer Center",
    "196": "RISC-SYSTEM - Rockwell Scientific Company",
    "197": "RAYTHEON--2 - Raytheon Company",
    "198": "DNIC--00198 - DoD Network Information Center",
    "199": "LVLT-199-203 - Level 3 Communications, Inc.",
    "200": "LVLT-199-203 - Level 3 Communications, Inc.",
    "201": "LVLT-199-203 - Level 3 Communications, Inc.",
    "202": "LVLT-199-203 - Level 3 Communications, Inc.",
    "203": "LVLT-199-203 - Level 3 Communications, Inc.",
    "204": "PSCNET- - Pittsburgh Supercomputing Center",
    "205": "MONTCLAIR- - Montclair State University",
    "206": "CSC-IGN-AMER - Computer Sciences Corporation",
    "207": "CLI-GW- - Computational Logic, Inc.",
    "208": "DNIC--00208 - Navy Network Information Center (NNIC)",
    "209": "N-QWEST-US NOVARTIS-DMZ-US",
    "210": "WEST-NET-WEST - Utah Education Network",
    "211": "RADC-LONS-GW- - Rome Air Development Center",
    "212": "HQAFSC-LONS-GW- - Headquarters, Air Force Systems Command",
    "213": "DNIC--00213 - Headquarters, USAISC",
    "214": "DNIC--00214 - Navy Network Information Center (NNIC)",
    "215": "DNIC--00215 - Headquarters, USAISC",
    "216": "LMSC-HOSTNET- - 754th Electronic Systems Group",
    "217": "UMN-AGS-NET- - University of Minnesota",
    "218": "AFOTECPCNET- - 754th Electronic Systems Group",
    "219": "DNIC--00219 - Navy Network Information Center (NNIC)",
    "220": "OOALC-HOSTNET- - 754th Electronic Systems Group",
    "221": "WRALC-HOSTNET- - 754th Electronic Systems Group",
    "222": "SMALC-HOSTNET- - 754th Electronic Systems Group",
    "223": "TISW- - Sparta, Inc.",
    "224": "UNINETT UNINETT, The Norwegian University & Research Network",
    "225": "VIRGINIA- - University of Virginia",
    "226": "LOS-NETTOS- - Los Nettos",
    "227": "DNIC--00227 - Headquarters, USAISC",
    "228": "DNIC--00228 - DoD Network Information Center",
    "229": "MERIT--6 - Merit Network Inc.",
    "230": "MERIT--7 - Merit Network Inc.",
    "231": "MERIT--8 - Merit Network Inc.",
    "232": "MERIT--9 - Merit Network Inc.",
    "233": "MERIT--10 - Merit Network Inc.",
    "234": "BLACKROSE-1 - Blackrose Society",
    "235": "MERIT--12 - Merit Network Inc.",
    "236": "MERIT--13 - Merit Network Inc.",
    "237": "MERIT--14 - Merit Network Inc.",
    "238": "MERIT--15 - Merit Network Inc.",
    "239": "UTORONTO- - University of Toronto",
    "240": "SAALC-HOSTNET- - 754th Electronic Systems Group",
    "241": "OCALC-HOSTNET- - 754th Electronic Systems Group",
    "242": "SSSD- - SUPSHIP",
    "243": "HARRIS-ATD- - Harris Government Systems Sector",
    "244": "DNIC--00244 - DoD Network Information Center",
    "245": "PRC- - Planning Research Corporation",
    "246": "IFICS-GW- - 754th Electronic Systems Group",
    "247": "ROMENET- - Rome Air Development Center",
    "248": "ICEVPN- ICEVPN-",
    "249": "FNORD- 249",
    "250": "SACREDCHAO- 250.net Foundation",
    "251": "KAIAGLOBAL- Kaia Global Networks Ltd.",
    "252": "DNIC--00252 - Headquarters, USAISC",
    "253": "NTTA-253 - NTT America, Inc.",
    "254": "TWG-NET- - The Wollongong Group",
    "255": "PAFB-GW - 754th Electronic Systems Group",
    "256": "DNIC--00256 - Navy Network Information Center (NNIC)",
    "257": "DNIC--00257 - Navy Network Information Center (NNIC)",
    "258": "BRAGGSRI-EGP- - Headquarters, USAISC",
    "259": "SCUBED- - SCUBED",
    "260": "XCONNECT24 XCONNECT24",
    "261": "FR-CINES-MONTPELLIER FR",
    "262": "VERIO - Verio Inc.",
    "263": "NTTA-263 - NTT America, Inc.",
    "264": "SRINET- - SRI International",
    "265": "DSI-WR-16 - Advanced Info. Technology Servcies",
    "266": "DHC-USA-INC - DHC USA INCORPORATED",
    "267": "NETHER-NET - Nether.Net",
    "268": "USUHSNET- - Uniformed Services University of the Health Sciences",
    "269": "INCSYS- - Incremental Systems Corporation",
    "270": "PSCNI- - National Aeronautics and Space Administration",
    "271": "BCNET- - BCnet",
    "272": "CTNOSC-N-272 - Headquarters, USAISC",
    "273": "DNIC--00273 - DoD Network Information Center",
    "274": "AINET-274 - Advanced Information Technology Services, LLC",
    "275": "NTTA-275 - NTT America, Inc.",
    "276": "OTS--276 - University of Texas System",
    "277": "CSC-300-277 - Computer Sciences Corporation",
    "278": "Universidad Nacional Autonoma de Mexico",
    "279": "LVLT-279 - Level 3 Communications, Inc.",
    "280": "NTTA-280 - NTT America, Inc.",
    "281": "LVLT-281 - Level 3 Communications, Inc.",
    "282": "MERIT-AUX- - Merit Technology, Inc.",
    "283": "MPOWERLABS - MPower Labs, Inc.",
    "284": "UUNET-IPV6 - MCI Communications Services, Inc. d/b/a Verizon Business",
    "285": "DNIC--00285 - Headquarters, USAISC",
    "286": "KPN KPN Internet Backbone",
    "287": "DNIC--00287 - Navy Network Information Center (NNIC)",
    "288": "European Space Agency c/o Christoph Kroell Darmstadt, D-64293 DE",
    "289": "DNIC--00289 - Headquarters, USAISC",
    "290": "SHOWNET- - Interop Show Network",
    "291": "ESNET-ET - ESnet",
    "292": "ESNET-WEST - ESnet",
    "293": "ESNET - ESnet",
    "294": "FRANCE-IP-NET- Institut National de Recherche en Informatique et Automatique",
    "295": "DNIC--00295 - Navy Network Information Center (NNIC)",
    "296": "ACFP- - 754th Electronic Systems Group",
    "297": "NISN-SIP- - National Aeronautics and Space Administration",
    "298": "RADC-LONEX- - 754th Electronic Systems Group",
    "299": "UCINET- - University of California, Irvine",
    "300": "DNIC--00300 - DoD Network Information Center",
    "301": "C3PO- - 754th Electronic Systems Group",
    "302": "BCM-INFO-NET- - Baylor College of Medicine",
    "303": "DNIC--00303 - DoD Network Information Center",
    "304": "SRIEXPRIGNET- - SRI International",
    "305": "DNIC--00305 - Headquarters, USAISC",
    "306": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "307": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "308": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "309": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "310": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "311": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "312": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "313": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "314": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "315": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "316": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "317": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "318": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "319": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "320": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "321": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "322": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "323": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "324": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "325": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "326": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "327": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "328": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "329": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "330": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "331": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "332": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "333": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "334": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "335": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "336": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "337": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "338": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "339": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "340": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "341": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "342": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "343": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "344": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "345": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "346": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "347": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "348": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "349": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "350": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "351": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "352": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "353": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "354": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "355": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "356": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "357": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "358": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "359": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "360": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "361": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "362": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "363": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "364": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "365": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "366": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "367": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "368": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "369": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "370": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "371": "DNIC-BLK-00306-00371 - DoD Network Information Center",
    "372": "NSN-AMES- - National Aeronautics and Space Administration",
    "373": "MITRE--4 - The MITRE Corporation",
    "374": "BROOKS- - 754th Electronic Systems Group",
    "375": "TIETOTIE- Tieto Oyj",
    "376": "RISQ- - Reseau  d'informations scientifiques du Quebec (RISQ)",
    "377": "SNLA-NET- - Sandia National Laboratories",
    "378": "MACHBA- ILAN",
    "379": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "380": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "381": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "382": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "383": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "384": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "385": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "386": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "387": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "388": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "389": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "390": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "391": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "392": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "393": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "394": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "395": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "396": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "397": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "398": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "399": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "400": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "401": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "402": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "403": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "404": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "405": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "406": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "407": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "408": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "409": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "410": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "411": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "412": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "413": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "414": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "415": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "416": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "417": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "418": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "419": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "420": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "421": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "422": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "423": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "424": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "425": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "426": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "427": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "428": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "429": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "430": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "431": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "432": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "433": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "434": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "435": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "436": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "437": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "438": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "439": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "440": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "441": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "442": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "443": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "444": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "445": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "446": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "447": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "448": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "449": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "450": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "451": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "452": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "453": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "454": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "455": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "456": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "457": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "458": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "459": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "460": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "461": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "462": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "463": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "464": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "465": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "466": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "467": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "468": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "469": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "470": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "471": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "472": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "473": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "474": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "475": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "476": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "477": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "478": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "479": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "480": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "481": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "482": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "483": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "484": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "485": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "486": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "487": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "488": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "489": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "490": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "491": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "492": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "493": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "494": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "495": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "496": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "497": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "498": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "499": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "500": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "501": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "502": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "503": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "504": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "505": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "506": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "507": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "508": "AFCONC-BLOCK1- - 754th Electronic Systems Group",
    "509": "DNIC--00509 - DoD Network Information Center",
    "510": "INTERNET - ING Investment Management",
    "511": "TCOOM - TCoombs & Associates, LLC",
    "512": "DNIC--00512 - DoD Network Information Center",
    "513": "CERN CERN - European Organization for Nuclear Research",
    "514": "DNIC--00514 - DoD Network Information Center",
    "515": "DNIC--00515 - DoD Network Information Center",
    "516": "KODAK-BTC - Eastman Kodak Boston Technology Center",
    "517": "KPN Eurorings B.V.",
    "518": "DNIC--00518 - DoD Network Information Center",
    "519": "ISCNET - Systemhouse/INTERACTIVE Systems",
    "520": "COINSDISNET3 - Coins Community Online Intelligence System",
    "521": "FORD-SRL- - Ford Motor Company",
    "522": "AFSC-SSD- - 754th Electronic Systems Group",
    "523": "DNIC--00523 - Headquarters, USAISC",
    "524": "LVLT-524 - Level 3 Communications, Inc.",
    "525": "CTNOSC-525- - Headquarters, USAISC",
    "526": "DNIC--00526 - Headquarters, USAISC",
    "527": "DNIC--00527 - DoD Network Information Center",
    "528": "AUGSBURG-GW1- CDOIM Augsburg",
    "529": "BURTONWOOD-GW1- CDOIM Burtonwood Information Center",
    "530": "DNIC--00530 - Headquarters, USAISC",
    "531": "DNIC--00531 - Headquarters, USAISC",
    "532": "DNIC--00532 - DoD Network Information Center",
    "533": "DNIC--00533 - Headquarters, USAISC",
    "534": "DNIC--00534 - Headquarters, USAISC",
    "535": "DNIC--00535 - Headquarters, USAISC",
    "536": "DNIC--00536 - Headquarters, USAISC",
    "537": "DNIC--00537 - Headquarters, USAISC",
    "538": "DNIC--00538 - Headquarters, USAISC",
    "539": "DNIC--00539 - Headquarters, USAISC",
    "540": "DNIC--00540 - DoD Network Information Center",
    "541": "IGAUTON - Intelligenetics Inc.",
    "542": "ARNET - Alberta Research Council",
    "543": "HP-POLYCOM - Hewlett-Packard Company",
    "544": "SONERA-FUNET-TRANSIT Sonera Corporation",
    "545": "NRI - Corporation for National Research Initiatives",
    "546": "SPARTA- - Sparta, Inc.",
    "547": "N-IBM-LEX - IBM",
    "548": "HQUSAF- - 754th Electronic Systems Group",
    "549": "GTANET- - GTAnet Networking",
    "550": "CORNETT- - Los Alamos National Laboratory",
    "551": "TIS- - Sparta, Inc.",
    "552": "DNIC--00552 - DoD Network Information Center",
    "553": "BELWUE Landeshochschulnetz Baden-Wuerttemberg (BelWue)",
    "554": "CALINET- - California Internet Federation",
    "555": "VTSII - Velocity Technology Solutions II, Inc.",
    "556": "CALREN- - USC/Information Sciences Institute",
    "557": "UMAINE-SYS- - University of Maine System",
    "558": "NET2EZ - Net2EZ",
    "559": "SWITCH SWITCH, Swiss Education and Research Network",
    "560": "LVLT-560 - Level 3 Communications, Inc.",
    "561": "3COM-A - 3Com Corporation",
    "562": "3COM-B - 3Com Corporation",
    "563": "3COM-C - 3Com Corporation",
    "564": "DNIC--00564 - DoD Network Information Center",
    "565": "Technical Research Centre of Finland",
    "566": "CSSP-N - Canadian Space Agency",
    "567": "N-LNET- - Los Nettos",
    "568": "DNIC--00568 - DoD Network Information Center",
    "569": "DNIC--00569 - DoD Network Information Center",
    "570": "SSD-NET- - 754th Electronic Systems Group",
    "571": "DNIC--00571 - DoD Network Information Center",
    "573": "DNIC--00573 - DoD Network Information Center",
    "574": "PSC-TEST- - Pittsburgh Supercomputing Center",
    "575": "DNIC--00575 - Headquarters, USAISC",
    "576": "DNIC--00576 - DoD Network Information Center",
    "577": "BACOM - Bell Canada",
    "578": "PKDY-NUMBER - Packaging Dynamics",
    "579": "C4DR2 - Glynlyon",
    "580": "DNIC--00580 - DoD Network Information Center",
    "581": "AMC-MAF-C2-ENCLAVES - 754th Electronic Systems Group",
    "582": "GDSS-21AF- - 754th Electronic Systems Group",
    "583": "GDSS-22AF- - 754th Electronic Systems Group",
    "584": "GDSS-23AF- - 754th Electronic Systems Group",
    "585": "GDSS-322ALD- - 754th Electronic Systems Group",
    "586": "GDSS-834ALD- - 754th Electronic Systems Group",
    "587": "GDSS-ANG- - 754th Electronic Systems Group",
    "588": "DIRECTRON - Headquarters, USAISC",
    "589": "UNT-CAMPUS- - University of North Texas",
    "590": "EInet Operations Center",
    "591": "NSTN- - NSTN, Inc.",
    "592": "DNIC--00592 - Navy Network Information Center (NNIC)",
    "593": "EINET-1 Easinet Air Base",
    "594": "LVLT594-598 - Level 3 Communications, Inc.",
    "595": "LVLT594-598 - Level 3 Communications, Inc.",
    "596": "LVLT594-598 - Level 3 Communications, Inc.",
    "597": "LVLT594-598 - Level 3 Communications, Inc.",
    "598": "LVLT594-598 - Level 3 Communications, Inc.",
    "599": "NISC- - SRI International",
    "600": "OARNET- - OARnet",
    "601": "BACOM4- - Bell Canada",
    "602": "BACOM3- - Bell Canada",
    "603": "BACOM2- - Bell Canada",
    "604": "ONELAMBDA-INC - One Lambda, Incorporated",
    "605": "VHS-CHIL - Vanguard Health Management, Inc.",
    "607": "-NICO1 - Nico Holdings LLC",
    "608": "BUFORD-COMM-ALLIAN-1 - ALLIANCE COMMUNICATIONS NETWORK",
    "609": "EY--DE Ernst & Young LLP",
    "610": "NAVTEQLEVEL3DALL - HERE North America LLC",
    "611": "CANET11- - University of Toronto",
    "612": "PRECISIONTECH - PRECISION TECHNOLOGY Inc",
    "613": "BP-LIGW BP External LIGW",
    "614": "CSUNET- - California State University Chancellor's Office",
    "615": "DNIC--00615 - Headquarters, USAISC",
    "616": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "617": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "618": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "619": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "620": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "621": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "622": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "623": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "624": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "625": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "626": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "627": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "628": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "629": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "630": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "631": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "632": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "633": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "634": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "635": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "636": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "637": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "638": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "639": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "640": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "641": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "642": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "643": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "644": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "645": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "646": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "647": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "648": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "649": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "650": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "651": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "652": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "653": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "654": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "655": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "656": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "657": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "658": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "659": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "660": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "661": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "662": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "663": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "664": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "665": "DNIC-BLK-00616-00665 - DoD Network Information Center",
    "666": "CTNOSC-N-666 - Headquarters, USAISC",
    "667": "DNIC--00667 - DoD Network Information Center",
    "668": "DNIC--00668 - DoD Network Information Center",
    "669": "OFRIR-IP-INTERNET- INRIA",
    "670": "DNIC--00670 - Headquarters, USAISC",
    "671": "DNIC--00671 - Headquarters, USAISC",
    "672": "DNIC--00672 - Headquarters, USAISC",
    "673": "DNIC--00673 - Headquarters, USAISC",
    "674": "BBN-DSI - Advanced Information Technology Services, LLC",
    "675": "MSUS- - Minnesota State Colleges and Universities",
    "676": "United Nations Development Programme",
    "677": "U- - Arizona State University",
    "678": "DNIC--00678 - DoD Network Information Center",
    "679": "TUNET- Vienna University of Technology",
    "680": "DFN Verein zur Foerderung eines Deutschen Forschungsnetzes e.V.",
    "681": "ERX-KAWAIHIKO-1 The University of Waikato",
    "682": "-ORNL-IGRP1- - Oak Ridge National Laboratory",
    "683": "ARGONNE- - Argonne National Lab",
    "684": "MTSAL-N - MTS Allstream Inc.",
    "685": "NTTA-685 - NTT America, Inc.",
    "686": "OSD-GW- - 7th Communications Group/GNE",
    "687": "DNIC--00687 - DoD Network Information Center",
    "688": "RECNET- - Department of Interior",
    "689": "MERIT--26 - Merit Network Inc.",
    "690": "MERIT--27 - Merit Network Inc.",
    "691": "PEINET- - University of P.E.I",
    "692": "SEMATECH- - Sematech, Inc.",
    "693": "NOTRE-DAME- - University of Notre Dame",
    "694": "DNIC--00694 - Headquarters, USAISC",
    "695": "SWITCH-TEST1 SWITCH, The Swiss Education and Research Network",
    "696": "SWITCH-TEST2 SWITCH, The Swiss Education and Research Network",
    "697": "Gesellschaft fuer Mathematik und Datenverarbeitung",
    "698": "N-UIUC-REGION- - University of Illinois at Urbana-Champaign",
    "699": "KNBE - KANOBE INC",
    "700": "ROKNET- - Rockwell International Systems",
    "701": "UUNET - MCI Communications Services, Inc. d/b/a Verizon Business",
    "702": "702 Verizon Business EMEA - Commercial IP service provider in Europe",
    "703": "UUNET - MCI Communications Services, Inc. d/b/a Verizon Business",
    "704": "UUNET - MCI Communications Services, Inc. d/b/a Verizon Business",
    "705": "UUNET - MCI Communications Services, Inc. d/b/a Verizon Business",
    "706": "TEST-AUSTIN-IBM- - Advanced Workstations Division, IBM Corporation",
    "707": "ELAN- - 754th Electronic Systems Group",
    "708": "SB-COMM- - Sentinel Byte Community",
    "709": "UHEY-NET- Royal Air Force Base",
    "710": "BENT-NET- Royal Air Base",
    "711": "SB-COMM- - Torrejon Air Base",
    "712": "ALCON-NET- Royal Air Base",
    "713": "AFMPCGW- - 754th Electronic Systems Group",
    "714": "APPLE Apple Inc",
    "715": "WOODYNET-2 - WoodyNet",
    "716": "DNIC--00716 - Headquarters, USAISC",
    "717": "DNIC--00717 - DoD Network Information Center",
    "718": "DNIC--00718 - DoD Network Information Center",
    "719": "ELISA- Elisa Oyj",
    "720": "WR-LOGDIS- - 754th Electronic Systems Group",
    "721": "DNIC-BLK-00721-00726 - DoD Network Information Center",
    "722": "DNIC-BLK-00721-00726 - DoD Network Information Center",
    "723": "DNIC-BLK-00721-00726 - DoD Network Information Center",
    "724": "DNIC-BLK-00721-00726 - DoD Network Information Center",
    "725": "DNIC-BLK-00721-00726 - DoD Network Information Center",
    "726": "DNIC-BLK-00721-00726 - DoD Network Information Center",
    "727": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "728": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "729": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "730": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "731": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "732": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "733": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "734": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "735": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "736": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "737": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "738": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "739": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "740": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "741": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "742": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "743": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "744": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "745": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "746": "AFCONC-BLOCK2- - 754th Electronic Systems Group",
    "747": "DNIC--00747 - Headquarters, USAISC",
    "748": "DNIC--00748 - DoD Network Information Center",
    "749": "DNIC--00749 - DoD Network Information Center",
    "750": "MERIT--16 - Merit Network Inc.",
    "751": "MERIT--17 - Merit Network Inc.",
    "752": "MERIT--18 - Merit Network Inc.",
    "753": "MERIT--19 - Merit Network Inc.",
    "754": "MERIT--20 - Merit Network Inc.",
    "755": "MERIT--21 - Merit Network Inc.",
    "756": "MERIT--22 - Merit Network Inc.",
    "757": "MERIT--23 - Merit Network Inc.",
    "758": "MERIT--24 - Merit Network Inc.",
    "759": "MERIT--25 - Merit Network Inc.",
    "760": "University of Vienna, Austria",
    "761": "TIETORAITTI- Seinajoen Tietoraitti Oy",
    "762": "WELLFLEET- - Wellfleet Communications, Inc.",
    "763": "SQNT-TEAMNET- - IBM",
    "764": "FI-PMO- Prime Minister's Office",
    "765": "DNIC--00765 - DoD Network Information Center",
    "766": "REDIRIS Entidad Publica Empresarial Red.es",
    "767": "DNIC--00767 - DoD Network Information Center",
    "768": "DNIC--00768 - Navy Network Information Center (NNIC)",
    "769": "DNIC--00769 - DoD Network Information Center",
    "770": "DNIC--00770 - DoD Network Information Center",
    "771": "NSN-RICE- - National Aeronautics and Space Administration",
    "772": "DNIC--00772 - Headquarters, USAISC",
    "773": "SPARTA-MD- - SPARTA, Incorporated",
    "774": "FR-INRIA1 Institut National de Recherche en Informatique",
    "775": "FR-INRIA-ROCQ Institut National de Recherche en Informatique",
    "776": "FR-INRIA-SOPHIA INRIA Sophia-Antipolis",
    "777": "CEA-Saclay",
    "778": "FR-INRIA-MONTBONNOT INRIA Rhone-Alpes",
    "779": "FR-RENATER-VIKMAN Reseau Regional VIKMAN",
    "780": "FR-ARAMIS IMAG",
    "781": "FR-RENATER-LOTHAIRE Reseaux Regionaux StanNet et AmperNet",
    "782": "FR-LORIA  for the \" Laboratoire en recherche informatique et ses applications\"",
    "783": "FR-INRIA2 Institut National de Recherche en Informatique",
    "784": "HJFNET- - Henry M. Jackson Foundation for The Advancement of Military Medicine",
    "785": "DNIC--00785 - Headquarters, USAISC",
    "786": "JANET The JNT Association",
    "787": "DNIC--00787 - DoD Network Information Center",
    "788": "DNIC--00788 - Navy Network Information Center (NNIC)",
    "789": "IN2P3 IN2P3 Autonomous System",
    "790": "EUNETFI Elisa Oyj",
    "791": "AINET-791 - Advanced Information Technology Services, LLC",
    "792": "ORACLE-NBLOCK-N - Oracle Corporation",
    "793": "ORACLE-NBLOCK-N - Oracle Corporation",
    "794": "ORACLE-NBLOCK-N - Oracle Corporation",
    "795": "AMERITECH- - AT&T Services, Inc.",
    "796": "AMERITECH- - AT&T Services, Inc.",
    "797": "AMERITECH- - AT&T Services, Inc.",
    "798": "DNIC--00798 - Headquarters, USAISC",
    "799": "DNIC--00799 - Headquarters, USAISC",
    "800": "CABLEATLANTIC - Rogers Cable Communications Inc.",
    "802": "YORKU- - York University",
    "803": "SKTEL - Saskatchewan Telecommunications",
    "804": "ISTS-- - Institute for Space and Terrestrial Science",
    "805": "GONET-N-2 - GONET",
    "806": "ECONET- - Environment Canada",
    "807": "GONET-N-3 - GONET",
    "808": "GONET-N-1 - GONET",
    "809": "GONET-N-4 - GONET",
    "810": "SSCWEST - Government Telecommunications Agency",
    "811": "SSCET - Government Telecommunications Agency",
    "812": "ROGERS-CABLE - Rogers Cable Communications Inc.",
    "813": "UUNET-CANADA - MCI Communications Services, Inc. d/b/a Verizon Business",
    "814": "UUNET-CANADA - MCI Communications Services, Inc. d/b/a Verizon Business",
    "815": "UUNET-CANADA - MCI Communications Services, Inc. d/b/a Verizon Business",
    "816": "MOONV6 - MCI Communications Services, Inc. d/b/a Verizon Business",
    "817": "UUNET-CANADA - MCI Communications Services, Inc. d/b/a Verizon Business",
    "818": "DOC- - Department of Communications",
    "819": "LARG-NET - LARG*net",
    "820": "INDUSTRY-CANADA- - Industry Canada",
    "821": "DISC - Designed Information Systems Corporation",
    "822": "STJOSEPHS- - St. Joseph's Health Centre",
    "823": "UWO- - The University of Western Ontario",
    "824": "GLAXOSMITHKLINE - GlaxoSmithKline",
    "825": "CFWS-NET - Canadian Forces Weather Services",
    "826": "CRTC-GC- - CRTC",
    "827": "ALCAN- - Alcan International Ltd.,",
    "828": "NLC-BNC-GC- - Library and Archives Canada",
    "829": "SYGMA-INT-OR - Bell Sygma Systems Management",
    "830": "SYGMA-INT-QR - Bell Sygma Systems Management",
    "831": "SYGMA-EXT-OR - Bell Sygma Systems Management Inc.",
    "832": "SYGMA-EXT-QR - Beel Sygma Systems Management Inc.",
    "833": "GONET-N-5 - GONET",
    "834": "BPNA-1 - Banco Popular North America",
    "835": "GONET-N-6 - GONET",
    "836": "GONET-N-7 - GONET",
    "837": "RCMP - Royal Canadian Mounted Police",
    "838": "CANET2-N - Canadian Research Network",
    "839": "CANET2-N - Canadian Research Network",
    "840": "CANET2-N - Canadian Research Network",
    "841": "CANET2-N - Canadian Research Network",
    "842": "CANET2-N - Canadian Research Network",
    "843": "REPTILIAN-N - Reptillian Research",
    "844": "GONET-N-8 - GONET",
    "845": "GONET-N-9 - GONET",
    "846": "GONET-N-10 - GONET",
    "847": "GONET-N-11 - GONET",
    "848": "GONET-N-12 - GONET",
    "849": "GONET-N-13 - GONET",
    "850": "GONET-N-14 - GONET",
    "851": "RISQ-QIX - Reseau d'Informations Scientifiques du Quebec (RISQ) Inc.",
    "852": "N852 - TELUS Communications Inc.",
    "853": "GONET-N-15 - GONET",
    "854": "GONET-N-16 - GONET",
    "855": "CANET-N-4 - Bell Aliant Regional Communications, Inc.",
    "856": "NBIX4 - University of New Brunswick",
    "857": "GONET-N-17 - GONET",
    "858": "GONET-N-17 - GONET",
    "859": "GONET-N-17 - GONET",
    "860": "GONET-N-17 - GONET",
    "861": "GONET-N-17 - GONET",
    "862": "GONET-N-17 - GONET",
    "863": "GONET-N-17 - GONET",
    "864": "GONET-N-17 - GONET",
    "865": "GONET-N-17 - GONET",
    "866": "GONET-N-17 - GONET",
    "867": "GONET-N-17 - GONET",
    "868": "GONET-N-17 - GONET",
    "869": "GONET-N-17 - GONET",
    "870": "GONET-N-17 - GONET",
    "871": "GONET-N-17 - GONET",
    "872": "GONET-N-17 - GONET",
    "873": "GONET-N-17 - GONET",
    "874": "GONET-N-17 - GONET",
    "875": "GONET-N-17 - GONET",
    "876": "GONET-N-17 - GONET",
    "877": "GONET-N-17 - GONET",
    "878": "GONET-N-17 - GONET",
    "879": "GONET-N-17 - GONET",
    "880": "GONET-N-17 - GONET",
    "881": "GONET-N-17 - GONET",
    "882": "GONET-N-17 - GONET",
    "883": "GONET-N-17 - GONET",
    "884": "GONET-N-17 - GONET",
    "885": "GONET-N-17 - GONET",
    "886": "GONET-N-17 - GONET",
    "887": "GONET-N-17 - GONET",
    "888": "GONET-N-17 - GONET",
    "889": "GONET-N-17 - GONET",
    "890": "GONET-N-17 - GONET",
    "891": "GONET-N-17 - GONET",
    "892": "GONET-N-17 - GONET",
    "893": "GONET-N-17 - GONET",
    "894": "GONET-N-17 - GONET",
    "895": "GONET-N-17 - GONET",
    "896": "GONET-N-17 - GONET",
    "897": "GONET-N-17 - GONET",
    "898": "GONET-N-17 - GONET",
    "899": "GONET-N-17 - GONET",
    "900": "GONET-N-17 - GONET",
    "901": "GONET-N-17 - GONET",
    "902": "GONET-N-17 - GONET",
    "903": "GONET-N-17 - GONET",
    "904": "GONET-N-17 - GONET",
    "905": "GONET-N-17 - GONET",
    "906": "GONET-N-17 - GONET",
    "907": "GONET-N-17 - GONET",
    "908": "GONET-N-17 - GONET",
    "909": "GONET-N-17 - GONET",
    "910": "GONET-N-17 - GONET",
    "911": "GONET-N-17 - GONET",
    "912": "GONET-N-17 - GONET",
    "913": "GONET-N-17 - GONET",
    "914": "GONET-N-17 - GONET",
    "915": "GONET-N-17 - GONET",
    "916": "GONET-N-17 - GONET",
    "917": "GONET-N-17 - GONET",
    "918": "GONET-N-17 - GONET",
    "919": "GONET-N-17 - GONET",
    "920": "GONET-N-17 - GONET",
    "921": "GONET-N-17 - GONET",
    "922": "GONET-N-17 - GONET",
    "923": "GONET-N-17 - GONET",
    "924": "GONET-N-17 - GONET",
    "925": "GONET-N-17 - GONET",
    "926": "GONET-N-17 - GONET",
    "927": "GONET-N-17 - GONET",
    "928": "GONET-N-17 - GONET",
    "929": "GONET-N-17 - GONET",
    "930": "GONET-N-17 - GONET",
    "931": "GONET-N-17 - GONET",
    "932": "GONET-N-17 - GONET",
    "933": "GONET-N-17 - GONET",
    "934": "GONET-N-17 - GONET",
    "935": "GONET-N-17 - GONET",
    "936": "GONET-N-17 - GONET",
    "937": "GONET-N-17 - GONET",
    "938": "GONET-N-17 - GONET",
    "939": "GONET-N-17 - GONET",
    "940": "GONET-N-17 - GONET",
    "941": "GONET-N-17 - GONET",
    "942": "GONET-N-17 - GONET",
    "943": "GONET-N-17 - GONET",
    "944": "GONET-N-17 - GONET",
    "945": "GONET-N-17 - GONET",
    "946": "GONET-N-17 - GONET",
    "947": "GONET-N-17 - GONET",
    "948": "GONET-N-17 - GONET",
    "949": "GONET-N-17 - GONET",
    "950": "GONET-N-17 - GONET",
    "951": "GONET-N-17 - GONET",
    "952": "GONET-N-17 - GONET",
    "953": "GONET-N-17 - GONET",
    "954": "GONET-N-17 - GONET",
    "955": "GONET-N-17 - GONET",
    "956": "GONET-N-17 - GONET",
    "957": "GONET-N-17 - GONET",
    "958": "GONET-N-17 - GONET",
    "959": "GONET-N-17 - GONET",
    "960": "GONET-N-17 - GONET",
    "961": "GONET-N-17 - GONET",
    "962": "GONET-N-17 - GONET",
    "963": "GONET-N-17 - GONET",
    "964": "GONET-N-17 - GONET",
    "965": "GONET-N-17 - GONET",
    "966": "GONET-N-17 - GONET",
    "967": "GONET-N-17 - GONET",
    "968": "GONET-N-17 - GONET",
    "969": "GONET-N-17 - GONET",
    "970": "GONET-N-17 - GONET",
    "971": "GONET-N-17 - GONET",
    "972": "GONET-N-17 - GONET",
    "973": "GONET-N-17 - GONET",
    "974": "GONET-N-17 - GONET",
    "975": "GONET-N-17 - GONET",
    "976": "GONET-N-17 - GONET",
    "977": "GONET-N-17 - GONET",
    "978": "GONET-N-17 - GONET",
    "979": "GONET-N-17 - GONET",
    "980": "GONET-N-17 - GONET",
    "981": "GONET-N-17 - GONET",
    "982": "GONET-N-17 - GONET",
    "983": "GONET-N-17 - GONET",
    "984": "GONET-N-17 - GONET",
    "985": "GONET-N-17 - GONET",
    "986": "GONET-N-17 - GONET",
    "987": "GONET-N-17 - GONET",
    "988": "GONET-N-17 - GONET",
    "989": "GONET-N-17 - GONET",
    "990": "GONET-N-17 - GONET",
    "991": "GONET-N-17 - GONET",
    "992": "GONET-N-17 - GONET",
    "993": "GONET-N-17 - GONET",
    "994": "GONET-N-17 - GONET",
    "995": "GONET-N-17 - GONET",
    "996": "GONET-N-17 - GONET",
    "997": "GONET-N-17 - GONET",
    "998": "GONET-N-17 - GONET",
    "999": "GONET-N-17 - GONET",
    "1000": "GONET-N-17 - GONET",
    "1001": "GONET-N-17 - GONET",
    "1002": "GONET-N-17 - GONET",
    "1003": "GONET-N-17 - GONET",
    "1004": "GONET-N-17 - GONET",
    "1005": "GONET-N-17 - GONET",
    "1006": "GONET-N-17 - GONET",
    "1007": "GONET-N-17 - GONET",
    "1008": "GONET-N-17 - GONET",
    "1009": "GONET-N-17 - GONET",
    "1010": "GONET-N-17 - GONET",
    "1011": "GONET-N-17 - GONET",
    "1012": "GONET-N-17 - GONET",
    "1013": "GONET-N-17 - GONET",
    "1014": "GONET-N-17 - GONET",
    "1015": "GONET-N-17 - GONET",
    "1016": "GONET-N-17 - GONET",
    "1017": "GONET-N-17 - GONET",
    "1018": "GONET-N-17 - GONET",
    "1019": "GONET-N-17 - GONET",
    "1020": "GONET-N-17 - GONET",
    "1021": "GONET-N-17 - GONET",
    "1022": "GONET-N-17 - GONET",
    "1023": "GONET-N-17 - GONET",
    "1024": "GONET-N-17 - GONET",
    "1025": "GONET-N-17 - GONET",
    "1026": "GONET-N-17 - GONET",
    "1027": "GONET-N-17 - GONET",
    "1028": "GONET-N-17 - GONET",
    "1029": "GONET-N-17 - GONET",
    "1030": "GONET-N-17 - GONET",
    "1031": "GONET-N-17 - GONET",
    "1032": "GONET-N-17 - GONET",
    "1033": "GONET-N-17 - GONET",
    "1034": "GONET-N-17 - GONET",
    "1035": "GONET-N-17 - GONET",
    "1036": "GONET-N-17 - GONET",
    "1037": "GONET-N-17 - GONET",
    "1038": "GONET-N-17 - GONET",
    "1039": "GONET-N-17 - GONET",
    "1040": "GONET-N-17 - GONET",
    "1041": "GONET-N-17 - GONET",
    "1042": "GONET-N-17 - GONET",
    "1043": "GONET-N-17 - GONET",
    "1044": "GONET-N-17 - GONET",
    "1045": "GONET-N-17 - GONET",
    "1046": "GONET-N-17 - GONET",
    "1047": "GONET-N-17 - GONET",
    "1048": "GONET-N-17 - GONET",
    "1049": "GONET-N-17 - GONET",
    "1050": "GONET-N-17 - GONET",
    "1051": "GONET-N-17 - GONET",
    "1052": "GONET-N-17 - GONET",
    "1053": "GONET-N-17 - GONET",
    "1054": "GONET-N-17 - GONET",
    "1055": "GONET-N-17 - GONET",
    "1056": "GONET-N-17 - GONET",
    "1057": "GONET-N-17 - GONET",
    "1058": "GONET-N-17 - GONET",
    "1059": "GONET-N-17 - GONET",
    "1060": "GONET-N-17 - GONET",
    "1061": "GONET-N-17 - GONET",
    "1062": "GONET-N-17 - GONET",
    "1063": "GONET-N-17 - GONET",
    "1064": "GONET-N-17 - GONET",
    "1065": "GONET-N-17 - GONET",
    "1066": "GONET-N-17 - GONET",
    "1067": "GONET-N-17 - GONET",
    "1068": "GONET-N-17 - GONET",
    "1069": "GONET-N-17 - GONET",
    "1070": "GONET-N-17 - GONET",
    "1071": "GONET-N-17 - GONET",
    "1072": "GONET-N-17 - GONET",
    "1073": "GONET-N-17 - GONET",
    "1074": "GONET-N-17 - GONET",
    "1075": "GONET-N-17 - GONET",
    "1076": "GONET-N-17 - GONET",
    "1077": "GONET-N-17 - GONET",
    "1078": "GONET-N-17 - GONET",
    "1079": "GONET-N-17 - GONET",
    "1080": "GONET-N-17 - GONET",
    "1081": "GONET-N-17 - GONET",
    "1082": "GONET-N-17 - GONET",
    "1083": "GONET-N-17 - GONET",
    "1084": "GONET-N-17 - GONET",
    "1085": "GONET-N-17 - GONET",
    "1086": "GONET-N-17 - GONET",
    "1087": "GONET-N-17 - GONET",
    "1088": "GONET-N-17 - GONET",
    "1089": "GONET-N-17 - GONET",
    "1090": "GONET-N-17 - GONET",
    "1091": "GONET-N-17 - GONET",
    "1092": "GONET-N-17 - GONET",
    "1093": "GONET-N-17 - GONET",
    "1094": "GONET-N-17 - GONET",
    "1095": "GONET-N-17 - GONET",
    "1096": "GONET-N-17 - GONET",
    "1097": "GONET-N-17 - GONET",
    "1098": "GONET-N-17 - GONET",
    "1099": "GONET-N-17 - GONET",
    "1100": "GONET-N-17 - GONET",
    "1101": "IP-EEND- IP-EEND BV",
    "1102": "SURFNET- SURFnet BV P.O. Box Utrecht NL",
    "1103": "SURFNET-NL SURFnet, The Netherlands",
    "1104": "NIKHEF FOM-Nikhef",
    "1105": "SURFNET- SURFnet BV",
    "1106": "SURFNET- SURFnet BV",
    "1107": "SURFNET- SURFnet BV",
    "1108": "SURFNET- SURFnet BV",
    "1109": "UNI-SALZBURG University of Salzburg",
    "1110": "University of Innsbruck",
    "1111": "University of Klagenfurt",
    "1112": "Montanuniversitaet Leoben",
    "1113": "TUGNET Technische Universitaet Graz, AT",
    "1114": "Universitaet Graz",
    "1115": "Austrian Academy of Sciences",
    "1116": "MDWNET Universitaet f. Musik und darstellende Kunst Wien",
    "1117": "Universitaet fuer Bodenkultur, Wien",
    "1118": "N-Graz",
    "1119": "N-Wien",
    "1120": "ACONET_SERVICES ACOnet Services @ Vienna Internet eXchange",
    "1121": "VIX-RS VIX Route Server",
    "1122": "UK-",
    "1123": "Technikum Vorarlberg",
    "1124": "UVA-NL Universiteit van Amsterdam",
    "1125": "SURFnet Test Network",
    "1126": "VANCIS Vancis Advanced ICT Services",
    "1127": "SURFnet Multicast Test N",
    "1128": "TUDELFT-NL DTO TUDELFT, The Netherlands -",
    "1129": "SURFNET- SURFnet BV",
    "1130": "SURFnet VPN TEST N",
    "1131": "SURFNET- SURFnet BV",
    "1132": "METEOCONSULT- Meteo Consult BV",
    "1133": "UTWENTE- University Twente",
    "1134": "KPNM-NL KPN Mobile Network Operator",
    "1135": "Veronica Interactive Plaza",
    "1136": "KPN KPN Internet Solutions",
    "1137": "UNIP",
    "1138": "UNUSED",
    "1139": "AMOLF",
    "1140": "SIDN Stichting Internet Domeinregistratie Nederland",
    "1141": "TUE-SPACELABS Eindhoven University of Technology",
    "1142": "WKAPNET Springer Science and Business Media B.V.",
    "1143": "NOTINUSE- currently not in use",
    "1144": "SURFNET- SURFnet BV",
    "1145": "KENNISNET- Kennisnet",
    "1146": "SURFNET- SURFnet BV",
    "1147": "MCL- Medisch Centrum Leeuwarden",
    "1148": "LOFAR- Stichting LOFAR",
    "1149": "SURFNET- SURFnet BV",
    "1150": "SURFNET- SURFnet BV",
    "1151": "SURFNET- SURFnet BV",
    "1152": "SURFNET- SURFnet BV",
    "1153": "SURFNET- SURFnet BV",
    "1154": "SURFNET- SURFnet BV",
    "1155": "SURFnet5 Test-",
    "1156": "SURFNET- SURFnet BV",
    "1157": "SURFNET- SURFnet BV",
    "1158": "SURFNET- SURFnet BV",
    "1159": "SURFNET- SURFnet BV",
    "1160": "SURFNET- SURFnet BV",
    "1161": "-TUE Technische Universiteit Eindhoven (TU/e)",
    "1162": "SURFSARA- Science Park 140",
    "1163": "SURFNET- SURFnet BV",
    "1164": "SURFNET- SURFnet BV",
    "1165": "SURFNET- SURFnet BV",
    "1166": "SURFNET- SURFnet BV",
    "1167": "SURFNET- SURFnet BV",
    "1168": "SURFNET- SURFnet BV",
    "1169": "SURFNET- SURFnet BV",
    "1170": "SURFNET- SURFnet BV",
    "1171": "SURFNET- SURFnet BV",
    "1172": "SURFNET- SURFnet BV",
    "1173": "SURFNET- SURFnet BV",
    "1174": "SURFNET- SURFnet BV",
    "1175": "SURFNET- SURFnet BV",
    "1176": "SURFNET- SURFnet BV",
    "1177": "SURFNET- SURFnet BV",
    "1178": "SURFNET- SURFnet BV",
    "1179": "SURFNET- SURFnet BV",
    "1180": "SURFNET- SURFnet BV",
    "1181": "SURFNET- SURFnet BV",
    "1182": "SURFNET- SURFnet BV",
    "1183": "SURFNET- SURFnet BV",
    "1184": "SURFNET- SURFnet BV",
    "1185": "SURFNET- SURFnet BV",
    "1186": "SURFNET- SURFnet BV",
    "1187": "SURFNET- SURFnet BV",
    "1188": "SURFNET- SURFnet BV",
    "1189": "SURFNET- SURFnet BV",
    "1190": "SURFNET-CTIT-QBONE-",
    "1191": "SURFNET- SURFnet BV",
    "1192": "SURFNET- SURFnet BV",
    "1193": "SURFNET- SURFnet BV",
    "1194": "SURFNET- SURFnet BV",
    "1195": "SURFNET- SURFnet BV",
    "1196": "SURFNET- SURFnet BV",
    "1197": "NETWORKABILITY Network Ability Limited",
    "1198": "BELSURF",
    "1199": "ABUSEHUB- SURFnet",
    "1200": "AMS-IX1 Amsterdam Internet Exchange B.V.",
    "1201": "N-ODU-- - Old Dominion University",
    "1202": "JSC-JIN- - National Aeronautics and Space Administration",
    "1203": "ITALTEL- Italtel Sit",
    "1204": "SUNYNET-N- - State University of New York, Central",
    "1205": "JKU-LINZ- University Linz",
    "1206": "PSCNET-HS- - Pittsburgh Supercomputing Center",
    "1207": "PSCNET-HS-TEST- - Pittsburgh Supercomputing Center",
    "1208": "DNIC--01208 - DoD Network Information Center",
    "1209": "DNIC--01209 - Navy Network Information Center (NNIC)",
    "1210": "3RD-US-ARMY-N - Headquarters, USAISC",
    "1211": "DNIC--01211 - Headquarters, USAISC",
    "1212": "DNIC--01212 - Headquarters, USAISC",
    "1213": "HEANET HEAnet Limited",
    "1214": "COLOEXCHANGE - COLOEXCHANGE.COM A CALIFORNIA CORP",
    "1215": "ORACLE-NA- - Oracle Corporation",
    "1216": "ORACLE-EUROPE- - Oracle Corporation",
    "1217": "ORACLE-PACRIM- - Oracle Corporation",
    "1218": "NCUBE-BELMONT- - Oracle Corporation",
    "1219": "NCUBE-OREGON- - Oracle Corporation",
    "1220": "INFON- - INFONET Services Corporation",
    "1221": "N-TELSTRA Telstra Pty Ltd",
    "1222": "EPCC- - EL PO COMMUNITY COLLEGE",
    "1223": "AINET-1223 - Advanced Information Technology Services, LLC",
    "1224": "NCSA- - National Center for Supercomputing Applications",
    "1225": "NTTA-1225 - NTT America, Inc.",
    "1226": "CTA-42-1226 - California Technology Agency",
    "1227": "SDSC-TEST1- - San Diego Supercomputer Center",
    "1228": "UNINET-NBLOCK",
    "1229": "UNINET-NBLOCK",
    "1230": "UNINET-NBLOCK",
    "1231": "UNINET-NBLOCK",
    "1232": "UNINET-NBLOCK",
    "1233": "ERX-NDA-N National Space Development Agency",
    "1234": "FORTUM- Fortum",
    "1235": "FR-U-1-CRI-RENNES Universite de Rennes1",
    "1236": "GDC4S-GROUP-2 - General Dynamics C4 Systems, Inc.",
    "1237": "KREONET--KR Korea Institute of Science and Technology Information",
    "1238": "ICM-MALAYSIA - US Sprint",
    "1239": "1239 SprintLink Global Network",
    "1240": "ICM-PACIFIC - Sprint",
    "1241": "FORTHNET-GR Forthnet",
    "1242": "PLH- - 754th Electronic Systems Group",
    "1243": "DNIC--01243 - Headquarters, USAISC",
    "1244": "AMOCO- - Amoco Corporation",
    "1245": "DET4LAN- - 754th Electronic Systems Group",
    "1246": "TLL-WEST - Zito Media",
    "1247": "AFTERLIFE-GW- - DoD Network Information Center",
    "1248": "NOKIA NOKIA Corporation",
    "1249": "FIVE-COLLEGES- - Five Colleges Network",
    "1250": "ERX-SINGAPORE- National University of Singapore",
    "1251": "FUNDA\u00c7\u00c3O DE AMPARO \u00c0 PESQUISA DO ESTADO S\u00c3O PAULO",
    "1252": "UNMC- - University of Nebraska Medical Center",
    "1253": "VEROAUTOSYS- The National Board of Taxation",
    "1254": "NA-LARC- - National Aeronautics and Space Administration",
    "1255": "SMITHCOLLEGE- - Smith College",
    "1256": "MSNET- - Massachusetts Education Computer Network",
    "1257": "TELE2",
    "1258": "XKL-NET- - XKL, LLC",
    "1259": "WRAIR-N - Headquarters, USAISC",
    "1260": "PLE - 754th Electronic Systems Group",
    "1261": "NATINST-- - National Instruments Corporation",
    "1262": "NSN-NCAR-- - National Aeronautics and Space Administration",
    "1263": "NSN-NCAR-- - National Aeronautics and Space Administration",
    "1264": "USACESPK- - Headquarters, USAISC",
    "1265": "SAINT-MARYS- - Saint Mary's College",
    "1266": "DNIC--01266 - Navy Network Information Center (NNIC)",
    "1267": "N-INFOSTRADA WIND Telecomunicazioni S.p.A.",
    "1268": "Infostrada S.p.A.",
    "1269": "IUNET2- Italian UNIX Network (IUNET)",
    "1270": "UUNET-DE UUNET Germany",
    "1271": "experimental GAIP/DE",
    "1272": "Universitaet Konstanz",
    "1273": "CW Cable and Wireless Worldwide plc",
    "1274": "FHG-IT-BIR FhG Institutszentrum Birlinghoven",
    "1275": "DFN-BWIN-IP DFN-IP service and DFN customer networks",
    "1276": "DSI-WR-18 - Advanced Technology Services",
    "1277": "FIBERMEDIA - FiberMedia Group, LLC",
    "1278": "UNIONCARBIDE- - Union Carbide Corporation",
    "1279": "MCDOUGL- McDonnell Douglas Information Systems International",
    "1280": "ISC-1280 Internet Systems Consortium, Inc.",
    "1281": "COGENT-1281 - PSINet, Inc.",
    "1282": "COGENT-1282 - PSINet, Inc.",
    "1283": "COGENT-1283 - PSINet, Inc.",
    "1284": "COGENT-1284 - PSINet, Inc.",
    "1285": "CMC- - Communication Machinery Corporation",
    "1286": "IV01 - Altay Corporation",
    "1287": "PROFESSIONAL-EDUCATION-INSTITUTE - Professional Education Institute",
    "1288": "C4DR3 - Glynlyon",
    "1289": "COLGATE-UNIVERSITY - Colgate University",
    "1290": "TELSTRAEUROPELTD-BACKBONE Telstra Europe Ltd",
    "1291": "DNIC--01291 - DoD Network Information Center",
    "1292": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "1293": "HPES - Hewlett-Packard Company",
    "1294": "DELL-NETPLEX- - Dell, Inc.",
    "1295": "BGNOGE - General Electric Company",
    "1296": "University of Chili",
    "1297": "USLHCNET CERN - European Organization for Nuclear Research",
    "1298": "DNIC--01298 - Navy Network Information Center (NNIC)",
    "1299": "TELIANET TeliaSonera International Carrier",
    "1300": "FR-RENATER-R3T2-MARSEILLE Reseau Regional R3T2",
    "1301": "FR-EDFDPT3 Electricite de France Service National",
    "1302": "FRANCE-NBLOCK- INRIA",
    "1303": "FR-IDRIS-ORSAY FR",
    "1304": "FR-SFINX SFINX Route Servers",
    "1305": "FR-CICT-TOULOUSE FR",
    "1306": "FRANCE-NBLOCK- INRIA",
    "1307": "FR-U-JUSSIEU-PARIS",
    "1308": "FRANCE-NBLOCK- INRIA",
    "1309": "FR-RENATER Reseau National de telecommunications pour la Technologie",
    "1310": "CACI-FED - CACI Inc., Federal",
    "1311": "BARRA-NET- - BARRA",
    "1312": "VA-TECH- - Virginia Polytechnic Institute and State Univ.",
    "1313": "ADOBE1-- - Adobe Systems Inc.",
    "1314": "DNIC--01314 - DoD Network Information Center",
    "1316": "LERC-- - National Aeronautics and Space Administration",
    "1317": "DNIC--01317 - Navy Network Information Center (NNIC)",
    "1318": "ICRFNET- Imperial Cancer Research Fund",
    "1319": "DNIC--01319 - Navy Network Information Center (NNIC)",
    "1320": "DNIC--1320 - Navy Network Information Center (NNIC)",
    "1321": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1322": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1323": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1324": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1325": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1326": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1327": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1328": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1329": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1330": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1331": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1332": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1333": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1334": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1335": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1336": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1337": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1338": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1339": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1340": "ANSBB-NNET-1 - Advanced Networks & Services Inc.",
    "1341": "AB- - Allen-Bradley Company, Inc.",
    "1342": "Fujitsu Invia Finland IP-network",
    "1343": "NIMBUS - Cisco Systems",
    "1344": "DNIC--01344 - Navy Network Information Center (NNIC)",
    "1345": "DNIC--01345 - Navy Network Information Center (NNIC)",
    "1346": "DNIC--01346 - Navy Network Information Center (NNIC)",
    "1347": "ONVOY3 - Onvoy",
    "1348": "CA-DOTNET- - California Department of Transportation",
    "1349": "RADIANZ--1349 - RADIANZ Americas, Inc.",
    "1350": "SEARSNET- - Sears Technology Services Incorporated",
    "1351": "UVM-EDU- - University of Vermont",
    "1352": "SISSA-1- Scuola Internazionale Sup. di Studi Avanzati",
    "1353": "SISSA-2- Scuola Internazionale Sup. di Studi Avanzati",
    "1354": "NEXT-N- - NeXT Software, Inc",
    "1355": "AHMSI-HQDC - American Home Mortgage Servicing, Inc.",
    "1356": "N-55WATER - Sullivan & Cromwell",
    "1357": "ORYX-ENERGY- - Oryx Energy Company",
    "1358": "HNSNET- - Hughes Network Systems, Inc.",
    "1359": "INPO - Institute of Nuclear Power Operations, Inc.",
    "1360": "MEWS-04 - Mayfield Electric & Water Systems",
    "1361": "DNIC--01361 - Navy Network Information Center (NNIC)",
    "1362": "DNIC--01362 - Navy Network Information Center (NNIC)",
    "1363": "DNIC--01363 - Navy Network Information Center (NNIC)",
    "1364": "DNIC--01364 - Navy Network Information Center (NNIC)",
    "1365": "DNIC--01365 - Navy Network Information Center (NNIC)",
    "1366": "DNIC--01366 - Navy Network Information Center (NNIC)",
    "1367": "DNIC--01367 - Navy Network Information Center (NNIC)",
    "1368": "DNIC--01368 - Navy Network Information Center (NNIC)",
    "1369": "DNIC--01369 - Navy Network Information Center (NNIC)",
    "1370": "DNIC--01370 - Navy Network Information Center (NNIC)",
    "1371": "DNIC--01371 - Navy Network Information Center (NNIC)",
    "1372": "DNIC--01372 - Navy Network Information Center (NNIC)",
    "1373": "DNIC--01373 - Navy Network Information Center (NNIC)",
    "1374": "DNIC--01374 - Navy Network Information Center (NNIC)",
    "1375": "DNIC--01375 - Navy Network Information Center (NNIC)",
    "1376": "DNIC--01376 - Navy Network Information Center (NNIC)",
    "1377": "DNIC--01377 - Navy Network Information Center (NNIC)",
    "1378": "IBEL - Interbel Telephone Cooperative, Inc.",
    "1379": "SYBE365 - Sybase 365, Inc",
    "1380": "MCVEAN - McVEAN Trading & Investments, LLC",
    "1381": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1382": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1383": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1384": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1385": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1386": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1387": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1388": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1389": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1390": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1391": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1392": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1393": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1394": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1395": "ANSBB-NNET-2 - Advanced Networks & Services Inc.",
    "1396": "T2-JC-AN - ThinkTech, Inc",
    "1397": "T2-JC-CN - ThinkTech, Inc",
    "1398": "T2-JC-PN - ThinkTech, Inc",
    "1399": "T2-CT-CN - ThinkTech, Inc",
    "1400": "T2-CT-AN - ThinkTech, Inc",
    "1401": "N1 - DSW Information Technology LLC.",
    "1402": "T2-CT-PN - ThinkTech, Inc",
    "1403": "ELECTRONICBOX - ELECTRONIC BOX",
    "1404": "VERTICALRESPONSE - VerticalResponse, Inc.",
    "1405": "LIONAPPAREL - LION APPAREL",
    "1406": "MOTOROLA-MOBILITY - Motorola Inc",
    "1407": "QUOTEMEDIA - Quotemedia",
    "1408": "CCB- - CCBill",
    "1410": "CELLONE-IP - SMITH BAGLEY INC",
    "1411": "CHRISTOPHER-NEWPORT-UNIVERSITY - Christopher Newport University",
    "1412": "GRVYUS-PIT-A - Gravity Interactive, Inc.",
    "1413": "-SBARRO - Sbarro Inc",
    "1414": "N1 - Genuine Parts Company",
    "1415": "CHNETWORK - Christus Health",
    "1416": "CHICAGO-PUBLIC-SCHOOLS - Chicago Public Schools",
    "1417": "WARNACO-MILFORD - WARNACO, INC.",
    "1418": "MATE1- - MATE1.COM, INC.",
    "1419": "SELERITY - Selerity Financial, Inc.",
    "1420": "STL-C9D - STL OFFICE SOLUTIONS, INC.",
    "1421": "WANSECURITY - WANSecurity, Inc.",
    "1422": "MEDIA6-N - Media6degrees",
    "1423": "CARSON-RTCA - Carson Communications, LLC",
    "1424": "MOTOROLA-MOBILITY - Motorola Inc",
    "1425": "ELLICOTT-CITY-CABLE-WAVERLY - Ellicott City Cable",
    "1426": "LIGHTWAVENET - Lightwave Networking, LLC",
    "1427": "ALION20706 - Alion Science and Technology Corporation",
    "1428": "DRW-HOLDINGS - DRW Holdings, LLC",
    "1429": "ARGUS - FriendFinder Networks Inc",
    "1430": "BB0-BOSTON - Board of Bar Overseers",
    "1431": "ALLCONET - Allegany County Public Schools",
    "1432": "AC--1 - Albion College",
    "1433": "VML-20-N - Valinor Management, LLC",
    "1434": "DWIM-590 - DW Investment Management, LP",
    "1435": "NWTFE - 100 NWT Fee Owner LP",
    "1436": "MHS - Meridian Health System",
    "1437": "VISONEX-LLC - Visonex LLC",
    "1438": "PIONEER-STATE-MUTUAL-INSURANCE - PIONEER STATE MUTUAL INSURANCE CO.",
    "1439": "SBISD - Spring Branch Independent School District",
    "1440": "ALFORD-MEDIA-SERVICES-DAL-TX - Alford Media Services, Inc.",
    "1441": "THUNDERIT - Thunder IT Services",
    "1442": "NSISL SureHosting Internet Solution, Inc.",
    "1443": "SUPERCOOPER01 - CooperVision, Inc.",
    "1444": "VCPI-N-1 - Virtual Care Provider, Inc.",
    "1445": "MILLIMAN - Milliman, Inc.",
    "1447": "CHIPOTLE-MEXICAN-GRILL-INC - Chipotle Mexican Grill, INC",
    "1449": "THE-ANTIOCH-COMPANY-N - THE ANTIOCH COMPANY",
    "1450": "DNIC--01450 - Headquarters, USAISC",
    "1451": "DNIC-BLK-01451-01456 - Headquarters, USAISC",
    "1452": "DNIC-BLK-01451-01456 - Headquarters, USAISC",
    "1453": "DNIC-BLK-01451-01456 - Headquarters, USAISC",
    "1454": "DNIC-BLK-01451-01456 - Headquarters, USAISC",
    "1455": "DNIC-BLK-01451-01456 - Headquarters, USAISC",
    "1456": "DNIC-BLK-01451-01456 - Headquarters, USAISC",
    "1457": "DNIC--01457 - Headquarters, USAISC",
    "1458": "DNIC-BLK-01458-01460 - Headquarters, USAISC",
    "1459": "DNIC-BLK-01458-01460 - Headquarters, USAISC",
    "1460": "DNIC-BLK-01458-01460 - Headquarters, USAISC",
    "1461": "DNIC--01461 - Headquarters, USAISC",
    "1462": "DNIC-BLK-01462-01463 - Headquarters, USAISC",
    "1463": "DNIC-BLK-01462-01463 - Headquarters, USAISC",
    "1464": "DNIC-BLK-01464-01465 - Headquarters, USAISC",
    "1465": "DNIC-BLK-01464-01465 - Headquarters, USAISC",
    "1466": "DNIC--01466 - Headquarters, USAISC",
    "1467": "DNIC-BLK-01467-01468 - Headquarters, USAISC",
    "1468": "DNIC-BLK-01467-01468 - Headquarters, USAISC",
    "1469": "DNIC-BLK-01469-01470 - Headquarters, USAISC",
    "1470": "DNIC-BLK-01469-01470 - Headquarters, USAISC",
    "1471": "DNIC-BLK-01471-01472 - Headquarters, USAISC",
    "1472": "DNIC-BLK-01471-01472 - Headquarters, USAISC",
    "1473": "DNIC--01473 - Headquarters, USAISC",
    "1474": "DNIC-BLK-01474-01477 - Headquarters, USAISC",
    "1475": "DNIC-BLK-01474-01477 - Headquarters, USAISC",
    "1476": "DNIC-BLK-01474-01477 - Headquarters, USAISC",
    "1477": "DNIC-BLK-01474-01477 - Headquarters, USAISC",
    "1478": "DNIC-BLK-01478-01479 - Headquarters, USAISC",
    "1479": "DNIC-BLK-01478-01479 - Headquarters, USAISC",
    "1480": "DNIC--01480 - Headquarters, USAISC",
    "1481": "CTNOSC-N-1481 - Headquarters, USAISC",
    "1482": "DNIC--01482 - Headquarters, USAISC",
    "1483": "DNIC--01483 - Headquarters, USAISC",
    "1484": "DNIC--01484 - Headquarters, USAISC",
    "1485": "DNIC--01485 - Headquarters, USAISC",
    "1486": "DNIC-BLK-01486-01487 - Headquarters, USAISC",
    "1487": "DNIC-BLK-01486-01487 - Headquarters, USAISC",
    "1488": "DNIC-BLK-01488-01489 - Headquarters, USAISC",
    "1489": "DNIC-BLK-01488-01489 - Headquarters, USAISC",
    "1490": "20THSUPCOM - Headquarters, USAISC",
    "1491": "DNIC--01491 - Headquarters, USAISC",
    "1492": "DNIC-BLK-01492-01493 - Headquarters, USAISC",
    "1493": "DNIC-BLK-01492-01493 - Headquarters, USAISC",
    "1494": "DNIC-BLK-01494-01495 - Headquarters, USAISC",
    "1495": "DNIC-BLK-01494-01495 - Headquarters, USAISC",
    "1496": "DNIC-BLK-01496-01497 - Headquarters, USAISC",
    "1497": "DNIC-BLK-01496-01497 - Headquarters, USAISC",
    "1498": "DNIC-BLK-01498-01499 - Headquarters, USAISC",
    "1499": "DNIC-BLK-01498-01499 - Headquarters, USAISC",
    "1500": "DNIC-BLK-01500-01502 - Headquarters, USAISC",
    "1501": "DNIC-BLK-01500-01502 - Headquarters, USAISC",
    "1502": "DNIC-BLK-01500-01502 - Headquarters, USAISC",
    "1503": "DNIC--01503 - Headquarters, USAISC",
    "1504": "DNIC--01504 - Headquarters, USAISC",
    "1505": "DNIC--01505 - Headquarters, USAISC",
    "1506": "WOOD- - Headquarters, USAISC",
    "1507": "DNIC--01507 - Headquarters, USAISC",
    "1508": "DNIC--01508 - Headquarters, USAISC",
    "1509": "DNIC-BLK-01509-01510 - Headquarters, USAISC",
    "1510": "DNIC-BLK-01509-01510 - Headquarters, USAISC",
    "1511": "DNIC--01511 - Headquarters, USAISC",
    "1512": "CTNOSC-N-1512 - Headquarters, USAISC",
    "1513": "DNIC-BLK-01513-01518 - Headquarters, USAISC",
    "1514": "DNIC-BLK-01513-01518 - Headquarters, USAISC",
    "1515": "DNIC-BLK-01513-01518 - Headquarters, USAISC",
    "1516": "DNIC-BLK-01513-01518 - Headquarters, USAISC",
    "1517": "DNIC-BLK-01513-01518 - Headquarters, USAISC",
    "1518": "DNIC-BLK-01513-01518 - Headquarters, USAISC",
    "1519": "DNIC--01519 - Headquarters, USAISC",
    "1520": "DNIC--01520 - Headquarters, USAISC",
    "1521": "DNIC--01521 - Headquarters, USAISC",
    "1522": "DNIC-BLK-01522-01526 - Headquarters, USAISC",
    "1523": "DNIC-BLK-01522-01526 - Headquarters, USAISC",
    "1524": "DNIC-BLK-01522-01526 - Headquarters, USAISC",
    "1525": "DNIC-BLK-01522-01526 - Headquarters, USAISC",
    "1526": "DNIC-BLK-01522-01526 - Headquarters, USAISC",
    "1527": "DNIC--01527 - Headquarters, USAISC",
    "1528": "DNIC--01528 - Headquarters, USAISC",
    "1529": "DNIC-BLK-01529-01530 - Headquarters, USAISC",
    "1530": "DNIC-BLK-01529-01530 - Headquarters, USAISC",
    "1531": "DNIC--01531 - Headquarters, USAISC",
    "1532": "DNIC--01532 - Headquarters, USAISC",
    "1533": "DNIC--01533 - Headquarters, USAISC",
    "1534": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1535": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1536": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1537": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1538": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1539": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1540": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1541": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1542": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1543": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1544": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1545": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1546": "DNIC-BLK-01534-01546 - Headquarters, USAISC",
    "1547": "IDK-NETWORK JSCC Interdnestrcom",
    "1548": "DNIC-BLK-01548-01549 - Headquarters, USAISC",
    "1549": "DNIC-BLK-01548-01549 - Headquarters, USAISC",
    "1550": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1551": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1552": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1553": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1554": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1555": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1556": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1557": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1558": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1559": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1560": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1561": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1562": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1563": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1564": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1565": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1566": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1567": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1568": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1569": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1570": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1571": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1572": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1573": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1574": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1575": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1576": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1577": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1578": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1579": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1580": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1581": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1582": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1583": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1584": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1585": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1586": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1587": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1588": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1589": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1590": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1591": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1592": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1593": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1594": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1595": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1596": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1597": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1598": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1599": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1600": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1601": "DNIC-BLK-01550-01601 - DoD Network Information Center",
    "1602": "DNIC--01602 - Headquarters, USAISC",
    "1603": "HSU- - Henderson State University",
    "1604": "TBCDSB - TBCDSB",
    "1605": "ALGT-HQNET - Allegiant Travel Company",
    "1606": "EXCEL-N - Excelenet, Inc",
    "1607": "CAROLINANET-RALEIGH-NC - Guilford Communications, Inc.",
    "1608": "ITG - ITG INC",
    "1609": "GISX - Global Imaging Systems Inc",
    "1610": "CONTE-25-N - Contegix",
    "1611": "ONLINE-BUDDIES-01 - Online Buddies, Inc.",
    "1612": "FLUXTEL - Flux Telecom, LLC",
    "1613": "-TMPI - Target Media Partners Interactive, LLC",
    "1614": "ISLLC--01 - IOWA STUDENT LOAN LIQUIDITY CORP.",
    "1615": "EXEL - Exelixis Inc.",
    "1616": "CORELINK-US-N - CoreLink Data Centers",
    "1617": "JLEM - Jacobs Levy Equity Management, Inc.",
    "1618": "NETWORKS-1 - Daytona Net Works, Inc.",
    "1619": "PLANET-DATA - Planet Data Solutions, Inc.",
    "1620": "-DOELEGAL - doelegal llc",
    "1621": "N-SECURIAN - Securian Financial Group, Inc.",
    "1623": "WDT-NET - WDT World Discount Telecommunications",
    "1624": "SITAYVR- - SITA Information Networking Computing Canada Ltd",
    "1625": "CORESPACE - CoreSpace, Inc.",
    "1626": "DNIC--1626 - Headquarters, USAISC",
    "1628": "COMMDNS Community DNS Ltd.",
    "1629": "ROSEINC200 - Rose Associates, Inc",
    "1630": "TALEO-RND-SITE1 - Taleo Corporation",
    "1631": "-LOS-ANGELES - Radnet Management, Inc.",
    "1633": "VMSYSAB - 353233 Alberta LTD",
    "1634": "PCADV - Pennsylvania Coalition Against Domestic Violence",
    "1635": "WSC-READING - Weidenhammer",
    "1636": "TRUENEGATIVELLC - True Negative, LLC",
    "1637": "DNIC--01637 - Headquarters, USAISC",
    "1638": "MCC-N-1 - Mott Community College",
    "1639": "CRTA-N1 - C.R.S.T. Telephone Authority",
    "1640": "TVSCABLE - T.V. SERVICE INC",
    "1641": "STAPLES-SPP - Staples Contract & Commercial, Inc.",
    "1642": "COLORCON - Colorcon Inc",
    "1643": "BROC-11-N - Brockway Television Inc.",
    "1644": "DNIC--1644 - Headquarters, USAISC",
    "1645": "PACHEZ - PACHEZ HOLDINGS LTD.",
    "1646": "ABF - American Solutions for Business",
    "1647": "INTEROP- - Interop Technologies",
    "1648": "JEFFERSON-PARISH-SCHOOL-BOARD - Jefferson Parish School Board",
    "1649": "DNIC--01649 - Headquarters, USAISC",
    "1650": "CAMBRIDGEMA-PUBLIC-SCHOOLS - Cambridge Public Schools",
    "1651": "CABLELYNX - Cablelynx",
    "1652": "MIDFLORIDA- - MIDFLORIDA Federal Credit Union",
    "1653": "SUNET SUNET Swedish University Network",
    "1654": "SKOGEN Skogen Network",
    "1655": "DNIC--01655 - Navy Network Information Center (NNIC)",
    "1656": "LM-EIS-GV - Lockheed Martin Corporation",
    "1657": "LOUISVILLE - University of Louisville",
    "1658": "NMI-NET - Network Management, Inc.",
    "1659": "ERX-TANET-N1 Tiawan Academic Network (TANet) Information Center",
    "1660": "ANS-CORP-NY - ANS Communications",
    "1661": "ANS-ATLANTA - ANS Communications",
    "1662": "VFN-BACKBONE - ANS Communications",
    "1663": "BERTELSMANN Bertelsmann AG",
    "1664": "AOL-CORP - America Online",
    "1665": "VFN-MARKETCENTERS - ANS Communications",
    "1666": "VFN-MEMBERS - ANS Communications",
    "1667": "ANS-DC2 - ANS Communications",
    "1668": "AOL-ATDN - AOL Transit Data Network",
    "1669": "ANS-BB2 - ANS Communications",
    "1670": "ANS-UK - ANS Communications",
    "1671": "ANS-1671- - ANS Communications",
    "1672": "ANS-CHICAGO - ANS Communications",
    "1673": "ANS-BB - ANS Communications",
    "1674": "ANS-SANFRAN - ANS Communications",
    "1675": "ANS-NY2- - ANS Communications",
    "1676": "AMERI - American Standard, Inc.",
    "1677": "ANS-NY3- - ANS Communications",
    "1678": "DOW - The Dow Chemical Company",
    "1679": "FICO- - Fair Isaac Corporation",
    "1680": "NV-N 013 NetVision Ltd.",
    "1681": "ANS-CORP-MI - ANS Communications",
    "1682": "AOL-1682- - America Online",
    "1683": "ANS-NY4- - ANS Communications",
    "1684": "ANS-1684- - ANS Communications",
    "1685": "ANS-JAPAN - ANS Communications",
    "1686": "ANS-1686- - ANS Communications",
    "1687": "ANS-1687- - ANS Communications",
    "1688": "ANS-AT-PACBELL-NAP - ANS Communications",
    "1689": "ANS-1689- - ANS Communications",
    "1690": "BOCES - BOCES Southern Westchester",
    "1691": "TELUS - TELUS Communications Inc.",
    "1692": "ANS-1692- - ANS Communications",
    "1693": "ANS-1693- - ANS Communications",
    "1694": "ANS-SANFRAN2- - ANS Communications",
    "1695": "ANS-1695- - ANS Communications",
    "1696": "CITIGROUP  for Citigroup",
    "1697": "NETENG-MONITORING - ANS Communications",
    "1698": "PRODIGY - AT&T Internet Services",
    "1699": "ANS-1699- - ANS Communications",
    "1700": "SESQUI-3 - Sesquinet",
    "1701": "EOSDIS-V0 - National Aeronautics and Space Administration",
    "1703": "MIX - University of Minnesota",
    "1704": "KAIST-SEOUL--KR Korea Advanced Institute of Science and Technology",
    "1705": "HPES - Hewlett-Packard Company",
    "1706": "UNIV-ARIZ - University of Arizona",
    "1707": "FR-RENATER Reseau National de telecommunications pour la Technologie",
    "1708": "FR-CNET-ISSY - Centre National d'Etudes des Telecommunication -- CNET",
    "1709": "FR-RENATER",
    "1710": "FR-RENATER",
    "1711": "FR-RENATER",
    "1712": "FR-RENATER-ENST Ecole Nationale Superieure des Telecommunications,",
    "1713": "FR-RENATER",
    "1714": "FR-RENATER",
    "1715": "FR-REMIP2000 REMIP 2000 Autonomous System",
    "1716": "FR-RENATER RENATER",
    "1717": "FR-RENATER-PROJETS This network interconnects the various",
    "1718": "FR-INRIA-RENNES INRIA Rennes",
    "1719": "FR-RENATER-SYNAPSE Synapse network Autonomous System",
    "1720": "FR-RENATER RENATER-NBLOCK",
    "1721": "FR-RENATER Reseau National de telecommunications pour la Technologie",
    "1722": "FR-RENATER Reseau National de telecommunications pour la Technologie",
    "1723": "FR-RENATER-R3LR6 Reseau Regional de la Region Languedoc Roussillon",
    "1724": "FR-AMPLIVIA-2012 AMPLIVIA IV - Conseil Regional Rhone Alpes",
    "1725": "FR-NOROPALE Reseau NOROPALE",
    "1726": "FR-RENATER-TELEMUS3A Reseau regional Champagne Ardennes 3A",
    "1727": "DNIC--01727 - DoD Network Information Center",
    "1728": "SRI-TPA-GW1 - SRI-TPA-gw1",
    "1729": "TELIA-TCN TeliaSonera AB",
    "1730": "KATZ-GROUP-CANADA - Pharma Plus DrugMarts",
    "1731": "THIOKOL - Thiokol Corporation - Network Engineering",
    "1732": "MIKROK- Mikrokonsultit Oy",
    "1733": "DISACENT-NIPR-N - DoD Network Information Center",
    "1734": "ROP-COCA-01 - Contra Costa County Regional Occupation Program / Richmond",
    "1735": "FISHER- - Fisher Controls Int. Inc.",
    "1736": "MU- - Marquette University",
    "1737": "RAYTHEON--1 - Raytheon Company",
    "1738": "OKOBANK- OP-Pohjola Group Central Cooperative",
    "1739": "TUTNET TUT Autonomous System",
    "1740": "CERFNET - CERFnet",
    "1741": "FUNET FUNET autonomous system",
    "1742": "HARVARD-UNIV - Harvard University",
    "1743": "MCI-SF- - MCI Telecommunications",
    "1744": "LOCKHEED - Lockheed Missles & Space Company",
    "1745": "CRT- - Chicago Reseach and Trading",
    "1746": "SIRSIDYNIX - Data Research Associates, Inc.",
    "1747": "IBMWATSON- - IBM T.J. Watson Research Center",
    "1748": "FINNAIR- FINNAIR",
    "1749": "NA-GSFC- - National Aeronautics and Space Administration",
    "1750": "GURU - Hitachi Computer Products Inc.",
    "1751": "LEXMARK- - Lexmark International Inc.",
    "1752": "BT-CIN-AND-ADTRAL Used by BT IP networks for Intranet Test and Development",
    "1753": "OBT-ESCOM - Ohio Bell Telephone Co.",
    "1754": "DESY-HAMBURG",
    "1755": "1755 Svensk Teleutveckling & Produktinnovation, STUPI AB",
    "1756": "HAMYAR- Shiraz Hamyar Co.",
    "1757": "LEXIS- - LEXIS-NEXIS",
    "1758": "AFMPCGW1- - 754th Electronic Systems Group",
    "1759": "TSF-IP-CORE TeliaSonera Finland IP Network",
    "1760": "INTELNET - Intel Corporation",
    "1761": "TGSCNET - General Services Commission",
    "1762": "DMIS-VAX - ACS National Systems, Inc.",
    "1763": "ITTHARTFORD - ITT Hartford",
    "1764": "NEXTLAYER- next layer Telekommunikationsdienstleistungs- GmbH",
    "1765": "DNIC--01765 - DoD Network Information Center",
    "1766": "N-EXXONMOBIL-US - Exxon Mobil Corporation",
    "1767": "ILIGHT-NET - Indiana Higher Education Telecommunication System",
    "1768": "ERX-SEEDNET-N1 Institute for Information Industry, Taiwan, ROC",
    "1769": "ERX-IIINET-N1 SEEDNet Service Center",
    "1770": "IOPS- NO-IOPS",
    "1771": "SOLBERG-CORE-NET Solberg Network Engineering",
    "1772": "DNIC--01772 - Navy Network Information Center (NNIC)",
    "1773": "SJ-LEVINSON-AND-SONS-LLC - S.J. Levinson & Sons LLC",
    "1774": "HEANET-IE Higher Education Authority Network (HEAnet)",
    "1775": "FMCC-1 - Ford Motor Credit Corporation",
    "1776": "Wirtschaftsuniversitaet Wien",
    "1777": "SAINT-XAVIER-UNIVERSITY-CHICAGO - Saint Xavier University",
    "1778": "DNIC--01778 - DoD Network Information Center",
    "1779": "PSTAR- - Pentastar Services, Inc.",
    "1780": "VALNET Valmet Corporation",
    "1781": "KAIST-DAEJEON--KR Korea Advanced Institute of Science and Technology",
    "1782": "ESPAL - Espalier Global Management LLC",
    "1783": "TAL-N - Tourmalet Advisors LP",
    "1784": "GNAPS - Global NAPs Networks",
    "1785": "-PAETEC-NET - PaeTec Communications, Inc.",
    "1786": "AIXSERV- - IBM",
    "1787": "1787 - Thomson Reuters U.S. LLC",
    "1788": "SONAMNET - SONAM Corporation",
    "1789": "SPRINTLINK1 - Sprint Government Systems Division",
    "1790": "Sprint US",
    "1791": "SPRINTLINK3 - Sprint Government Systems Division",
    "1792": "SPRINTLINK4 - Sprint Government Systems Division",
    "1793": "SPRINTLINK5 - Sprint Government Systems Division",
    "1794": "SPRINTLINK6 - Sprint Government Systems Division",
    "1795": "SPRINTLINK7 - Sprint Government Systems Division",
    "1796": "GRADED-LABS-LLC - Graded Labs, LLC",
    "1797": "Uruguay",
    "1798": "OREGON - State of Oregon",
    "1799": "ICMNET-1 - Sprint",
    "1800": "ICM-ATLANTIC - Sprint",
    "1801": "Sprint/ICM in London",
    "1802": "ICMNET-4 - Sprint",
    "1803": "ICMNET-5 - Sprint",
    "1804": "ICMNET-6 - Sprint",
    "1805": "ICMNET-7 - Sprint",
    "1806": "ICMNET-8 - Sprint",
    "1807": "ICMNET-9 - Sprint",
    "1808": "ICMNET-10 - Sprint",
    "1809": "BGLNG - BG LNG Services, LLC",
    "1810": "CSC-300-1810-1815 - Computer Sciences Corporation",
    "1811": "CSC-300-1810-1815 - Computer Sciences Corporation",
    "1812": "CSC-300-1810-1815 - Computer Sciences Corporation",
    "1813": "CSC-300-1810-1815 - Computer Sciences Corporation",
    "1814": "CSC-300-1810-1815 - Computer Sciences Corporation",
    "1815": "CSC-300-1810-1815 - Computer Sciences Corporation",
    "1816": "FSDN-LLC - Full Service Data Networks, LLC",
    "1817": "-SCSENGINEERS - STEARNS, CONRAD AND SCHMIDT, CONSULTING ENGINEERS, INC.",
    "1818": "DIALKENTUCKY - DIALOG TELECOMMUNICATIONS, INC.",
    "1819": "DCM-CABLE - DCM Cable Inc.",
    "1820": "STUDY-GROUP - Study Group",
    "1821": "NETWORKINV-1 - Network Innovations Inc.",
    "1822": "PHX - Virtual Radiologic Corporation",
    "1823": "HANNAH-MOTOR - Hannah Motor Company",
    "1824": "HOSTING - Vertisoft",
    "1825": "SETCLEAR - SetClear Pte. Ltd.",
    "1826": "UNIVERSITY-OF-ARKANS-FORT-SMITH - University of Arkansas-Fort Smith",
    "1827": "MANAT-1 - Manatee County Government",
    "1828": "UNIT - Unitas Global LLC",
    "1829": "NOTES - Los Alamos National Laboratory",
    "1831": "ITESO, A.C.",
    "1832": "SMU - Southern Methodist University",
    "1833": "TELIANET-USA TeliaNet USA",
    "1834": "DNIC--01834 - DoD Network Information Center",
    "1835": "FSKNET-DK Forskningsnettet - Danish network for Research and Education",
    "1836": "GREEN green.ch AG Autonomous System",
    "1837": "NCIA NATO Communications and Information Agency",
    "1838": "CERFNET-2 - CERFnet",
    "1839": "DNA-SCN - Los Alamos National Laboratory",
    "1840": "Universidad de Las Americas-Puebla",
    "1841": "CP--LHR CP--LHR",
    "1842": "USGS- - United States Geological Survey",
    "1843": "NA-KSC- - National Aeronautics and Space Administration",
    "1844": "NA-KSC- - National Aeronautics and Space Administration",
    "1845": "NA-KSC- - National Aeronautics and Space Administration",
    "1846": "NA-KSC- - National Aeronautics and Space Administration",
    "1847": "NA-KSC- - National Aeronautics and Space Administration",
    "1848": "EBWAN - National Aeronautics and Space Administration",
    "1849": "Verizon UK Limited",
    "1850": "ISNIC Internet Iceland Inc. (ISNIC)",
    "1851": "ERX-ADELAIDE-UNI The University of Adelaide",
    "1852": "UCDC-NET - University of California - Office of the President",
    "1853": "ACONET ACOnet Backbone",
    "1854": "NOVOGROUP Novo Group Oyj",
    "1855": "DISN-PILOTNET1 - Bolt Beranek and Newman Inc.",
    "1856": "DISN-PILOTNET2 - Bolt Beranek and Newman Inc.",
    "1857": "DISN-PILOTNET3 - Bolt Beranek and Newman Inc.",
    "1858": "DISN-PILOTNET4 - Bolt Beranek and Newman Inc.",
    "1859": "DISN-PILOTNET5 - Bolt Beranek and Newman Inc.",
    "1860": "DISN-PILOTNET6 - Bolt Beranek and Newman Inc.",
    "1861": "DISN-PILOTNET7 - Bolt Beranek and Newman Inc.",
    "1862": "DISN-PILOTNET8 - Bolt Beranek and Newman Inc.",
    "1863": "DISN-PILOTNET9 - Bolt Beranek and Newman Inc.",
    "1864": "DISN-PILOTNET10 - Bolt Beranek and Newman Inc.",
    "1865": "DISN-PILOTNET11 - Bolt Beranek and Newman Inc.",
    "1866": "DISN-PILOTNET12 - Bolt Beranek and Newman Inc.",
    "1867": "DISN-PILOTNET13 - Bolt Beranek and Newman Inc.",
    "1868": "DISN-PILOTNET14 - Bolt Beranek and Newman Inc.",
    "1869": "DISN-PILOTNET15 - Bolt Beranek and Newman Inc.",
    "1870": "3COM-EUR - 3Com Corporation",
    "1871": "3COM-USA - 3Com Corporation",
    "1872": "3COM-HDQ - 3Com Corporation",
    "1873": "HPES - Hewlett-Packard Company",
    "1874": "HPES - Hewlett-Packard Company",
    "1875": "CIS - Southern Methodist University",
    "1876": "SE - Southern Methodist University",
    "1878": "STUPI Svensk Teleutveckling & Produktinnovation, STUPI AB",
    "1879": "STUPI Svensk Teleutveckling & Produktinnovation, STUPI AB",
    "1880": "STUPI Svensk Teleutveckling & Produktinnovation, STUPI AB",
    "1881": "FMV FMV",
    "1882": "STUPI Svensk Teleutveckling & Produktinnovation, STUPI AB",
    "1883": "STUPI Svensk Teleutveckling & Produktinnovation, STUPI AB",
    "1885": "SBN- SBN Sigorta",
    "1886": "BTNET BTnet d.o.o.",
    "1887": "NK-ACADEMIC NAUKOWA I AKADEMICKA SIEC KOMPUTEROWA INSTYTUT BADAWCZY",
    "1888": "CWI-NL Stichting Centrum voor Wiskunde en Informatica",
    "1889": "HP-EUROPE- Hewlett Packard Europe S.A.S.",
    "1890": "Verizon Nederland B.V.",
    "1891": "SCARLET2 Scarlet",
    "1892": "DBP Deutsche Telekom AG",
    "1893": "Deutsches Klimarechenzentrum GmbH",
    "1894": "BHN",
    "1895": "Friedrich Alexander Universitaet Erlangen-Nuernberg",
    "1896": "REVUE",
    "1897": "EUNETPT NOVIS Telecom, S.A.",
    "1898": "VMUNIX Torsten Blum",
    "1899": "1899 OLD KPNQwest France",
    "1900": "Computervision UK R&D Ltd",
    "1901": "EUNETAT- A1 Telekom Austria AG",
    "1902": "CONTACTEL GTSNovera",
    "1903": "GTSCZ-TRANSIT GTS Czech Republic Transit",
    "1904": "FR-RENATER-REMIP",
    "1905": "DRC - Dynamics Research Corporation",
    "1906": "NORTHROP-GRUMMAN - Northrop Grumman",
    "1907": "IPSERV- - Single Source Network Systems, Inc.",
    "1908": "DNIC--01908 - DoD Network Information Center",
    "1909": "ALPHA-NAP- - San Diego Supercomputer Center",
    "1910": "DNIC-BLK-01910-01914 - DoD Network Information Center",
    "1911": "DNIC-BLK-01910-01914 - DoD Network Information Center",
    "1912": "DNIC-BLK-01910-01914 - DoD Network Information Center",
    "1913": "DNIC-BLK-01910-01914 - DoD Network Information Center",
    "1914": "DNIC-BLK-01910-01914 - DoD Network Information Center",
    "1915": "SEQUOIA- - National Science Foundation",
    "1916": "Associa\u00e7\u00e3o Rede Nacional de Ensino e Pesquisa",
    "1917": "CTCSERV- - CTC",
    "1918": "DNIC--01918 - DoD Network Information Center",
    "1919": "UMS-AMHERST1 - University of Massachusettes",
    "1920": "RADIANZ--1920 - RADIANZ Americas, Inc.",
    "1921": "NICAT NIC.at head office Salzburg",
    "1922": "UAKOM UAKOM",
    "1923": "Tampere Telelphone Company",
    "1924": "DAFFY - Unified Industries, Inc.",
    "1925": "DNIC--01925 - DoD Network Information Center",
    "1926": "UTANET- University of Tampere",
    "1927": "DNIC--01927 - Navy Network Information Center (NNIC)",
    "1928": "WRNL-PDVS - Parke-Davis",
    "1929": "UMSNET-NET - University of Massachusetts",
    "1930": "RCCN Rede Ciencia Tecnologia e Sociedade (RCTS)",
    "1931": "HPES - Hewlett-Packard Company",
    "1932": "CONED - Consolidated Edison Co. of New York, Inc.",
    "1933": "DNIC-R-01933 - DoD Network Information Center",
    "1934": "ANS-RESTON- - Advanced Network & Services",
    "1935": "FR-RENATER-LIMOUSIN Reseau Regional Limousin",
    "1936": "FR-RENATER-PICARDIE Reseau Regional Picardie",
    "1937": "FR-CRATERE-2008 CRATERE  Number",
    "1938": "FR-RENATER-IRISA Irisa/Inria Rennes",
    "1939": "FR-RENATER-POLYNESIE Reseau National de telecommunications pour la Technologie",
    "1940": "FR-RENATER-R3LR Reseau Regional R3LR",
    "1941": "FR-RENATER-CNRS-DSI-TRELAZE FR",
    "1942": "FR-TIGRE Toile Informatique GREnobloise",
    "1943": "FR-RENATER-RETECOR-1BIS Reseau Regional Corse",
    "1944": "FR-RENATER-GREPA3-SFR Reseau regional Aquitaine GREPA3 opere par SFR",
    "1945": "FR-LYRES Lyon Recherche et Enseignement Sup\u00e9rieur (LyRES)",
    "1946": "FR-RENATER",
    "1947": "FR-RENATER",
    "1948": "FR-RENATER-SAPHIR Education and research network of the Saclay plateau",
    "1949": "FR-RENATER",
    "1950": "FR-RENATER",
    "1951": "FR-RENATER",
    "1952": "FR-RENATER",
    "1953": "RENATER-NBLOCK FR-RENATER",
    "1954": "RENATER-NBLOCK FR-RENATER",
    "1955": "HBONE- HUNGARNET",
    "1956": "IBMEVS- - IBM",
    "1957": "ANSCIX- - Advanced Network & Services, Inc.",
    "1958": "NCRWIN1958 - NCR Corporation",
    "1959": "DNIC--01959 - DoD Network Information Center",
    "1960": "MARS-EUROPE ISI",
    "1961": "MARS-AMERIC ISI",
    "1962": "MARS-IA-PACIFIC ISI",
    "1963": "PENRIL- - Penril Datacomm Networks",
    "1964": "MCI-NETCS - MCI Telecommunications",
    "1965": "TUELECTRIC - Texas Utilities Services, Inc.",
    "1966": "DNIC--01966 - Navy Network Information Center (NNIC)",
    "1967": "TR-NET Middle East Technical University",
    "1968": "UMSP-DOM - University of Massachusettes",
    "1969": "TELEDYNE- - Advanced Network & Services",
    "1970": "TAMUS-NET - Texas A&M University",
    "1971": "DNIC--01971 - DoD Network Information Center",
    "1972": "HPN-ISIE - USC/ISI",
    "1973": "PHNSY-SYLAN - Navy Network Information Center (NNIC)",
    "1974": "MEHEALTH-SOUTH - Southern Maine Medical Center",
    "1975": "PROQUEST- - PROQUEST LLC",
    "1976": "DNIC--01976 - Navy Network Information Center (NNIC)",
    "1977": "DNIC--01977 - Navy Network Information Center (NNIC)",
    "1978": "DNIC--01978 - Navy Network Information Center (NNIC)",
    "1979": "DNIC--01979 - Navy Network Information Center (NNIC)",
    "1980": "DNIC--01980 - Navy Network Information Center (NNIC)",
    "1981": "DNIC--01981 - Navy Network Information Center (NNIC)",
    "1982": "N-NWNEXUS - Northwest Nexus Inc.",
    "1983": "BERNALILLO - Bernalillo County",
    "1984": "DNIC--01984 - Navy Network Information Center (NNIC)",
    "1985": "DNIC--01985 - Navy Network Information Center (NNIC)",
    "1986": "DNIC--01986 - Navy Network Information Center (NNIC)",
    "1987": "DNIC--01987 - Navy Network Information Center (NNIC)",
    "1988": "DNIC--01988 - Navy Network Information Center (NNIC)",
    "1989": "DNIC--01989 - Navy Network Information Center (NNIC)",
    "1990": "DNIC--01990 - Navy Network Information Center (NNIC)",
    "1991": "DNIC--01991 - Navy Network Information Center (NNIC)",
    "1992": "DNIC--01992 - Navy Network Information Center (NNIC)",
    "1993": "DNIC--01993 - Navy Network Information Center (NNIC)",
    "1994": "DNIC--01994 - Navy Network Information Center (NNIC)",
    "1995": "DNIC--01995 - Navy Network Information Center (NNIC)",
    "1996": "N1 - Fairdinkum Consulting, LLC",
    "1997": "IBMDES- - IBM Dallas Engineering & Scientific",
    "1998": "STATE-OF-MN - State of Minnesota",
    "1999": "HOUSE--1 - U.S. House of Representatives",
    "2000": "IA- - Internet Awareness, Inc.",
    "2001": "-NALCO-MPLS - Nalco Company",
    "2002": "IBM-PV- - IBM Corporation",
    "2003": "EPRI-PA - Electric Power Research Institute",
    "2004": "TNO-FEL",
    "2005": "INFONET1 - INFONET Services Corporation",
    "2006": "INFONET2 - INFONET Services Corporation",
    "2007": "INFONET-EUROPE Infonet Services Corporation",
    "2008": "INFONET4 - INFONET Services Corporation",
    "2009": "INFONET5 - INFONET Services Corporation",
    "2010": "INFONET6 - INFONET Services Corporation",
    "2011": "WACHOVIA - Wachovia Operational Services Corporation",
    "2012": "ELTENET ELTENET",
    "2013": "PACIFIC-G - PG&E",
    "2014": "SPRINT-INTL - Sprintlink",
    "2015": "MSEN-SYSTEM - Msen, Inc.",
    "2016": "OTANET Otaniemi Science Park",
    "2017": "KRPNET National Bureau of Investigation",
    "2018": "TENET-1",
    "2019": "JMC- - JPMorgan Chase & Co.",
    "2020": "ADHESIVE-N - Adhesives Research, Inc.",
    "2021": "UNISYS-INT - UNISYS",
    "2022": "SIEMENS- - Siemens Power Corp",
    "2023": "RUTYC - SIRACyT",
    "2024": "NU - Northeast Utilities",
    "2025": "UTOLEDO - University of Toledo",
    "2026": "HELSINKI City of Helsinki",
    "2027": "MSF Medecins Sans Frontieres",
    "2028": "Nortel Plc",
    "2029": "GGR- BNR Europe Limited",
    "2030": "TBCN2 - The Boeing Company",
    "2031": "COWACONET - St. Louis County Water Company",
    "2032": "CSC-TMD-CC - 754th Electronic Systems Group",
    "2033": "PANIX - Panix Network Information Center",
    "2034": "ATK-1 - Alliant Techsystems",
    "2035": "ATK-2 - Alliant Techsystems",
    "2036": "JOANNEUM RESEARCH",
    "2037": "CSUFRESNO - California State University at Fresno",
    "2038": "IT-HEP Italian Hepnet",
    "2039": "INFN-2 Instituto Nazionale Fisica Nucleare (INFN)",
    "2040": "INFN-3 Instituto Nazionale Fisica Nucleare (INFN)",
    "2041": "STNORBERTCOLLEGE - St. Norbert College",
    "2042": "ERX-JARING  JARING Communications Sdn Bhd.",
    "2043": "CIS-NET CIS-NET TESTNETWORK",
    "2044": "IINET-2044 - Infinity Internet, Inc.",
    "2045": "FACILITIES ICL Data Oy",
    "2046": "DNIC--02046 - DoD Network Information Center",
    "2047": "N-ROCHE-BLE F. Hoffmann-La Roche AG",
    "2048": "LANET-1 - State of Louisiana Office of Telecommunications Management",
    "2049": "AVL-GRAZ AVL List GmbH",
    "2050": "SPRINTCORP - Sprint Enterprise Information Services",
    "2051": "CISCO-EXT - Cisco Systems, Inc.",
    "2052": "RJRNI-NFGI - Nabisco Foods Group",
    "2053": "SPRINTCORP1 - Sprint Enterprise Information Services",
    "2054": "DNIC--02054 - DoD Network Information Center",
    "2055": "LSU-1 - Louisiana State University",
    "2056": "AOL- - America Online",
    "2057": "RENATER_NBLOCK1 FR-RENATER",
    "2058": "RENATER_NBLOCK1 FR-RENATER",
    "2059": "RENATER_NBLOCK1 FR-RENATER",
    "2060": "FR-RENATER RENATER_NBLOCK1",
    "2061": "FR-RENATER RENATER_NBLOCK1",
    "2062": "FR-CEA-RENATER Commissariat a l'Energie Atomique",
    "2063": "RENATER_NBLOCK1 FR-RENATER",
    "2064": "RENATER_NBLOCK1 FR-RENATER",
    "2065": "FR-RENATER-HDMON Reseau metropolitain de Montpellier HDMON",
    "2066": "FR-RENATER-TER-5 Reseau Regional Midi-Pyrenees TER-5",
    "2067": "RENATER_NBLOCK1 FR-RENATER",
    "2068": "RENATER_NBLOCK1 FR-RENATER",
    "2069": "RENATER_NBLOCK1 FR-RENATER",
    "2070": "RENATER_NBLOCK1 FR-RENATER",
    "2071": "FR-RENATER RENATER_NBLOCK1",
    "2072": "FR-RENATER-REVE Reseau REVE",
    "2073": "RENATER_NBLOCK1 FR-RENATER",
    "2074": "FR-CRIHAN-ROUEN FR",
    "2075": "RENATER_NBLOCK1 FR-RENATER",
    "2076": "RENATER_NBLOCK1 FR-RENATER",
    "2077": "RENATER_NBLOCK1 FR-RENATER",
    "2078": "FR-RENATER RENATER_NBLOCK1",
    "2079": "RENATER_NBLOCK1 FR-RENATER",
    "2080": "RENATER_NBLOCK1 FR-RENATER",
    "2081": "RENATER_NBLOCK1 FR-RENATER",
    "2082": "RENATER_NBLOCK1 FR-RENATER",
    "2083": "RENATER_NBLOCK1 FR-RENATER",
    "2084": "RENATER_NBLOCK1 FR-RENATER",
    "2085": "FR-RENATER-PACRRET METROPLITAN NETWORK",
    "2086": "RENATER_NBLOCK1 FR-RENATER",
    "2087": "RENATER_NBLOCK1 FR-RENATER",
    "2088": "FR-RENATER-MAYOTTE Reseau National de telecommunications pour la Technologie",
    "2089": "FR-MAN-CAEN FR",
    "2090": "RENATER_NBLOCK1 FR-RENATER",
    "2091": "FR-LHCONE-FRANCE LHC Open Network Environment - France",
    "2092": "RENATER_NBLOCK1 FR-RENATER",
    "2093": "RENATER_NBLOCK1 FR-RENATER",
    "2094": "FR-TELECOM-MANAGEMENT-SUDPARIS Telecom & Management Sud Paris",
    "2095": "RENATER_NBLOCK1 FR-RENATER",
    "2096": "RENATER_NBLOCK1 FR-RENATER",
    "2097": "RENATER_NBLOCK1 FR-RENATER",
    "2098": "RENATER_NBLOCK1 FR-RENATER",
    "2099": "RENATER_NBLOCK1 FR-RENATER",
    "2100": "FR-INRIA5 Institut National de Recherche en Informatique",
    "2101": "RENATER_NBLOCK1 FR-RENATER",
    "2102": "RENATER_NBLOCK1 FR-RENATER",
    "2103": "RENATER_NBLOCK1 FR-RENATER",
    "2104": "RENATER_NBLOCK1 FR-RENATER",
    "2105": "FR-RENATER-PIR2 Reseau Regional PICARDIE",
    "2106": "RENATER_NBLOCK1 FR-RENATER",
    "2107": "ARNES-NET ARNES",
    "2108": "CARNET- Croatian Academic and Research Network",
    "2109": "TDC TDC A/S",
    "2110": "-BTIRE BT Communications Ireland Limited",
    "2111": "SKYNET- SkyNet Group Ltd",
    "2113": "CELLNET",
    "2114": "ESIC ESCUEL DE ESTUDIOS SUPERIORES ESIC SACERDOTES DEL CORAZON DE JESUS PADRES REPARADORES",
    "2115": "OPEGIEKA-PL OPEGIEKA Sp. z o.o.",
    "2116": "N-CATCHCOM Broadnet",
    "2117": "ESO, Garching, Germany",
    "2118": "RELCOM- OOO \"NPO Relcom\"",
    "2119": "TELENOR-NEXTEL Telenor Norge",
    "2120": "DAXNET DAXnet Tele2 Norge",
    "2121": "RIPE-MEETING- Reseaux IP Europeens Network Coordination Centre (RIPE NCC)",
    "2122": "JSC PIOGLOBAL Asset Management, www.pioglobal.ru",
    "2123": "DFN-CERT Services GmbH",
    "2124": "DFN-CERT Services GmbH",
    "2125": "UUNET-WIN UUNET Germany",
    "2127": "AVIAR- Fujitsu (Ireland) Limited",
    "2128": "INEX Internet Neutral Exchange Association Limited",
    "2129": "HP-EUROPE--TRADE HP Enterprise Services UK Ltd",
    "2130": "PHILIPS-GLOBAL-NETWORK Koninklijke Philips Electronics N.V.",
    "2131": "SOFTWAREPARK-HAGENBERG Real-Treuhand Portfoliomanagement GmbH",
    "2132": "The Post Office (IT)",
    "2133": "The UCL-CS cisco2 Autonomous system",
    "2134": "GSVNET- GS Virtual Network Produban",
    "2135": "EuroKom Mail Service",
    "2136": "TCP--MOSCOW TCP",
    "2137": "DNIC--02137 - DoD Network Information Center",
    "2138": "DOW2- - Houston Dow Center",
    "2139": "DOW1- - Houston Dow Center",
    "2140": "ISSC- - IBM Corporation",
    "2141": "DNIC--02141 - DoD Network Information Center",
    "2142": "NSI-FFIX-E - National Aeronautics and Space Administration",
    "2143": "NSN-FFIX-W - National Aeronautics and Space Administration",
    "2144": "ERX-ETAFE South Australian Government Department of Employment",
    "2145": "NAMECT-NAMECT-LLC - Namecast, LLC",
    "2146": "CRNet: Red Nacional de Investigaci\u00f3n de C.R.",
    "2147": "COMPNEWS- Computer Newspaper Services Ltd.",
    "2148": "ITEP A.I.Alikhanov Institute",
    "2149": "COGENT-2149 - Cogent Communications",
    "2150": "CSUNET-SW - California State University Network",
    "2151": "CSUNET-SE - California State University Network",
    "2152": "CSUNET-NW - California State University Network",
    "2153": "CSUNET-NE - California State University Network",
    "2154": "HPES - Hewlett-Packard Company",
    "2155": "HPES - Hewlett-Packard Company",
    "2156": "HPES - Hewlett-Packard Company",
    "2157": "HPES - Hewlett-Packard Company",
    "2158": "HPES - Hewlett-Packard Company",
    "2159": "HPES - Hewlett-Packard Company",
    "2160": "HPES - Hewlett-Packard Company",
    "2161": "HPES - Hewlett-Packard Company",
    "2162": "HPES - Hewlett-Packard Company",
    "2163": "HPES - Hewlett-Packard Company",
    "2164": "HPES - Hewlett-Packard Company",
    "2165": "HPES - Hewlett-Packard Company",
    "2166": "HPES - Hewlett-Packard Company",
    "2167": "EDS-MITCHELDEAN EDS - Mitcheldean",
    "2168": "HPES - Hewlett-Packard Company",
    "2169": "HPES - Hewlett-Packard Company",
    "2170": "HPES - Hewlett-Packard Company",
    "2171": "HPES - Hewlett-Packard Company",
    "2172": "EDS-STOCKLEY EDS - Stockley Park",
    "2173": "HPES - Hewlett-Packard Company",
    "2174": "FR-NBLOCK INRIA-Rocquencourt",
    "2175": "FR-NBLOCK INRIA-Rocquencourt",
    "2176": "FR-NBLOCK INRIA-Rocquencourt",
    "2177": "FR-NBLOCK INRIA-Rocquencourt",
    "2178": "FR-NBLOCK INRIA-Rocquencourt",
    "2179": "FR-NBLOCK INRIA-Rocquencourt",
    "2180": "FR-NBLOCK INRIA-Rocquencourt",
    "2181": "FR-NBLOCK INRIA-Rocquencourt",
    "2182": "FR-NBLOCK INRIA-Rocquencourt",
    "2183": "FR-NBLOCK INRIA-Rocquencourt",
    "2184": "FR-NBLOCK INRIA-Rocquencourt",
    "2185": "FR-NBLOCK INRIA-Rocquencourt",
    "2186": "FR-NBLOCK INRIA-Rocquencourt",
    "2187": "FR-RENATER-SYRHANO-2 Reseau Regional SYRHANO 2",
    "2188": "FR-RENATER Reseau National de telecommunications pour la Technologie",
    "2189": "FR-NBLOCK INRIA-Rocquencourt",
    "2190": "FR-NBLOCK INRIA-Rocquencourt",
    "2191": "FR-NBLOCK INRIA-Rocquencourt",
    "2192": "FR-ANSBLOCK FR-RENATER",
    "2193": "FR-RENATER-SRHD-2 Reseau regional Poitou-Charente",
    "2194": "FR-RENATER-SEQUANET Reseau regional SEQUANET de collecte pour l'enseignement superieur et la recherche",
    "2195": "FR-NBLOCK INRIA-Rocquencourt",
    "2196": "FR-NBLOCK INRIA-Rocquencourt",
    "2197": "FR-NBLOCK FR-SPANIP",
    "2198": "FR-TOM-NOUVELLE-CALEDONIE FR",
    "2199": "FR-DOM-MARTINIQUE Iles de la Martinique",
    "2200": "FR-RENATER Reseau National de telecommunications pour la Technologie",
    "2201": "FR-NBLOCK FR-RENATER",
    "2202": "FR-RENATER-REAUMUR Reseau Regional REAUMUR",
    "2203": "FR-NBLOCK INRIA-Rocquencourt",
    "2204": "FR-NBLOCK INRIA-Rocquencourt",
    "2205": "FR-NBLOCK INRIA-Rocquencourt",
    "2206": "FR-NBLOCK INRIA-Rocquencourt",
    "2207": "FR-NBLOCK INRIA-Rocquencourt",
    "2208": "FR-NBLOCK INRIA-Rocquencourt",
    "2209": "FR-NBLOCK INRIA-Rocquencourt",
    "2210": "FR-NBLOCK INRIA-Rocquencourt",
    "2211": "FR-NBLOCK INRIA-Rocquencourt",
    "2212": "FR-NBLOCK INRIA-Rocquencourt",
    "2213": "FR-NBLOCK INRIA-Rocquencourt",
    "2214": "FR-NBLOCK INRIA-Rocquencourt",
    "2215": "FR-NBLOCK INRIA-Rocquencourt",
    "2216": "FR-NBLOCK INRIA-Rocquencourt",
    "2217": "FR-NBLOCK INRIA-Rocquencourt",
    "2218": "FR-NBLOCK INRIA-Rocquencourt",
    "2219": "FR-NBLOCK INRIA-Rocquencourt",
    "2220": "FR-NBLOCK INRIA-Rocquencourt",
    "2221": "FR-NBLOCK INRIA-Rocquencourt",
    "2222": "FR-RENATER FR",
    "2223": "FR-INRETS-ARCUEIL FR",
    "2224": "FR-NBLOCK INRIA-Rocquencourt",
    "2225": "FR-NBLOCK INRIA-Rocquencourt",
    "2226": "FR-NBLOCK INRIA-Rocquencourt",
    "2227": "FR-NBLOCK INRIA-Rocquencourt",
    "2228": "FR-NBLOCK INRIA-Rocquencourt",
    "2229": "FR-NBLOCK INRIA-Rocquencourt",
    "2230": "FR-NBLOCK INRIA-Rocquencourt",
    "2231": "FR-RENATER-U-PPA-PAU Universite de Pau et des Pays de l'Adour",
    "2232": "FR-NBLOCK INRIA-Rocquencourt",
    "2233": "FR-RENATER-POUTOUCHAR Reseau Regional POITOU CHARENTE",
    "2234": "FR-NBLOCK INRIA-Rocquencourt",
    "2235": "FR-NBLOCK INRIA-Rocquencourt",
    "2236": "FR-U-ORLEANS FR",
    "2237": "FR-U-REAUMUR-BORDEAUX FR",
    "2238": "FR-NBLOCK INRIA-Rocquencourt",
    "2239": "FR-U-REIMS FR",
    "2240": "FR-NBLOCK INRIA-Rocquencourt",
    "2241": "FR-NBLOCK INRIA-Rocquencourt",
    "2242": "FR-NBLOCK INRIA-Rocquencourt",
    "2243": "FR-U-SCIENCES-NANTES FR",
    "2244": "FR-NBLOCK INRIA-Rocquencourt",
    "2245": "FR-NBLOCK INRIA-Rocquencourt",
    "2246": "FR-NBLOCK INRIA-Rocquencourt",
    "2247": "FR-NBLOCK INRIA-Rocquencourt",
    "2248": "FR-NBLOCK INRIA-Rocquencourt",
    "2249": "FR-NBLOCK INRIA-Rocquencourt",
    "2250": "FR-NBLOCK INRIA-Rocquencourt",
    "2251": "FR-NBLOCK INRIA-Rocquencourt",
    "2252": "FR-NBLOCK INRIA-Rocquencourt",
    "2253": "FR-NBLOCK INRIA-Rocquencourt",
    "2254": "FR-NBLOCK INRIA-Rocquencourt",
    "2255": "FR-ESPCI-PARIS ESPCI-PARIS",
    "2256": "FR-NBLOCK INRIA-Rocquencourt",
    "2257": "FR-NBLOCK INRIA-Rocquencourt",
    "2258": "FR-NBLOCK INRIA-Rocquencourt",
    "2259": "FR-U-STRBOURG OSIRIS - UNIVERSITE DE STRBOURG",
    "2260": "FR-NBLOCK INRIA-Rocquencourt",
    "2261": "FR-NBLOCK INRIA-Rocquencourt",
    "2262": "FR-NBLOCK INRIA-Rocquencourt",
    "2263": "FR-RENATER-TELECOM-RENNES TELECOM Bretagne, Campus Rennes",
    "2264": "FR-RESUBIE Reseau Universite de Bourgogne Iufm Ensam",
    "2265": "FR-NBLOCK INRIA-Rocquencourt",
    "2266": "FR-NBLOCK INRIA-Rocquencourt",
    "2267": "FR-NBLOCK INRIA-Rocquencourt",
    "2268": "FR-NBLOCK INRIA-Rocquencourt",
    "2269": "FR-U-PARISSUD-ORSAY FR",
    "2270": "FR-NBLOCK INRIA-Rocquencourt",
    "2271": "FR-NBLOCK INRIA-Rocquencourt",
    "2272": "FR-NBLOCK INRIA-Rocquencourt",
    "2273": "FR-NBLOCK INRIA-Rocquencourt",
    "2274": "CBO - Congressional Budget Office",
    "2275": "DNIC--02275 - DoD Network Information Center",
    "2276": "OCS-1 - OpenConnect Systems",
    "2277": "ECUANET - CORPORACION ECUATORIANA DE INFORMACION",
    "2278": "FRANCE-TELECOM- France Telecom",
    "2279": "FRANCE-TELECOM- France Telecom",
    "2280": "FRANCE-TELECOM- France Telecom",
    "2281": "FRANCE-TELECOM- France Telecom",
    "2282": "FRANCE-TELECOM- France Telecom",
    "2283": "FRANCE-TELECOM- France Telecom",
    "2284": "FRANCE-TELECOM- France Telecom",
    "2285": "FRANCE-TELECOM- France Telecom",
    "2286": "FRANCE-TELECOM- France Telecom",
    "2287": "FRANCE-TELECOM- France Telecom",
    "2288": "FRANCE-TELECOM- France Telecom",
    "2289": "FRANCE-TELECOM- France Telecom",
    "2290": "FRANCE-TELECOM- France Telecom",
    "2291": "FRANCE-TELECOM- France Telecom",
    "2292": "FRANCE-TELECOM- France Telecom",
    "2293": "FRANCE-TELECOM- France Telecom",
    "2294": "FRANCE-TELECOM- France Telecom",
    "2295": "FRANCE-TELECOM- France Telecom",
    "2296": "FRANCE-TELECOM- France Telecom",
    "2297": "FRANCE-TELECOM- France Telecom",
    "2298": "FRANCE-TELECOM- France Telecom",
    "2299": "FRANCE-TELECOM- France Telecom",
    "2300": "FRANCE-TELECOM-IPX France Telecom SA",
    "2301": "FRANCE-TELECOM- France Telecom",
    "2302": "FRANCE-TELECOM- France Telecom",
    "2303": "FRANCE-TELECOM- France Telecom",
    "2304": "FRANCE-TELECOM- France Telecom",
    "2305": "FRANCE-TELECOM- France Telecom",
    "2306": "FRANCE-TELECOM- France Telecom",
    "2307": "FRANCE-TELECOM- France Telecom",
    "2308": "FRANCE-TELECOM- France Telecom",
    "2309": "FRANCE-TELECOM- France Telecom",
    "2310": "FRANCE-TELECOM- France Telecom",
    "2311": "FRANCE-TELECOM- France Telecom",
    "2312": "FRANCE-TELECOM- France Telecom",
    "2313": "FRANCE-TELECOM- France Telecom",
    "2314": "FRANCE-TELECOM- France Telecom",
    "2315": "FRANCE-TELECOM- France Telecom",
    "2316": "FRANCE-TELECOM- France Telecom",
    "2317": "FRANCE-TELECOM- France Telecom",
    "2318": "FRANCE-TELECOM- France Telecom",
    "2319": "FRANCE-TELECOM- France Telecom",
    "2320": "FRANCE-TELECOM- France Telecom",
    "2321": "FRANCE-TELECOM- France Telecom",
    "2322": "FRANCE-TELECOM- France Telecom",
    "2323": "FRANCE-TELECOM- France Telecom",
    "2324": "FRANCE-TELECOM- France Telecom",
    "2325": "FRANCE-TELECOM- France Telecom",
    "2326": "FRANCE-TELECOM- France Telecom",
    "2327": "FRANCE-TELECOM- France Telecom",
    "2328": "FRANCE-TELECOM- France Telecom",
    "2329": "FRANCE-TELECOM- France Telecom",
    "2330": "FRANCE-TELECOM- France Telecom",
    "2331": "FRANCE-TELECOM- France Telecom",
    "2332": "FRANCE-TELECOM- France Telecom",
    "2333": "FRANCE-TELECOM- France Telecom",
    "2334": "FRANCE-TELECOM- France Telecom",
    "2335": "FRANCE-TELECOM- France Telecom",
    "2336": "FRANCE-TELECOM- France Telecom",
    "2337": "FRANCE-TELECOM- France Telecom",
    "2338": "FRANCE-TELECOM- France Telecom",
    "2339": "FRANCE-TELECOM- France Telecom",
    "2340": "FRANCE-TELECOM- France Telecom",
    "2341": "FRANCE-TELECOM- France Telecom",
    "2342": "FRANCE-TELECOM- France Telecom",
    "2343": "FRANCE-TELECOM- France Telecom",
    "2344": "FRANCE-TELECOM- France Telecom",
    "2345": "FRANCE-TELECOM- France Telecom",
    "2346": "FRANCE-TELECOM- France Telecom",
    "2347": "FRANCE-TELECOM- France Telecom",
    "2348": "FRANCE-TELECOM- France Telecom",
    "2349": "FRANCE-TELECOM- France Telecom",
    "2350": "FRANCE-TELECOM- France Telecom",
    "2351": "FRANCE-TELECOM- France Telecom",
    "2352": "FRANCE-TELECOM- France Telecom",
    "2353": "FRANCE-TELECOM- France Telecom",
    "2354": "FRANCE-TELECOM- France Telecom",
    "2355": "FRANCE-TELECOM- France Telecom",
    "2356": "FRANCE-TELECOM- France Telecom",
    "2357": "FRANCE-TELECOM- France Telecom",
    "2358": "FRANCE-TELECOM- France Telecom",
    "2359": "FRANCE-TELECOM- France Telecom",
    "2360": "FRANCE-TELECOM- France Telecom",
    "2361": "FRANCE-TELECOM- France Telecom",
    "2362": "FRANCE-TELECOM- France Telecom",
    "2363": "FRANCE-TELECOM- France Telecom",
    "2364": "FRANCE-TELECOM- France Telecom",
    "2365": "FRANCE-TELECOM- France Telecom",
    "2366": "FRANCE-TELECOM- France Telecom",
    "2367": "FRANCE-TELECOM- France Telecom",
    "2368": "FRANCE-TELECOM- France Telecom",
    "2369": "FRANCE-TELECOM- France Telecom",
    "2370": "FRANCE-TELECOM- France Telecom",
    "2371": "FRANCE-TELECOM- France Telecom",
    "2372": "FRANCE-TELECOM- France Telecom",
    "2373": "FRANCE-TELECOM- France Telecom",
    "2374": "FRANCE-TELECOM- France Telecom",
    "2375": "FRANCE-TELECOM- France Telecom",
    "2376": "FRANCE-TELECOM- France Telecom",
    "2377": "FRANCE-TELECOM- France Telecom",
    "2378": "DOI-BIA - DOI - BIA",
    "2379": "EMBARQ-WNPK - Embarq Corporation",
    "2380": "ESTNET Elion Enterprises Ltd.",
    "2381": "WISCNET1- - WiscNet",
    "2382": "WISCNET2- - WiscNet",
    "2383": "OTA - Office of Technology Assessment",
    "2384": "AOCNET - Architect of the Capitol",
    "2385": "JUNGBU--KR JUNGBU",
    "2386": "INS- - AT&T Data Communications Services",
    "2387": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2388": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2389": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2390": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2391": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2392": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2393": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2394": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2395": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2396": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2397": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2398": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2399": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2400": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2401": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2402": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2403": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2404": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2405": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2406": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2407": "FR-NBLOCK2 FR-U-CAEN",
    "2408": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2409": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2410": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2411": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2412": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2413": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2414": "FR-RENATER-LIMOUSIN Reseau Regional LIMOUSIN",
    "2415": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2416": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2417": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2418": "FR-NBLOCK2 FR-MAN-SOPHIA-ANTIPOLIS",
    "2419": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2420": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2421": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2422": "FR-RENATER-RAP Metropolitan Paris Academic Network",
    "2423": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2424": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2425": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2426": "FR-RENATER-RUBIS RUBIS Metropolitan Area Network",
    "2427": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2428": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2429": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2430": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2431": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2432": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2433": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2434": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2435": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2436": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2437": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2438": "FR-INRIA3 Institut National de Recherche en Informatique",
    "2439": "FR-REMUS MAN of the Polytechnicum",
    "2440": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2441": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2442": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2443": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2444": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2445": "FR-JTM-93 Reseau de Collecte du Nord-Est Francilien",
    "2446": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2447": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2448": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2449": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2450": "CNES-Toulouse",
    "2451": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2452": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2453": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2454": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2455": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2456": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2457": "FR-RAIMU-2 Reseau de collecte des Universites d'Aix Marseille",
    "2458": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2459": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2460": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2461": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2462": "FR-U-ANGERS NBLOCK2",
    "2463": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2464": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2465": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2466": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2467": "FR-INRIA4 Institut National de Recherche en Informatique",
    "2468": "FR-NBLOCK2 INRIA-Rocquencourt",
    "2469": "FR-DEMO-RENATER Reseau National de telecommunications pour la Technologie",
    "2470": "FR-LAREUNION Ile de la Reunion Departement d'Outre-Mer",
    "2471": "FR-DOM-GUADELOUPE Iles de la Guadeloupe",
    "2472": "FR-DOM-GUYANE Guyane Francaise",
    "2473": "FR-CETP CETP/UVSQ 78140 VELIZY, France",
    "2474": "FR-RENATER-LOTHAIRE-METZ Reseau Regional Lothaire Metz",
    "2475": "FR-RENATER-SRHD3 Reseau Regional Poitou Charentes",
    "2476": "FR-I-MEDOC MEDOC Project",
    "2477": "FR-ROYAL Reseau Optique Yvelinois pour la Communaute Academique",
    "2478": "FR-RENATER-R3T2-SOPHIA Reseau Regional R3T2",
    "2479": "FR-UNIVLM Universite du Maine - D.S.I.",
    "2480": "FR-L-MARSEILLE Laboratoire d'Astronomie Spatiale",
    "2481": "FR-INRIA-2481 INRIA",
    "2482": "NIC-FR-2482 AFNIC (Association Francaise pour le Nommage Internet en Cooperation)",
    "2483": "NIC-FR-2483 AFNIC (Association Francaise pour le Nommage Internet en Cooperation)",
    "2484": "NIC-FR-DNS-ANYCT-AFNIC AFNIC (Association Francaise pour le Nommage Internet en Cooperation)",
    "2485": "NIC-FR-SITES-SQY-TH3 AFNIC (Association Francaise pour le Nommage Internet en Cooperation)",
    "2486": "NIC-FR-DNS-UNICT-PARIS2 AFNIC (Association Francaise pour le Nommage Internet en Cooperation)",
    "2487": "MOSCOW-HEP Institute for Theoretical & Experimental Physicis",
    "2488": "IIA-NET International Institute for Applied Systems Analysis",
    "2489": "NETIOWA- - Net Iowa",
    "2490": "MILNET-T20 - Bolt Beranek and Newman Inc.",
    "2491": "2491-RTI - Rogers Cable Communications Inc.",
    "2492": "2492-RTI - Rogers Cable Communications Inc.",
    "2493": "2493-RTI - Rogers Cable Communications Inc.",
    "2494": "MUWNET MUWNET Autonomous System",
    "2495": "KANREN - Kansas Research and Education Network",
    "2496": "UKANS - University of Kansas",
    "2497": "IIJ Internet Initiative Japan Inc.",
    "2498": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2499": "IPV4EXH-LAB Japan Network Information Center",
    "2500": "WIDE-BB WIDE Project",
    "2501": "UTNET Information Technology Center,The University of Tokyo",
    "2502": "TRAIN Information Technology Center, The University of Tokyo",
    "2503": "TOPIC Tohoku Open Internet Community",
    "2504": "NCA5 Kyoto University",
    "2505": "HEPNET-J High Energy Accelerator Research Organization, KEK",
    "2506": "SUPERCSI NTT WEST CHUGOKU CORPORATION",
    "2507": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2508": "KYUSHU-U Kyushu University",
    "2509": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2510": "INFOWEB FUJITSU LIMITED",
    "2511": "CORE NTT",
    "2512": "TCP-NET TCP Inc.",
    "2513": "JST Japan Science and Technology Agency",
    "2514": "INFOSPHERE NTT PC Communications, Inc.",
    "2515": "JPNIC Japan Network Information Center",
    "2516": "KDDI KDDI CORPORATION",
    "2517": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2518": "BIGLOBE NEC BIGLOBE, Ltd.",
    "2519": "VECTANT VECTANT Ltd.",
    "2520": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2521": "IDC2521 Yahoo Japan Corporation",
    "2522": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2523": "JAIN JSPS 163rd Committee on Internet Technology",
    "2524": "RIM EJWORKS CORPORATION",
    "2525": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2526": "HITNET HITACHI,Ltd. Information Technology Division.",
    "2527": "SO-NET So-net Entertainment Corporation",
    "2528": "JPNIC-2BYTE-BLOCK-AP Block of 32  numbers from 2497 to 2528",
    "2529": "DEMON-INTERNET Now maintained by Cable & Wireless Worldwide",
    "2530": "CIBA- Ciba (CIBA-GEIGY AG) TeleCommunication Services (TCS)",
    "2531": "DNIC--02531 - DoD Network Information Center",
    "2532": "LOC - Library of Congress",
    "2533": "HOU-METRO- - MIS Group",
    "2534": "ROCHE-PALO-ALTO - Hoffmann LaRoche, Inc.",
    "2535": "BP-UK BP Internet UK",
    "2536": "TCADA - Texas Commission on Alcohol & Drug Abuse",
    "2537": "ERX-STATS-GOVTNZ New Zealand Department of Statistics",
    "2538": "IBM-PLP - IBM",
    "2539": "GLAXOSMITHKLINE - GlaxoSmithKline",
    "2540": "INGRES- - Ingres Information Services",
    "2541": "JUMP- Jump Management SRL",
    "2542": "VOUGHT - Vought Aircraft Company",
    "2543": "UCIMC- - University of California, Irvine",
    "2544": "METRO- - King County Gov",
    "2545": "STRATHOST - 754th Electronic Systems Group",
    "2546": "ARIADNE-T Ariadne-t Network",
    "2547": "BMENET- Budapest University of Technology and Economics",
    "2548": "ALGX-ATCW- - XO Communications",
    "2549": "Universidad de Guadalajara",
    "2550": "STRATS - 754th Electronic Systems Group",
    "2551": "LVLT-2551 - Level 3 Communications, Inc.",
    "2552": "WUSTL-N - Washington University",
    "2553": "FSU- - Florida State University",
    "2554": "IDC2554 Yahoo Japan Corporation",
    "2555": "INTER-GRP-B - PSI",
    "2556": "INTER-GRP-C - PSI",
    "2557": "INTER-GRP-D - PSI",
    "2558": "CIWMBNET - California Integrated Waste Management Board (CIWMB)",
    "2559": "VISANET - Visa International",
    "2560": "BOCA- - IBM",
    "2561": "EUN",
    "2562": "TI-US/INTL - Texas Instruments, Inc.",
    "2563": "SNU2--KR Seoul National University",
    "2564": "GLO - Texas General Land Office",
    "2565": "TX-DARS - Texas Department of Assistive and Rehabilitative Services",
    "2566": "ISINM - International Symposium on Integrated Network Management",
    "2567": "SLB-WESTERNGECO- - Schlumberger Limited",
    "2569": "IVPN-TELECOM-NZ Telecom New Zealand Ltd",
    "2570": "T-TELECOM-NZ Telecom New Zealand Ltd",
    "2571": "DHL- DHL Systems Inc.",
    "2572": "MORENET - University of Missouri - dba the Missouri Research and Education Network (MOREnet)",
    "2573": "QED-SYS - QED Systems, Inc.",
    "2574": "TRS - Teacher Retirement System of Texas",
    "2575": "SRPNET - Salt River Project Agricultural Improvement & Power District",
    "2576": "DOT- - U. S. Department of Transportation",
    "2577": "DNIC--02577 - DoD Network Information Center",
    "2578": "DEMOS- Demos, Moscow, Russia",
    "2580": "SEMBLY - California SEMBLY",
    "2581": "GAO - U.S. Government Accountability Office",
    "2582": "CDE - California Department of Education",
    "2583": "ADG-CTLEACCESS - Affinity Development Group",
    "2584": "CUMMINS - Cummins Engine Co. Inc.",
    "2585": "OPTICTELECOM- Optic Telecom LLC",
    "2586": "UNINET- Elisa Eesti",
    "2587": "FREE-NET-2587 OOO FREEnet Group",
    "2588": "LATNETSERVISS- LATNET SERVISS Ltd.",
    "2589": "WANSTOR Wanstor Ltd",
    "2590": "The Cellphone Group PLC",
    "2591": "IMPLETEC- IMPLETEC TECHNOLOGIES LTD",
    "2592": "EGE- Ege University",
    "2593": "N-VSIX VSIX Nap del Nord Est",
    "2594": "N-CSI CSI Piemonte",
    "2595": "CSP- CSP s.c. a r.l.",
    "2596": "NAP- NW's NAP",
    "2597": "CCTLD-IT Registry of ccTLD it  - IIT-CNR",
    "2598": "CNR Consiglio Nazionale delle Ricerche",
    "2599": "OJSC \"Vimpelcom\"",
    "2600": "TEKSTILBANK A.S.",
    "2601": "INTEROP-EU InteropNet Europe",
    "2602": "RESTENA Fondation RESTENA",
    "2603": "NORDUNET NORDUnet",
    "2604": "MHS-GRAZ HS fuer Musik und darstellende Kunst, Graz, AT",
    "2605": "CESNET CESNET z.s.p.o.",
    "2606": "Societa Italiana per l'Esercizio delle Telecomunicazione",
    "2607": "SANET Slovak Academic Network",
    "2608": "The JNT Association",
    "2609": "TN-BB- Tunisia BackBone",
    "2610": "EUnet/SI Autonomous system",
    "2611": "BELNET BELNET",
    "2612": "SITYS AG",
    "2613": "COM AG",
    "2614": "ROEDUNET Agentia pentru Administrarea Retelei de Informatica pentru Educatie si Cercetare",
    "2615": "BECHTEL - Bechtel Corp.",
    "2616": "DNIC-BLK-02616-02620 - Navy Network Information Center (NNIC)",
    "2617": "DNIC-BLK-02616-02620 - Navy Network Information Center (NNIC)",
    "2618": "DNIC-BLK-02616-02620 - Navy Network Information Center (NNIC)",
    "2619": "DNIC-BLK-02616-02620 - Navy Network Information Center (NNIC)",
    "2620": "DNIC-BLK-02616-02620 - Navy Network Information Center (NNIC)",
    "2621": "DNIC--02621 - DoD Network Information Center",
    "2622": "DNIC--02622 - DoD Network Information Center",
    "2623": "DNIC--02623 - DoD Network Information Center",
    "2624": "DNIC--02624 - DoD Network Information Center",
    "2625": "DNIC-R-02625 - DoD Network Information Center",
    "2626": "DNIC--02626 - DoD Network Information Center",
    "2627": "DNIC--02627 - DoD Network Information Center",
    "2628": "DNIC--02628 - DoD Network Information Center",
    "2629": "DNIC--02629 - DoD Network Information Center",
    "2630": "DNIC--02630 - DoD Network Information Center",
    "2631": "DISCOVERY- - Discovery Communications",
    "2632": "DNIC--02632 - DoD Network Information Center",
    "2633": "N1- - National Academy of Sciences",
    "2634": "ALLTEL - Cellco Partnership DBA Verizon Wireless",
    "2635": "AUTOMATTIC - Automattic, Inc",
    "2636": "OOVOOUS1 - ooVoo LLC",
    "2637": "GEORGIA-TECH - Georgia Institute of Technology",
    "2638": "CENTRO DE ADMINISTRACION NIC.NI",
    "2639": "ZOHO- - ZOHO",
    "2640": "AMESLAB- - Ames Laboratory",
    "2641": "TSRI- - The Scripps Research Institute",
    "2642": "LEG-CA-GOV - State of California",
    "2643": "IHEP-SU",
    "2644": "SMARTS- - System Management ARTS, Inc.",
    "2645": "N-CAVENET - The Commnet Project",
    "2646": "CONEXANT - Conexant",
    "2647": "SITA SITA",
    "2648": "NIST-BOULDER - NIST/U.S. Dept. of Commerce",
    "2649": "COGENT-2649 - PSINet, Inc.",
    "2650": "EOP_GATEKEEPER - Executive Office Of The President",
    "2651": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2652": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2653": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2654": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2655": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2656": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2657": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2658": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2659": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2660": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2661": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2662": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2663": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2664": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2665": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2666": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2667": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2668": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2669": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2670": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2671": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2672": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2673": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2674": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2675": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2676": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2677": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2678": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2679": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2680": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2681": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2682": "CDAGOVN - Government Telecommunications and Informatics Services",
    "2683": "RADIO-MSU RADIO-MSU",
    "2684": "NET-SEMBLY-CA-GOV - California SEMBLY",
    "2685": "ATTCA AT&T Global Network Services - CA",
    "2686": "AT&T Global Network Services - EMEA",
    "2687": "ATTCA AT&T Global Network Services - AP",
    "2688": "ATTCA AT&T Global Network Services - LA",
    "2689": "ATGS-MMD- - AT&T Global Network Services, LLC",
    "2690": "ATGS-MMD- - AT&T Global Network Services, LLC",
    "2691": "ATGS-MMD- - AT&T Global Network Services, LLC",
    "2692": "ATGS-MMD- - AT&T Global Network Services, LLC",
    "2693": "ATGS-MMD- - AT&T Global Network Services, LLC",
    "2694": "ATGS-MMD- - AT&T Global Network Services, LLC",
    "2695": "RJRT01-TOB1 - RJ Reynolds Tobacco Company",
    "2696": "IREN- - Iowa Research and Education Network",
    "2697": "ERX-ERNET- Education and Research Network",
    "2698": "ITATE- - Iowa State University",
    "2699": "AINET-2699 - Advanced Information Technology Services, LLC",
    "2700": "CLARIS-CORP - FileMaker, Inc.",
    "2701": "KSU-NET - Kansas State University",
    "2702": "INTERSERVE - Novx Systems, Inc",
    "2703": "DATAPR-3 - Data-Prompt, Inc.",
    "2704": "HOOKUP-NET-A - HookUp Communication Corporation",
    "2705": "BJCHE-1 - BJC HEALTH SYSTEM",
    "2706": "PI-HK Pacnet Internet (Hong Kong) Limited",
    "2707": "FIRSTCOMM-1 - First Communications LLC",
    "2708": "Universidad de Guanajuato",
    "2709": "AOS- - Apple Inc.",
    "2710": "AMSINC-NET - American Management Systems, Inc.",
    "2711": "SPIRITTEL- - Spirit Telecom",
    "2712": "LGC - Landmark Graphics Corporation",
    "2713": "ERX-INTERSPIN- AT&T Jens Corporation",
    "2714": "GSA-GOV - General Services Administration",
    "2715": "Fundacao de Amparo a Pesquisa/RJ",
    "2716": "Universidade Federal do Rio Grande do Sul",
    "2717": "CUMMINS-1 - Cummins Engine Co. Inc.",
    "2718": "APSCN-AR - Arkansas Public School Computer Network",
    "2719": "PIXEL8 - Pixel8 Networks, Inc.",
    "2720": "PARKED-CLUSTER1-AMERIC - Parked.com, Ltd.",
    "2721": "SCLR - CULR, LLC",
    "2722": "C-LIGHT - CULR, LLC",
    "2723": "ENDURANCE - ENDURANCE REINSURANCE CORPORATION OF AMERICA",
    "2724": "FAC- - Flad Affiliated Corp",
    "2725": "BES-NET - Berkeley Educational Services of New Jersey, Inc.",
    "2726": "-WEBFORMIX - Webformix Company",
    "2727": "GEPB2009 - Electric Plant Board of the City of Glasgow, Kentucky",
    "2729": "TOPICA-LA - Topica, Inc.",
    "2730": "WINKY- - WINKY NETWORKS LLC",
    "2731": "HORIZONTELCOM - Horizon Telcom Inc.",
    "2732": "NOVAESP-1 - NovaESP, Inc.",
    "2734": "CORESITE - CoreSite",
    "2735": "ETE-46- - Eastern Irrigation District",
    "2736": "KWSHELLS - KwShells Internet Services",
    "2737": "ING-AMERIC-WHOLESALE - ING Financial Services, LLC",
    "2738": "-SHIELDS-COM - Shields Health Care Group",
    "2739": "Facultad de Ingenieria",
    "2740": "CARIBCABLE - Caribbean Cable Communications",
    "2741": "DNIC--02741 - DoD Network Information Center",
    "2742": "TDAC-LAFB - 754th Electronic Systems Group",
    "2743": "AFIWC01 - 754th Electronic Systems Group",
    "2744": "DNIC--02744 - DoD Network Information Center",
    "2745": "DNIC--02745 - DoD Network Information Center",
    "2746": "DNIC--02746 - Navy Network Information Center (NNIC)",
    "2747": "AF-PROTEUS - 754th Electronic Systems Group",
    "2748": "DNIC--02748 - DoD Network Information Center",
    "2749": "DNIC--02749 - Navy Network Information Center (NNIC)",
    "2750": "CTNOSC-N-2750 - Headquarters, USAISC",
    "2751": "ATT-PARADYNE - AT&T Paradyne",
    "2752": "THOMSONCA- - Thomson Financial Networks",
    "2753": "LARSECOM - Larse Corporation",
    "2754": "EPNG- - El Paso Natural Gas Company",
    "2755": "SJHMC_CHW - Saint Joseph's Hospital & Medical Center",
    "2756": "ERX-EYNZ-O Ernst & Young",
    "2757": "MCI-NETA - MCI Telecommunications",
    "2758": "MCI-NETB - MCI Telecommunications",
    "2759": "MCI-NETC - MCI Telecommunications",
    "2760": "MCI-NETD - MCI Telecommunications",
    "2761": "MCI-NETE - MCI Telecommunications",
    "2762": "ADIFY-1 - ADIFY CORPORATION",
    "2763": "N1 - Computer Systems Integration",
    "2764": "AAPT AAPT Limited",
    "2765": "CONNECTED - Connected INC",
    "2766": "OJSC \"Vimpelcom\"",
    "2767": "ALLST-2767 - Allstream Corp.",
    "2768": "ERIE-COUNTY - The County of Erie",
    "2769": "NEBRKA - State of Nebraska, D, Division of Communications",
    "2770": "TDHS-WEL-NET - Texas Department of Human Resources",
    "2771": "TRW-HSV - TRW Huntsville Operations",
    "2772": "CITICTEL-CPC-2772 CITIC Telecom International CPC Limited",
    "2773": "DBP Deutsche Telekom AG",
    "2774": "DBP Deutsche Telekom AG",
    "2775": "DBP Deutsche Telekom AG",
    "2776": "DBP Deutsche Telekom AG",
    "2777": "DBP Deutsche Telekom AG",
    "2778": "DBP Deutsche Telekom AG",
    "2779": "DBP Deutsche Telekom AG",
    "2780": "DBP Deutsche Telekom AG",
    "2781": "DBP Deutsche Telekom AG",
    "2782": "DBP Deutsche Telekom AG",
    "2783": "DBP Deutsche Telekom AG",
    "2784": "DBP Deutsche Telekom AG",
    "2785": "DBP Deutsche Telekom AG",
    "2786": "DBP Deutsche Telekom AG",
    "2787": "DBP Deutsche Telekom AG",
    "2788": "DBP Deutsche Telekom AG",
    "2789": "DBP Deutsche Telekom AG",
    "2790": "DBP Deutsche Telekom AG",
    "2791": "DBP Deutsche Telekom AG",
    "2792": "DBP Deutsche Telekom AG",
    "2793": "Rikspolisstyrelsen",
    "2794": "Rikspolisstyrelsen",
    "2795": "Rikspolisstyrelsen",
    "2796": "Rikspolisstyrelsen",
    "2797": "Rikspolisstyrelsen",
    "2798": "Rikspolisstyrelsen",
    "2799": "Rikspolisstyrelsen",
    "2800": "Rikspolisstyrelsen",
    "2801": "Rikspolisstyrelsen",
    "2802": "Rikspolisstyrelsen",
    "2803": "Rikspolisstyrelsen",
    "2804": "Rikspolisstyrelsen",
    "2805": "Rikspolisstyrelsen",
    "2806": "Rikspolisstyrelsen",
    "2807": "Rikspolisstyrelsen",
    "2808": "Rikspolisstyrelsen",
    "2809": "Rikspolisstyrelsen",
    "2810": "Rikspolisstyrelsen",
    "2811": "Rikspolisstyrelsen",
    "2812": "Rikspolisstyrelsen",
    "2813": "Rikspolisstyrelsen",
    "2814": "Rikspolisstyrelsen",
    "2815": "Rikspolisstyrelsen",
    "2816": "Rikspolisstyrelsen",
    "2817": "Rikspolisstyrelsen",
    "2818": "BBC BBC Internet Services, UK",
    "2819": "GTSCZ GTS Czech s.r.o.",
    "2820": "ELVIS- ZAO \"Elvis-Telecom\"",
    "2821": "LKAB Kiruna",
    "2822": "UUNET Belgium/Luxembourg",
    "2823": "ERX-BT-AU-1 Bankers Trust",
    "2824": "DB-NA-1 - Deutsche Bank",
    "2825": "DB-NA-2 - Deutsche Bank",
    "2826": "GDC4S-PACIFIC - General Dynamics C4 Systems, Inc.",
    "2827": "KH- - Kelsey Hayes Corporation",
    "2828": "XO-15 - XO Communications",
    "2829": "I-LINK - I-Link",
    "2830": "MCI-DUAL-HOMED-CUSTOMERS Verizon Nederland B.V.",
    "2831": "LTUNET Lulea Tekniska Universitet",
    "2832": "SUNET/NORDUnet",
    "2833": "SUNET-UMU Umea Universitet",
    "2834": "UUNET Uppsala University",
    "2835": "SUNET/NORDUnet",
    "2836": "BAGNET Bengt Arne Gorden Data",
    "2837": "SUNET-KI Karolinska Institutet",
    "2838": "SUNT Stockholm University",
    "2839": "Kungliga Tekniska Hogskolan",
    "2840": "GSIX Stiftelsen Goteborgs Studentbostader",
    "2841": "CHALMERS Chalmers University of Technology",
    "2842": "Goteborgs universitet",
    "2843": "LIUNET Linkopings Universitet",
    "2844": "SUNET/NORDUnet",
    "2845": "Lunds Universitet",
    "2846": "Lunds Universitet",
    "2847": "LITNET Kaunas University of Technology",
    "2848": "MSU Federal State Educational Institution of Higher Professional Education M.V.Lomonosov Moscow State University",
    "2849": "Dublin-MAN",
    "2850": "UNIVERSITY-COLLEGE-DUBLIN University College Dublin",
    "2852": "CESNET2 CESNET z.s.p.o.",
    "2854": "ROSPRINT- LLC Equant",
    "2855": "BTRADIANZPARIS BT Public Internet Service",
    "2856": "BT-UK- BTnet UK Regional network",
    "2857": "RLP-NET Johannes Gutenberg-Universitaet Mainz",
    "2858": "EUnet Test",
    "2859": "RESILANS-LAB Resilans AB",
    "2860": "NOVIS Novis Telecom, S.A.",
    "2861": "Udo Steinegger",
    "2862": "MOL autonymous system",
    "2863": "SPRITELINK Centor AB",
    "2864": "Trafalgar House Engineering",
    "2865": "EVRY-ONE-NET EVRY One Nat Uppsala AB",
    "2866": "The JNT Association",
    "2867": "The JNT Association",
    "2868": "The JNT Association",
    "2869": "The JNT Association",
    "2870": "The JNT Association",
    "2871": "DOSTAL Tobias Dostal",
    "2872": "ODIN Informations Office",
    "2873": "UTVI-N The Internet Business Ltd",
    "2874": "ORANGE-BUSINESS-SERVICES-NORDICS Equant Inc.",
    "2875": "JINR- JINR/HEPNET",
    "2876": "TLD- TOP LEVEL DOMAIN SRL",
    "2877": "LSC- Latvian Shipping Company JSC",
    "2878": "ULRT- OJSC Rostelecom",
    "2879": "German-HEP-IP",
    "2880": "NIIT - National Information Infrastructure Testbed",
    "2881": "RHGC- - Rensselaer Hartford Graduate Center",
    "2882": "RSNG-PACBELL - Merit Network Inc.",
    "2883": "NAP-AADS - Merit Network Inc.",
    "2884": "NAP-THREE - RA-NAP",
    "2885": "NAP-MAEET - Merit Network Inc.",
    "2886": "EPO-TEST-0 - Almond Oil Process, LLC.",
    "2887": "RRM-N - Ford Motor Company",
    "2888": "MCI-AREA-1 - MCI",
    "2889": "MCI-AREA-2 - MCI",
    "2890": "MCI-AREA-3 - MCI",
    "2891": "MCI-AREA-4 - MCI",
    "2892": "MCI-AREA-5 - MCI",
    "2893": "CLI-NET - Computational Logic, Inc.",
    "2894": "CALIF-DWR - California Department of Water Resources",
    "2895": "FREE-NET- FREEnet",
    "2896": "ANGELVA - Angel.Com Incorporated",
    "2897": "GEORGIA-1 - Georgia Technology Authority",
    "2898": "GEORGIA-1S - Georgia Technology Authority",
    "2899": "SPRO-NET - SOLUTION PRO",
    "2900": "WN-AZ- - Arizona Tri University Network",
    "2901": "OGT- - Oso Grande Technologies, Inc.",
    "2902": "WN-WY- - University of Wyoming",
    "2903": "MORIC - Madison-Oneida BOCES",
    "2904": "Universidad Autonoma De Ciudad Juarez",
    "2905": "TICSA-N",
    "2906": "NETFLIX Netflix Streaming, Inc.",
    "2907": "SINET- Research Organization of Information and Systems, National Institute of Informatics",
    "2908": "CITI1 - Citicorp",
    "2909": "CITI2 - Citicorp",
    "2910": "CITI3 - Citicorp",
    "2911": "CITI4 - Citicorp",
    "2912": "CITI5 - Citicorp",
    "2913": "CITI6 - Citicorp",
    "2914": "NTT-COMMUNICATIONS-2914 - NTT America, Inc.",
    "2915": "ERX-SPIN-NET AT&T Jens Corporation",
    "2916": "CYBER- - Creative Cybernetics",
    "2917": "2917 France Telecom Orange Business Service",
    "2918": "ERCNET - ERC, Incorporated",
    "2919": "DIRECTV - Designed Information Systems Corporation",
    "2920": "LACOE - Los Angeles County Office of Education",
    "2921": "S-SDD Scandinavian Airlines Data Denmark Inc.",
    "2922": "CRSS - CRSS Architects",
    "2923": "-TIAA-NET - TIAA-CREF",
    "2924": "EQUIFAX-NS - Equifax, Inc.",
    "2925": "ERX-FIS Freightways Information Services Ltd.",
    "2926": "ERX-DB-2 Dominion Breweries Ltd.",
    "2927": "ZONE-NET1 - ZONE One Network Exchange",
    "2928": "COAT - Burlington Coat Factory Warehouse",
    "2929": "SUN-RM - Sun Company Inc.",
    "2930": "NCA- - Nat'l Academy of Sciences & Engineering",
    "2931": "BIS - Baird Information Systems",
    "2932": "NEDI-GIS - News Electronic Data, Inc.",
    "2933": "NETNODE - Real/Time Communications",
    "2934": "TXHLTH - Texas Department of State Health Services",
    "2935": "CDOLNET-GOV - Connecticut Department of Labor",
    "2936": "NERSC - National Energy Research Scientific Computing Center",
    "2937": "NERSC - National Energy Research Scientific Computing Center",
    "2938": "SPRINT-MRN - U.S. Sprint",
    "2939": "SCAROLINA- - State of South Carolina",
    "2940": "NET-UEN-UTAH - Utah Education Network",
    "2941": "ONEPA-DUFVA - OnePartner, LLC",
    "2942": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2943": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2944": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2945": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2946": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2947": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2948": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2949": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2950": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2951": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2952": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2953": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2954": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2955": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2956": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2957": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2958": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2959": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2960": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2961": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2962": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2963": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2964": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2965": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2966": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2967": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2968": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2969": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2970": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2971": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2972": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2973": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2974": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2975": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2976": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2977": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2978": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2979": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2980": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2981": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2982": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2983": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2984": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2985": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2986": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2987": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2988": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2989": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2990": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2991": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2992": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2993": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2994": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2995": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2996": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2997": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2998": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "2999": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3000": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3001": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3002": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3003": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3004": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3005": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3006": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3007": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3008": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3009": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3010": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3011": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3012": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3013": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3014": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3015": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3016": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3017": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3018": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3019": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3020": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3021": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3022": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3023": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3024": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3025": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3026": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3027": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3028": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3029": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3030": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3031": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3032": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3033": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3034": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3035": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3036": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3037": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3038": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3039": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3040": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3041": "SPRINT-MRN-BLOCK - U.S. Sprint",
    "3042": "LACHMAN-N - Lachman Technology, Inc.",
    "3043": "INTERNET-OPERATING-SERVICES - Amphibian Media Corporation",
    "3044": "SNAP-01 - Sesquinet",
    "3045": "SNAP-02 - Sesquinet",
    "3046": "SNAP-03 - Sesquinet",
    "3047": "SNAP-04 - Sesquinet",
    "3048": "SNAP-05 - Sesquinet",
    "3049": "SNAP-06 - Sesquinet",
    "3050": "SNAP-07 - Sesquinet",
    "3051": "SNAP-08 - Sesquinet",
    "3052": "SNAP-09 - Sesquinet",
    "3053": "SNAP-10 - Sesquinet",
    "3054": "FIRST-FLOOR - First Floor, Inc.",
    "3055": "SHL - SHL Systemhouse, Inc.",
    "3056": "AB-N - Allen-Bradley Company, Inc.",
    "3057": "3COM-BGPTEST - 3 Com Corp.",
    "3058": "R- Joint SuperComputer Center of the Russian Academy of Sciences",
    "3059": "IBMCAN - IBM Canada Network Services Company",
    "3060": "SC-YORKTECH - York Technical College",
    "3061": "PDNPVD-1 - ProvDotNet LLC",
    "3062": "CBIS-NET - Cincinnati Bell Information Systems",
    "3063": "TIS-BA-NET - Sparta, Inc.",
    "3064": "AFFINITY-FTL - Affinity Internet, Inc",
    "3065": "NYCENET- - NYCENET/Information Resources Unit",
    "3066": "RS- - Robert E. Seastrom",
    "3067": "DENINF-IPLAN",
    "3068": "DENINF-IVAN",
    "3069": "AINET-3069 - Advanced Information Technology Services, LLC",
    "3070": "AINET-3070 - Advanced Information Technology Services, LLC",
    "3071": "AINET-3071 - Advanced Information Technology Services, LLC",
    "3072": "AINET-3072 - Advanced Information Technology Services, LLC",
    "3073": "CITI7 - Citicorp",
    "3074": "CITI8 - Citicorp",
    "3075": "CITI9 - Citicorp",
    "3076": "CITI10 - Citicorp",
    "3077": "CITI11 - Citicorp",
    "3078": "CITI12 - Citicorp",
    "3079": "CITI13 - Citicorp",
    "3080": "CITI14 - Citicorp",
    "3081": "CITI15 - Citicorp",
    "3082": "ADVANTIS - Advantis",
    "3083": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3084": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3085": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3086": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3087": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3088": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3089": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3090": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3091": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3092": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3093": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3094": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3095": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3096": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3097": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3098": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3099": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3100": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3101": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3102": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3103": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3104": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3105": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3106": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3107": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3108": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3109": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3110": "HOLONET - Information Access Technologies, Inc.",
    "3111": "RESEARCH - Internet Direct, Inc.",
    "3112": "OARNET--1 - OARnet",
    "3113": "DOC-ESA-N - U.S. Dept. of Commerce",
    "3114": "DOJ-CRT-N - Department of Justice",
    "3115": "DSMNET - Infotex of Iowa",
    "3116": "PPCI - Point to Point Communications, Inc.",
    "3117": "TXMHMR - Texas Dept. of Mental Health & Mental Retardation",
    "3118": "N1 - Envision EMI, LLC",
    "3119": "DATAPOINT - Datapoint Corporation",
    "3120": "MAGIC-INTRNL - General Magic, Inc.",
    "3121": "MAGIC-INTRNL - General Magic, Inc.",
    "3122": "MAGIC-INTRNL - General Magic, Inc.",
    "3123": "MAGIC-INTRNL - General Magic, Inc.",
    "3124": "MAGIC-INTRNL - General Magic, Inc.",
    "3125": "MAGIC-INTRNL - General Magic, Inc.",
    "3126": "MAGIC-INTRNL - General Magic, Inc.",
    "3127": "CAPRICA- - Caprica Telecomputing Resources",
    "3128": "WISC1- - University of Wisconsin, Div. of Info. Tech",
    "3129": "WISC2- - University of Wisconsin-Madison",
    "3130": "RGNET-3130 RGnet/PSGnet",
    "3131": "DIALNET - The Dial Corp.- Consumer Products Group",
    "3132": "Red Cientifica Peruana",
    "3133": "HHS-PSC-ITIO - U.S. Dept. of Health and Human Services",
    "3134": "USAID-N - U.S. Agency for International Development",
    "3135": "MITC - Maryland Information Technology Center",
    "3136": "STATE-OF-WISCONSIN-1 - State of WI Dept. of Administration",
    "3137": "STATE-OF-WISCONSIN-2 - State of WI Dept. of Administration",
    "3138": "GSA-DDN - General Services Administration",
    "3139": "EE - American Society fro Engineering Education",
    "3140": "TJHSST- - The Thomas Jefferson High School for Science and Tech.",
    "3141": "Benemerita Universidad Autonoma de Puebla",
    "3142": "DORSAI - The Dorsai Embassy",
    "3143": "VANET - U.S. Department of Veterans Affairs",
    "3144": "PINNACLE - Pinnacle On-Line",
    "3145": "WESTPUB- - West Publishing Corporation",
    "3146": "DMSSC - Scientific Application International Corp. (SAIC)",
    "3147": "US-BANCORP - U.S. BANCORP",
    "3148": "WISC-CS - University of Wisconsin Madison",
    "3149": "SOSI- - Spectrum Online Systems Inc",
    "3150": "NTTA-3150 - NTT America, Inc.",
    "3151": "CEDEL-MRS Cedel",
    "3152": "FNAL- - Fermi National Accelerator Laboratory (Fermilab)",
    "3153": "FEMANET - Federal Emergency Management Agency",
    "3154": "The JNT Association",
    "3155": "The JNT Association",
    "3156": "The JNT Association",
    "3157": "The JNT Association",
    "3158": "The JNT Association",
    "3159": "The JNT Association",
    "3160": "LUMIUS Lumius, spol. s r.o.",
    "3161": "ITPROFI IT PROFI s.r.o.",
    "3163": "WWH World Wide Hosting Limited",
    "3164": "EXIMTUR- EXIMTUR SRL",
    "3165": "PTLANET- Przedsiebiorstwo Telekomunikacyjne LANET sp. z o.o.",
    "3166": "OREBRO Orebro Kommun",
    "3167": "INFOPRO CKIT InfoPro, Ltd.",
    "3168": "INTELECOMTV PE Dityatev Sergey Yurievich",
    "3169": "BRKNETWORKDEVICES Jacek Pasek BRK Network Devices",
    "3170": "GALATEA- Galatea FHU Dominik Budzowski",
    "3171": "NETHOUSE-SE Nethouse Sverige AB",
    "3172": "The JNT Association",
    "3173": "STANLEYWORKS-BE- Stanleyworks (Europe)GmbH",
    "3175": "MIG-LTD- MIG Ltd",
    "3176": "BDL Banque Du Liban",
    "3177": "VISPARAD-LLC Visparad Web Hosting Service LLC",
    "3178": "WIDETELECOM- WideTelecom Internet Services Ltd.",
    "3179": "AKVALIS- Akvalis Ltd.",
    "3180": "ROSENGINEERING- ROSENGINEERING CJSC",
    "3181": "N-MATRIXMOBILE CJSC \"Matrix Mobile\"",
    "3182": "EAB-CONTACT- Ekspertno analiticheskoe buerau Kontakt Ltd.",
    "3184": "ICO-WM24 ICO International GmbH",
    "3186": "INTERSUS- Interscholz Inc.",
    "3187": "BNPPF- BNP Paribas Personal Finance EAD",
    "3188": "ALTYR Alastyr Telekomunikasyon Internet Bilgisayar Hizmetleri Sanayi Ticaret Limited Sirketi",
    "3189": "ATLANTSTROY- Atlant-Stroy ltd.",
    "3190": "DREI-S- 3-S-IT Dienstleistungen GmbH",
    "3191": "CENTRINFORM- Federal State Unitary Enterprise CentrInform",
    "3192": "FREESTYLE- Freestyle Ltd.",
    "3194": "SATGATE-IRAQ SatGate Company for Trading of Computers Systems and Communications Appliances WLL",
    "3195": "FOURSE- Fourse Pishgam Company (private joint stock)",
    "3196": "CHRONOS- CHRONOS SERV INVEST CONSTRUCT SRL",
    "3197": "MOJENO- Ideh Pardazan Mojeno Ltd",
    "3198": "PARSUA Pirouz Sotoudeh Tehran Co. Private J.S.",
    "3199": "BAUMANN- A.+U. Baumann OHG",
    "3200": "NAVICON Navicon group Ltd.",
    "3201": "UMDCH- Umdasch AG",
    "3202": "DIGITALSCREENS TOV Digital Screens",
    "3203": "VIDEOKANAL PTO Videokanal, Ltd.",
    "3204": "SERVICELAN- LLC ServiceLan",
    "3205": "ON-CITY LLC Online-City",
    "3206": "AFB- AF Blakemore & Son Ltd",
    "3208": "ARN",
    "3209": "VODANET Vodafone GmbH",
    "3210": "SECURE-DATA- Secure Data Systems SRL",
    "3211": "Vodafone GmbH",
    "3212": "TRIERA TRIERA",
    "3213": "BOGONS-N Bogons Ltd",
    "3214": "Department of Computing,",
    "3215": "3215 Orange S.A.",
    "3216": "SOVAM- OJSC \"Vimpelcom\"",
    "3217": "SIMBIRSK-UL JSC ULTRAMARINE",
    "3218": "COSMOS-3218- Space Research Institute of Russian Academy of Sciences",
    "3219": "HU-GOVNET Ministry of Local Government and Regional Development",
    "3220": "INTERNET-TECHNOLOGY-ADVISORS Internet Technology Advisors Scandinavia Ab",
    "3221": "Hariduse Infotehnoloogia Sihtasutus",
    "3222": "CORENETFI Corenet Oy",
    "3223": "VOXILITY Voxility S.R.L.",
    "3224": "KTHNOC Kungliga Tekniska Hogskolan",
    "3225": "GULFNET-KUWAIT Gulfnet Kuwait",
    "3226": "MARK-ITT- OOO Izhevsk.NET",
    "3227": "Unassigned",
    "3228": "N-NETTUNO Tiscali Italia S.P.A.",
    "3229": "Internet Eireann Ltd.",
    "3230": "N-ESA ESA-ESRIN",
    "3231": "INFORIS- INFORIS Network",
    "3232": "DRA-EXT-",
    "3233": "RNC RNC",
    "3234": "Parliament of CR",
    "3235": "GOLDENISP- OJSC \"Vimpelcom\"",
    "3236": "GEC Plessey Semiconductors",
    "3237": "MANDR10- M & R 10 EOOD.",
    "3238": "ALCOM Alands Datakommunikation Ab",
    "3239": "RU-SURNET OJSC Rostelecom",
    "3240": "SEKTORNET Sektornet, DK Ministry of Education",
    "3241": "Smith New Court Securities Ltd",
    "3242": "N-ITNET ITnet S.r.l.",
    "3243": "TELEPAC PT Comunicacoes S.A.",
    "3244": "BANKNET 3c. Kft.",
    "3245": "DIGSYS- Digital Systems Ltd",
    "3246": "TDCSONG TDC Finland",
    "3247": "INS INS GmbH",
    "3248": "SIL-AT Tele2 Telecommunication GmbH",
    "3249": "ESTPAK Elion Enterprises Ltd.",
    "3250": "NETMANAGE",
    "3251": "Centro de Calculo da Faculdade de Ciencias de Lisboa",
    "3252": "UA-TS- Scientific -Industrial Firm \"Volz\" Ltd",
    "3253": "OJSC \"Vimpelcom\"",
    "3254": "LNUA LN.UA Ltd.",
    "3255": "UARNET- State Enterprise Scientific and Telecommunication Centre \"Ukrainian Academic and Research Network\" of the Institute for Condensed Matter Physics of the National Academy of Science of Ukraine (UARNet)",
    "3256": "SFINX (Service of French Internet Exchange)",
    "3257": "TINET-BACKBONE Tinet SpA",
    "3258": "MCLAUT-SMELA LLC \"McLaut-Invest\"",
    "3259": "EXPERIAN DOCAPOST BPO S",
    "3260": "INTRACOM INTRACOM S.A. TELECOM SOLUTIONS",
    "3261": "DIPT- LLC \"FTICOM\"",
    "3262": "SARENET SAREnet,S.A.",
    "3263": "TELEBIT Tieto A/S",
    "3264": "AUBG- American University in Bulgaria",
    "3265": "XS4ALL-NL XS4ALL Internet BV",
    "3266": "Roke Manor Research",
    "3267": "RUNNET State Institute of Information Technologies and",
    "3268": "CYNET",
    "3269": "N-IBSNAZ Telecom Italia S.p.a.",
    "3270": "HHR",
    "3271": "SAP-AG Walldorf",
    "3272": "FUJITSU-DK",
    "3273": "Xarxa Cinet, S.A.",
    "3274": "CYGATE Cygate Oy",
    "3275": "N-CINECA CINECA CONSORZIO INTERUNIVERSITARIO",
    "3276": "MTER-NET",
    "3277": "RUSNET- \"NPO RUSnet\"",
    "3278": "SEW SEW-EURODRIVE GmbH & Co KG",
    "3279": "Algonet AB",
    "3286": "IOL BT Communications Ireland Limited",
    "3287": "REDLINE- REDLINE",
    "3288": "MOFET- Mofet Institute",
    "3289": "MIDOCAR- MIDOCAR SRL",
    "3290": "TVS- Tekniikka",
    "3291": "PSINET-EUROPE PSINet Europe / VIA NET.WORKS international",
    "3292": "TDC TDC Data Networks",
    "3294": "ITEREU ITER Garching",
    "3295": "Societe Generale",
    "3296": "SOCIETE-GENERALE Societe Generale",
    "3297": "Societe Generale",
    "3298": "Societe Generale",
    "3299": "Societe Generale",
    "3300": "BT-INFONET-EUROPE British Telecommunications plc",
    "3301": "TELIANET-SWEDEN TeliaSonera AB",
    "3302": "INFRACOM-NETWORK-APPLICATION- Infracom Italia S.p.A.",
    "3303": "SWISSCOM Swisscom (Switzerland) Ltd",
    "3304": "SCARLET Scarlet",
    "3305": "Societe Francaise du Radiotelephone S.A.",
    "3306": "ATT-Unisource Internet Service DE",
    "3307": "BANETELE-NORWAY Ventelo Networks (formerly BaneTele ), Norway",
    "3308": "TELIANET-DENMARK TeliaSonera AB",
    "3309": "TELIANET-IPV6 TeliaNet IPv6",
    "3310": "BT-INFONET-EUROPE British Telecommunications plc",
    "3311": "ESI",
    "3312": "ELEKTRA- Elektra network",
    "3313": "INET- BT Italia S.p.A.",
    "3314": "KFKI- MTA Wigner Fizikai Kutatokozpont",
    "3315": "Association of scientific and educational organizations-computer networks users \"RELARN\"",
    "3316": "RELARN Association of scientific and educational organizations-computer networks users \"RELARN\"",
    "3317": "Universiteit van Amsterdam",
    "3318": "Power System of Sverdlovsk Region",
    "3319": "KSNET Association of users of Ukrainian Research & Academic",
    "3320": "DTAG Deutsche Telekom AG",
    "3321": "MACH-APS MACH Aps",
    "3323": "NTUA National Technical University of Athens",
    "3324": "3324_FUJITSU_SPAIN FUJITSU TECHNOLOGY SOLUTIONS, S.A.",
    "3325": "KSU Kazan University",
    "3326": "VOSTOK-UA PrivateJSC DataGroup",
    "3327": "LINXTELECOM Linxtelecom",
    "3329": "Hellas OnLine Electronic Communications S.A.",
    "3330": "PROFINET-AT OEBB Telekom Service GmbH",
    "3331": "-EURO-BB",
    "3332": "HANSA- Swedbank",
    "3333": "RIPE-NCC- Reseaux IP Europeens Network Coordination Centre (RIPE NCC)",
    "3334": "VTX-NETWORK VTX Services SA",
    "3335": "NSU- Federal State Educational Institution of Higher Professional Education \"Novosibirsk State University, National Research\"",
    "3336": "ELISA- Elisa Oyj",
    "3338": "HUNGARNET-SZTAKI MTA SZTAKI",
    "3339": "TELEELDA- Tele Elda, S.A",
    "3340": "GTS-HUNGARY- GTS Hungary Telecommunications Limited Liability Company",
    "3343": "RUNNET- State Institute of Information Technologies and Telecommunications (SIIT&T \"Informika\")",
    "3344": "BURSTFIRE Burstfire Networks Limited",
    "3345": "VOL-ITALY Telecom Italia Spa",
    "3347": "CETREL-LU-1 CETREL S.A.",
    "3348": "Catalan Foundation for the Research",
    "3349": "PVT, Ltd.",
    "3350": "Particle Physics Department",
    "3351": "IOFFE-PHYSICAL-THECHICAL-INSTITUTE- Ioffe Physical-Technical Institute of the Russian Academy of Sciences",
    "3352": "TELEFONICA-DATA-ESPANA TELEFONICA DE ESPANA",
    "3353": "N-PHONELINK  # -PHONELINK CONVERTED TO N-PHONELINK FOR RPSL COMPLIANCE Phonelink Ltd",
    "3354": "THENET--3354 - University of Texas System",
    "3355": "LITC - LOCKHEED INFORMATION TECHNOLOGY COMPANY",
    "3356": "LEVEL3 Level 3 Communications",
    "3357": "DJEDU--KR DongJak District office of Education",
    "3358": "UCIA- - Central Intelligence Agency",
    "3359": "U-ALBERTA - University of Alberta",
    "3360": "CSC-N - Computer Sciences Corporation",
    "3361": "DF-TUKWILA01 - Digital Fortress, Inc.",
    "3362": "GROUP-NAMES - Data Transfer Group",
    "3363": "HKUST--HK Hong Kong University of Science and Technology",
    "3364": "CSDCO- - Computer Systems Design Company",
    "3365": "MCSNET - Macro Computer Solutions, Inc.",
    "3366": "A2I-WEST - a2i communications",
    "3368": "DATAPOINTINC-3368 - DataPoint",
    "3369": "MCI-N - MCI",
    "3370": "MCI-N - MCI",
    "3371": "MCI-N - MCI",
    "3372": "MCI-N - MCI",
    "3373": "MCI-N - MCI",
    "3374": "MCI-N - MCI",
    "3375": "MCI-N - MCI",
    "3376": "MCI-N - MCI",
    "3377": "MCI-N - MCI",
    "3378": "MCI-N - MCI",
    "3379": "KAISER-NCAL - Kaiser Foundation Health Plan",
    "3380": "PPPL-1 - Princeton Plasma Physics Laboratory",
    "3381": "MHPCC- - Maui High Performance Computing Center",
    "3382": "ERX-JUITA-UINET University of Indonesia",
    "3383": "REDBRICK-HQ - Red Brick Systems",
    "3384": "CELT - Center for Educational Leadership and Technology",
    "3385": "BROADVIEWNET--3385 - Broadview Networks, Inc.",
    "3386": "USNET- - US Net Incorporated",
    "3387": "USIA - US Information Agency/USIA Computer Center",
    "3388": "UNM- - University of New Mexico",
    "3389": "FORDSRL- - Ford Motor Company",
    "3390": "UMKCNET - University of Missouri - Kansas City",
    "3391": "ERX-CII-NET CIInet Corporation",
    "3392": "GMTI-ORF - GANNETT MEDIA TECHNOLOGIES INTERNATIONAL",
    "3393": "NDEX - National Default Exchange Holdings, LP",
    "3394": "ELPRESS- - Electric Press, Inc.",
    "3395": "ERX-HUMAN-HEALTH Commonwealth Department of Human Services and Health",
    "3396": "EGG - T G & A",
    "3397": "DAVINCI - Davinci Broadband Inc.",
    "3398": "SAND-NET - Sun Users Group Metro San Diego Network Coop",
    "3399": "ITSKR - Keith Alan Rodwell",
    "3400": "POWERDOG - Powerdog Industries",
    "3401": "SEATTLE - City of Seattle, Dept. of Admin. Services",
    "3403": "TIAC - The Internet Access Co.",
    "3404": "COLORADOCOOP - Colorado Internet Cooperative Association",
    "3405": "QNSNET - Questar Information Systems, Inc.",
    "3406": "UUN - UUN",
    "3407": "INTERPATH-NC - Interpath",
    "3408": "AMC-NETWORKS - Rainbow Media Holdings LLC",
    "3409": "CALLVOX - Callvox LLC",
    "3410": "CORNELLCOLLEGE - Cornell College",
    "3411": "SMH-N - St. Michael's Hospital",
    "3412": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3413": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3414": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3415": "CREDITSUISSEGROUP- Credit Suisse Group",
    "3416": "DNIC--03416 - DoD Network Information Center",
    "3417": "DNIC--03417 - DoD Network Information Center",
    "3418": "DNIC--03418 - DoD Network Information Center",
    "3419": "DNIC--03419 - DoD Network Information Center",
    "3420": "ATTIS-N3420 - AT&T Internet Services",
    "3421": "ATTIS-N3421 - AT&T Internet Services",
    "3422": "ATTIS-N3422 - AT&T Internet Services",
    "3423": "ATTIS-N3423 - AT&T Internet Services",
    "3424": "HFMT - Honeywell FM&T",
    "3425": "ESNET- - ESnet",
    "3426": "ESNET- - ESnet",
    "3427": "ESNET- - ESnet",
    "3428": "ESNET- - ESnet",
    "3429": "ESNET- - ESnet",
    "3430": "ESNET- - ESnet",
    "3431": "ESNET- - ESnet",
    "3432": "ESNET- - ESnet",
    "3433": "ESNET- - ESnet",
    "3434": "ESNET- - ESnet",
    "3435": "ESNET- - ESnet",
    "3436": "ESNET- - ESnet",
    "3437": "ESNET- - ESnet",
    "3438": "ESNET- - ESnet",
    "3439": "ESNET- - ESnet",
    "3440": "ESNET- - ESnet",
    "3441": "ESNET- - ESnet",
    "3442": "ESNET- - ESnet",
    "3443": "ESNET- - ESnet",
    "3444": "ESNET- - ESnet",
    "3445": "ESNET-APNIC-TELESCOPE- - ESnet",
    "3446": "KANS - State of Kansas",
    "3447": "EMBARQ-CMDS - Embarq Corporation",
    "3448": "AWS- - AT&T Wireless Services",
    "3449": "Universidad Nacional de Buenos Aires",
    "3450": "UTK - The University of Tennessee Health Science Center",
    "3451": "DTD- - Downtown Digital",
    "3452": "UAB- - University of Alabama at Birmingham",
    "3453": "COMMNET - Board of Trustees of Community-Technical College",
    "3454": "Universidad Autonoma de Nuevo Leon",
    "3455": "WAUSAU-INS - Liberty Mutual Group",
    "3456": "TW-CABLE - Time Warner Cable",
    "3457": "ORACLE-4 - Oracle Corporation",
    "3458": "VWNA- - Volkswagen of America, Inc.",
    "3459": "STBTC---SOUTH-TEX-BLOOD-AND-TISSUE-CENTER - South Texas Blood and Tissue Center",
    "3460": "ERX-HEPC- Institute of High Energy Physics",
    "3461": "GONZAGA-N - Gonzaga College High School",
    "3462": "HINET Data Communication Business Group",
    "3463": "LOGIN-NONAZ - Login, Inc.",
    "3464": "C-NET - Alabama Supercomputer Network",
    "3465": "JBHUNT - J. B. Hunt Transport Inc.",
    "3466": "DNIC--3466 - DoD Network Information Center",
    "3467": "DNIC--03467 - DoD Network Information Center",
    "3468": "DNIC--03468 - DoD Network Information Center",
    "3469": "DNIC--03469 - DoD Network Information Center",
    "3470": "DNIC--03470 - DoD Network Information Center",
    "3471": "DNIC--03471 - DoD Network Information Center",
    "3472": "DNIC--03472 - DoD Network Information Center",
    "3473": "DNIC--03473 - DoD Network Information Center",
    "3474": "DNIC--03474 - DoD Network Information Center",
    "3475": "DNIC--03475 - Navy Network Information Center (NNIC)",
    "3476": "JIEO-ITSI-BB - LOGICON",
    "3477": "NOAA-BOULDER - NOAA-Boulder",
    "3478": "IGC-BACKBONE - State of Indiana",
    "3479": "PEACHNET-1 - Kennesaw State University",
    "3480": "PEACHNET-2 - Kennesaw State University",
    "3481": "STOFCT-DOIT - State of Connecticut",
    "3482": "MTSTGOV - State of Montana",
    "3483": "RECKITT-MRS - Sprint International",
    "3484": "Instituto Politecnico Nacional",
    "3485": "FCMCNET - Fuji Capital Markets Corporation",
    "3486": "JMC- - JPMorgan Chase & Co.",
    "3487": "Lagoven S.A., Telecommunication Engineering",
    "3488": "JAXANET Information Systems Department, Japan Aerospace Exploration Agency",
    "3489": "UNIFYNET - Unify Corporation",
    "3490": "CDINET - Communications Development, Inc.",
    "3491": "BTN-N - Beyond The Network America, Inc.",
    "3492": "ATLANTA - Mese Software / Internet Atlanta",
    "3493": "INTERLINK - Metrix Interlink Inc.",
    "3494": "INS-COM - INTERNATIONAL NETWORK SERVICES",
    "3495": "SENATE- - US Senate",
    "3496": "Maraven",
    "3497": "NET-DPA-CA-GOV - California Department of Personnel Administration",
    "3498": "NET-SEN-CA-GOV - California State Senate",
    "3499": "NET-DMV-CA-GOV - State of California Department of Motor Vehicles",
    "3500": "BLACK-STAR - Black Star Publishing Co. Inc.",
    "3501": "ES-USDA - Extension Service, USDA",
    "3502": "INTNET - Intelligence Network Online, Inc.",
    "3503": "SMSNET - Software Maintenance Specialists, Inc.",
    "3504": "MWDSOCA - Metropolitan Water District of Southern California",
    "3505": "WINDSTREAM - Windstream Communications Inc",
    "3506": "FSU-SCRI - Florida State University",
    "3507": "CAPSOC- - Capehart Associates",
    "3508": "TW-COMM - tw telecom holdings, inc.",
    "3509": "NET-CALPUC - California Public Utilities Commission",
    "3510": "ERX-RWC-NET Real World Computing Partnership",
    "3511": "INFONET - INFONET",
    "3512": "EUSHC - Emory University",
    "3513": "INET-ON-RAMP - Internet On-Ramp, Inc.",
    "3514": "INS-INFOSERVICES - netINS, Inc.",
    "3515": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3516": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3517": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3518": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3519": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3520": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3521": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3522": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3523": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3524": "DSI-WR - Bolt Beranek and Newman Inc.",
    "3525": "ALBERTSONS - Albertson's Inc.",
    "3526": "SCCS1 - South Coast Computing Services, Inc.",
    "3527": "NIH-NET - National Institutes of Health",
    "3528": "DNIC--03528 - DoD Network Information Center",
    "3529": "DNIC--03529 - DoD Network Information Center",
    "3530": "DNIC--03530 - DoD Network Information Center",
    "3531": "DNIC--03531 - DoD Network Information Center",
    "3532": "DNIC--03532 - DoD Network Information Center",
    "3533": "DNIC--03533 - DoD Network Information Center",
    "3534": "DNIC--03534 - DoD Network Information Center",
    "3535": "DNIC--03535 - DoD Network Information Center",
    "3536": "DNIC--03536 - DoD Network Information Center",
    "3537": "DNIC--03537 - DoD Network Information Center",
    "3538": "DNIC--03538 - DoD Network Information Center",
    "3539": "DNIC--03539 - DoD Network Information Center",
    "3540": "DNIC--03540 - DoD Network Information Center",
    "3541": "DNIC--03541 - DoD Network Information Center",
    "3542": "DNIC--03542 - DoD Network Information Center",
    "3543": "DNIC--03543 - DoD Network Information Center",
    "3544": "DNIC--03544 - DoD Network Information Center",
    "3545": "DNIC--03545 - DoD Network Information Center",
    "3546": "DNIC--03546 - DoD Network Information Center",
    "3547": "DNIC--03547 - DoD Network Information Center",
    "3548": "Centro de Investigacion y de EstudiosAvanzados del",
    "3549": "GBLX Global Crossing Ltd.",
    "3550": "ERX-PHILNET Ateneo de Manila University",
    "3551": "Universidad Tecnologica de Panama",
    "3552": "UMI-2 - UMI",
    "3553": "COVANET - Commonwealth of Virginia",
    "3554": "HALW - Holland America Line",
    "3555": "GRCI-WAN - GRC International, Inc.",
    "3556": "Intevep S.A.",
    "3557": "ISC-F-ROOT Internet Systems Consortium, Inc.",
    "3558": "ERX-MRWA Main Roads Western Australia",
    "3559": "KORNET--KR Korea Telecom",
    "3560": "GDS - Technetix, Inc.",
    "3561": "SAVVIS- SAVVIS-3561",
    "3562": "SNLL-NET- - Sandia National Laboratories",
    "3563": "PILOT-N - Pilot Network Services, Inc",
    "3564": "PENTELEDATA-1 - PenTeleData Inc.",
    "3565": "GHS-N - Greenville Hospital System",
    "3566": "JRIVER-LINK - James River Group, Inc.",
    "3567": "AGATE - Agate, Inc.",
    "3568": "WAIS- - WAIS, Inc.",
    "3569": "ANDERSEN - Andersen Worldwide S.C.",
    "3570": "FMC-1 - FMC Corporation",
    "3571": "EY- - Ernst & Young LLP",
    "3572": "TEX-TYC - Texas Youth Commission",
    "3573": "ACCENTURE-3573 Accenture CIO",
    "3574": "ICTV-NET - ICTV, Inc.",
    "3575": "SEANET-N - Seanet, Inc.",
    "3576": "-HODGSON-RUSS-NET - Hodgson Russ LLP",
    "3577": "N-VESTAMERIC - Vestas American Wind Technology",
    "3578": "MV-1 - MV Communications, Inc.",
    "3579": "DATABANK - Databank, Inc.",
    "3580": "ACCESSCOOP - Planet Access Networks",
    "3581": "OBS-NET - Open Business Systems Inc.",
    "3582": "UONET - University of Oregon",
    "3583": "ERX-IPTEK-N BPP Teknologi Networks Manager",
    "3584": "PUBNIX2-N - PubNIX, Inc.",
    "3585": "3585 - Tyco Electronics Corporation",
    "3586": "UWI N-UWI",
    "3587": "TWA - American Airlines Incorporated",
    "3588": "EVERGREEN- - Evergreen Internet Express",
    "3589": "DIALCORP - The Dial Corp",
    "3590": "C-TEC - COMMONWEALTH TELEPHONE CO.",
    "3591": "EMORY - Emory University",
    "3592": "TRINCOLL- - Trinity College",
    "3593": "FRONTIER-EPIX - Frontier Communications of America, Inc.",
    "3594": "RAIN1 - RAIN",
    "3595": "GNAXNET- - Global Net Access, LLC",
    "3596": "Universidad Autonoma Metropolitana",
    "3597": "Fundaci\u00f3n InnovaT",
    "3598": "MICROSOFT-CORP- - Microsoft Corporation",
    "3599": "BINCNET - CDW Technologies Inc.",
    "3600": "SUNNET- - Sun Networks, Inc.",
    "3601": "MOUATS Mouat's Technology Services, Inc.",
    "3602": "3602-RTI - Rogers Cable Communications Inc.",
    "3603": "University de Los Andes",
    "3604": "CPBX - Linder Computer Enterprises",
    "3605": "ERX-KUENTOS- Guam Cablevision, LLC.",
    "3606": "CONNCOLL- - Connecticut College",
    "3607": "HPES - Hewlett-Packard Company",
    "3608": "KIX--KR National Computerization Agency",
    "3609": "CYBER-NET - Cyberstore Systems Inc.",
    "3610": "MHV-NET - Computer Solutions by Hawkinson",
    "3611": "PIC - NETCOM Interactive",
    "3612": "DELL-BLK - Dell, Inc.",
    "3613": "DELL-BLK - Dell, Inc.",
    "3614": "DELL-BLK - Dell, Inc.",
    "3615": "DELL-BLK - Dell, Inc.",
    "3616": "IP-NET- - Internet Presence & Publishing",
    "3617": "MCIN-BLK - MCI Telecommunications",
    "3618": "MCIN-BLK - MCI Telecommunications",
    "3619": "MCIN-BLK - MCI Telecommunications",
    "3620": "MCIN-BLK - MCI Telecommunications",
    "3621": "MCIN-BLK - MCI Telecommunications",
    "3622": "MCIN-BLK - MCI Telecommunications",
    "3623": "MCIN-BLK - MCI Telecommunications",
    "3624": "BT-IGNITE-EU temp unassigned",
    "3625": "MCIN-2-BLK - MCI Telecommunications",
    "3626": "MCIN-2-BLK - MCI Telecommunications",
    "3627": "NRAO-VLBA - National Radio Astronomy Observatory (NRAO)",
    "3628": "NYSERNET-BLK - NYSERNet",
    "3629": "NYSERNET-BLK - NYSERNet",
    "3630": "NYSERNET-BLK - NYSERNet",
    "3631": "Ministry of Foreign Affairs",
    "3632": "Consejo Nacional de Ciencia y Tenologia (CONACYT)",
    "3633": "PROVINCE-OF-BRITISH-COLUMBIA - Province of British Columbia",
    "3634": "SFU- - Stephen F. Austin State University",
    "3635": "BEA - US Department of Commerce, Bureau of Economic Analysis",
    "3636": "Corpoven S.A.",
    "3637": "N-NWNEXUS2 - Northwest Nexus Inc.",
    "3638": "GLOBALI - Shaman Exchange, Inc.",
    "3639": "-BIZNET - Mystic Valley Communications",
    "3640": "CICESE",
    "3641": "ZITO-NETWORKS - Zito Networks",
    "3642": "GSA-PAN-DDN - GSA Data Communications and Networking Branch",
    "3643": "SL-AUSTRALIA - Sprint",
    "3644": "SPR-VPN - Sprint",
    "3645": "SPR-LOCAL-SIN - Sprint",
    "3646": "SPRINT-LON2-EA - Sprint",
    "3647": "SPRINT-BB2 - Sprint",
    "3648": "SPRINT-BB3 - Sprint",
    "3649": "SPRINT-BB4 - Sprint",
    "3650": "SPRINT-BB5 - Sprint",
    "3651": "SPRINT-BB6 - Sprint",
    "3652": "SPRINT-BB7 - Sprint",
    "3653": "SKYMALL - SKYMALL, INC.",
    "3654": "AMSTD-NET - American Standard",
    "3655": "GE-IPS - General Electric Company",
    "3656": "CITYPHX1 - City of Phoenix",
    "3657": "TSS-NET - TSS Systems Corporation",
    "3658": "LIGHTLINK - Lightning PC",
    "3659": "CLAREMONT - Claremont University Consortium",
    "3660": "BPC-N - Berry Plastics Corporation",
    "3661": "ERX-CUHKNET The Chinese University of Hong Kong",
    "3662": "HARNET Joint Universities Computer Centre Limited",
    "3663": "NETNET-NET - NetNet",
    "3664": "DNIC-BLK-03664-03667 - DoD Network Information Center",
    "3665": "DNIC-BLK-03664-03667 - DoD Network Information Center",
    "3666": "DNIC-BLK-03664-03667 - DoD Network Information Center",
    "3667": "DNIC-BLK-03664-03667 - DoD Network Information Center",
    "3668": "GNP-DCN - AT&T Network Systems",
    "3669": "IQUEST - Small Systems Specialists",
    "3670": "OPTIMUM- - Optimum Group",
    "3671": "SLAC - SLAC National Accelerator Laboratory",
    "3672": "PRIMUS-3672 - Primus Telecommunications Canada Inc.",
    "3673": "SYNERGYNET - Synergy Commincations, Inc.",
    "3674": "RCN-6 - RCN",
    "3675": "IS-NET - Internet Services of Atlanta",
    "3676": "UIOWA- - University of Iowa",
    "3677": "UIOWA-EXTERNAL - University of Iowa",
    "3678": "GLOBAL-N - Global Vision Inc.",
    "3679": "SKYPOINT-NET - Skypoint Communications, Inc.",
    "3680": "NOVELL - Novell, Inc.",
    "3681": "FIU - Florida International University",
    "3682": "RACIN - CRACIN",
    "3683": "AMERICAN-NET - American Network",
    "3684": "DDI - Digital Decisions, Inc.",
    "3685": "BUFFALO-N - University of Buffalo",
    "3686": "BBSSYS-N - Innovative Logic Corp",
    "3687": "GLOBALCOM-1 - Globalcom",
    "3688": "HSS-1 - Hospital for Special Surgery",
    "3689": "CITICTEL-CPC-3689 CITIC Telecom International CPC Limited",
    "3690": "CITICTEL-CPC-3690 CITIC Telecom International CPC Limited",
    "3691": "CITICTEL-CPC-3691 CITIC Telecom International CPC Limited",
    "3692": "CITICTEL-CPC-3692 CITIC Telecom International CPC Limited",
    "3693": "CITICTEL-CPC-3693 CITIC Telecom International CPC Limited",
    "3694": "NOAA-SUITLAND - NOAA-NIC/NESDIS",
    "3695": "SPM-TELECOM-1 - SPM TELECOM",
    "3696": "DNIC--03696 - DoD Network Information Center",
    "3697": "FOXMEYER - FoxMeyer Corporation",
    "3698": "CPCNET CPCNet",
    "3699": "SENSE - Sense Networking",
    "3700": "CLOUD9 - Cloud 9 Internet, Inc.",
    "3701": "NERONET - Oregon Joint Graduate Schools of Engineering",
    "3702": "ICSI-NET - Internet Connect Services, Inc.",
    "3703": "EARTHLINK - EARTHLINK, Inc.",
    "3704": "LVEGNET- - LasVegas.Net LLC",
    "3705": "GPO-NET - U.S. Government Printing Office",
    "3706": "DIGEX-2 - Digital Express Group, Inc.",
    "3707": "DIGEX3707 - MCI Communications Services, Inc. d/b/a Verizon Business",
    "3709": "NET-CITY-SA - City of San Antonio",
    "3710": "REALM- - Realm Corporation",
    "3711": "ERX-ISIS-NZ-0 ISIS International (NZ) Ltd.",
    "3712": "CHE-US - Chase Research, Inc.",
    "3713": "ICFKAISER - ICF Kaiser International, Inc.",
    "3714": "KEC-NET - Kentucky Educational Computing Network",
    "3715": "THEBOE-3715 - The Boeing Company",
    "3716": "DATAWAVE - Datawave Network Services",
    "3717": "ERX-BUCT-NET Beijing University of Chemical Technology",
    "3718": "TCD-CONNECT - The Computer Den, Inc.",
    "3719": "CT-JIS - State of Connecticut Judicial Branch",
    "3720": "TIMS- - The Internet Mainstreet, Inc.",
    "3721": "N-MIKUNI - Mikuni Berkeley R&D Corp.",
    "3722": "TQ-DALL - Tranquil Hosting, Inc.",
    "3723": "ELECPRESS- - Electronic Press",
    "3724": "ALKA-ANET - State of Alaska",
    "3725": "N-SONY - Sony Corporation of America",
    "3726": "JCALS-NET - CSC- JCALS",
    "3727": "SHRUBB - Shrubbery Networks",
    "3728": "ONR-ADDR - Onramp Access Inc.",
    "3729": "DELL-NETPLEX- - Dell, Inc.",
    "3730": "AQUINA-001 - Aquinas College",
    "3731": "AFNCA-N - AFNCA Inc.",
    "3732": "CVCORP - Computervision Corp.",
    "3733": "LEVENFELD - Levenfeld Pearlstein, LLC",
    "3734": "SCCO - Santa Clara County Office of Education",
    "3735": "CONNECTION - Connection Technologies",
    "3736": "RABBITNET - The Rabbit Network, Inc.",
    "3737": "PTD- - PenTeleData Inc.",
    "3738": "SSB-N - State Street Bank and Trust Company",
    "3739": "SLPO - Smart Link Project Office",
    "3740": "CHICAGO-REN - University of Chicago",
    "3741": "IS",
    "3742": "SEMAPHORE-1 - Semaphore Corporation",
    "3743": "ARCEL-2 - ARCELORMITTAL USA INC.",
    "3744": "CAN-NET - Consolidated Access & Networks, Inc.",
    "3745": "VOLKSWAGEN Volkswagen AG, Wolfsburg 1",
    "3746": "IPAC-WORLD - Internet Public Access Corporation",
    "3747": "ERX-WANG-1 Wang NZ Ltd",
    "3748": "ETRI--KR Electronics and Telecommunications Research Institute",
    "3749": "TECNET - Tennessee Board Of Regents",
    "3750": "NETPOINT1-NET - Net Point LLC",
    "3751": "PHONAK-LLC - Phonak, LLC",
    "3752": "ELIZA-NETAXIS - Net Axis",
    "3753": "NSCEE - National Supercomputing Center for Energy and the Environment",
    "3754": "NYSERNET3- - NYSERNet",
    "3755": "NYSERNET3- - NYSERNet",
    "3756": "NYSERNET3- - NYSERNet",
    "3757": "TRAN--KR Korea Telecom",
    "3758": "ERX-SINGNET SingNet",
    "3759": "CALTEX- - Caltex",
    "3760": "TX-DEPT-AGR - Texas Department of Agriculture",
    "3761": "COOLIRIS - Cooliris, Inc.",
    "3762": "INSINET INSTINET GLOBAL SERVICES",
    "3763": "LINEARTECH-INC - LINEAR TECHNOLOGIES INC.",
    "3764": "IA-HOU- - Internet America, Inc.",
    "3765": "DNDCFNET1 - Department of National Defence/DISEM",
    "3766": "DNDCFNET2 - Department of National Defence/DISEM",
    "3767": "SOSCORP- - SOS Corp.",
    "3768": "DIALOG- - PROQUEST LLC",
    "3769": "HEARST- - Hearst Magazines, Inc.",
    "3770": "WORLDPATH- - WorldPath Internet Services",
    "3771": "SPERRY- - Sperry",
    "3772": "CETYS- - CETYS - Centro de Ensenanza Tecnica Y Superior",
    "3773": "ERX-TGE-1 TGE",
    "3774": "SECARDNEON - Security Card Systems, Inc.",
    "3775": "ERX-IBMAP-MPN Global Network Solutions, IBM Japan, Ltd.",
    "3776": "ALOHANET - Hawaii Online",
    "3777": "HAVERFORD - Haverford College",
    "3778": "TEMPLE - Temple University",
    "3779": "CRISIS-WORLD - Crisis Computer Corporation",
    "3780": "N-ADVANTIS2 - Advantis",
    "3781": "USBM-PGH - US Bureau of Mines",
    "3782": "SWARTHMORE - Swarthmore College",
    "3783": "AIU-GATEWAY - Allegheny Intermediate Unit",
    "3784": "ERX-POSTECHNET Pohang University of Science and Technology",
    "3785": "N1 - Dr. Leonard's Healthcare Corp.",
    "3786": "LGDACOM LG DACOM Corporation",
    "3787": "ERX-MOBILE-1 Telecom Mobile Communications Ltd.",
    "3788": "TEX-DOT - Texas Department of Transportation",
    "3789": "VRMC- - Virginia Regional Medical Center",
    "3790": "RADIOGRAFICA COSTARRICENSE",
    "3791": "VCHS- - Via Christi Health System, Inc.",
    "3792": "CIS2 - CIS Corporation",
    "3793": "TIC - The Internet Connection",
    "3794": "TAMU - Texas A&M University",
    "3795": "BRYNMAWR - Bryn Mawr College",
    "3796": "OUTERNET - OuterNet Connection Strategies, Inc.",
    "3797": "METYS-VNET - Metasys, Inc.",
    "3798": "LAW-SERVICES - Law School Admission Council, Inc.",
    "3799": "IDS - InteleCom Data Systems, Inc,",
    "3800": "IONITY - Ionity Corporation",
    "3801": "MISNET - Mikrotec Internet Services",
    "3802": "LGHS - Luthern General Health System",
    "3803": "RCN-1 - RCN",
    "3804": "WORLDLINX - WorldLinx Telecommunications, Inc.",
    "3805": "N-LAMB - Lamb & Company Inc.",
    "3806": "SCOOP - School Cooperative Network (Scoopnet)",
    "3807": "UMTNET-N - University of Montana",
    "3808": "CYBERGATE- - Cybergate Information Services",
    "3809": "NWCORP1 - Norwest Services, Inc.",
    "3810": "VWMX- - Volkswagen of America, Inc.",
    "3811": "INTAC- - INTAC Access Corporation",
    "3812": "LTVI - Look Communications Inc.",
    "3813": "SOGANG--KR sogang university",
    "3814": "IMS-INTERCOM - IMS Intercom",
    "3815": "AQUILA - Aquila BBS Inc.",
    "3816": "COLOMBIA TELECOMUNICACIONES S.A. ESP",
    "3817": "FREESIDE-NET - Freeside Communications, Inc.",
    "3818": "STEP2- - Step2 Software Inc.",
    "3819": "ABC-LEGAL - ABC Legal Services",
    "3820": "ACP - American Center for Physics",
    "3821": "ABLECOM - Able Technical Services",
    "3822": "ITSNET - Internet Technology Systems",
    "3823": "CIMTG - CIMtegration Inc",
    "3824": "USNETS - Kontera Technologies, Inc.",
    "3825": "HANANET--KR Korea Telecom",
    "3826": "REDLION - Red Lion Hotels & Inns",
    "3827": "ELECTRICITI - Electriciti",
    "3828": "CIRRUS - Cirrus Logic Inc.",
    "3829": "METROBBS - Metropolis BBS",
    "3830": "COGENT-3830 - AGIS",
    "3831": "FIBRNET-B1 - tw telecom holdings, inc.",
    "3832": "CINE-NET - Cinenet Communications",
    "3833": "WYOMING - wyoming.com",
    "3834": "PERFTECH - Performance Technology, Inc.",
    "3835": "DNIC--03835 - Navy Network Information Center (NNIC)",
    "3836": "THAISARN-TH--AP Thai Social/Scientific, Academic and Research Network",
    "3837": "LCM-N - LibertyView Capital Management, LLC",
    "3838": "SQUARETWO - SQUARE TWO FINANCIAL CORPORATION",
    "3839": "ERX-CHULANET Chulalongkorn University",
    "3840": "ERX-LABTAM Labtam Australia Pty. Ltd.",
    "3841": "BIHS-NET - Brazos Information Highway Services",
    "3842": "RAMNODE - RamNode LLC",
    "3843": "INTEXO-MRS Van Ommeren Intexo",
    "3844": "NTTA-3844 - NTT America, Inc.",
    "3845": "STATE-NET - CS&W, Inc.",
    "3846": "PAYTRONI - Paytronix Systems, Inc.",
    "3847": "NYC-REGIONAL - Envestnet Asset Management, Inc.",
    "3848": "WORLDLINX-2 - WorldLinx Telecommunications, Inc.",
    "3849": "NET-HA - DMSSC/OAD",
    "3850": "NAGRAUSA - OpenTV Inc",
    "3851": "SCS-NV - System Computing Services",
    "3852": "MAG- - Metropolitan and Global Ltd.",
    "3853": "WHIDBEY - Whidbey Telephone Company",
    "3854": "DNACO- - The Dayton Network Access Company",
    "3855": "IBL-LYNX - Internet Bermuda Limited",
    "3856": "PCH- - Packet Clearing House",
    "3857": "INC - Internet Connect, Inc.",
    "3858": "NPPDNET - Nebraska Public Power District",
    "3859": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3860": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3861": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3862": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3863": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3864": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3865": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3866": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3867": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3868": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3869": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3870": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3871": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3872": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3873": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3874": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3875": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3876": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3877": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3878": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3879": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3880": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3881": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3882": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3883": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3884": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3885": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3886": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3887": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3888": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3889": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3890": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3891": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3892": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3893": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3894": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3895": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3896": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3897": "DNIC-BLK-03859-03897 - Headquarters, USAISC",
    "3898": "UCSF-HISD - University of Calif. S.F. - Hospital Info Sys",
    "3899": "CHICO-NET - California State University, Chico",
    "3900": "TEXNET-N - YHC Corporation",
    "3901": "ARRAKIS - M & A Properties, LLC",
    "3902": "GLAXOSMITHKLINE - GlaxoSmithKline",
    "3903": "NAG- - Network Ananlysis Group",
    "3904": "THOUGHTPRT - ThoughtPort inc.",
    "3905": "CONSORCIO REDUNO S.A. de C.V",
    "3906": "ADS-1- - Advanced Data Systems",
    "3907": "CONNECT-1-NET - Connected INC",
    "3908": "QWEST--3908 - Qwest Communications Company, LLC",
    "3909": "QWEST--3908 - Qwest Communications Company, LLC",
    "3910": "QWEST--3908 - Qwest Communications Company, LLC",
    "3911": "MIS- - Micron",
    "3912": "NMSU- - Checs-net",
    "3913": "UMSM - University of Miami",
    "3914": "KMHP--ARIN - Keystone Mercy Health Plan",
    "3915": "TOWERS-IT-SERVICES - Towers IT Services",
    "3916": "OSIS-PACOM - Joint Intelligence Center Pacific",
    "3917": "SHELL-3917 Shell Information Technology International B.V.",
    "3918": "SHELL-3918 Shell Information Technology International B.V.",
    "3919": "HARBORNET - Harbor Net",
    "3920": "IMS-RTFM - Internet Multicasting Service",
    "3921": "AGNOGE - General Electric Company",
    "3922": "3922 - GXS",
    "3923": "FAA-MMAC - Federal Aviation Agency",
    "3924": "TX-OAG - Texas Attorney General",
    "3925": "ICO-SV - ICOnetworks",
    "3926": "FFX-CNTY - Fairfax County Dept of Information Technology",
    "3927": "RGNET-3927 RGnet Ashburn DC2",
    "3928": "VALLEY-TECH - Valley Tech Corporation",
    "3929": "ERX-FINSYS-NET Financial Systems Limited",
    "3930": "FERC-FED-US - Federal Energy Regulatory Commission",
    "3931": "LOGICAL - Logical Net Corporation",
    "3932": "VOICENET - Voicenet",
    "3933": "OPEN - Oregon Public Education Network",
    "3934": "NTTA-3934 - NTT America, Inc.",
    "3935": "ETWAUNIV - Eastern Washington University",
    "3936": "NTTA-3936 - NTT America, Inc.",
    "3937": "NTTA-3936 - NTT America, Inc.",
    "3938": "NTTA-3936 - NTT America, Inc.",
    "3939": "NTTA-3936 - NTT America, Inc.",
    "3940": "NTTA-3936 - NTT America, Inc.",
    "3941": "NTTA-3936 - NTT America, Inc.",
    "3942": "NTTA-3936 - NTT America, Inc.",
    "3943": "DMM - Cisco Systems, Inc.",
    "3944": "PARTAN-LAB - Partan & Partan",
    "3945": "NTTA-3945 - NTT America, Inc.",
    "3946": "NTTA-3946 - NTT America, Inc.",
    "3947": "NTTA-3946 - NTT America, Inc.",
    "3948": "ISC-MCT ISC.org Mcast Network",
    "3949": "NTTA-3946 - NTT America, Inc.",
    "3950": "IXL- - Internet Exchange, Ltd.",
    "3951": "QWST - Qwest Communications Company, LLC",
    "3952": "TELLABS-N - TELLABS Operations, Inc.",
    "3953": "PROFILE - Profile International",
    "3954": "DNIC--03954 - DoD Network Information Center",
    "3955": "GETRONICS-ICTO Used in EU",
    "3956": "TX-METRO - Texas Metronet",
    "3957": "AIP - American Institute of Physics Incorporated",
    "3958": "AIRCANADA - Air Canada",
    "3959": "ONEWORLD - One World Telecommunications, Inc.",
    "3960": "AAMERITECH - Ameritech Advertising Services",
    "3961": "INDUSTRYNET - Automation News Network",
    "3962": "DIRECTNIC-CLUSTER1-TORRONTO - DirectNIC, Ltd.",
    "3963": "INTERLINK-2 - Metrix Interlink Inc.",
    "3964": "INTERLINK-3 - Metrix Interlink Inc.",
    "3965": "INTERLINK-4 - Metrix Interlink Inc.",
    "3966": "INTERLINK-5 - Metrix Interlink Inc.",
    "3967": "NSM350 - Nationstar Mortgage, LLC",
    "3968": "El Colegio de Mexico, A.C.",
    "3969": "ERX-STPHNET Software Technology Park",
    "3970": "RGNET-3970 RGnet-3970",
    "3971": "NETS-ABQ-VA - Biomedical Research Institute of New Mexico",
    "3972": "-SPRINTLINK-NYSERN1 - Sprint, Business Services Group",
    "3973": "-SPRINTLINK-NYSERN2 - Sprint, Business Services Group",
    "3974": "REZONET - Rezonet",
    "3975": "AMSC - Automated Medical Systems Consultants Inc.",
    "3976": "ERX-NURI-N I.Net Technologies Inc.",
    "3977": "UTELFLA - Sprint/United Telephone-Florida",
    "3978": "UTELFLA - Sprint/United Telephone-Florida",
    "3979": "UTELFLA - Sprint/United Telephone-Florida",
    "3980": "UTELFLA - Sprint/United Telephone-Florida",
    "3981": "UTELFLA - Sprint/United Telephone-Florida",
    "3982": "UTELFLA - Sprint/United Telephone-Florida",
    "3983": "UTELFLA - Sprint/United Telephone-Florida",
    "3984": "UTELFLA - Sprint/United Telephone-Florida",
    "3985": "UTELFLA - Sprint/United Telephone-Florida",
    "3986": "UTELFLA - Sprint/United Telephone-Florida",
    "3987": "UTELFLA - Sprint/United Telephone-Florida",
    "3988": "UTELFLA - Sprint/United Telephone-Florida",
    "3989": "UTELFLA - Sprint/United Telephone-Florida",
    "3990": "UTELFLA - Sprint/United Telephone-Florida",
    "3991": "UTELFLA - Sprint/United Telephone-Florida",
    "3992": "UTELFLA - Sprint/United Telephone-Florida",
    "3993": "KW-NET - Kitchener-Waterloo Municipal Area Network",
    "3994": "INET-CORE- - Internetworsks, Inc.",
    "3995": "IWEB - Interweb Corporation",
    "3996": "FIRN - Florida Information Resource Network",
    "3997": "ACM- - Association of Computing Machines",
    "3998": "CITY-NET - CityNet, Inc.",
    "3999": "PENN-STATE - The Pennsylvania State University",
    "4000": "GLOBAL-SPLK - Sprint International",
    "4001": "GLOBAL-SPLK - Sprint International",
    "4002": "GLOBAL-SPLK - Sprint International",
    "4003": "GLOBAL-SPLK - Sprint International",
    "4004": "ORANGE-BUSINESS-SERVICES-UK Orange Business Services (formerly Equant)  for UK",
    "4005": "GLOBAL-SPLK - Sprint International",
    "4006": "COGENT-4006 - NetRail, Inc.",
    "4007": "SUBISU-CABLENET--AP Subisu Cablenet (Pvt) Ltd, Baluwatar, Kathmandu, Nepal",
    "4008": "UNIVERSAL - Universal Internet, Inc",
    "4009": "INET - Internetworsks, Inc.",
    "4010": "DNIC--04010 - Headquarters, USAISC",
    "4011": "DNIC--04011 - Headquarters, USAISC",
    "4012": "DCM - DCM",
    "4013": "N-GAN - Galaxy Access Network",
    "4014": "WIS - B3 Corporation",
    "4015": "QWEST--4015 - Qwest Corporation",
    "4016": "RIS - Regional Information System",
    "4017": "BELLST - VERIZON DATA SERVICES, INC",
    "4018": "DIA- - Defence Intelligence Agency",
    "4019": "IIE- - Institute of International Education",
    "4020": "N-4020-1 - 754th Electronic Systems Group",
    "4021": "N-4020-1 - 754th Electronic Systems Group",
    "4022": "N-4020-1 - 754th Electronic Systems Group",
    "4023": "N-4020-1 - 754th Electronic Systems Group",
    "4024": "N-4020-1 - 754th Electronic Systems Group",
    "4025": "N-4020-1 - 754th Electronic Systems Group",
    "4026": "N-4020-1 - 754th Electronic Systems Group",
    "4027": "N-4020-1 - 754th Electronic Systems Group",
    "4028": "N-4020-1 - 754th Electronic Systems Group",
    "4029": "N-4020-1 - 754th Electronic Systems Group",
    "4030": "N-4020-1 - 754th Electronic Systems Group",
    "4031": "N-4020-1 - 754th Electronic Systems Group",
    "4032": "N-4020-1 - 754th Electronic Systems Group",
    "4033": "N-4020-1 - 754th Electronic Systems Group",
    "4034": "N-4020-1 - 754th Electronic Systems Group",
    "4035": "N-4020-1 - 754th Electronic Systems Group",
    "4036": "N-4020-1 - 754th Electronic Systems Group",
    "4037": "N-4020-1 - 754th Electronic Systems Group",
    "4038": "N-4020-1 - 754th Electronic Systems Group",
    "4039": "ITSON- - ItsOn, Inc",
    "4040": "KORNET-PS--KR Korea Telecom",
    "4041": "RGNET-SJ0 - The Little Garden",
    "4042": "BSINET2 - Brainstorm Internet, Inc.",
    "4043": "MIC-N - Montana Internet Corporation",
    "4044": "AKSI-NET- - Acquired Knowledge Systems, Inc.",
    "4045": "-WINTERNET - StarNet Communications, Inc.",
    "4046": "FAA - Federal Aviation Administration",
    "4047": "CIRS- - Community Information & Referral",
    "4048": "QWEST--4048 - Qwest Communications Company, LLC",
    "4049": "ERX-OTP-1 Otago Polytechnic",
    "4050": "OMNINET-PRI- - OMNINET COMMUNICATIONS",
    "4051": "PACAFINY-GW - U. S. Air Force",
    "4052": "ROVI - Rovi Corporation",
    "4053": "USRX- - U.S.Robotics",
    "4054": "EZNET- - EZNet, Inc.",
    "4055": "N1 - Boutique Jacob",
    "4056": "LC-USAF - Lockheed Aeronautical Systems Company",
    "4057": "DCS-N - Mechant's Choice Payment Solutions",
    "4058": "CITICTEL-CPC-4058 CITIC Telecom International CPC Limited",
    "4059": "WENG- - Wagner Engineering",
    "4060": "KORNET-DJ--KR Korea Telecom",
    "4061": "GTTW-NET - Jax Gateway to the World",
    "4062": "SIGNALDATA - Signal Data, Inc.",
    "4063": "ELCSCI-N - Electro Scientific Industries",
    "4064": "COGENT-4064 - AGIS",
    "4065": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4066": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4067": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4068": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4069": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4070": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4071": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4072": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4073": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4074": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4075": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4076": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4077": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4078": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4079": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4080": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4081": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4082": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4083": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4084": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4085": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4086": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4087": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4088": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4089": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4090": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4091": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4092": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4093": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4094": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4095": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4096": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4097": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4098": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4099": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4100": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4101": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4102": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4103": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4104": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4105": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4106": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4107": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4108": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4109": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4110": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4111": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4112": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4113": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4114": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4115": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4116": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4117": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4118": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4119": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4120": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4121": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4122": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4123": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4124": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4125": "DNIC-BLK-04065-04125 - Headquarters, USAISC",
    "4126": "SPTEL2 - SP Tel",
    "4127": "DUPONT-SCD - DuPont Scientific Computing",
    "4128": "RGNET-4128 RGnet-4128",
    "4129": "WIRED-NET - Lycos, Inc.",
    "4130": "UPITT- - University of Pittsburgh",
    "4131": "USIS- - USIS",
    "4132": "COGENT-4132 - AGIS",
    "4133": "BITWISE - Bitwise Internet Technologies, Inc.",
    "4134": "CHINANET-BACKBONE No.31,Jin-rong Street",
    "4135": "ENVISIONET - ENVISIONET, Inc.",
    "4136": "QUALITYTECH-JCYNYC - Quality Technology Services, N.J., LLC",
    "4137": "DIRECTNET - Burningate, Inc.",
    "4138": "REACH - Reach Networks, Inc.",
    "4139": "INTERSRV - InterServe Communications",
    "4140": "INMIND - In Mind, Inc.",
    "4141": "GRUPO ICA, S.A. DE C.V.",
    "4142": "ERX-GIN-HK Global Information Networks Limited",
    "4143": "UNIBE - Unibase Telecom Ltd",
    "4144": "INTERGUIDE - InterGuide Communications",
    "4145": "UPS-4145 - UNITED PARCEL SERVICE",
    "4146": "TACH-NET - Tachyon Communications Corporation",
    "4147": "DNIC--04147 - Navy Network Information Center (NNIC)",
    "4148": "ACTCOM Active Communication Ltd.",
    "4149": "JPL-4149 - Jet Propulsion Laboratory",
    "4150": "SUPRANET-WIS - SupraNet Communications, Inc.",
    "4151": "USDA-1 - USDA",
    "4152": "USDA-1 - USDA",
    "4153": "USDA-1 - USDA",
    "4154": "USDA-1 - USDA",
    "4155": "USDA-1 - USDA",
    "4156": "USDA-1 - USDA",
    "4157": "USDA-1 - USDA",
    "4158": "CITYU--HK City University of Hong Kong",
    "4159": "ONEWORLD--1 - One World Productions",
    "4160": "SPECTRA - Internet Direct Marketing",
    "4161": "TIN-1 - 754th Electronic Systems Group",
    "4162": "TIN-1 - 754th Electronic Systems Group",
    "4163": "TIN-1 - 754th Electronic Systems Group",
    "4164": "TIN-1 - 754th Electronic Systems Group",
    "4165": "DNIC--04165 - DoD Network Information Center",
    "4166": "APPL--4166 - ClearBlue Technologies",
    "4167": "CONNECTSOFT-COM - Connectsoft Commercial Network Services",
    "4168": "GULFSTAR - Gulfstar Charters, Inc.",
    "4169": "ECHNET - Egleston Children's Hospital",
    "4170": "DNIC--04170 - DoD Network Information Center",
    "4171": "EUROGRAFIX - Eurografix, Inc.",
    "4172": "WAYNESBURG - Waynesburg College",
    "4173": "WATER - Water Wheel Systems",
    "4174": "AAPT AAPT Limited",
    "4175": "AAPT AAPT Limited",
    "4176": "PGH-NET - Pittsburgh OnLine, Inc.",
    "4177": "WORLTEK - AT73",
    "4178": "AZTEC",
    "4179": "CITY-OF-LA - City of Los Angeles",
    "4180": "CHAPUB - Chattanooga Publishing Company",
    "4181": "TDS- - TDS TELECOM",
    "4182": "MLSLI-2 - MLSListings inc.",
    "4183": "UUNET-MCIWCOM - UUNET, a Worldcom company",
    "4184": "STORTEK-WHQ - Oracle Corporation",
    "4185": "ATTIS-N4185 - AT&T Internet Services",
    "4186": "ATTIS-N4186 - AT&T Internet Services",
    "4187": "INFOBAHN - infobahn",
    "4188": "GILBARCO- - Gilbarco, Inc.",
    "4189": "OSSHENET1 - OSSHENET1",
    "4190": "BINGHAMTON-U - Binghamton University",
    "4191": "STORTEK-NAT - Oracle Corporation",
    "4192": "STORTEK-INT - Oracle Corporation",
    "4193": "WA-STATE-GOV - Department of Information Services",
    "4194": "SDINTERNET - Computer Dimensions, Inc.",
    "4195": "DE-SHAW- DE SHAW",
    "4196": "4196 - Wells Fargo & Company",
    "4197": "IDC4197 Yahoo Japan Corporation",
    "4198": "RADIXNET - RadixNet, Inc.",
    "4199": "CIBC-CITE1 - Canadian Imperial Bank of Commerce",
    "4200": "COGENT-4200 - AGIS",
    "4201": "ORST- - Oregon State University",
    "4202": "OTTOGI--KR ottogi.co.kr",
    "4203": "TGF-TIS - Together Foundation",
    "4204": "ALLWARE- - Allware",
    "4205": "CIBC-CITE2 - Canadian Imperial Bank of Commerce",
    "4206": "INMS - Internet Mississippi",
    "4207": "NET-INTRNET - Allied Access Inc.",
    "4208": "THE-ISERV-COMPANY - The Iserv Company, LLC",
    "4209": "Pequiven",
    "4210": "Y - D. E. Shaw & Co.",
    "4211": "N-MARICOPA1 - Maricopa County Government",
    "4212": "EMBARQ-ES - Embarq Corporation",
    "4213": "VPLSNET-ET - Krypt Technologies",
    "4214": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4215": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4216": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4217": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4218": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4219": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4220": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4221": "DNIC-BLK-04214-04221 - DoD Network Information Center",
    "4222": "LEN-NET - Lane Education Network (LEN)",
    "4223": "CONNIX - Caravela Software, Inc.",
    "4224": "CALYX-INSTITUTE The Calyx Institute",
    "4225": "NAV- - Navigator Communications",
    "4226": "N-PERSIS - International Reliable Access Network",
    "4227": "TCCGI- - The Chesapeake Computer Group, Incorporated",
    "4228": "CDFA-CA-GOV - State of California Department of Food & Agriculture",
    "4229": "DIRECT-NET2 - DataTex Computer Corporation",
    "4230": "EMBRATEL-EMPRESA BRILEIRA DE TELECOMUNICA\u00c7\u00d5ES SA",
    "4231": "N1 - Qnect.net",
    "4232": "EDEN- - Adhesive Media, Inc.",
    "4233": "DWRSCADA - State of Caligornia",
    "4234": "CT-WCC - Workers Compensation Commission",
    "4235": "DGS-2 - 48 Intelligence Squadron/SC, Air Intelligence Agency",
    "4236": "CITIZENS- - Citizens Bank",
    "4237": "CSC-IGN-FTW - Computer Sciences Corporation",
    "4238": "TX-TRENET - Texas Treasury",
    "4239": "ATCW- - XO Communications",
    "4240": "NJNET- - New Jersey Net, Inc.",
    "4241": "CSFTB - California State Franchise Tax Board",
    "4242": "Soluciones Avanzadas de Redes",
    "4243": "NC-FUNB- - WACHOVIA CORP",
    "4244": "Fondo de Informacion y Documentacion para la Industria INFOTEC",
    "4245": "ECHO- - Echo Communications Group, Inc.",
    "4246": "NJIT- - New Jersey Institute of Technology",
    "4247": "CAPCON- - CAPCON Library Network",
    "4248": "CYBERTRIBE - Nexus System",
    "4249": "LILLY- - Eli Lilly and Company",
    "4250": "ALENT-N-1 - Alentus Corporation",
    "4251": "ERX-TWICS TWICS Co. Ltd.",
    "4252": "DNIC--04252 - DoD Network Information Center",
    "4253": "RWJNET - Robert Wood Johnson University Hospital",
    "4254": "DNIC--04254 - Headquarters, USAISC",
    "4255": "BAIN - Bain And Company",
    "4256": "INTERGATE-GW - Intergate, Inc.",
    "4257": "CYBERCH- - CyberCash, Inc.",
    "4258": "WOLFENET - Wolfenet",
    "4259": "IOCOM - IOCOM, LTD",
    "4260": "DCCI- - DC Communications, Inc.",
    "4261": "BLUEGRSNET - Intermart Inc.",
    "4262": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4263": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4264": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4265": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4266": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4267": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4268": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4269": "CERNET-N-BLOCK - California Education and Research Federation Network",
    "4270": "Red de Interconexion Universitaria",
    "4271": "NETWORX - Networx",
    "4272": "MDN - Metropolitan Data Networks",
    "4273": "JSC-NET-N - Dod Joint Spectrum Center",
    "4274": "ERX-AU-NET Assumption University",
    "4275": "CLIPPER - ACC Data Systems",
    "4276": "INCH - The Internet Channel",
    "4277": "SEMBLER-STPETE - The Sembler Company",
    "4278": "IADFW - Internet America, Inc.",
    "4279": "INTERSOURCE - INTERSOURCE",
    "4280": "PIERPRO- - Pier Programming Services Ltd.",
    "4281": "SAVVIS - Savvis",
    "4282": "SAVVIS - Savvis",
    "4283": "SAVVIS - Savvis",
    "4284": "SAVVIS - Savvis",
    "4285": "SAVVIS - Savvis",
    "4286": "MCI-WORLD - MCI Telecommunications Inc.",
    "4287": "SAVVIS - Savvis",
    "4288": "SAVVIS - Savvis",
    "4289": "SAVVIS - Savvis",
    "4290": "SAVVIS - Savvis",
    "4291": "SAVVIS - Savvis",
    "4292": "SAVVIS - Savvis",
    "4293": "SAVVIS - Savvis",
    "4294": "SAVVIS - Savvis",
    "4295": "SAVVIS - Savvis",
    "4296": "SAVVIS - Savvis",
    "4297": "SAVVIS - Savvis",
    "4298": "SAVVIS - Savvis",
    "4299": "JSC-NET-N2 - Dod Joint Spectrum Center",
    "4300": "JSC-NET-N2 - Dod Joint Spectrum Center",
    "4301": "JSC-NET-N2 - Dod Joint Spectrum Center",
    "4302": "DNIC--04302 - Navy Network Information Center (NNIC)",
    "4303": "DNIC--04303 - DoD Network Information Center",
    "4304": "YPN-NET - YPN, Inc.",
    "4305": "PREMIER - Premier Communications",
    "4306": "NOVIA - Novia Corp",
    "4307": "SVINET-1 - SOUTH VALLEY INTERNET",
    "4308": "TEZCAT-N - Tezcatlipoca Inc.",
    "4309": "FRMCO - FMRCO.COM",
    "4310": "SCC-FL-EDU - Seminole State College of Florida",
    "4311": "WINC - Winfield Communications",
    "4312": "FYI - FYI Networks",
    "4313": "XOXO-4313 - XO Communications",
    "4314": "XFONE-N1 - XFone USA, Inc.",
    "4315": "DNIC--04315 - Headquarters, USAISC",
    "4316": "DSI-CUST-BLK - Houston Associates, Inc.",
    "4317": "MLECNET - Mille Lacs Energy Cooperative",
    "4318": "FMI-NET- - Freeport-McMoran Inc.",
    "4319": "CORTLAND - Cortland Electronics Corp.",
    "4320": "TA-GW - Television Audio Support Activity",
    "4321": "INSINC2 - Intergrated Network Services Inc.",
    "4322": "EBTECH - Electrobyte Technologies",
    "4323": "TWTC - tw telecom holdings, inc.",
    "4324": "WHC-NET - WhiteHorse Communications, Inc.",
    "4325": "DNIC--04325 - Navy Network Information Center (NNIC)",
    "4326": "TNTONLINE - TNT Online, Inc.",
    "4327": "SNA-NET - Sacramento Network Access, Inc.",
    "4328": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4329": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4330": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4331": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4332": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4333": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4334": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4335": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4336": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4337": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4338": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4339": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4340": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4341": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4342": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4343": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4344": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4345": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4346": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4347": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4348": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4349": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4350": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4351": "DNIC-BLK-04328-04351 - Headquarters, USAISC",
    "4352": "EMRNET--HK-AP Emerson (NYSE:EMR) is a global company",
    "4353": "WNET- - WorldNet Inc.",
    "4354": "N-ENOC - EnerNOC, Inc.",
    "4355": "ERMS-EARTHLNK - EARTHLINK, INC.",
    "4356": "EPICGA-HQ- - Epic Games Inc.",
    "4357": "PHE4-RO - Phase IV Systems, Inc.",
    "4358": "XNET - XNet Information Systems, Inc.",
    "4359": "DIGIPRESS- - Graphics Express",
    "4360": "AGNES-SCOTT - Agnes Scott College",
    "4361": "PCIX- - IDT Corporation",
    "4362": "DIGITOPIA- - Mediapolis, Inc.",
    "4363": "ALPHA-BETA - World Ramp Inc.",
    "4364": "IGLOU - IgLou Internet Services",
    "4365": "DIGITAL-CAFE-N - Digital Cafe",
    "4366": "GE-AMC - General Electric - Corp. Info. Mgmt.",
    "4367": "SECSTATE-CA-GOV - California Secretary of State",
    "4368": "CRCNET - Coleman Research Corporation",
    "4369": "IQUEST-N - InterQuest Inc.",
    "4370": "TELERES-NET - Datalytics, Inc",
    "4371": "FEMA-GOV - State of California Office of Emergency Services",
    "4372": "NET-LM - Luce McQuillin Corporation",
    "4373": "OCLC- - Online Computer Library Center",
    "4374": "CKEREST - CARL KARCHER ENTERPRISES",
    "4375": "KEY - KeyNet",
    "4376": "DSW-INET - Dahlin Smith White, Inc.",
    "4377": "SSSI-NETS - System Software Support, Inc.",
    "4378": "HOSTINGCOM - WCP/32POINTS INTERMEDIATE HOLDING COMPANY, INC.",
    "4379": "DNIC--04379 - DoD Network Information Center",
    "4380": "DNIC--04380 - Headquarters, USAISC",
    "4381": "ERX-CONNECT-COM2 connect.com.au pty ltd",
    "4382": "INDONUSA-ID PT. Indonusa System Integrator Prima",
    "4383": "NAIC - 754th Electronic Systems Group",
    "4384": "MULTI-NET - Husky Labs, Inc.",
    "4385": "RIT-N - Rochester Institute of Technology",
    "4386": "SOO-N - State of Oregon",
    "4387": "Secretaria de Ciencia y Tecnologia - Red Cientific",
    "4388": "COGENT-4388 - AGIS",
    "4389": "DATERVE- - DataServe LTD",
    "4390": "BELLATLANTIC-COM - Bell Atlantic, Inc.",
    "4391": "BRI-NET - B R I",
    "4392": "CROWN-NET - Crown Engineering Inc.",
    "4393": "PATHFINDER - Time Inc.",
    "4394": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4395": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4396": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4397": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4398": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4399": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4400": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4401": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4402": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4403": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4404": "DSI-CUST-BLK2 - Houston Associates, Inc.",
    "4405": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4406": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4407": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4408": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4409": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4410": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4411": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4412": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4413": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4414": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4415": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4416": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4417": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4418": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4419": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4420": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4421": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4422": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4423": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4424": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4425": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4426": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4427": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4428": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4429": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4430": "CREDITSUISSEGROUP- Credit Suisse Group",
    "4431": "ERX-LINGNAN Lingnan College",
    "4432": "CSTONE-NET - Cornerstone Communications, Inc.",
    "4433": "ERX-ACCESS-ONE UUNET",
    "4434": "ERX-RADNET1- PT Rahajasa Media Internet",
    "4435": "INCH--1 - The Internet Channel",
    "4436": "-NLAYER - nLayer Communications, Inc.",
    "4437": "WEBB - Webb Systems",
    "4438": "NEPTUNE - Neptune Travel Industry Network",
    "4439": "IMEFDJOSS - Commanding General",
    "4440": "IIIMEFDJOSS - Commanding General",
    "4441": "MARFORPACDJOSS - Marine Forces Pacific",
    "4442": "DNIC--04442 - Headquarters, USAISC",
    "4443": "RHWINECO225 - R. H. WINE & CO., INC.",
    "4444": "CISNET- - CISNet Inc.",
    "4445": "CWI- - Cable & Wireless Americas Operations, Inc.",
    "4446": "INFINET-N - Infinet Technologies and Services",
    "4447": "HOOKED- - Hooked Communications Inc.",
    "4448": "OPEN-ACCESS- - Open Access Inc.",
    "4449": "N-GALSTAR - Galaxy Star Systems",
    "4450": "WEBNET - Web Net Communications, Inc.",
    "4451": "N1 - 1199SEIU National Benefit Funds",
    "4452": "AMERICA - Access America",
    "4453": "TDS-TELECOM - TDS TELECOM",
    "4454": "TNET- - State of Tennessee",
    "4456": "GSNET-NETS - Gulf South Internet Services, Inc.",
    "4457": "NESTE-NET NESTE Corporation",
    "4458": "CCNET CarelComp Oy",
    "4459": "KDDIA-NET - Telecomet, Inc.",
    "4460": "RVCC - Raritan Valley Community College",
    "4461": "OPUSTEL- - Blitz Product Development Corporation",
    "4462": "NDLINK - Network Data Link",
    "4463": "ONET3-DOM - ONET, Inc.",
    "4464": "TWNAO- - DPRO Honeywell/Alliant Tech Systems",
    "4465": "EYLINK1 - AT&T Services, Inc.",
    "4466": "ATTIDNS AT&T Global Network iDNS Service",
    "4467": "EYLINK3 - AT&T Services, Inc.",
    "4468": "EYLINK4 - AT&T Services, Inc.",
    "4469": "MATROX- - MATROX ELECTRONIC SYSTEMS LTD",
    "4470": "N-CITENET - Citenet Telecom Inc.",
    "4471": "MICAE91- - Michigan Internet Cooperative Association",
    "4472": "IONET ioNET, Inc.",
    "4473": "ATTIS-N4473 - AT&T Internet Services",
    "4474": "TCT- - TCT West, Inc.",
    "4475": "HUNTINGTON-TRAVEL - Huntington Travel",
    "4476": "BCIT - British Columbia Institute of Technology",
    "4477": "BBDATA - B&B Data Link",
    "4478": "PNET-STL - P-Net, Inc.",
    "4479": "JTM - JTM Multimedia",
    "4480": "CMS-1 - 754th Electronic Systems Group",
    "4481": "CMS-2 - 754th Electronic Systems Group",
    "4482": "CMS-3 - 754th Electronic Systems Group",
    "4483": "EMTF-SPANG - 754th Electronic Systems Group",
    "4484": "EMTF-BIT - 754th Electronic Systems Group",
    "4485": "EMTF-RAMDEN - 754th Electronic Systems Group",
    "4486": "EMTF-RAM - 754th Electronic Systems Group",
    "4487": "EMTF-UPW - 754th Electronic Systems Group",
    "4488": "EMTF-CRO - 754th Electronic Systems Group",
    "4489": "EMTF-MOL - 754th Electronic Systems Group",
    "4490": "EMTF-LAK - 754th Electronic Systems Group",
    "4491": "MULTIPRO - MultiNet, LLP",
    "4492": "COMMSPEED1 - CommSpeed LLC",
    "4493": "Universidad de Sonora",
    "4494": "INTERBYTES - Megabytes.inc.",
    "4495": "TERRAPORT - TerraPort Online Inc.",
    "4496": "UUCOM- - UUcom, Inc.",
    "4497": "UPSTEL-NET - Upsala Co-operative Telephone Association",
    "4498": "GLOBALONE - Internet Services of New Hampshire",
    "4499": "WEBNET-N - Web Net Communications, Inc.",
    "4500": "NET-TIVOLI - Tivoli Systems, Inc",
    "4501": "MICAE91-MICA - The Michigan Internet Cooperative Association.",
    "4502": "CINCOM-MRS - Cincom Systems UK Ltd.",
    "4503": "EGINTERLINK - Grady Memorial Hospital",
    "4504": "GSNETXGW - General Services Administration",
    "4505": "TORBIT-ANYCT - Torbit, Inc.",
    "4506": "SEW- - SEW, Inc.",
    "4507": "N-SUDRCSS-NET - Sudbury District R.C.S.S. Board",
    "4508": "-G-2-TRADING - G 2 Trading LLC",
    "4509": "MAGMA-4509-4510 - Magma Communications Ltd.",
    "4510": "MAGMA-4509-4510 - Magma Communications Ltd.",
    "4511": "MIAMI-EDU - University of Miami",
    "4512": "PCWNET - PCW Microsystem, Inc.",
    "4513": "INTERNAP-4513 - Internap Network Services Corporation",
    "4514": "-JCM - JINKIEWICZ CAPITAL MANAGEMENT, LLC",
    "4515": "ERX-STAR PCCW IMSBiz",
    "4516": "TRENDLINE - Trendline",
    "4517": "VOLANT - Volant",
    "4518": "TELECOM - Comptrodex, Inc.",
    "4519": "MA - Maas Communications",
    "4520": "AQUA - Aquidneck Web, Inc.",
    "4521": "MIRACLE - Miracle Net Communication",
    "4522": "COMPUCALL - CompuCall Internet Services",
    "4523": "4523 - GXS",
    "4524": "TRU-MRS Toys R Us",
    "4525": "POPPE - 707 California Street",
    "4526": "ARMY-FMO - Dod Joint Spectrum Center",
    "4527": "RCN--1 - RCN",
    "4528": "HKU--HK The University of Hong Kong",
    "4529": "RIS-NET - Regional Information System",
    "4530": "RCN-5 - RCN",
    "4531": "MEDWEB - Nexsys Electronics, Inc.",
    "4532": "WARWICK - Alteva Inc",
    "4533": "GLOBESAT - Globesat Corp",
    "4534": "IXA-N - Interconnected Associates (IXA) Inc.",
    "4535": "Inter Network Solutions",
    "4536": "DNIC--04536 - Navy Network Information Center (NNIC)",
    "4537": "DNIC--04537 - Headquarters, USAISC",
    "4538": "ERX-CERNET-BKB China Education and Research Network Center",
    "4539": "SEL- - Schweitzer Engineering Laboratories, Inc.",
    "4540": "N01-SOGE - SOGETEL INC",
    "4541": "IWORK - Internet at Work",
    "4542": "RRNET- - Red River Net, Inc.",
    "4543": "TIMESNET - The New York Times Company",
    "4544": "CONXION-A - ConXioN Corporation",
    "4545": "SONNET-N - Sonora ONline",
    "4546": "MCGRAW- - McGraw-Hill",
    "4547": "BLS- - Bureau of Labor Statistics",
    "4548": "AG - Access Global Information Services",
    "4549": "ESPN- - ESPN",
    "4550": "COGENT-4550 - Cogent Communications",
    "4551": "EP0-BLK-NBLOCK - Almond Oil Process, LLC.",
    "4552": "EP0-BLK-NBLOCK-2 - Almond Oil Process, LLC.",
    "4553": "NAP-MAEWEST - Merit Network Inc.",
    "4554": "EP0-BLK-NBLOCK-4 - Almond Oil Process, LLC.",
    "4555": "EP0-BLK-NBLOCK-5 - RA-NAP",
    "4556": "EP0-BLK-NBLOCK-6 - Almond Oil Process, LLC.",
    "4557": "SOUTHET-TEX-GIGAPOP - Rice University",
    "4558": "EP0-BLK-NBLOCK-8 - Almond Oil Process, LLC.",
    "4559": "EP0-BLK-NBLOCK-9 - Almond Oil Process, LLC.",
    "4560": "EP0-BLK-NBLOCK-10 - Almond Oil Process, LLC.",
    "4561": "EP0-BLK-NBLOCK-11 - Almond Oil Process, LLC.",
    "4562": "INTEX - Intex-Net",
    "4563": "BTMU-AMERICA - The Bank of Tokyo-Mitsubishi UFJ",
    "4564": "DNIC--04564 - DoD Network Information Center",
    "4565": "MEGAPATH2-US - MegaPath Networks Inc.",
    "4566": "CYRACOM-INTERNATIONAL-N - CYRACOM INTERNATIONAL",
    "4567": "DEC-ENET - Digital Equipment Corporation",
    "4568": "WALLACE-NET - Wallace Computer Services, Inc.",
    "4569": "HTON-NET1 - Ashton Systems Corporation",
    "4570": "IH2000 - IH2000",
    "4571": "UUNET-SA",
    "4572": "JAXINTER - Jacksonville Internet Service",
    "4573": "SEQUEL2 - Sequel Concepts",
    "4574": "NETDOOR - Internet Doorway, Inc.",
    "4575": "CYBERHOUSE - CyberHouse Corp.",
    "4576": "N1 - Michael & Susan Dell Foundation",
    "4577": "HHGREGG - H.H. Gregg",
    "4578": "NETCENTER - Network Center Inc.",
    "4579": "GUIDEWIRE2 - Guidewire Software, Inc.",
    "4580": "CORSAIR - Net Daemons Associates, Inc.",
    "4581": "SOCKET - Socket Internet Services Corporation",
    "4582": "REALLINK - RealLink, Inc.",
    "4583": "WESTPUB-A - West Publishing Corporation",
    "4584": "PTI-NET - PagePath Technologies, Inc.",
    "4585": "NAVISOFT - Navisoft Inc.",
    "4586": "TX-TNRIS - Texas Natural Resources Information System",
    "4587": "ONEWORLD2 - One World Internetworking, Inc",
    "4588": "FINNPAP-MRS FinnPap",
    "4589": "EYNET Easynet Global Services",
    "4590": "MARCAM-GW - CONSULTIX",
    "4591": "SYRANET-GW - Consultix Computer Services",
    "4592": "OPENMARKET-NET - Open Market, Inc",
    "4593": "RELIANCE - Reliance Electric Co.",
    "4594": "ERX-INOAC-HK Inoac Software Limited",
    "4595": "2020-4595 - 2020 Communications LLC",
    "4596": "MONGTOMERY - Bank of America",
    "4597": "MILLIPORE - Millipore Corp.",
    "4598": "COMMUNICATION-NETWORK-CORPORATION - Communication Network Corporation",
    "4599": "MINNNET-NET - MinnNet Coummunications, Inc.",
    "4600": "UO-TRANSIT - Oregon GigaPOP",
    "4601": "PAGESAT - Network Wizards",
    "4602": "DNIC--04602 - Navy Network Information Center (NNIC)",
    "4603": "QUANTA - Quanta Computer Inc.",
    "4604": "HOUSTON-ISD - Houston Independent School District",
    "4605": "ERX-HKBUNET Hong Kong Baptist University",
    "4606": "HCI - Harbour Communications",
    "4607": "NORAD-SPACE - 754th Electronic Systems Group",
    "4608": "APNIC-SERVICES Asia Pacific Network Information Centre",
    "4609": "CTM-MO Companhia de Telecomunicacoes de Macau SARL",
    "4610": "ODYSSEY-NZ-AP Odyssey Networks New Zealand",
    "4611": "CICNET-4611 China Internet Corporation",
    "4612": "INFOLINK-HK Infolink Communications",
    "4613": "MOS-NP Mercantile Office Systems",
    "4614": "IAONLINE-HK- Asia Online (Hong Kong)  Number",
    "4615": "DIGICOM-PK Digicom Pakistan Private Limited",
    "4616": "HKPOLYU-HK Information Technology Services",
    "4617": "BRUIX BruNet Internet Exchange",
    "4618": "INET-TH- Internet Thailand Company Limited",
    "4619": "UNSPECIFIED Spider Net (HK) Ltd.",
    "4620": "UNSPECIFIED HongKongLink Communications Limited",
    "4621": "UNSPECIFIED UNINET-TH",
    "4622": "ID-NIC Indonesia Network Information Center",
    "4623": "CHEVALIER-01 Chevalier (Internet) Limited autonomous system #1",
    "4624": "UNSPECIFIED InterServe Communication (H.K.) Ltd.",
    "4625": "UNSPECIFIED Hong Kong",
    "4626": "UNSPECIFIED TELECOMMUNICATION EQUIPMENT & COMMUNICATION SERVICES",
    "4627": "UNSPECIFIED ABC NET Ltd",
    "4628": "N-PACIFIC-INTERNET-IX Pacific Internet Ltd",
    "4629": "PACNET-MY Pacnet MY",
    "4630": "UNSPECIFIED Internet Access HK Ltd.",
    "4631": "UTCNET-AP United Techinologies Corp.",
    "4632": "TMNS- Telstra Managed Network Services",
    "4633": "UN-NET-HK UniNet International Ltd",
    "4634": "PLANET-AU FlowCom Ltd, Service Provider, Australia",
    "4635": "HKIX-RS1 Hong Kong Internet Exchange--Route Server 1",
    "4636": "TFN-TW-GCN-1 Taiwan Fixed Network Co., LTD.",
    "4637": "N-TELSTRA-GLOBAL Telstra Global",
    "4638": "IS-FJ- Fiji Post and Telecommunications Ltd",
    "4639": "PLANET-HK- Planet Internet Limited - HK",
    "4640": "N-TIC-HK  # -TIC-HK CONVERTED TO N-TIC-HK FOR RPSL COMPLIANCE The Internetworking Corporation",
    "4641": "N-CUHKNET  # -CUHKNET CONVERTED TO N-CUHKNET FOR RPSL COMPLIANCE The Chinese University of Hong Kong",
    "4642": "CATHAYPACIFIC--AP Cathay Pacific Airways Ltd.",
    "4643": "TXU--AP Optus Customer Network",
    "4644": "UNSPECIFIED Concentric Network Corporation / Hong Kong",
    "4645": "N-HKNET-AP HKNet Co. Ltd",
    "4646": "INFOLINK-HK- INFOLINK-HK  Number",
    "4647": "CENTRANETWORKS-AU Suite 4.25, 433 Logan Rd",
    "4648": "NZIX-2 Netgate",
    "4649": "INTERNET-CONNECTIONS--AP CitiWell Technology, 1225",
    "4650": "SPEEDNET--AP Speednet Communications (Hong Kong) Ltd.",
    "4651": "THAI-GATEWAY The Communications Authority of Thailand(CAT)",
    "4652": "THAI-EXCHANGE The Communications Authority of Thailand(CAT)",
    "4653": "DATA3-AU 67 High St",
    "4654": "TECHNOWORKS- TECHNOWORKS AUSTRALIA",
    "4655": "UNSPECIFIED Sing Tao Electronic Daily",
    "4656": "TIGLION-HK Tiglion Consultancy Company Limited",
    "4657": "STARHUBINTERNET- StarHub Internet Exchange",
    "4658": "M2012LIMITED- 2012 Limited,",
    "4659": "CHINA169-CN CNCGROUP old Jitong IP network",
    "4660": "UNSPECIFIED Hansol Telecom Inc.",
    "4661": "PTCLBB-PK PTCL MMBB DATA CENTRE",
    "4662": "QTCN-N1 GCNet (Reach & Range Inc.)",
    "4663": "ELIMNET- ELIMNET, INC",
    "4664": "HIT-KR-AP Shinbiro",
    "4665": "YONSEI--KR Yonsei University",
    "4666": "SAMSUNGELECTRONICS--KR Samsung Electronics",
    "4667": "GNS-NZ--AP GNS Science New Zealand",
    "4668": "LGNET--KR LG CNS",
    "4669": "NOWCOM--KR Nowcom",
    "4670": "HYUNDAI-KR Shinbiro",
    "4671": "GCC-KR Government Computer Center (GCC)",
    "4672": "IBMNET IBM Japan, Ltd.",
    "4673": "INTERVIA NTT DATA CORPORATION",
    "4675": "U-NETSURF UNIADEX, LTD.",
    "4677": "PTOP Oki Electric Industry Co., Ltd.",
    "4678": "FINE Canon IT Solutions Inc.",
    "4680": "MIND Mitsubishi Electric Information Network Corporation",
    "4681": "IDC4681 Yahoo Japan Corporation",
    "4682": "ITNET JAPAN TELECOM Co., LTD.",
    "4683": "P Phase One, Inc.",
    "4684": "NTTPC NTT PC Communications, Inc.",
    "4685": "AHI-NET Asahi Net",
    "4686": "BEKKOAME BEKKOAME INTERNET INC.",
    "4688": "HI-HO Internet Initiative Japan Inc.",
    "4690": "WIDE-MEXP WIDE Project",
    "4691": "DTI Dream Train Internet Inc.",
    "4692": "INTERGATE InternetWare Co., LTD.",
    "4693": "CSK CSK-IT MANAGEMENT CORPORATION",
    "4694": "IDC Yahoo Japan Corporation",
    "4695": "URBAN Energia Communications, Inc.",
    "4697": "NTTV6NET NTT PF Labs",
    "4698": "INTERLINK InterLink Co., Ltd.",
    "4700": "NIJI-NET Niji-Net Inc.",
    "4704": "SANNET Fusion Communications Corp.",
    "4708": "INFONIA Nippon Internet Access Inc.",
    "4709": "NETLAPUTA NetLaputa Corporation",
    "4710": "ID-NET NTT",
    "4711": "INTEC INTEC INTERNET CONNECTIONS",
    "4712": "JT-NET JAPAN TOBACCO INC.",
    "4713": "OCN NTT Communications Corporation",
    "4716": "POWEREDCOM KDDI CORPORATION",
    "4717": "AI3 WIDE Project",
    "4718": "CKP Cyber Kansai Project",
    "4719": "OET ONKYO ENTERTAINMENT TECHNOLOGY CORPORATION",
    "4721": "JCN Japan Cablenet Limited",
    "4722": "WSIP JAPAN TELECOM CO.,LTD.",
    "4723": "DOLPHIN Dolphin",
    "4725": "ODN SOFTBANK TELECOM Corp.",
    "4727": "BSS KYODO PRINTING BUSINESS SOLUTIONS CO.,LTD",
    "4729": "JAEA Japan Atomic Energy Agency",
    "4730": "ODINS Osaka University",
    "4732": "DION KDDI CORPORATION",
    "4733": "SAISON SAISON INFORMATION SYSTEMS CO., LTD.",
    "4736": "MAGNADATA-AU Magnadata Australia Pty Ltd",
    "4737": "UNSPECIFIED IAP Group Pty Ltd",
    "4738": "AARNET-TEST--AP AARNET Test",
    "4739": "INTERNODE- Internode Pty Ltd",
    "4740": "OZEMAIL- OzEmail ISP",
    "4741": "SAMART-BOARDER- Samart Corporation Co., Ltd.",
    "4742": "ATT-ELSAU- AT&T EasyLink Services Australia",
    "4744": "N-HTAL Hutchison Telecoms (Aust) Ltd",
    "4745": "GMARKET--KR GMARKET",
    "4746": "PRISTINE-COMM Pristine Communications Limited",
    "4747": "TFN-TW-TTN TTN N merged by TFN",
    "4748": "RESOLINK--AP Resources Link Network Limited",
    "4749": "WISETECHGLOBAL-AU-SYD WiseTechGlobal Pty Ltd",
    "4750": "CSLOXINFO--AP CS LOXINFO PUBLIC COMPANY LIMITED",
    "4751": "NBIP--AP TongLian(Ningbo)Info-Port Co.,Ltd",
    "4752": "UNSPECIFIED Geko Pty Limited",
    "4753": "LGDACOM4753 LG DACOM Corporation",
    "4754": "STPN-GAC-ICANN 1016, Electronics Niketan, 6, CGO Complex",
    "4755": "TATACOMM- TATA Communications formerly VSNL is Leading ISP",
    "4756": "HANACATV--KR HANACATV Broadcast Ltd",
    "4757": "UPRESTO--KR EY Research Institute",
    "4758": "NICNET-VSNL-BOARDER-AP National Informatics Centre",
    "4759": "EVOSERVE--AP EvoServe is a content and online access Internet provider company",
    "4760": "HKTIMS-AP PCCW Limited",
    "4761": "INDOSAT-INP-AP INDOSAT Internet Network Provider",
    "4762": "MAHIDOL-BORDER- Mahidol University, Thailand",
    "4763": "TELSTRANZ- TelstraClear Ltd",
    "4764": "WIDEBAND--AU Wideband Networks Pty Ltd, Transit",
    "4765": "WORLDNET- World Net & Services Co., Ltd.",
    "4766": "KIXS--KR Korea Telecom",
    "4767": "AIT-CS-N Computer Science",
    "4768": "CLIX-NZ TelstraClear Ltd",
    "4769": "ICONZ-WEBVISIONS-AP Iconz-Webvisions Pte. Ltd.",
    "4770": "ICONZ- ICONZ Ltd",
    "4771": "NZTELECOM Telecom New Zealand Ltd.",
    "4772": "SINGNET-MSN- SingNet Business Dept",
    "4773": "MOBILEONELTD--AP MobileOne Ltd. Mobile/Internet Service Provider Singapore",
    "4774": "ABONE- A-Bone by Internet Initiative Japan Inc.",
    "4775": "GLOBE-TELECOM- Globe Telecoms",
    "4776": "ANET-TH-AP A-Net Co., Ltd.",
    "4777": "APNIC-NSPIXP2- Asia Pacific Network Information Centre",
    "4778": "BORAL-LIMITED-AP Optus Customer Network",
    "4779": "PHOPENIX--PH Philippine Open Internet Exchange",
    "4780": "SEEDNET Digital United Inc.",
    "4781": "PAGICNET-1 PAGIC.net , INC.",
    "4782": "GSNET Data Communication Business Group",
    "4783": "SYSNET-1 SYSTEX CORPORATION",
    "4784": "ANET-CUST-TH-AP South-East Asia University",
    "4785": "CCD1--AP Cocoon Data Limited",
    "4786": "COMSYSAUST--AP Computer Systems (Australia) Pty Ltd",
    "4787": "N-CBN Internet Service Provider",
    "4788": "TMNET--AP TM Net, Internet Service Provider",
    "4789": "CERNAP1-CN NAP1 at CERNET",
    "4790": "CHOSUN--KR DIGITAL CHOSUN",
    "4791": "JOONGANGLIBO--KR JoongAng Ilbo",
    "4792": "SKCOMMS--KR SK communications",
    "4793": "HHI--KR Hyundai Heavy Industries",
    "4794": "OV-NSW-QLD-AP Optus Vision",
    "4795": "INDOSATM2-ID INDOSATM2  N",
    "4796": "BANDUNG-NET--AP Institute of Technology Bandung",
    "4797": "WSM--IN Wipro Spectramind Services Pvt Ltd  (BPO -INDIA)",
    "4798": "UNSPECIFIED SBI&S",
    "4799": "CHINA169-JT CNCGROUP Jitong IP network",
    "4800": "LINTARTA--AP Network Access Provider and Internet Service Provider",
    "4802": "N-IINET iiNet Limited",
    "4803": "TTGN-DOM--AP TTGN , DOMESTIC INTERNET EXCHANGE , THAILAND",
    "4804": "MPX- Microplex PTY LTD",
    "4805": "EQUANT-OCEANIA Orange Business  for Oceania",
    "4806": "INTERNODE-PROF-ACCESS-AP Internode Professional Access",
    "4807": "CAMTECHSA--AP Camtech (SA) Pty Ltd",
    "4808": "CHINA169-BJ CNCGROUP IP network China169 Beijing Province Network",
    "4809": "CHINATELECOM-CORE-WAN-CN2 China Telecom Next Generation Carrier Network",
    "4810": "CHINANET-CORE-WAN-SOUTH CHINANET core WAN Central",
    "4811": "CHINANET-SHANGHAI-MAN China Telecom (Group)",
    "4812": "CHINANET-SH-AP China Telecom (Group)",
    "4813": "BACKBONE-GUANGDONG-AP China Telecom(Group)",
    "4814": "CHINA169-BBN CNCGROUP  IP network\u00a1\u00aaChina169 Beijing Broadband Network",
    "4815": "CHINANET-IDC-SH China Telecom (Group)",
    "4816": "CHINANET-IDC-GD China Telecom (Group)",
    "4817": "DESTRA-AU-AP Destra Corporation",
    "4818": "DIGIIX-AP DiGi Telecommunications Sdn. Bhd.",
    "4819": "STRATOS-GLOBAL-IAPAC--AP Xantic BV",
    "4820": "NSWDAGJ--AP Multi-homing N for NSW",
    "4821": "SINERGINET--ID PT Sinergi Semesta Telematika",
    "4822": "NATIONAL-LIBRARY-AU National Library of Australia",
    "4823": "JINET-GEC-IAINFONET Multihome network  between Jasmine Internet(7616)",
    "4824": "GLOWWAVE--AP glowwave.com",
    "4825": "FAL--AP Metcash Trading Ltd",
    "4826": "VOCUS-BACKBONE- Vocus Connect International Backbone",
    "4827": "RESERVED-CSLOXINFO-TH CSLOXINFO",
    "4828": "WING-HANG-BANK-HK-AP WING HANG BANK LIMITED",
    "4829": "MYTELECOM-PL--AU-AP My Telecom Holdings Pty. Ltd.",
    "4830": "N-WESTPACNZ-AP  # -WESTPACNZ-AP CONVERTED TO N-WESTPACNZ-AP FOR RPSL COMPLIANCE Westpactrust",
    "4831": "MELCO-NZ--AP Melco Sales (NZ) Ltd",
    "4832": "INTERNUXNET--ID PT. iNterNUX",
    "4833": "SPOTNET--AP PT. Usaha Mediantara Intranet (ISP)",
    "4834": "ESURF--AP eSurf Wireless Ltd",
    "4835": "CHINANET-IDC-SN China Telecom (Group)",
    "4836": "NUS-SOX Singapore Open Exchange",
    "4837": "CHINA169-BACKBONE CNCGROUP China169 Backbone",
    "4838": "WHCOMGRP-AP Wholesale Communications Group Pty Ltd, Wholesale",
    "4839": "CERNAP2-CN NAP2 at CERNET located in Shanghai",
    "4840": "CERNAP3-CN NAP3 at CERNET located in Guangzhou",
    "4841": "TLRGNET--AP Level 5, 100 Harris St",
    "4842": "HCCT--AP Community Assets Ltd",
    "4843": "CAINONET-CN--AP China MST's High Speed Router Test Network",
    "4844": "SUPERINTERNET--AP SuperInternet ACCESS Pte Ltd",
    "4845": "SINGTEL-TW Chung Hsiao East Road",
    "4846": "AITEL-SA-AU-AP AI TEL P/L",
    "4847": "CNIX-AP China Networks Inter-Exchange",
    "4848": "UNSPECIFIED Super Telecom, Ltd.",
    "4849": "HKINTCOM- AsiaTech Telecom Ltd.",
    "4850": "DIGICOM--AP Digicom LLC",
    "4851": "HOSTNETWORKS--AU-AP Web Hosting, Dedicated Servers, Co-location.",
    "4852": "IINET-SA- iiNet Technologies (SA) Pty Ltd",
    "4853": "COMMANDER--AP Commander Communications",
    "4854": "IINET-AU Netspace Online Systems",
    "4855": "PI-ID--AP Pacific Link Indonesia",
    "4856": "ANET-4856-TH-AP Customer of ANET",
    "4857": "TVP-OPERATIONS-COMPANY-AP TVP Operations Company",
    "4858": "CORPITA--AP Corpita Pty Ltd",
    "4859": "CEISTNET--AP The State Information Center of P.R.China",
    "4860": "VZB-AU- Verizon Australia PTY Limited",
    "4861": "GLOBAL-IP-KOREA--AP Orange Business",
    "4862": "EQUANT-IA Orange Business  for Asia",
    "4863": "EY-PH MECO Enterprises Inc.",
    "4866": "POLYVORE - Polyvore Inc.",
    "4867": "BATS-EXCHANGE-1 - BATS Exchange, Inc.",
    "4868": "PIONEER - Pioneer Hi-Bred International, Inc.",
    "4869": "CNMCC - Central New Mexico Community College",
    "4870": "EHS-BHAM - Electronic Healthcare Systems, Inc.",
    "4871": "ITMN- - InterMune Inc",
    "4872": "AHSREDDEER - Alberta Health Services",
    "4873": "COOPERINDUSTRIES - Cooper Industries LTD",
    "4874": "UNCOMMON-NET - Uncommon Technology Incorporated",
    "4875": "LMC - Long Motor Corporation",
    "4876": "PACIFICPULMONARY-AUTONOMOUSSYSTEM - Pacific Pulmonary Services",
    "4877": "G3TEL- - G3 Telecom Corp.",
    "4878": "NOKIA-CTO-ES - Nokia, CTO Operations",
    "4879": "BURYPARKPRESS - BURY PARK PRESS",
    "4880": "LIFELINE-N - Lifeline Systems, Company",
    "4881": "ALBANY-WGL - City of Albany Water, Gas & Light Commission",
    "4882": "VOXEO-L - Voxeo Corporation",
    "4883": "ALLIANT-01 - Alliant Managed Services",
    "4884": "TCHD - Tarrant County Hospital District",
    "4885": "THCP-N - Twin Haven Capital Partners, LLC",
    "4886": "LIFECORPORATION - Life Corporation",
    "4887": "PORTOFCC - Port of Corpus Christi Authority",
    "4888": "USPSOIG-1 - United States Postal Service Office of Inspector General",
    "4889": "USPSOIG-2 - United States Postal Service Office of Inspector General",
    "4890": "N-RICHLINE-FL - Richline Group Inc",
    "4891": "FERRI-3 - Ferric Systems, LLC",
    "4893": "RGM-N-1 - RGM Advisors LLC",
    "4894": "COANAHEIM - City of Anaheim",
    "4895": "BLOOMIP-INC - Bloomip Inc.",
    "4896": "INGENICO - Ingenico Inc",
    "4897": "ECHO-LABS-LLC - ECHO Labs LLC",
    "4898": "OPENTABLE- - Opentable, Inc.",
    "4899": "-ULTRACART-1 - UltraCart.com",
    "4900": "N1 - Montgomery County Hospital District",
    "4901": "GWU-CAAREN - The George Washington University",
    "4902": "CI-CCN - CONSERVATION INTERNATIONAL FOUNDATION",
    "4903": "ANYPRESENTATIONS - ANY PRESENTATIONS LLC",
    "4904": "COATUE - Coatue Management",
    "4905": "FA-LAX-1 - Future Ads LLC",
    "4906": "FDS-01 - Frontline Data Services, Inc",
    "4907": "BRICKSHELF - Brickshelf LLC",
    "4908": "-CONCENTRIC - XO Communications",
    "4909": "DNIC--04909 - DoD Network Information Center",
    "4910": "SPRINTNET-NC - Sprint Mid-Atlantic Telecom",
    "4911": "QWEST--4911 - Qwest Communications Company, LLC",
    "4912": "CENTIER - CENTIER BANK",
    "4913": "NET-CPRK CapRock",
    "4914": "Red Nacional de Honduras, HONDUNet",
    "4915": "TRANE-UPG - The TRANE Co.UPG",
    "4916": "HQINSCOM - US ARMY INSCOM",
    "4917": "AMDOCS- - AMDOCS",
    "4918": "THEPOINT-NET - Silver Creek Industries",
    "4919": "CONSOLIDATED - Consolidated Access & Networks, Inc.",
    "4920": "CYBERPORTS - Cyberports, Inc.",
    "4921": "EX-SV-GW5 - Exodus Communiations, Inc.",
    "4922": "GLOBALCOM - Shentel Service Company",
    "4923": "HOYT - MCIX, Inc.",
    "4924": "NIIA-NET - Northern Indiana Internet Access, Inc.",
    "4925": "FIRSTDATA - First Data Corp.",
    "4926": "Telefonica de Argentina",
    "4927": "IMPU Impulse Internet Services",
    "4928": "VAIS - Virginia Internet Services",
    "4929": "BENCHMARK - Benchmark Communications",
    "4930": "DMG1 - Digital Management Group",
    "4931": "INTERSRV2 - Internet Services of Central Florida",
    "4932": "I3 - I3 Inc",
    "4933": "LOGICAL3 - Logical Net Corporation",
    "4934": "LANIER-WW - Lanier Worldwide",
    "4935": "DIRECTNIC-ANYCT1-ETCOT - DirectNIC, Ltd.",
    "4936": "HC-LIB - Howard County Library",
    "4937": "IAMERICA-NET - Internet America, Inc.",
    "4938": "SPRINTNET-SC - Sprint Mid-Atlantic Telecom",
    "4939": "N-SOLECT - Solect Technology Group, Inc.",
    "4940": "IAP-WORLDWIDE-SERVICES - IAP World Service Inc",
    "4941": "FDT - The CD-ROM Store",
    "4942": "B-NET - B-Net Technologies",
    "4943": "NOL- - Networks On-Line",
    "4944": "Petroleos de Venezuela S.A.",
    "4945": "HARRIS-SEMICONDUCTOR - Harris Semiconductor Sector Telecommunications",
    "4947": "IA-LA- - Internet America, Inc.",
    "4948": "AIX-NET - Alpha Internet",
    "4949": "UCINET-EIGRP - University of California at Irvine",
    "4950": "N-SPRN-NYSERNET1 - SPRINT, Business Serices Group",
    "4951": "SPRINTLINK-NYSERNET2B - SPRINT, Business Serices Group",
    "4952": "CAPECOD - Intramedia",
    "4953": "BCPL - Baltimore County Public Library",
    "4954": "CARR - Carroll County Government",
    "4955": "NDL - Network Datalink, Inc.",
    "4956": "LOGICSYS - Logic Systems",
    "4957": "VCNET - Internet Access of Ventura County",
    "4958": "LDSNET - Long Distance Savers",
    "4959": "CORPCOMM - Corporate Communications, Inc.",
    "4960": "PERNET - PERnet Communications, Inc.",
    "4961": "DISC--KR Daewoo Information System",
    "4962": "WINKCOMM - Wink Communications Group, Inc.",
    "4963": "TEXOMA - Internet Texoma",
    "4964": "Refineria ISLA (Curazao) S.A.",
    "4965": "AMER - Vision Bahn Corp",
    "4966": "CELLAWTE - Casella Waste System Inc",
    "4967": "STARTEL S.A.",
    "4969": "MEDIMMUNE - Medimmune, LLC",
    "4970": "N1 - RONALD BLUE & CO., LLC",
    "4971": "NWPROS - Network Pros, Inc.",
    "4972": "UPS-4972 - UNITED PARCEL SERVICE",
    "4973": "UPS-4973 - UNITED PARCEL SERVICE",
    "4974": "GROVE-MRS Rawdon House",
    "4975": "LER-NET-BLOCK - Computer Tech Services, Inc.",
    "4976": "SUNGLSES - Florida Imports Inc",
    "4977": "N1 - Qinetiq North America Operations,LLC",
    "4978": "GDI-NET- - Global Datalink, Inc.",
    "4979": "4979 - GXS",
    "4980": "NO - Whole Sale",
    "4981": "TECLINK - MCI Communications Services, Inc. d/b/a Verizon Business",
    "4982": "JAZZIE - Jazzie Systems",
    "4983": "INTEL-SC- - Intel Corporation",
    "4984": "INGRESS - Ingress Communications, Inc.",
    "4985": "PGWORKS - PHILADELPHIA G WORKS",
    "4986": "INTERSTAR - InterStar Network Services, Inc.",
    "4987": "ALOHANET2 - Hawaii Online",
    "4988": "ALOHANET1 - Hawaii Online",
    "4989": "YUMESJDC01 - YUME",
    "4990": "ATTIS-N4990 - AT&T Internet Services",
    "4991": "COGENT-4991-4994 - AGIS",
    "4992": "COGENT-4991-4994 - AGIS",
    "4993": "COGENT-4991-4994 - AGIS",
    "4994": "COGENT-4991-4994 - AGIS",
    "4995": "Netup S.A.",
    "4996": "SBI - Citigroup",
    "4997": "AFS-WEST - American Fiber Systems, Inc.",
    "4998": "LANDE - The Lande Group",
    "4999": "SPRINTIPDIAL - Sprint",
    "5000": "IDT- IDT GLOBAL LIMITED",
    "5001": "SONIC - Sonicnet",
    "5002": "BBSATLGA - BellSouth Business Systems",
    "5003": "GIGAN-2 - Insync Internet Services, Inc.",
    "5004": "EAGLENET - Eaglenet, Inc.",
    "5005": "Asociados Espada C.A.",
    "5006": "ZAYOMN1 - Onvoy",
    "5007": "COMPUTOPIA - Computopia",
    "5008": "BRADSHAW-RICHARDSON-TX-US-01 - Bradshaw",
    "5009": "ADVTEL - EATEL",
    "5010": "KISNET-1 - KISNET Corporation",
    "5011": "EMTF-AVI - 754th Electronic Systems Group",
    "5012": "EMTF-AZO - 754th Electronic Systems Group",
    "5013": "EMTF-IZM - 754th Electronic Systems Group",
    "5014": "EMTF-INC - 754th Electronic Systems Group",
    "5015": "SHOUTING - Shouting Ground Technologies",
    "5016": "BRAGG-NEC - Headquarters, USAISC",
    "5017": "CITICTEL-CPC-5017 CITIC Telecom International CPC Limited",
    "5018": "CITICTEL-CPC-5018 CITIC Telecom International CPC Limited",
    "5019": "DATACOM-GATE - InterSec, Inc.",
    "5020": "MEA - Mitsubishi Electronics",
    "5021": "PACAF-GCCS - 754th Electronic Systems Group",
    "5022": "FANEUIL - Faneuil Systems",
    "5023": "FIREBALL - Publication Services",
    "5024": "BRIDGE - BridgeNet, LC",
    "5025": "N-DATABANK - Databank, Inc.",
    "5026": "LVVWD - Las Vegas Valley Water District",
    "5027": "ACSIL - Applied Computer Services",
    "5028": "GATEWAYNORTH - Evergreen Technologies Corporation",
    "5029": "VEG-NET - On Ramp Internet Computer Services",
    "5030": "TAL - Transamerica Leasing",
    "5031": "DNIC--05031 - DoD Network Information Center",
    "5032": "VARDE-PART Varde Partners Europe Ltd.",
    "5033": "ISW - Internet Specialties West Inc.",
    "5034": "-STARNET - STAR Communications",
    "5035": "CYNET - WebNet",
    "5036": "WCA - Whalley Computer Associates",
    "5037": "DNIC--05037 - Navy Network Information Center (NNIC)",
    "5038": "NSAN-DOM - Success Institutes, Inc.",
    "5039": "TECNET2 - Tecnet",
    "5040": "MINT - B+C Consulting, Inc.",
    "5041": "3PD - 3PD",
    "5042": "INFOWAVE - Discnet",
    "5043": "PERRAUT - Perraut Corporation",
    "5044": "N-DATABANK1 - Databank, Inc.",
    "5045": "N-DATABANK1 - Databank, Inc.",
    "5046": "RANDOMC - Random Communications, Inc",
    "5047": "ARNET2 - ARNet",
    "5048": "FIBER - FIBERNET Corp.",
    "5049": "MORGAN-N - Morgan Stanley Group Inc.",
    "5050": "PSC-EXT - Pittsburgh Supercomputing Center",
    "5051": "KOLNET--KR Korea Telecom Hitel",
    "5052": "DNIC--05052 - DoD Network Information Center",
    "5053": "HTP - HTP Net, Inc",
    "5054": "PROGNET - RealNetworks, Inc.",
    "5055": "WANET - Software Design Associates",
    "5056": "INS-NET-2 - Iowa Network Services",
    "5057": "XENITEC - GS1115",
    "5058": "NRL-EXP - Navy Network Information Center (NNIC)",
    "5059": "STARPAGING - Star Paging, Inc.",
    "5060": "CLEARBLUE- - ClearBlue Technologies",
    "5061": "CLEARBLUE- - ClearBlue Technologies",
    "5062": "CLEARBLUE- - ClearBlue Technologies",
    "5063": "CLEARBLUE- - ClearBlue Technologies",
    "5064": "CLEARBLUE- - ClearBlue Technologies",
    "5065": "NAVISITE-IE Navisite Ireland",
    "5066": "CLEARBLUE- - ClearBlue Technologies",
    "5067": "CLEARBLUE- - ClearBlue Technologies",
    "5068": "CLEARBLUE- - ClearBlue Technologies",
    "5069": "CLEARBLUE- - ClearBlue Technologies",
    "5070": "COMED - CoMed Communications",
    "5071": "WESTEL-1 - WesTel Telecommunications",
    "5072": "INDYNET - IndyNet",
    "5073": "HPES - Hewlett-Packard Company",
    "5074": "N-ATTELS - AT&T BMGS",
    "5075": "N-ATTGMS - AT&T BMGS",
    "5076": "UNICOM - Unicom Communications, Inc.",
    "5077": "N-WSNET - WSNetwork Communications Services, Inc.",
    "5078": "ONENET--1 - Oklahoma Network for Education Enrichment and",
    "5079": "DIAL-CALL - Nextel Communications, Inc",
    "5080": "ARAMCO ARAMCO  number",
    "5081": "CCS- - CLARE COMPUTER SOLUTIONS",
    "5082": "CLOVERLEAF - Stanton Network Services",
    "5083": "DRAKE-NET - Dnet Internet Services",
    "5084": "GSL-HQ - Sprint International",
    "5085": "ERX-NETFUN Net Fun Limited",
    "5086": "IDNET - Innovative Data Services",
    "5087": "LANKA-COM Lanka Communication Services",
    "5088": "NAIINT - News Corporation",
    "5089": "NTL Virgin Media Limited",
    "5090": "ARKANSTECH - ARKANS TECH UNIVERSITY",
    "5091": "FXC-N - International Foreign Exchange Concepts, L.P.",
    "5092": "NNE - North by Northeast Networks, Inc.",
    "5093": "OVID- - Ovid Technologies",
    "5094": "PARAGON- - Paragon Cable",
    "5095": "BOOKLINK- - Booklink/Navisoft",
    "5096": "411CA - 411 LOCAL SEARCH CORP.",
    "5097": "INVESTORSTITLE - Investors Title Company",
    "5098": "OPUSONE-NETS - Opus One Winery, LLC",
    "5099": "NWUC - Northwestern University",
    "5100": "N-TX-DDC - Tristero, Inc.",
    "5101": "LEECOUNTYSCHOOLS - The School District of Lee County",
    "5102": "ATTIS-N5102 - AT&T Internet Services",
    "5103": "ATTIS-N5103 - AT&T Internet Services",
    "5104": "ATTIS-N5104 - AT&T Internet Services",
    "5105": "ATTIS-N5105 - AT&T Internet Services",
    "5106": "WINPR - WinPR, Inc.",
    "5107": "ATTIS-N5107 - AT&T Internet Services",
    "5108": "PADENA-N - City of Pasadena",
    "5109": "HT-IDS5109 - HuntTel",
    "5110": "CITY-OF-VANCOUVER - City of Vancouver",
    "5111": "CABLE-N - it.canada",
    "5112": "SIDLINGER - Sidlinger Computer Corporation",
    "5113": "HGEA- - H.G.E.A",
    "5114": "KBI-NET-GW - Knowledge Broker, Inc.",
    "5115": "ONESTEP - OneStep Internet Services",
    "5116": "SPI-N - Spruce Private Investors, LLC",
    "5118": "BGA-N - Brysam Global Advisors, LLC",
    "5119": "ALTARUM-INSTITUTE - Altarum Institute",
    "5120": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5121": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5122": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5123": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5124": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5125": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5126": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5127": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5128": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5129": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5130": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5131": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5132": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5133": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5134": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5135": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5136": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5137": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5138": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5139": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5140": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5141": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5142": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5143": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5144": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5145": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5146": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5147": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5148": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5149": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5150": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5151": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5152": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5153": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5154": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5155": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5156": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5157": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5158": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5159": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5160": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5161": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5162": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5163": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5164": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5165": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5166": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5167": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5168": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5169": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5170": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5171": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5172": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5173": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5174": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5175": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5176": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5177": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5178": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5179": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5180": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5181": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5182": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5183": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5184": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5185": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5186": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5187": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5188": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5189": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5190": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5191": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5192": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5193": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5194": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5195": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5196": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5197": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5198": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5199": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5200": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5201": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5202": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5203": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5204": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5205": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5206": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5207": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5208": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5209": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5210": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5211": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5212": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5213": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5214": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5215": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5216": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5217": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5218": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5219": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5220": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5221": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5222": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5223": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5224": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5225": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5226": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5227": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5228": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5229": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5230": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5231": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5232": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5233": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5234": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5235": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5236": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5237": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5238": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5239": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5240": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5241": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5242": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5243": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5244": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5245": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5246": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5247": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5248": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5249": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5250": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5251": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5252": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5253": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5254": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5255": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5256": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5257": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5258": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5259": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5260": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5261": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5262": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5263": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5264": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5265": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5266": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5267": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5268": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5269": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5270": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5271": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5272": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5273": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5274": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5275": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5276": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5277": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5278": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5279": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5280": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5281": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5282": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5283": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5284": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5285": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5286": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5287": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5288": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5289": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5290": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5291": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5292": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5293": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5294": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5295": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5296": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5297": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5298": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5299": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5300": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5301": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5302": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5303": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5304": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5305": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5306": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5307": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5308": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5309": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5310": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5311": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5312": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5313": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5314": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5315": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5316": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5317": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5318": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5319": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5320": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5321": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5322": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5323": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5324": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5325": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5326": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5327": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5328": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5329": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5330": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5331": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5332": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5333": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5334": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5335": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5336": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5337": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5338": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5339": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5340": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5341": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5342": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5343": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5344": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5345": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5346": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5347": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5348": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5349": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5350": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5351": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5352": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5353": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5354": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5355": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5356": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5357": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5358": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5359": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5360": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5361": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5362": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5363": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5364": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5365": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5366": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5367": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5368": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5369": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5370": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5371": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5372": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5373": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5374": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5375": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5376": "DNIC-BLK-05120-05376 - DoD Network Information Center",
    "5377": "TAIDE-EMEA Astrium Services Enterprises",
    "5378": "Cable & Wireless UK P.U.C.",
    "5379": "MK-UKIM- Univerzitet \"Sv. Kiril i Metodij\"",
    "5380": "MONOLIT ISP",
    "5381": "POWTECH- PowerTech Information Systems",
    "5382": "TELESYSTEM-NET Planet Service Srl",
    "5383": "Siemens AG",
    "5384": "EMIRATES-INTERNET Emirates Telecommunications Corporation",
    "5385": "RUSSMEDIA-IT Teleport Consulting & Systemmanagement GmbH",
    "5386": "COSMOS-SN- Space Research Institute of Russian Academy of Sciences",
    "5387": "NSC Institute of Computational Technologies of SB R",
    "5388": "ENERGIS- Energis UK",
    "5389": "EUROWEB Internet Service Provider Co.",
    "5390": "EURONET Online Breedband B.V.",
    "5391": "T-HT Hrvatski Telekom d.d.",
    "5392": "TELNET-ITALY TELNET S.r.l.",
    "5393": "ISYSHU- iSYS Hungary Kft.",
    "5394": "UNIDATA UNIDATA S.p.A.",
    "5395": "Agora' Telematica S.p.A.",
    "5396": "MC-LINK MC-link Spa",
    "5397": "INROMA- CPUR Consorzio per le Applicazioni di Supercalcolo",
    "5398": "TINET SA",
    "5399": "bART Internet Services B.V.",
    "5400": "BT British Telecommunications plc",
    "5401": "N-CLUENET The ClueNet Project",
    "5403": "5403 APA-IT Informations Technologie G.m.b.H",
    "5404": "CONOVA- N conova communications GmbH",
    "5405": "CSO_NET CSO.Net",
    "5406": "BNIX",
    "5407": "SKYNET-CZ SkyNet",
    "5408": "GR-NET Greek Research and Technology Network S.A",
    "5409": "TPL-N toplink GmbH",
    "5410": "N-BOUYGTEL-ISP Bouygues Telecom S.A.",
    "5411": "CC-NET-",
    "5413": "5413 Daisy Communications Ltd",
    "5414": "Zynet Ltd",
    "5415": "GU CJSC Global Ukraine",
    "5416": "Batelco",
    "5417": "DEMON-NL XS4ALL Internet BV",
    "5418": "NERDNET- nerdnet",
    "5419": "CUCI Cubic Circle B.V.",
    "5420": "KEMNET Kemira Oyj",
    "5421": "SU-NET- Sofia University \"St. Kliment Ohridski\"",
    "5422": "Superonline Corporate Business Unit Autonomous System",
    "5423": "ETELAT eTel Austria AG",
    "5424": "ATNET-AT ATnet",
    "5425": "SPIDERNET SpiderNet Services Public Ltd",
    "5426": "SUNRISE-MOBILE Sunrise Communications AG",
    "5427": "PRTL-DE Primus Telecommunications GmbH, Germany",
    "5428": "ECL- Energis Communications Ltd",
    "5429": "IIP-NET-5429 \"UMOS CENTER\" LLC",
    "5430": "FREENETDE freenet Datenkommunikations GmbH",
    "5431": "FG-CORE OOO FREEnet Group",
    "5432": "BELGACOM-SKYNET- Belgacom regional N",
    "5433": "ROKSON- VEROLINE Ltd",
    "5434": "NURSAT-ALA- JSC Nursat",
    "5435": "VELCOM- Velcom d.o.o.",
    "5436": "BT-FRANCE BT France",
    "5437": "FranceNet",
    "5438": "ATI-TN Agence Tunisienne d'Internet",
    "5439": "5439 5439",
    "5440": "N-GARRINT Consortium GARR",
    "5441": "N-CNAF Consortium GARR",
    "5442": "N-CILEA Consortium GARR",
    "5443": "N-CINECA-GARR Consortium GARR",
    "5444": "N-PISA Consortium GARR",
    "5445": "N-ROMA Consortium GARR",
    "5446": "N-FRCATI Consortium GARR",
    "5447": "N-LNGS Consortium GARR",
    "5448": "N-INFNMI Consortium GARR",
    "5449": "N-TRIESTE Consortium GARR",
    "5450": "N-BARI Consortium GARR",
    "5451": "N-NAPOLI Consortium GARR",
    "5452": "N-ER Consortium GARR",
    "5453": "N-BARI Consortium GARR",
    "5454": "N-PALERMO Consortium GARR",
    "5455": "N-UNITO Consortium GARR",
    "5456": "N-POLITO Consortium GARR",
    "5457": "N-FIRENZE Consortium GARR",
    "5458": "FNV Finans Yatirim Menkul Degerler A.S.",
    "5459": "LINX- London Internet Exchange Ltd.",
    "5460": "REST Networks.",
    "5461": "OKB MEI",
    "5462": "CABLEINET Virgin Media Limited",
    "5463": "PERCEVAL Perceval S.A.",
    "5464": "NETDISCOUNTER Netdiscounter GmbH autonomous system",
    "5466": "EIRCOM Eircom Limited",
    "5467": "MIPT Non state educational institution \"Educational Scientific and Experimental Center of Moscow Institute of Physics and Technology\"",
    "5468": "URFU Yeltsin UrFU, Ural Federal University",
    "5469": "AGNET Ahlstrom Corporation",
    "5470": "AUTHNET Aristotle University of Thessaloniki",
    "5471": "SCI-NNOV scientific/educational network",
    "5472": "CC Power Ltd",
    "5473": "NORILSK Iterica LLC",
    "5474": "TOBBETU-NET TOBB Economics and Technology University",
    "5475": "Universitaet Hamburg",
    "5476": "TU Hamburg-Harburg",
    "5477": "Universitaet der Bundeswehr Hamburg",
    "5478": "GKSS Forschungszentrum Geesthacht Gmbh",
    "5479": "UNI-VILNIUS Kaunas University of Technology",
    "5480": "R61NET State Educational institution for High professional education 'Southern Federal University'",
    "5481": "ISET ISET Informatica",
    "5482": "5482 Daisy Communications Ltd",
    "5483": "HTC- Magyar Telekom Plc.",
    "5484": "CIS Shabakeh Gostar Shahriyar Co. (Ltd.)",
    "5485": "LIMITLESS- Limitless Technical Dimensions",
    "5486": "SMILE-N 012 Smile Communications LTD.",
    "5487": "Elisa Oyj",
    "5488": "BELGACOM Belgacom",
    "5489": "TEI-THES Technological and Educational Institute of Thessaloniki",
    "5490": "CZ-TERMINAL Nextra Czech Republic s.r.o.",
    "5491": "OLSSON_NET Jan Olsson",
    "5493": "Ecsnet S.r.l.",
    "5495": "N-SPBGU Saint-Petersburg State University",
    "5496": "WIREHUB Easynet Nederland B.V.",
    "5497": "ZERO Nethead Ltd",
    "5498": "UNIBEL- UNIBEL",
    "5499": "Cybernet Italia S.p.A.",
    "5500": "CQM- Colloquium Limited",
    "5501": "FRAUNHOFER-CLUSTER-BW Fraunhofer-Gesellschaft zur Foerderung der angewandten Forschung e.V.",
    "5502": "NATO SACLANT Undersea Research Centre",
    "5503": "RMIFL RM Education PLC",
    "5504": "LOGOSNET Logosnet Services Limited",
    "5507": "HU-BIX- Council Hungarian Internet Provider",
    "5508": "WJQS- LLC \"Jasmin International\"",
    "5510": "Italia Com Consortium",
    "5511": "OPENTRANSIT Orange S.A.",
    "5513": "TMH T-Mobile Hungary Telecommunications Company Limited by Shares",
    "5514": "PiSoft Network Solutions Srl",
    "5515": "TS-FINLAND-DATANET-OLD TS Finland DataNet",
    "5516": "INESC INESC - Instituto de Engenharia de Sistemas e Computadores PCUP",
    "5517": "CSL CSL Computer Service Langenbach GmbH",
    "5518": "TELIALATVIJA Telia Latvija SIA",
    "5519": "5519 Daisy Communications Ltd",
    "5520": "UNI-KOELN Universitaet zu Koeln",
    "5521": "MCS-CITYLINE MCS Moorbek Computer Systeme GmbH",
    "5522": "OMNITEL OMNITEL Net",
    "5523": "RMT CJSC \"CREDO-TELECOM\"",
    "5524": "BREEDBANDNEDERLAND Breedband Nederland B.V.",
    "5525": "DU-2 Emirates Integrated Telecommunications Company PJSC",
    "5526": "WR-PL- Telekomunikacja Internetowa Sp. z o.o.",
    "5527": "JJS- JJS Sp. z o.o.",
    "5528": "ANADANA- SIA AnaDana",
    "5529": "DIAG- DIAG Dienstleistungen AG",
    "5530": "EDS-GROUP- \"Commercial House Inter Trading Plus\" LTD",
    "5531": "TEZTOUR- \"Tez Tour\", Ltd.",
    "5532": "TERRANETMALTA GO p.l.c.",
    "5533": "CLARANET-PT Claranet Portugal Telecomunicacoes S.A.",
    "5534": "BT Communications Ireland Limited",
    "5535": "Food And Agriculture Organization of the United Nations",
    "5536": "INTERNET-EGYPT Internet Egypt Network",
    "5537": "GARANT-PARK-TELECOM Garant-Park-Telecom, Ltd",
    "5538": "SIGMANET-NIC Institute of Mathematics and Computer Science of University of Latvia",
    "5539": "SPACENET SpaceNET AG",
    "5540": "The Israel Electric Corporation Limited",
    "5541": "ADNET-TELECOM SC AD NET MARKET MEDIA SRL",
    "5542": "Ort Israel",
    "5543": "RIA-AVERS- JSC Volgatranstelecom",
    "5544": "UCNC UCNC Networks",
    "5545": "VyatRegNet",
    "5547": "ORTEL- Orient-Telecom",
    "5548": "MIIT-RZD- State Educational Institution of higher professional education Moscow State University of Railway Engineering",
    "5549": "SEICOM- SEICOM-EXTERN",
    "5550": "TK- Technical University of Gdansk, Academic Computer Center TK",
    "5551": "CORINET Cable & Wireless UK P.U.C.",
    "5552": "DIALNET-UK Redcentric Managed Solutions Limited",
    "5553": "TAMBOVMAN- State Educational Institution of Higher Professional Education \"Tambov State Technical University\"",
    "5554": "INTEGRA Integra Zrt.",
    "5555": "SOHONETEU- Sohonet Limited",
    "5559": "Saltmine Creative",
    "5560": "MTN-ICS Belgacom International Carrier Services SA",
    "5562": "INTERHOUSE-FRANKFURT TELECITYGROUP INTERNATIONAL LIMITED",
    "5563": "URAL CJSC Ural WES",
    "5564": "SOL- Brightsolid Ltd",
    "5565": "SATRAX-NET Ltd.",
    "5566": "COSMOS",
    "5567": "5567 National Research Tomsk Polytechnic University",
    "5568": "RBNET ROSNIIROS Russian Institute for Public Networks",
    "5569": "Posten AB, IT",
    "5570": "UKNET- UK Network Services",
    "5571": "NETCOM MDNX Enterprise Services Limited",
    "5572": "BOTIK Botik Technologies Ltd.",
    "5573": "KRNET- OJSC Rostelecom",
    "5574": "TDC-SE TDC Sverige AB",
    "5575": "TM-POP-FI",
    "5576": "AKSHI Agjencia Kombetare Shoqerise se Informacionit",
    "5577": "ROOT root SA",
    "5578": "GTS-SK- GTS Slovakia, a.s.",
    "5579": "MIDRAY- Midray GmbH",
    "5580": "ATRATO Atrato IP Networks",
    "5581": "EHIS-",
    "5582": "MICROSOFT NETWORK IN FRANCE",
    "5583": "ORANGE-BUSINESS-SERVICES-BENELUX Orange S.A.",
    "5584": "Computer centre",
    "5585": "IIX-N Israel Internet Association",
    "5586": "MCI-INT Verizon UK Limited",
    "5587": "BUSINESSSERVE Legend Communications plc.",
    "5588": "GTSCE GTS Czech s.r.o.",
    "5589": "MUNBANK- Novosibirsk Municipal bank",
    "5591": "MARTELCOM- OJSC Rostelecom",
    "5592": "CONCOM- ConCom Ltd (Kharkov, Ukraine)",
    "5593": "CRIS- Crimean Internet Service",
    "5594": "LHSYSHU Lufthansa Systems Hungaria",
    "5595": "Netway AG",
    "5596": "TMH T-Mobile Hungary Telecommunications Company Limited by Shares",
    "5597": "INTENSIVE Business Serve plc",
    "5598": "NETLUX- Teleradiocompany Nadezhda Ltd",
    "5599": "UUNET-DK Verizon Denmark A/S",
    "5600": "TCPNET- Total Connectivity Providers Ltd",
    "5601": "Kungliga Tekniska Hogskolan",
    "5602": "KPNQwest Italia S.p.a",
    "5603": "SIOL-NET Telekom Slovenije d.d.",
    "5604": "FREEDOMTOSURF PIPEX Communications (Freedom2surf)",
    "5605": "NETUSE NetUSE AG",
    "5606": "KQRO GTS Telecom SRL",
    "5607": "BSKYB-BROADBAND- British Sky Broadcasting Limited",
    "5608": "FVNN ForthView.Net",
    "5609": "N-CSELT  # -CSELT CONVERTED TO N-CSELT FOR RPSL COMPLIANCE TELECOM ITALIA SPA",
    "5610": "TO2-CZECH-REPUBLIC Telefonica Czech Republic, a.s.",
    "5612": "HNHW8- Handelsweg8.nl",
    "5613": "DUBAIMERC-AE Dubai Mercantile Exchange",
    "5614": "UUNET PIPEX UK MSN and DIAL",
    "5615": "TISNL-BACKBONE Koninklijke KPN N.V.",
    "5616": "MEDIATEL- Elterix S.A.",
    "5617": "TPNET Telekomunikacja Polska S.A.",
    "5618": "DPI DP IRAN",
    "5619": "ERGO EVRY",
    "5620": "ADRIAMEDIA- Adria Media ZAGREB d.o.o.",
    "5621": "Verizon Nederland B.V.",
    "5622": "Thomson Corporation Switzerland AG",
    "5623": "ATT-EMEA Autonomous System",
    "5624": "CSC Danmark A/S",
    "5626": "ONI ONITELECOM - Infocomunicacoes S.A.",
    "5627": "WWL Internet GmbH Stuttgart",
    "5628": "EUROTEL-SK Slovak Telecom, a. s.",
    "5629": "GRAL GRAL's  Number",
    "5630": "_AWL-DE Atos Worldline S",
    "5631": "VITAL-GROUP VITAL-GROUP UK Network",
    "5632": "CRONOS-CAPITAL - Cronos",
    "5633": "Internet Online S.A. de C.V.",
    "5634": "MILESTONE - Milestone Research and Development Labs Inc.",
    "5635": "GLAXOSMITHKLINE - GlaxoSmithKline",
    "5636": "LISTING - NetWork Access",
    "5637": "SAF-HOLLAND - SAF HOLLAND INC.",
    "5638": "BREWER-SCIENCE - Brewer Science",
    "5639": "Telecommunication Services of Trinidad and Tobago",
    "5640": "NCSA-VBNS-EX - National Center for Supercomputing Applications",
    "5641": "DATAPOINTINC-5641 - DataPoint",
    "5642": "HDOWN-TECH - Ashdown Technologies, Inc.",
    "5643": "SILKROAD-US - The Silk Road Group, Ltd.",
    "5644": "N-USA - USAinternet, Inc.",
    "5645": "TEKSAVVY-TOR TekSavvy Solutions Inc. Toronto",
    "5646": "NN-CNSM - NAP.NET, LLC",
    "5647": "N-KODAK - Eastman Kodak Company",
    "5648": "Satlink S.A.",
    "5649": "KEVNET-N - Kevin Communication Services",
    "5650": "FRONTIER-FRTR - Frontier Communications of America, Inc.",
    "5651": "DESTEK - Friends of Synergytics",
    "5652": "IN-NET - INTERNET Indiana",
    "5653": "UCSF - University of California San Francisco",
    "5654": "TISHNET - The Information SuperHighway Corp",
    "5655": "DECADE-DOM - Decade Communications",
    "5656": "ACCESSUS-DOM - accessU.S./BENet",
    "5657": "NOVAIAC-N - FC Business Systems",
    "5658": "CCE-NET - Coca-Cola Enterprises",
    "5659": "VIVANET - Vivanet Inc.",
    "5660": "JCI-NET - Johnson Control",
    "5661": "USF - UNIVERSITY OF SOUTH FLORIDA",
    "5662": "N-TBS-1 - Turner Broadcasting",
    "5663": "EDCNET - US Geological Survery",
    "5664": "SHERIDAN-NET - Sheridan College",
    "5665": "DELMARVA-N - Delmarva Power & Light Company",
    "5666": "NET-CPRK - Harris CapRock Communications, Inc.",
    "5667": "FTNET2-N - You Tools Corporation/FastNet",
    "5668": "-5668 - CenturyTel Internet Holdings, Inc.",
    "5669": "VIA-NET-WORKS- PSINet Europe / VIA NET.WORKS international",
    "5670": "MONTEREY - Monterey Bay Internet",
    "5671": "PBI-NET-BLK - AT&T Internet Services",
    "5672": "PBI-NET-BLK - AT&T Internet Services",
    "5673": "PBI-NET-BLK - AT&T Internet Services",
    "5674": "PBI-NET-BLK - AT&T Internet Services",
    "5675": "PBI-NET-BLK - AT&T Internet Services",
    "5676": "PBI-NET-BLK - AT&T Internet Services",
    "5677": "PBI-NET-BLK - AT&T Internet Services",
    "5678": "PBI-NET-BLK - AT&T Internet Services",
    "5679": "PBI-NET-BLK - AT&T Internet Services",
    "5680": "PBI-NET-BLK - AT&T Internet Services",
    "5681": "PBI-NET-BLK - AT&T Internet Services",
    "5682": "NETONE - Online Network Enterprises",
    "5683": "MCBB - Mad City Broadband, Inc.",
    "5684": "GANNETT-NET - Gannett Company, Inc.",
    "5685": "DRANET-NORTH - Data Research Associates, Inc.",
    "5686": "AOL-5686 - CompuServe Interactive Services, Inc",
    "5687": "AA-NET - Alternate Access Inc.",
    "5688": "PRIMUS-5688 - Primus Telecommunications Canada Inc.",
    "5689": "HOOSIERNET - HoosierNet, Inc.",
    "5690": "VIANET-NO - Via Computer and Communications (ViaNet)",
    "5691": "MITRE--5 - The MITRE Corporation",
    "5692": "Universidad Nacional de La Plata",
    "5693": "LATISYS-IRVINE - Latisys-Irvine, LLC",
    "5694": "UNIFIED-NET - Blue Cross Blue Shield Association",
    "5695": "MAILROOM-NT - Allen Bradley Inc.",
    "5696": "EXPRES - Express Scripts Incorporated",
    "5697": "SG-INTER - Interliant",
    "5698": "NETPUB- - Network Publishing, Inc.",
    "5699": "N-AHRCNYC - AHRC New York City",
    "5700": "XL-NET - MISHA, Inc.",
    "5701": "HEALTH-ONE - HealthOne",
    "5702": "GALAXY - Galaxy Networks (division of Kolacom, Inc.)",
    "5703": "TIGERFUND - Tiger Management Coporation",
    "5704": "CARIBE-NET - Caribbean Internet Service, Corp.",
    "5705": "COLUMBIA-CREDIT-UNION - Columbia Community Credit Union",
    "5706": "DEERFIELDROUTERS - PC Quote, Inc.",
    "5707": "UTHSC-H - The University of Texas Health Science Center at Houston",
    "5708": "Universidad Autonoma de Guerrero",
    "5709": "ERX-KMB-1 Kiwifruit Marketing Board",
    "5710": "NBTBA-N - NBT BANCORP INC.",
    "5711": "CYBER2 - CyberStream Information Services, Inc.",
    "5712": "RCN-4 - RCN",
    "5713": "SAIX-NET",
    "5714": "HPES - Hewlett-Packard Company",
    "5715": "ONVOY-CO - Onvoy",
    "5716": "CYBERCOM - Cyber Access Internet Communications, Inc.",
    "5717": "IWIN-NET - World Information Network, Inc.",
    "5718": "MECNET - Merrimack Education Center",
    "5719": "SUNYSB - SUNY at Stony Brook",
    "5720": "TSOFT - Advanced Software Technology",
    "5721": "NDU-NET - National Defense University",
    "5722": "Universidad Nacional de Colombia",
    "5723": "JHU - Johns Hopkins University",
    "5724": "UMSMED - University of Massachusetts Medical School",
    "5725": "XO - XO Communications",
    "5726": "INTERWORLD - InterWorld Communications, Inc.",
    "5727": "WORLDNET-0 - AT&T Services, Inc.",
    "5728": "WORLDNET1 - AT&T Services, Inc.",
    "5729": "WORLDNET2 - AT&T Services, Inc.",
    "5730": "WORLDNET3 - AT&T Services, Inc.",
    "5731": "5731 - AT&T Services, Inc.",
    "5732": "ACCESINDIANA - Sprint, Sprintlink Engineering",
    "5733": "MONRO-1 - Monroe County",
    "5734": "TIENET",
    "5735": "GALT-TECHNO - Galt Technologies",
    "5736": "VEL- - Velocity Networks, Inc.",
    "5737": "QWEST--5737 - Qwest Corporation",
    "5738": "SOVER-N - SoVerNet, Inc.",
    "5739": "UCSC - University of California, Santa Cruz",
    "5740": "WORKFORCE- WorkForce Software 5740",
    "5741": "TRIAD-LVK - Triad Systems Corporation",
    "5742": "CCINET - Consolidated Communications, Inc.",
    "5743": "N-VFPA - Port Metro Vancouver",
    "5744": "USPTO - United States Patent and Trademark Office",
    "5745": "Organizacion Panamericana de la Salud",
    "5746": "CELESTAR-N - Celestar",
    "5747": "N-RISQ-QIX - Reseau d'Informations Scientifiques du Quebec (RISQ) Inc.",
    "5748": "BBNET - BB-Net, Inc.",
    "5749": "RP - Peets Coffee & Tea",
    "5750": "FLEXNET-HAWAII - FlexNet Inc.",
    "5751": "SYTEX - Sytex Access Ltd.",
    "5752": "GREATBIN - Great Basin Internet Services, Inc",
    "5753": "EMPAC-DOM - EMPaC International Corp.",
    "5754": "PIXINET1 - Pacific Information Exchange, Inc.",
    "5755": "QNETIX- - Qnetix Computer Consultants Inc.",
    "5756": "POINTCT - Pointcast Inc.",
    "5757": "GPC-N - General Physics Corporation",
    "5758": "ALPHACOMM - ALPHA ENTERPRISES LIMITED, INC.",
    "5759": "RAINSTORM - Storm Network Systems, LLC",
    "5760": "BIDDEFORD1 - Biddeford Internet Corp",
    "5761": "MICROSOFT-CORP-MSN--SATURN - Microsoft Corporation",
    "5762": "NETMAG - Magnet Interactive Studios",
    "5763": "TRI-DEV-GRP - Trilogy, Inc.",
    "5764": "CONVOKE Convoke Communications Corp.",
    "5765": "TELUS--5765 - TELUS Communications Inc.",
    "5766": "IHS-MD- - Indian Health Service",
    "5767": "INFINITY - Infinity AccessNET",
    "5768": "ICANECT - ICANECT",
    "5769": "VIDEOTRON - Videotron Telecom Ltee",
    "5770": "EMPLINK- - EMPaC International Corp.",
    "5771": "ALSK-5771 - Alaska Communications Systems Group, Inc.",
    "5772": "Unisys Brasil Ltda.",
    "5773": "LAMBEAU-TELECOM-COMPANY-LLC - Lambeau Telecom Company LLC",
    "5774": "USPS-001 - United States Postal Service.",
    "5775": "DIVERS-ALERT-NETWORK - Divers Alert Network, Inc",
    "5776": "WORLDWEB - World Web Limited",
    "5777": "N1 - GENBAND Inc.",
    "5778": "EMBARQ-RCMT - Embarq Corporation",
    "5779": "Y-BR-SERV - Yahoo! Broadcast Services, Inc.",
    "5780": "GIGD3 - Giga Information Group",
    "5781": "CSI-GATEWAY-2 - Connectivity Solutions, Inc.",
    "5782": "EXTREMES - Digital Extremes, Inc.",
    "5783": "KCSOS-NET - Kern County Superintendent of Schools",
    "5784": "GETNET - Getnet International",
    "5785": "DCPS-DC- - DC Public Schools",
    "5786": "UPRENET - University of Puerto Rico",
    "5787": "SNAPONSBS - Snap-on Business Solutions Inc.",
    "5788": "HSSBC-PRIMARY - Vancouver Coastal Health",
    "5789": "EZNET - E-Znet Incorporated",
    "5790": "NETMARKET - CUC INTERNATIONAL",
    "5791": "CSI-GATEWAY-1 - Connectivity Solutions, Inc.",
    "5792": "SIMPLE-NET - Simple Access",
    "5793": "PENTELEDATA-2 - PenTeleData Inc.",
    "5794": "NWREGION-ESD - Northwest Regional ESD",
    "5795": "THOMSON-REUTERS-US-INC - Thomson Reuters U.S. LLC",
    "5796": "COMET - Metronetics",
    "5797": "CISPROD- - CheckFree Corporation",
    "5798": "SUPERLATIVE - Superlative, Inc.",
    "5799": "IGCNET - Internet Gateway Connections, Inc.",
    "5800": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5801": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5802": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5803": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5804": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5805": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5806": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5807": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5808": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5809": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5810": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5811": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5812": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5813": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5814": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5815": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5816": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5817": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5818": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5819": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5820": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5821": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5822": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5823": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5824": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5825": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5826": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5827": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5828": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5829": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5830": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5831": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5832": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5833": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5834": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5835": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5836": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5837": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5838": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5839": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5840": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5841": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5842": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5843": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5844": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5845": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5846": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5847": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5848": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5849": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5850": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5851": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5852": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5853": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5854": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5855": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5856": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5857": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5858": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5859": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5860": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5861": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5862": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5863": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5864": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5865": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5866": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5867": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5868": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5869": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5870": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5871": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5872": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5873": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5874": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5875": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5876": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5877": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5878": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5879": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5880": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5881": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5882": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5883": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5884": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5885": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5886": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5887": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5888": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5889": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5890": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5891": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5892": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5893": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5894": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5895": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5896": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5897": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5898": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5899": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5900": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5901": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5902": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5903": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5904": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5905": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5906": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5907": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5908": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5909": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5910": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5911": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5912": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5913": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5914": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5915": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5916": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5917": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5918": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5919": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5920": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5921": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5922": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5923": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5924": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5925": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5926": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5927": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5928": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5929": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5930": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5931": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5932": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5933": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5934": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5935": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5936": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5937": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5938": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5939": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5940": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5941": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5942": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5943": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5944": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5945": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5946": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5947": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5948": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5949": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5950": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5951": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5952": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5953": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5954": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5955": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5956": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5957": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5958": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5959": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5960": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5961": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5962": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5963": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5964": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5965": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5966": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5967": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5968": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5969": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5970": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5971": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5972": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5973": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5974": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5975": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5976": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5977": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5978": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5979": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5980": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5981": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5982": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5983": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5984": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5985": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5986": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5987": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5988": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5989": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5990": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5991": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5992": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5993": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5994": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5995": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5996": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5997": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5998": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "5999": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6000": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6001": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6002": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6003": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6004": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6005": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6006": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6007": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6008": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6009": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6010": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6011": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6012": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6013": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6014": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6015": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6016": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6017": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6018": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6019": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6020": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6021": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6022": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6023": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6024": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6025": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6026": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6027": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6028": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6029": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6030": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6031": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6032": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6033": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6034": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6035": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6036": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6037": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6038": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6039": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6040": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6041": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6042": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6043": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6044": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6045": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6046": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6047": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6048": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6049": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6050": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6051": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6052": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6053": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6054": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6055": "DNIC-BLK-05800-06055 - DoD Network Information Center",
    "6056": "COLBY - Colby College",
    "6057": "Administracion Nacional de Telecomunicaciones",
    "6058": "NORTHWESTEL-INC - Northwestel Inc.",
    "6059": "UMS2-N - University of Maryland",
    "6060": "MAGI-NET-GW - Management Alliance Group Inc.",
    "6061": "ANTHION-MANAGEMENT - Anthion Management, LLC",
    "6062": "NETPLEX - NETPLEX",
    "6063": "Internet Corporativo, S.A. de C.V.",
    "6065": "Terra Networks Mexico, S.A. de C.V.",
    "6066": "VERIZON-BUSINESS-MAE-6066 - Verizon Business Network Services Inc.",
    "6067": "ONYX Onyx Internet",
    "6068": "LGRND--KR LG CNS",
    "6069": "IGC- - Institute for Global Communications",
    "6070": "FUTURIS - Futuris Networks Inc.",
    "6071": "UNISYS--E - Unisys Corporation",
    "6072": "UNISYS-6072 For routing issues, email hostmaster@unisys.com",
    "6073": "ETI - KAPS, Inc",
    "6074": "LIUNET - Long Island University",
    "6075": "LM-CORP - Lockheed Martin Corporation",
    "6076": "ERINET - CoreComm Internet Services Inc",
    "6077": "BCBSNE - Blue Cross Blue Shield of Nebraska",
    "6078": "JERSEY - InterActive Network Services",
    "6079": "RCN- - RCN",
    "6080": "LINKNET-LA - Linknet Internet Services",
    "6081": "AISNET - American Information Systems, Inc.",
    "6082": "IPIFONY- - IPiFony Systems, Inc.",
    "6083": "POSIX-AFRICA",
    "6084": "Internet Corporativo, S.A. de C.V.",
    "6085": "SITA-IPNET SITA Network Operations Center",
    "6086": "INFOMAGIC - MagicNET, Inc",
    "6087": "IPRO-NET - Internet Profiles Corporation",
    "6088": "BOX - The Black Box",
    "6089": "MWEB-6089",
    "6090": "TIA- - Techmatics Informaton Alliance",
    "6091": "AMERION - Amerion",
    "6092": "HARFORDCC- - Harford Community College",
    "6093": "INFSYS-N - Infinite Systems",
    "6094": "GRAPEVINEINC - GrapeVine Interactive, Inc.",
    "6095": "NIBR-US-DMZ - Novartis Institutes for BioMedical Research",
    "6096": "SYSNET-1 - Sysnet Corp",
    "6097": "N-CKS-CU - CKS Group",
    "6098": "WEBSPINNERS - WebSpinners, Inc.",
    "6099": "BAE-NET-N - Alameda County Office of Education",
    "6100": "NAME - North American Media Engines",
    "6101": "TAC-NET - The Atlanta Connection",
    "6102": "CBSCORPORATE - CBS inc.",
    "6103": "MTW-N - The Manitowoc Company Inc",
    "6104": "STARGATE - Stargate Industries, Inc.",
    "6105": "NO - Origin Digital, Inc.",
    "6106": "UCR-EDU - University of California, Riverside",
    "6107": "GLOBENET - Mnematics, Incorporated",
    "6108": "POND - Cascade Communications Group, Inc.",
    "6109": "NDCORP-NET - National Data Corporation",
    "6110": "BOXTOP - BoxTop Entertainment",
    "6111": "FHIS - Florida Hospital",
    "6112": "AUBURN - Auburn University",
    "6113": "GRIDNET - GridNet International",
    "6114": "CAPITAL-HOSPICE-VA - Capital Hospice",
    "6115": "HTW - HarvardNet",
    "6116": "WB-DUPLEX - Warner Bros. Interactive Entertainment",
    "6117": "SJMERCURY - San Jose Mercury News",
    "6118": "MCCLATCHY-CORP - MCCLATCHY MANAGEMENT SERVICES, INC.",
    "6119": "WWWPS - WWW Passport Inc",
    "6120": "INTERGLOBE - interGlobe Networks, Inc.",
    "6121": "Argentine Ministry of Justice",
    "6122": "ICN- - Iowa Communications Network",
    "6123": "WEBPROS-N-1 - Web Professionals",
    "6124": "MARIST - Marist College",
    "6125": "Associa\u00e7\u00e3o Rede Nacional de Ensino e Pesquisa",
    "6126": "CA-INTL- - Computer Associates International",
    "6127": "IDSC",
    "6128": "CABLE-NET-1 - Cablevision Systems Corp.",
    "6129": "247REALMEDIA-NEWYORK - 24/7 Real Media, Inc.",
    "6130": "AIS-WEST - American Internet Services, LLC.",
    "6131": "HOSP-INFO-NET - Hospitality Information Networks, Inc.",
    "6132": "INGRESSNET - Ingress Enterprises, Inc w/ Ingress Communications, Inc.",
    "6133": "Red Nacional de Guatemala, MAYANet",
    "6134": "EXABYTE - Exabyte Corporation",
    "6135": "Terra Networks Mexico, S.A. de C.V.",
    "6136": "NWRAINET - NW RAIN.net, Inc",
    "6137": "SISNA - SISNA, Inc.",
    "6138": "CIOE - CIOE, Inc.",
    "6139": "SAUDI - Washington Coordinating Center",
    "6140": "TWO-P - Two P",
    "6141": "GRINNELL-MUTUAL-REINSURANCE-COMPANY - Grinnell Mutual Reinsurance Company",
    "6142": "SUN-JAVA - Sun Microsystems, Inc",
    "6143": "STARKBRO - Stark Brothers Fulfillment",
    "6144": "SOUND-ADVICE-LTD - Sound Advice Limited",
    "6145": "3TIER-SEA - 3TIER Inc, 3TIER",
    "6146": "ZUORA - Zuora, Inc",
    "6147": "Telefonica del Peru S.A.A.",
    "6149": "TENET-2",
    "6150": "NCIFCRF - National Cancer Institute/Frederick Cancer Research",
    "6151": "Q- - Allen, Bradley Ward",
    "6152": "PACIFICWEBWORKS - Pacific WebWorks, Inc.",
    "6153": "N-SPRN-NYSERNET - SPRINT, Business Serices Group",
    "6154": "SPRINTLINK-NYSERNET5 - SPRINT, Business Serices Group",
    "6155": "SPRINTLINK-NYSERNET6 - SPRINT, Business Serices Group",
    "6156": "SPRINTLINK-NYSERNET7 - SPRINT, Business Serices Group",
    "6157": "SPRINTLINK-HOSTING - SPRINT, Business Serices Group",
    "6158": "SPRINTLINK-NYSERNET9 - SPRINT, Business Serices Group",
    "6159": "TWAVE - Greer Educational Resources, Inc.",
    "6160": "SMARTS-1 - System Management ARTS, Inc.",
    "6161": "COMCT-6161 - Comcast Cable Communications",
    "6162": "ISI-ISP - Integration Specialists, Inc.",
    "6163": "ERX-MOZCOM-NETWRK Mosaic Communications Inc.",
    "6164": "NET66UU - Egix, Inc.",
    "6165": "UPTILT-N - Uptilt, Inc.",
    "6166": "RADIOMAIL - Radiomail Corp",
    "6167": "CELLCO-PART - Cellco Partnership DBA Verizon Wireless",
    "6168": "EK-GROUP- Emirates Airline",
    "6169": "PENTELEDATA-3 - PenTeleData Inc.",
    "6170": "PENTELEDATA-3 - PenTeleData Inc.",
    "6171": "WORLDGATE - WorldGate",
    "6172": "NEN- - New Edge Networks",
    "6173": "SMARTLINK - SmartLink Communications Inc.",
    "6174": "SPRINTLINK8 - Sprint",
    "6175": "SPRINTLINK9 - Sprint",
    "6176": "SPRINTLINK10 - Sprint",
    "6177": "SPRINTLINK11 - Sprint",
    "6178": "INLINK - INLINK",
    "6179": "WESTWOOD - Westwood Studios",
    "6180": "NIS-CT",
    "6181": "FUSE-NET - Cincinnati Bell Telephone",
    "6182": "MICROSOFT-CORP-MSN--4 - Microsoft Corporation",
    "6183": "MARKET-FACTS - Synovate, Inc.",
    "6184": "DATTORM - Datastorm Technologies, Inc.",
    "6185": "APPLE-AUSTIN - Apple Inc.",
    "6186": "GARCIA-N - Garcia Consulting, Inc.",
    "6187": "SPRINT-ZA",
    "6188": "VPSDATACENTER - VPS Datacenter, LLC",
    "6189": "EPFL- - Enoch-Pratt Free Library",
    "6190": "VERTRUE - Vertrue Inc.",
    "6191": "CECLFROC - Network Design and Implementation",
    "6192": "UCDAVIS-CORE - University of California at Davis",
    "6193": "Corporacion La Prensa S.A.",
    "6194": "MSFT - Microsoft Corporation",
    "6195": "GSCO - The Goldman Sachs Group, Inc.",
    "6196": "INTERNET-SYSTEMS - Internet Systems, Inc.",
    "6197": "BATI-ATL - BellSouth Network Solutions, Inc",
    "6198": "BATI-MIA - BellSouth Network Solutions, Inc",
    "6199": "COOPERUNION - Cooper Union",
    "6200": "UIC- - University of Illinois at Chicago",
    "6201": "ATEXT - Architext",
    "6202": "NEXTRON - IMV/Internet",
    "6203": "ISDN-NET - The Nexus Group, Inc.",
    "6204": "PARK-5 - Internet Multicasting Service",
    "6205": "PARK-2 - Internet Multicasting Service",
    "6206": "PARK-3 - Internet Multicasting Service",
    "6207": "PARK-4 - Internet Multicasting Service",
    "6208": "PARK-1 - Internet Multicasting Service",
    "6209": "NFL2 - National Football League",
    "6210": "NFL1 - National Football League",
    "6211": "SPRNTDATANET - Sprint Communications Corp.",
    "6212": "IGC-DC- - Institute for Global Communications",
    "6213": "GETONTHENET - OnThe.Net, Inc.",
    "6214": "ANET-04 - Interactive Network Systems Inc.",
    "6215": "-ALTO-EXT1 - ALTO",
    "6216": "IV- - Intellectual Ventures Management, LLC",
    "6217": "ANS-AXISNET - Axis.Net Inc.",
    "6218": "MIBX - MIBX, Inc.",
    "6219": "NBIX3- - University of New Brunswick",
    "6220": "6220 - inContact Inc.",
    "6221": "USCYBERSITES - US Cybersites, Inc",
    "6222": "EMBARQ-CLTN - Embarq Corporation",
    "6223": "QWEST-NBLK-2 - Qwest Communications Company, LLC",
    "6224": "QWEST-NBLK-2 - Qwest Communications Company, LLC",
    "6225": "QWEST-NBLK-2 - Qwest Communications Company, LLC",
    "6226": "QWEST-NBLK-2 - Qwest Communications Company, LLC",
    "6227": "QWEST-NBLK-2 - Qwest Communications Company, LLC",
    "6228": "BSDI-N - BSDI (Berkeley Software Design, Inc)",
    "6229": "NETVOYAGE - Digital Design (NETVOYAGE-DOM)",
    "6230": "GANET - Global Access Network",
    "6231": "SCANA - SCANA Corporation",
    "6232": "WINS - Iowa Network Services (INS)",
    "6233": "NETRUS - Netrus",
    "6234": "ETAK-NET2 - Etak, Inc.",
    "6235": "SMG-NJ - SUMMIT MEDICAL GROUP",
    "6236": "BBCON - Business & Banking Concepts",
    "6237": "WEBBED - Webbed Communications",
    "6238": "DPSC- - Dept. of Public Safety & Corrections",
    "6239": "RF-NETWORKS - RF Networks",
    "6240": "Chilenet Ltda.",
    "6241": "DISTRIBUTEL-6241 - DISTRIBUTEL COMMUNICATIONS LTD.",
    "6242": "TELEMAIL - Sprint Communications Corp.",
    "6243": "INET-AMERICA - Internet America, Inc.",
    "6244": "SWIEC - Swieca Holdings, LLC",
    "6245": "NETWORK-SOLUTIONS - InterNIC Registration Services",
    "6246": "AVALONTEL - AvalonTel",
    "6247": "SPANIT - SPAN INFORMATION TECHNOLOGY, Inc.",
    "6248": "WEBMEDIABRANDS - WebMediaBrands Inc.",
    "6249": "RCN-3 - RCN",
    "6250": "NEONOVA-NET - Neonova Network Services",
    "6251": "PSNET - UCLA Physical Sciences Division",
    "6252": "EVOLUTION - Evolution On-Line Systems, Inc.",
    "6253": "PRUN - The Prudential Insurance Company of America",
    "6254": "EGGINC - EG&G, Inc.",
    "6255": "CHANNEL1 - Channel 1 Communications",
    "6256": "ALLTEL - Cellco Partnership DBA Verizon Wireless",
    "6257": "NOVALINK-GW - Novalink USA",
    "6258": "INOC-N - Telecon Communications Corp.",
    "6259": "COGENT-6259 - Cogent Communications",
    "6260": "CROSSLINK-NUNET- - NuNet Inc.",
    "6261": "VISINET - NetTelcos",
    "6262": "CSIRO Commonwealth Scientific and Industrial",
    "6263": "NDIN - State of North Dakota",
    "6264": "-ALTO-EXT2 - ALTO",
    "6265": "SIVENSA - Sivensa Corp.",
    "6266": "ICONN- - Iconn LLC",
    "6267": "MEGAPATH3-US - MegaPath Networks Inc.",
    "6268": "EXPRESS - Mistik Systems",
    "6269": "ATT-INTERNET2 - AT&T Services, Inc.",
    "6270": "COGENT-6270 - NetRail, Inc.",
    "6271": "COGENT-6271 - NetRail, Inc.",
    "6272": "6272 - NetRail, Inc.",
    "6273": "COGENT-6273 - NetRail, Inc.",
    "6274": "COGENT-6274 - NetRail, Inc.",
    "6275": "COGENT-6275 - NetRail, Inc.",
    "6276": "COGENT-6276 - NetRail, Inc.",
    "6277": "COGENT-6277 - NetRail, Inc.",
    "6278": "NOC-BB - Moran Communications Group",
    "6279": "BTN-TWO - Beyond The Network America, Inc.",
    "6280": "SYNAPSE - Babillard Synapse Inc.",
    "6281": "CMSA - CMS Automation, Inc.",
    "6282": "UNETY - UNETY Systems, Inc.",
    "6283": "LYCEUM - Lyceum Internet",
    "6284": "METRONET - MetroNet Internet Services",
    "6285": "EN- - CoreComm Internet Services Inc",
    "6286": "HEALTHWAYS - American Healthways Services, Inc.",
    "6287": "SPACESTAR - Spacestar Communications",
    "6288": "PERTECH-CA-01 - PerTech Inc.",
    "6289": "AHM-CORP - American Honda Motor Corporation",
    "6290": "ALCOM - AT&T Alascom, Inc.",
    "6291": "MICROSOFT-CORP-MSN- - Microsoft Corporation",
    "6292": "LTT-ET - Lightstream Transmission and Telecom Inc",
    "6293": "ESKIMO - Eskimo North, Inc.",
    "6294": "CTEKUSA - Compu-Tek International",
    "6295": "WHIDBEY1 - Whidbey Internet Services",
    "6296": "MIND - InfoStructure",
    "6297": "NETBLK-ORGANIC-2 - Organic, Inc",
    "6298": "N-CXA-PH-6298-CBS - Cox Communications Inc.",
    "6299": "TELALINK - Telalink Corporation",
    "6300": "CCI-TEX - Consolidated Communications, Inc.",
    "6301": "HP-CLOUD-SERVICES - Hewlett-Packard Company",
    "6302": "TELSCAPE-COMMUNICATIONS - Telscape Communications, Inc.",
    "6303": "BARCLAYS-CAPITAL - Barclays Capital",
    "6304": "CSTBRANDS - CST Brands Inc.",
    "6305": "AENT- - Alliance Entertainment",
    "6306": "TELEFONICA VENEZOLANA, C.A.",
    "6307": "AMERICAN-EXPRESS - American Express Company",
    "6308": "ALCOM-MIS - AT&T ALCOM",
    "6309": "DICEH-6309 - Dice Holdings, Inc.",
    "6310": "MAXPERTS- - Maxperts, Inc.",
    "6311": "OXNET-6311 - Oxford Networks",
    "6312": "GARNET- - WestWorld Media, LLC",
    "6313": "PROMETHEUS - Prometheus Information Corp.",
    "6314": "CDC- - Chattanooga Data Connection, Inc.",
    "6315": "XMISSION - XMission, L.C.",
    "6316": "-PAETEC-NET - PaeTec Communications, Inc.",
    "6317": "MILLENNIANET - MillenniaNet, LLC",
    "6318": "CHECKFREE - CheckFree Corporation",
    "6319": "MARRIOT-N - Marriot Corporation",
    "6320": "FUSEDNETWORKS- MDNX Enterprise Services Ltd",
    "6321": "ADVTEL - EATEL",
    "6322": "PEAKBROADBAND-COS - Peak Broadband",
    "6323": "ENEWS - The Electronic Newstand",
    "6324": "MFS-ET- - MFS Global Network Services, Inc.",
    "6325": "ILLINOIS-CENTURY - Illinois Century Network",
    "6326": "LEBANET1 - LebaNet, Inc.",
    "6327": "SHAW - Shaw Communications Inc.",
    "6328": "SYNAPSETON1 - Synapse, L.L.C.",
    "6329": "FIHN - Fist In Hand Networks",
    "6330": "WORLDWIDE- - Worldwide Communications",
    "6331": "AIT-NET - Atlantic Internet Technologies, Inc.",
    "6332": "Telefonos del Noroeste, S.A. de C.V.",
    "6333": "INFOCOM - infocom, inc.",
    "6334": "N-TSG - The Sabre Group",
    "6335": "NTRNET - NTR.NET Corporation",
    "6336": "TURN-US-N - Turn Inc.",
    "6337": "HIWAAY - HIWAAY INFORMATION SERVICES, INC.",
    "6338": "MIX-COMMUNICATIONS - MIX Communications",
    "6339": "I95-NET - Voicelink Communications, Inc.",
    "6340": "EMPIRE - EMPIRE.NET, Inc.",
    "6341": "WIEC - Wisconsin Electric Power Company",
    "6342": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "6343": "PICS - Professional Implementation Consulting Services, Inc.",
    "6344": "VALUENET - Value Net Internetworking Services, Inc.",
    "6345": "ZIPNET- - ZipCall Internet Services",
    "6346": "VUI - Valhalla Unlimited, Inc",
    "6347": "DIAMOND - Savvis",
    "6348": "BETTYPLATFORMS - Prodigy Services",
    "6349": "LAMBEAU-TELECOM-1 - Lambeau Telecom Company LLC",
    "6350": "VRIS-6350 - Verizon Online LLC",
    "6351": "MWEB-6351",
    "6352": "ETRADE- - E*Trade Group",
    "6353": "NETZONE - Netzone, L.L.C.",
    "6354": "LYCOS - Lycos, Inc.",
    "6355": "FRANK-RUSSELL-COMPANY - Russell Investments",
    "6356": "NERDCNET - Northeast Regional Data Center",
    "6357": "DBTECH - DB Technology",
    "6358": "MERC- - Mercury Mail",
    "6359": "DATOL - DataSol, Inc.",
    "6360": "UNIVHAWAII - University of Hawaii",
    "6361": "NTEGRATED-SOLUTIONS - Ntegrated Solutions",
    "6362": "MIDLANDCOLLEGE-N - Midland College",
    "6363": "ENTERYS-NETWORKS - Enterasys Networks",
    "6364": "ATLANTIC-NET - Atlantic.net, Inc.",
    "6365": "I1 - Internet 1st, Inc.",
    "6366": "PDXNET - Portland State University",
    "6367": "EMBARQ-KLLN - Embarq Corporation",
    "6368": "NETNITCO-N - Northwestern Indiana Telephone Co.",
    "6369": "NETRUNNER - Netrunner Inc",
    "6370": "LUCENT-N - Lucent Technologies",
    "6371": "AMERICATEL - Americatel Corporation",
    "6372": "DCANET - DCANet",
    "6373": "OPUS1 - Opus One",
    "6374": "MFS-WEST- - MFS Global Network Services, Inc.",
    "6375": "XROADS - Crossroads Communications",
    "6376": "BRODER207 - Broderbund Software",
    "6377": "4JNET - Eugene School District 4J",
    "6378": "NWNT - Northwest Networks",
    "6379": "ALINK - A-Link Network Services, Inc.",
    "6380": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6381": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6382": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6383": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6384": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6385": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6386": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6387": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6388": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6389": "BELLSOUTH-NET-BLK - BellSouth.net Inc.",
    "6390": "KANSCITY - The Kansas City Star",
    "6391": "URBAN-15- - Urban Networks Inc.",
    "6392": "MWCI-NET - MidWest Communications, Inc.",
    "6393": "PRYSM- - Prysm Technologies",
    "6394": "DATA-BROADCTING - Data Broadcasting Corp.",
    "6395": "LVLT-6395 - Level 3 Communications, Inc.",
    "6396": "COTALNET-N - Global Information Exchange Corp",
    "6397": "LIBBY - Lincoln County Tech Group",
    "6398": "TELEDESIC - Teledesic Corporation",
    "6399": "NEREP-N - You Tools Corporation",
    "6400": "Compa\u00f1\u00eda Dominicana de Tel\u00e9fonos, C. por A. - CODETEL",
    "6401": "ALLST-6401 - Allstream Corp.",
    "6402": "NFRAME - nFrame",
    "6403": "OPN - Oregon Public Networking",
    "6404": "FACTSET - FactSet Research Systems, Inc.",
    "6405": "AIN - American Information Network",
    "6406": "CEBAF - Continuous Electron Beam Accelerator Facility",
    "6407": "PRIMUS-6407 - Primus Telecommunications Canada Inc.",
    "6408": "PRADO - Prado Internet Access INc.",
    "6409": "RESEARCHMAG - Research Holdings, LTD.",
    "6410": "ICOM - I COMMUNICATIONS",
    "6411": "INSWEB - Strategic Concepts Corporation",
    "6412": "KW KEMS",
    "6413": "SOCOMM - Southern Online Systems, Inc.",
    "6414": "IPNET - Thurber Technology Group",
    "6415": "SILICONREEF - Silicon Reef, Inc.",
    "6416": "NOVELL- - Novell, Inc.",
    "6417": "AGENTS-INC - Agents, Inc.",
    "6418": "SATELNET- - SatelNet Communications, Inc.",
    "6419": "IDD - IDD Enterprises, LP",
    "6420": "INTERPLAY - Interplay Productions",
    "6421": "TATACOMM- TATA Communications formerly VSNL is Leading ISP",
    "6422": "JUNCTION - Okanagan Internet Junction, Inc.",
    "6423": "EYSTREET-ONLINE - EasyStreet Online Services, Inc.",
    "6424": "NETROVER - netROVER Inc.",
    "6425": "TEN - T E Network, Inc.",
    "6426": "NETCOT - NETCOT Communications, Inc.",
    "6427": "HURRICANE-ELEC - Hurricane Electric, Inc.",
    "6428": "CDM - CDM",
    "6429": "Telmex Chile Internet S.A.",
    "6430": "DIGITALINK - Digital Ink",
    "6431": "ATT-RESEARCH - ATT LABS",
    "6432": "DOUBLELCICK- Dummy object for doubleclick",
    "6433": "JLC - John Leslie Consulting",
    "6434": "PIERPONTSECURITIES - Pierpont Securities LLC",
    "6435": "TRI-NET-SOLUTIONS - Tri-Net Solutions LLC.",
    "6436": "INTERACCESS-NET - Interaccess Corp.",
    "6437": "NETREX - Netrex, Inc.",
    "6438": "OMINUX-NETWORK - Outwest Network Services Inc.",
    "6439": "WEBMATE - Webmate Technologies, Inc.",
    "6440": "EMF- - emf.net",
    "6441": "BIGBOOK - BigBook",
    "6442": "GLOBALLINK-N - Global Link Information Network",
    "6443": "EMANON - Emanon Service Corporation",
    "6444": "SBSIB - Siemens Business Systems Intranet Backbone",
    "6445": "SIEMENS-US - Siemens Corporation",
    "6446": "SIEMENS-IPO - Siemens International Procurement Office",
    "6447": "UOREGON-IX - University of Oregon",
    "6448": "QAD - QAD, Inc.",
    "6449": "SPRINT-ISP - Sprint Multimedia Internet Division",
    "6450": "PIXNET- - Providers Internet Exchange",
    "6451": "ACCESSCOMNET - AccessCom",
    "6452": "WESTWORLD - Westworld Communications",
    "6453": "GLOBEINTERNET TATA Communications",
    "6454": "PIONET-NET - Pioneer Internet",
    "6455": "TOMCO - Tomco Systems, Inc.",
    "6456": "ALTOPIA-6456 Altopia  6456",
    "6457": "KDCOL-N - KDC-Online",
    "6458": "Telgua",
    "6459": "TRANSBEAM - I-2000, Inc.",
    "6460": "INTERNEXT - InterNext",
    "6461": "MFNX MFN - Metromedia Fiber Network",
    "6462": "NATGEOGRAPH- - National Geographic Society",
    "6463": "ALLST-6463 - Allstream Corp.",
    "6464": "FUTURELABS - FutureLabs, Inc.",
    "6465": "PACWEST - Pac-West Telecomm, INC.",
    "6466": "ARPA-6466 - Multiverse, Inc.",
    "6467": "ESPIRECOMM - Xspedius Communications Co.",
    "6468": "EYLINK EasyLink",
    "6469": "ARTEMIS - Artemis Research",
    "6470": "WEB2000-N - Web2000, Inc.",
    "6471": "ENTEL CHILE S.A.",
    "6472": "NETSET - Net Asset",
    "6473": "WCIXN4 - WCIX.Net, Inc.",
    "6474": "FLHNET- - SBC IP Communications, Inc.",
    "6475": "KESMAI - Kesmai Corporation",
    "6476": "MIWORLD - Micro-Integration Corporation",
    "6477": "DIRECTMEDIA- - Direct Media, Inc.",
    "6478": "ATT-INTERNET3 - AT&T Services, Inc.",
    "6479": "MCHENRY - McHenryCom Company",
    "6480": "LITLE - LitleNet, LLC",
    "6481": "SWRI - Southwest Research Institute",
    "6482": "SUPER-1 - SuperMedia LLC",
    "6483": "DIGEX-3 - Digital Express Group, Inc.",
    "6484": "EYLINK Easylink",
    "6485": "TDSC1-N - Track Data Corp",
    "6486": "NEWREACH - NewReach Communications",
    "6487": "CyberNet de Guatemala S.A.",
    "6488": "FTQ-0 - Arizona Macintosh Users Group",
    "6489": "INOW- - Network Solutions, Inc. (INOW-DOM)",
    "6490": "DESERTEYE - DesertEye Publishing",
    "6491": "TELEKACHINA - TeleKachina",
    "6492": "PCCD - Palomar Community College District",
    "6493": "BEACON-TECHNOLOGIES- - Beacon Technologies, Inc",
    "6494": "COGENT-6494 - Cogent Communications",
    "6495": "HSBC Mexico, S.A., Institucion de Banca Multiple, Grupo Financiero HSBC",
    "6496": "COGENT-6496 - Cogent Communications",
    "6497": "ACQUION - ACQUION, Inc.",
    "6498": "WEST-NGN - West Corporation",
    "6500": "NIELSEN - Nielsen Interactive Network",
    "6501": "SOUTHERNET - The Southern Company",
    "6502": "INTEGRA-ELIX - Integra Telecom, Inc.",
    "6503": "Axtel, S.A.B. de C.V.",
    "6504": "NOVAGATE - Novagate Communications Corporation",
    "6505": "EQUANT DO BRIL",
    "6506": "HOYT - David H. Hoyt & COS., Inc.",
    "6507": "RIOT-NA1 - Riot Games, Inc",
    "6508": "WARENETN - Technicolor, Inc.",
    "6509": "CANARIE-NTN - Canarie Inc",
    "6510": "BYU - Brigham Young University",
    "6511": "STRATANET - StrataCom, Inc.",
    "6512": "GLOBAL2000 - Global 2000 Communications, Inc.",
    "6513": "PROXIMUS - Proximus",
    "6514": "SRMC - Scientific Research Management Corporation",
    "6515": "INTERSTICE - Interstice Inc.",
    "6516": "TRUENET - TrueNet Corporation",
    "6517": "RELIANCEGLOBALCOM - Reliance Globalcom Services, Inc",
    "6518": "CIX-GCCC - CIX, Inc. and Greater Cinti Chamber of Commerce",
    "6519": "KETCHUM KETCHUM LIMITED",
    "6520": "NOLA-INXP-1 - InterCommerce Corporation",
    "6521": "AROSNET - ArosNet, Inc",
    "6522": "LEHIGH - Lehigh University",
    "6523": "NETLINK207 - Net-Link Solutions",
    "6524": "GXS-6524 - GXS",
    "6525": "INFO-HIGHWAY - Info-Highway International, Inc",
    "6526": "MAVERICK-BBS - King Communications",
    "6527": "MSACHUSETTS - Commonwealth of Massachusetts",
    "6528": "WORLD-LYNX - World Lynx",
    "6529": "PLAN-B",
    "6530": "XENSEI - The Xensei Corporation",
    "6531": "COFFEYCAN - Burlington USD #244",
    "6532": "SGN - SGN, Inc.",
    "6533": "VARNER - Varner Technologies",
    "6534": "OCEANIC-CABLE - Oceanic Cable",
    "6535": "Telmex Servicios Empresariales S.A.",
    "6536": "CITYNET - CityNet",
    "6537": "ALLST-6537 - Allstream Corp.",
    "6538": "KINTEK- - Tai Feng Corp",
    "6539": "GT-BELL - Bell Canada",
    "6540": "CALWEB - CalWeb Internet Services",
    "6541": "VZN-VOL1 - Verizon Online LLC",
    "6542": "MICL--MELBOURNE - M.I.C.L.",
    "6543": "Ecospar Serv. e Part. Ltda.",
    "6544": "ADICON-N - Advanced Digital Concepts, Inc.",
    "6545": "TRUEVISION CORPORACION C.A",
    "6546": "AGAIN-NET-1 - PEGLabs",
    "6547": "DCT-N - DCT Technologies, Inc.",
    "6548": "GLOB - Glob, Inc.",
    "6549": "VIEWPOINTDATALABSN - Viewpoint DataLabs Int'l Inc.",
    "6550": "SBSERVICES- - Softbank Services Group",
    "6551": "ENHANCEDTECH - Network Enhanced Technologies",
    "6552": "C2NET - Community ConneXion, Inc.",
    "6553": "HTCNET-ORG - HTCNET.ORG",
    "6554": "BDM - BDM Federal, Inc.",
    "6555": "RCN-6555 - RCN",
    "6556": "INSP - Inspiration Ministries",
    "6557": "CLINIC - C. C. Net, Inc.",
    "6558": "SKYGATE - DIVERSIFIED COMMUNICATIONS INC",
    "6559": "NCIH - State of NC - State Telecommunications Services",
    "6560": "GEM",
    "6561": "CH-MAN-N - CH Management Services, LLC",
    "6562": "INBOXMARKETER - Inbox Marketer Corporation",
    "6563": "NECANET - NECAnet, Inc.",
    "6564": "CONSTANT - CONSTANT COMMUNICATIONS",
    "6565": "FREDNET- - FREDNET",
    "6566": "TROWE-NET - T. Rowe Price",
    "6567": "CIA - Cable Internet Access Inc. d/b/a WorldNET",
    "6568": "Ag para el Desarrollo de la Sociedad de la Inf en Bolivia - ADSIB",
    "6569": "NATIONWIDEN - Nationwide Services, Inc",
    "6570": "CYPRESSCOMM - Cypress Communications, Inc.",
    "6571": "EGIX-CHAMPAIGN--6571 - Egix, Inc.",
    "6572": "USVI-N - Octagon Consultants Int'l Inc.",
    "6573": "MPATH - MPATH Interactive",
    "6574": "DWG-N - Worldview Systems",
    "6575": "WISEN - Wilmington Internet Service Enterprises, Inc.",
    "6576": "SUMMITCOMM - SUMMIT COMMUNICATIONS SYSTEM, INC.",
    "6577": "OSSINC - Online System Services, Inc.",
    "6578": "AXXIS - AXXIS Corporation",
    "6579": "MEMORIALU - Memorial University of Newfoundland",
    "6580": "GWTC-N - Golden West Telecommunications Coop., Inc.",
    "6581": "PATHLINK - Pathlink Technology",
    "6582": "FRII - Front Range Internet Inc.",
    "6583": "WEBSECURE - Websecure, Inc.",
    "6584": "MICROSOFT-GP- - Microsoft Corporation",
    "6585": "AIMTECH - Aimtech  Corp",
    "6586": "WEBCENTRIC - WebCentric Communications, Inc.",
    "6587": "AMICUS-N - Amicus Networks",
    "6588": "IN-QUICK - Internet QuickLink Corporation",
    "6589": "BTCPROD - Beneficial Technology",
    "6590": "Supernet S.A. de C.V.",
    "6591": "INGR-N - Intergraph Corporation",
    "6592": "NETUS - Netus, Inc.",
    "6593": "CITIZEN1 - Citizen 1 Software",
    "6594": "DIGIS-MICROSERV - JAB Wireless, INC.",
    "6595": "MAGENTA-NETLOGIC- MAGENTA NETLOGIC LTD",
    "6596": "N-BUNGI - Bungi Communications",
    "6597": "-XILOGIX - Xilogix, LLC",
    "6598": "COMMFUNCTION - Wired Waters, Inc.",
    "6599": "ICCOM-N - Internet Communications",
    "6600": "GHGNETN - GHG Corporation",
    "6601": "PAVLOVMEDIA- - Sol Tec, Inc.",
    "6602": "SPNC--01 - Spectranetics Corporation",
    "6603": "MTWEST208 - CottonWood CyberVentures",
    "6604": "PTW - Lancaster Internet",
    "6605": "HTSI-N - Honeywell Technology Solutions Inc.",
    "6606": "WIZNET - Tyler Technologies, Inc.",
    "6607": "HOMENET - Homenet Communications, Inc.",
    "6608": "ALIANT- - Bell Aliant Regional Communications, Inc.",
    "6609": "MIINT - Millennia Internet, Inc.",
    "6610": "INTERSTATE - Interstate Networking Corporation",
    "6611": "MAGICCARPET - Magic Carpet/Roxy Systems, Inc.",
    "6612": "JAGUNET - jaguNET Access Services",
    "6613": "DIGITAL-MEDIA - Digital Media Group, Inc.",
    "6614": "USCC-N - United States Cellular Telephone Company, LP",
    "6615": "PCIS - Kelly Consultants",
    "6616": "DATTAR - Datastar, Inc.",
    "6617": "PBB-MY - Information Management Systems",
    "6618": "JOHNS-122 - Johns Hopkins HealthCare",
    "6619": "SAMSUNGSDS--KR SamsungSDS Inc.",
    "6620": "-6620 - AMA Communications, LLC",
    "6621": "HNS-DIRECPC - Hughes Network Systems",
    "6622": "ZENOX - Zenox Communications Corporation",
    "6623": "CBSI-1 - CBS Interactive Inc.",
    "6624": "GOWER - Gower.Net",
    "6625": "UI - Jim Morton Consulting",
    "6626": "MULTITKING - Multi-Tasking, Inc.",
    "6627": "GRAPEVINE - Grapevine Systems, Inc.",
    "6628": "PPS - Portland Public Schools",
    "6629": "NOAA- - NOAA",
    "6630": "LOA - Log-On America, Inc.",
    "6631": "NN-CAE - NAP.NET, LLC",
    "6632": "IMAGINATION - Imagination Network",
    "6633": "CMGDI - CMG Direct Interactive",
    "6634": "WTCI - Western Tele_Communications, Inc.",
    "6635": "NARROWLINE207 - NarrowLine",
    "6636": "ARMIGERON - Armigeron Information Services, Inc.",
    "6637": "INFOEX - Infoexchange/Sprint",
    "6638": "OANET - OA Internet Inc.",
    "6639": "CW-CAYMAN- Cable&Wireless Cayman Islands",
    "6640": "QWEST--6640 - Qwest Communications Company, LLC",
    "6641": "SPORTSLINE - SportsLine USA Inc.",
    "6642": "RDSB-N - Rainbow District School Board",
    "6643": "JIVE Jive Communications, Inc.",
    "6644": "PARSECWEB- - PARSEC",
    "6645": "OLEAN-GENERAL-HOSPITAL - OLEAN GENERAL HOSPITAL",
    "6646": "AETNA - Aetna",
    "6647": "BITNAMES-ANYCT - Solfo Inc.",
    "6648": "BAYAN-TELECOMMUNICATIONS Bayan Telecommunications, Inc.",
    "6649": "SIRWEB-NET - Sirweb Communications",
    "6650": "LOGICWORKS- - Logicworks Corporation",
    "6651": "LABDX - LABDX",
    "6652": "PIMA-COLLEGE - Pima Community College",
    "6653": "PRIVATEI - privateI, LLC",
    "6654": "NSGDA- - NSGDatacom, Inc.",
    "6655": "GTE-IM - GTE Interactive Media",
    "6656": "STARINTERNET Star Technology Services Limited",
    "6657": "ORGATECH- orgatech GmbH",
    "6658": "NAPRI s.r.o.",
    "6659": "EYNET-DE easynet GmbH",
    "6660": "CWIA Cable & Wireless UK P.U.C.",
    "6661": "EPT-LU Entreprise des Postes et Telecommunications",
    "6662": "RU-KTS- Krastelecomservice Ltd.",
    "6663": "TTI-NET Euroweb Romania SA",
    "6664": "N-IBSBKBONE TELECOM ITALIA",
    "6665": "SHINY- Shiny Corporation",
    "6666": "HEADLIGHT-INTERN Seicom Verwaltungs GmbH",
    "6667": "EUNET-FINLAND Elisa Oyj",
    "6670": "JV Media Groupe JV",
    "6671": "State Educational Institution of Higher Professional Education \"Samara State University\"",
    "6672": "RELCOMSPB LIMITED LIABILITY COMPANY RELCOM-SPB",
    "6673": "INCOMA- IncomA Ltd.",
    "6674": "NATIONAL-BANK-OF-GREECE NATIONAL BANK OF GREECE S.A.",
    "6675": "COLT-FRANCE- COLT Technology Services Group Limited",
    "6676": "Network-i Limited",
    "6677": "ICENET-1 Siminn hf",
    "6678": "N-NOOS NC Numericable S.A.",
    "6679": "SKADI- Skadi Telecom CJSC",
    "6681": "UPLOAD-NET Private Person Lemets Vitaliy Volodimirovich",
    "6682": "GNC-ALFA GNC-ALFA CJSC",
    "6684": "RTCOMM-SIBIR-NOVOKUZNETSK- CJSC \"RTComm-Sibir\" Novokuznetsk City Autonomous System",
    "6685": "BTRADIANZFRANKFURT BT Public Internet Service",
    "6686": "ATT-GCH-VOI-SF- AT&T Global Network Services Nederland B.V.",
    "6687": "KDO- Kommunale Datenverarbeitung Oldenburg",
    "6688": "ATT-GCH-VOI-LA- AT&T Global Network Services Nederland B.V.",
    "6689": "DEPOTELECOM Depo Telecom Ltd",
    "6690": "WEBPLUS- Web Plus ZAO",
    "6691": "N-BNL Banca Nazionale del Lavoro",
    "6692": "NOVOPLAT OOO Sovremennye Platejnye Sistemy",
    "6693": "UNIBUC University of Bucharest",
    "6694": "RTSNET- Nonprofit Partnership for the Development of Financial Market RTS",
    "6695": "DECIX- DE-CIX Management GmbH",
    "6696": "IONIP Online Internet nv/sa",
    "6697": "BELPAK- Republican Unitary Telecommunication Enterprise Beltelecom",
    "6698": "ARCHERNET SPD Solomaha Yuriy Vladimirovich",
    "6699": "URAN- Institute of Mathematic and Mechanic of Ural Department of Russian Science Academy",
    "6700": "BEOTEL- BeotelNet-ISP d.o.o",
    "6701": "ETF Elektrotehnicki fakultet Univerziteta u Beogradu",
    "6702": "APEXNCC- Science Production Company \"Trifle\" Ltd.",
    "6703": "ALKAR- PRIVATE JOINT-STOCK COMPANY \"FARLEP-INVEST\"",
    "6706": "VOL- Volny a.s.",
    "6707": "HEPSI-BURADA- D-Market Elektronik Hizmetler Tic. A.S.",
    "6709": "BGNETT DataGuard",
    "6710": "EUMETSAT- EUMETSAT",
    "6711": "HUNGARNET-SZEGED University of Szeged",
    "6712": "FORMAT-TV- MSP Format Ltd.",
    "6713": "IAM-",
    "6714": "ATOMNET GTS Poland Sp. z o.o.",
    "6716": "TUNZ Tunz.com SA/NV",
    "6717": "6717 Internet Central Limited",
    "6718": "NAV-TELECOM NAV DATACENTER TELECOM SRL",
    "6719": "KNOPP- Limited Liability Company KNOPP",
    "6720": "MAGWIEN Magistrat der Stadt Wien, Magistratsabteilung 14",
    "6721": "CZ-TERMINAL The Terminal Bar, internet cafe s.r.o.",
    "6722": "Synergon Information Systems Ltd.",
    "6723": "UA-XAIM Oleg Vereshchinsky PE",
    "6724": "STRATO STRATO AG",
    "6726": "GTS-SK--BACKUP GTS Slovakia a.s.",
    "6727": "EYNET-FRANCE Easynet Global Services Limited",
    "6728": "NILDRAM PIPEX Communications (Nildram)",
    "6730": "SUNRISE Sunrise Communications AG",
    "6731": "COMSTAR- MTS OJSC",
    "6732": "CYBERLINK-TRANSIT Cyberlink AG",
    "6733": "DIMDI DIMDI Deutsches Institut fuer medizinische Dokumentation und Information",
    "6734": "N-SPIN Spin s.r.l.",
    "6735": "SDTNET sdt.net AG",
    "6736": "IRANET-IPM Research Center of Theoretical Physics & Mathematics (IPM)",
    "6737": "METAWARE- Valvolari S.r.l",
    "6738": "DRI DRI http://www.dri.fr - Internet Service Provider",
    "6739": "ONO- Cableuropa - ONO",
    "6740": "TISCALI TS-Data s.r.o.",
    "6742": "AT&T EMEA",
    "6744": "RACTI-NET Research Academic Computer Technology Institute (CTI)",
    "6745": "QUZA-UK Global Crossing",
    "6746": "TRAL UPC Romania Srl, Romania",
    "6747": "LATTELEKOM Lattelekom",
    "6748": "ATT-WN-MIS ATT WN-MIS Europe",
    "6749": "DEMON-INTERNET Demon Internet",
    "6750": "SDR Soluciones Dinamicas de la Red, S.L.",
    "6751": "GERMANYNET- Vodafone D2 GmbH",
    "6752": "ANDORRA Servei de Telecomunicacions d'Andorra",
    "6755": "TURNET-N Turk Telekomunikasyon Anonim Sirketi",
    "6757": "MULTIMSG Cable & Wireless UK P.U.C.",
    "6758": "6758 MONACO TELECOM",
    "6759": "FE- Future Electronics",
    "6761": "INGATE CJSC Ingate Development",
    "6762": "SEABONE-NET TELECOM ITALIA SPARKLE S.p.A.",
    "6763": "JOSEBA-2 British Sky Broadcasting Limited",
    "6764": "PERFTECH-SLOVENIA- PERFTECH, podjetje za proizvodnjo in uvajanje novih tehnologij, d.o.o.",
    "6765": "Internet Network Services",
    "6766": "Tampere City autonomous system",
    "6768": "EUROTEL- EUROTEL Ltd",
    "6769": "SICN State Enterprise Infostruktura",
    "6770": "THE-AEXIOMUS-AUTONOMOUS-SYSTEM Cyberstrider Network Services Limited",
    "6771": "BFS BELGACOM FRANCE",
    "6772": "IMPNET- ImproWare AG",
    "6773": "SIBS Forward Payment Solutions, S.A.",
    "6774": "ASN-BICS Belgacom International Carrier Services SA",
    "6775": "BACKBONE_EHF_EUROPE Backbone ehf",
    "6776": "THENET TheNet - Internet Services AG",
    "6777": "AMS-IX-RS Amsterdam Internet Exchange B.V.",
    "6778": "BPTNET- BPT Telbank S.A.",
    "6779": "ICLNET- Fujitsu",
    "6780": "LFV-SE Luftfartsverket Sverige",
    "6781": "Telecom Finland Oy",
    "6782": "BDNET  for the county net in Norrbotten Sweden",
    "6784": "MOL Nyrt.",
    "6785": "CYBERCITY Telenor A/S",
    "6786": "CRONON-BERLIN- CRONON AG",
    "6787": "AGIX Strawberry EDV-Systeme GmbH",
    "6788": "ORC- Online Resource Center, ISP",
    "6789": "CRELCOM-NET LLC \"CRELCOM\"",
    "6790": "GTS-HUNGARY GTS Hungary Telecommunications Limited Liability Company",
    "6791": "AIVANET Aivanet Autonomous System",
    "6793": "TELIVO- TDC Oy Finland",
    "6794": "N-HRTNET  # -HRTNET CONVERTED TO N-HRTNET FOR RPSL COMPLIANCE HRT - Croatian Radio Television",
    "6797": "PHONERA Phonera Networks AB",
    "6798": "NET4YOU- Net4You Internet GmbH",
    "6799": "OTENET-GR Ote SA (Hellenic Telecommunications Organisation)",
    "6801": "Federal State Institution Russian Scientific Center Kurchatovsky                institute",
    "6802": "UNICOM-B- NREN - Bulgaria",
    "6803": "SWAN SWAN a.s.",
    "6805": "TDDE-N1 Telefonica Germany GmbH & Co.OHG",
    "6807": "KHARKIV- National Technical University 'Kharkiv Polytechnical Institute'",
    "6808": "TINET-IA-BACKBONE Tinet SpA Asia Network",
    "6810": "BEZEK \"Bezeq\"- THE ISRAEL TELECOMMUNICATION CORP. LTD.",
    "6811": "Verizon Denmark A/S",
    "6813": "FLEXNET Autonomous System",
    "6814": "Tinet SpA",
    "6815": "ING-NL- ING Bank N.V.",
    "6816": "ING Bank N.V.",
    "6817": "ING Bank N.V.",
    "6818": "IPCENTAUK iPcenta UK Customer Network",
    "6819": "QIICT Qi ict B.V.",
    "6820": "LEIVO LEIVO Ltd.",
    "6821": "MT--OWN Makedonski Telekom",
    "6822": "SUPERONLINE- SuperOnline autonomous system",
    "6823": "CCCB 3C1B Telekomunikasyon ve Internet Hiz. San. ve Tic. Ltd. Sti",
    "6824": "HERMES-NETWORK Hermes Telecom International Ltd",
    "6825": "IDDQD- Corsellis-Montford Group PLC",
    "6826": "GARANTIYA- Limited Liability Company \"Garantiya\"",
    "6828": "USI OJSC Rostelecom",
    "6829": "NO-SOGNFJORDFYLKE Sogn og Fjordane fylke",
    "6830": "LGI-UPC Liberty Global Operations B.V.",
    "6831": "NETECOM Net & Com s.r.l.",
    "6832": "Swiss Telecom F+E",
    "6833": "GVS- Terranets bw GmbH",
    "6834": "6834 KMD A/S",
    "6836": "LTAMPA- Editrice La Stampa S.p.A.",
    "6837": "SWISSCOM-TRANSIT- Swisscom (Switzerland) Ltd",
    "6838": "FLIX- The Flirble Internet Exchange",
    "6839": "MTV3- MTV Oy",
    "6840": "THEBRAIN-NOC- THE BRAINWORK S.r.l. - Internet Service Provider",
    "6841": "BT-INFONET-EUROPE BT-Infonet-Europe",
    "6842": "AUCS Communications Services v.o.f.",
    "6843": "RF Cryptosvyaz, Penza",
    "6844": "TECHNODESIGN Joint Stock Company \"Techno Design\"",
    "6845": "MACSYS MacSYS Computers - ROMANIA/Bucharest",
    "6846": "UKRPACK Joint Ukrainan-German Enterprise \"INFOCOM\" LLC",
    "6847": "CERBERNET Cerbernet Ltd",
    "6848": "TELENET- Telenet N.V.",
    "6849": "UKRTELNET JSC UKRTELECOM,",
    "6850": "METROCOM- CJSC \"Metrocom\"",
    "6851": "BKCNET SIA \"Baltcom TV\"",
    "6852": "UNITEDBANKERS- UB Securities Ltd.",
    "6853": "ORANGE-BUSINESS-SERVICES-SOUTHEUR Equant Inc.",
    "6854": "SYNTERRA- CJSC Synterra",
    "6855": "Slovak Telecom, a. s.",
    "6856": "IC-VORONEZH- IC-VORONEZH",
    "6857": "PTC- Saint-Petersburg State University",
    "6858": "COMLINK- Comlink Ltd",
    "6859": "KCP- DIGITAL CONTINUITY LIMITED",
    "6860": "IWAN- Saint-Petersburg State University,",
    "6861": "ITALIA-ONLINE- Italia Online S.p.A",
    "6862": "GRATEX-",
    "6863": "ROSNET- OJSC Rostelecom",
    "6865": "WEB A/S",
    "6866": "CYTA-NETWORK Cyprus Telecommunications Authority",
    "6867": "UCNET University of Crete",
    "6868": "BMSTU- Moscow State Technical University named NE Bouwman (state enterprise no commercial organisation)",
    "6869": "FREE-6869 OOO FREEnet Group",
    "6870": "H1N H1 LLC",
    "6871": "PLUSNET PlusNet PLC",
    "6872": "SADN- Scandinavian Airlines Data Norway",
    "6873": "LIBRUM- Librum Sp. z o.o.",
    "6874": "PSTU- State Educational Institution of Higher Professional Education \"Perm State Technical University\"",
    "6876": "TENET- TeNeT Scientific Production Enterprise LLC",
    "6877": "6877 BelABM Ukraine",
    "6878": "6878-T-SYSTEMS T-Systems International GmbH",
    "6879": "ENSTINET-EG",
    "6880": "OKB MEI",
    "6881": "NIXCZ NIX.CZ z.s.p.o.",
    "6882": "RTRT-PEGO Regione Toscana",
    "6883": "Parlamentsdirektion",
    "6884": "N-EURONET Neon-V Communications",
    "6885": "CITYNET2 CITYNET MARCIN SOBALA - PIOTR MISIUDA",
    "6886": "INTS-N INTS",
    "6887": "PRTL-ES Primus Telecommunications Spain",
    "6889": "FRINK- Frink International Network",
    "6890": "WISPER-UK Wisper UK Network",
    "6891": "INFEUROPE- infeurope Autonomous System",
    "6892": "Vasileostrovsky Telecom Center",
    "6893": "SAITIS-NETWORK Saitis Network, N.Desir",
    "6894": "KDDI KDDI Europe Ltd.",
    "6895": "ESPANIX OCIACION ESPANIX",
    "6898": "INTERNETONE_CH Swiss Engineering Laboratories SA",
    "6899": "NETSTORE- Daisy Data Centre Solutions Limited",
    "6900": "6900 Hewlett Packard GmbH",
    "6903": "ZENON- ZENON N.S.P.",
    "6904": "ATT-IAPACIDC-SNG1- AT&T Webhosting Singapore IDC",
    "6905": "ATT-EMEAIDC-AMS1- AT&T Webhosting Amsterdam IDC",
    "6906": "GEANT-APOLLO Lattelecom",
    "6907": "EBAY-DE- eBay GmbH",
    "6908": "DATAHOP Datahop Ltd",
    "6910": "DIALTELECOMRO Dial Telecom S.R.L.",
    "6911": "PRO-NET Pro-Net Internet Services Ltd",
    "6912": "HCSNET-NBLK - Hayes Computer Systems",
    "6913": "HCSNET-NBLK - Hayes Computer Systems",
    "6914": "HCSNET-NBLK - Hayes Computer Systems",
    "6915": "HCSNET-NBLK - Hayes Computer Systems",
    "6916": "EXCO-NA - Exco RMJ Securities Corp",
    "6917": "MULTEXSYS - Multex Systems, Inc.",
    "6918": "PENNCOM - Penncom Internet Co.",
    "6919": "IMPACT - Impact Telecom, LLC.",
    "6920": "TRADEMED- - Trade Media",
    "6921": "ARACHNITEC - Arachnitec, INC.",
    "6922": "TEXAGENCYNET - Texas Department of Information Resources",
    "6923": "OKNET - OKNET Internet Services",
    "6924": "STARTRIB - Star Tribune Newspaper",
    "6925": "DIGADV- - Digital Advantage Corporation",
    "6926": "SOLLUNA- - Solluna",
    "6927": "Ternium Mexico, S.A. de C.V.",
    "6928": "RAINNET - Tacoma-Pierce County Association",
    "6929": "COSITE-N-1 - COSITE, INC.",
    "6930": "GOLD- - FIRST VIRTUAL HOLDINGS INC.",
    "6931": "RINGLING - Ringling College of Art and Design",
    "6932": "EBSCOPUB - EBSCO Publishing",
    "6933": "HARBING-N - Harbinger Net Services",
    "6934": "ATT-COLUMBUS- - AT & T",
    "6935": "IDG-ISG - IDG Interactive Services Group",
    "6936": "NETGATE-SC1 - NetGate Communications",
    "6937": "WWWPROD- - WWW Productions, Inc.",
    "6938": "GREENLAKE-IOC - Greenlake/IOC",
    "6939": "HURRICANE - Hurricane Electric, Inc.",
    "6940": "COMSTREAM - Comstream",
    "6941": "HEALTHEON - Healtheon Corp.",
    "6942": "CLARINET - ClariNet Communications Corporation",
    "6943": "INFOTECHSYS - Information Technology Systems, Inc.",
    "6944": "NTTA-6944 - NTT America, Inc.",
    "6945": "SVNet",
    "6946": "ST-NETWORK-2 - American Messaging Services L.L.C.",
    "6947": "AMCITY - American City Business Journals",
    "6948": "INTERCOM - Intercom Online",
    "6949": "CHARLES-SCHWAB - Charles Schwab & Co., Inc.",
    "6950": "LAMBDA - Lambda Telecom",
    "6951": "CREDITCALL-NETWORKS - CreditCall Corporation",
    "6952": "WMEX - World Merchandise Exchange",
    "6953": "NETONLINE208 - Internet Marketing Solutions",
    "6954": "NACS - New Age Consulting Service",
    "6955": "DANDH - D&H Distributing Company",
    "6956": "INTERACT-N1 - InterAct Computer",
    "6957": "TECNOLOGIA UNO-CERO, SA DE CV",
    "6958": "DTS-WORLDWIDE - Diplomatic Telecommunications Services",
    "6959": "DTS-AFRICA - Diplomatic Telecommunications Services",
    "6960": "DTS-INTER-AMER - Diplomatic Telecommunications Services",
    "6961": "DTS-ET-IAN - Diplomatic Telecommunications Services",
    "6962": "DTS-EUROPE - Diplomatic Telecommunications Services",
    "6963": "DTS-CANADA - Diplomatic Telecommunications Services",
    "6964": "DTS-NEAR-ET - Diplomatic Telecommunications Services",
    "6965": "DTS-SOUTH-IAN - Diplomatic Telecommunications Services",
    "6966": "USDOS - U.S. Department of State",
    "6967": "6967 - MP4200 LLC",
    "6968": "UNIFORUM-SA",
    "6969": "N2K-N - N2K Inc.",
    "6970": "BSG-AIR-NET - Imonics Corporation",
    "6971": "MEDIACTNET - Mediacast Holdings, LLC",
    "6972": "INETWEST - Santa Cruz Community Internet",
    "6974": "ROSS-N - Ross Technology, Inc.",
    "6975": "LEX2 - Lexington County School District",
    "6976": "VZN-VOL2 - Verizon Online LLC",
    "6977": "IAC- - Internet Access Cincinnati",
    "6978": "SECURITIES- - Internet Securities Incorporated",
    "6979": "SAP - SAP America Inc.",
    "6980": "CAJUNNET- - Cajun.Net",
    "6981": "11456 - Windstream Nuvox, Inc.",
    "6982": "DRAGON - Dragon Networks, Inc.",
    "6983": "ITCDELTA - ITC^Deltacom",
    "6984": "NYNEX- - Verizon Data Services LLC",
    "6985": "DIXON - Dixon Networking",
    "6986": "ANGEL-NETWORKS - Angel Networks",
    "6987": "AXIONINTERNET - Axion Internet Inc.",
    "6988": "STREAM - Stream International",
    "6989": "GTSI - Government Technology Services Inc.",
    "6990": "ONE-O - One-O, Inc.",
    "6991": "USLD-N - US Long Distance",
    "6992": "NETSCAPE- - Netscape Communications Corp.",
    "6993": "INTERNAP-SEA - Internap Network Services Corporation",
    "6994": "FTMETRICS - Fastmetrics",
    "6995": "VRIS-6995 - Verizon Online LLC",
    "6996": "ALLST-6996 - Allstream Corp.",
    "6997": "SILLS- - SILLS CUMMIS EPSTEIN & GROSS",
    "6998": "BRITEVOICE - Brite Voice Systems Inc",
    "6999": "UU-ITNNET - Interactive Telecom Network",
    "7000": "DBEACH - Globel Net, Inc.",
    "7001": "YSAL-MEZZEMI - Mezzemi",
    "7002": "Mexico Communicates, S.C.",
    "7003": "VIRTUALENTERPRISES- - Advanced Systems Group",
    "7004": "CTC Transmisiones Regionales S.A.",
    "7005": "InterServer SA",
    "7006": "CYBERNEX - Cybernex Inc.",
    "7007": "FLIX - FL Internet Exchange",
    "7008": "TIBA- - The Internet Business Association",
    "7009": "QDECK-MDR - Quarterdeck Corp.",
    "7010": "DRKNGS-N - DRK Network & Graphics Solutions",
    "7011": "FRONTIER-AND-CITIZENS - Frontier Communications of America, Inc.",
    "7012": "PHYBER - Phyber Communications, LLC.",
    "7013": "NETSELECT - Health Sciences Libraries Consortium",
    "7014": "XO-7014 - XO Communications",
    "7015": "COMCT-7015 - Comcast Cable Communications Holdings, Inc",
    "7016": "CCCH-3 - Comcast Cable Communications Holdings, Inc",
    "7017": "SCRR-7015 - Time Warner Cable Internet LLC",
    "7018": "ATT-INTERNET4 - AT&T Services, Inc.",
    "7019": "NTTA-7019 - NTT America, Inc.",
    "7020": "QDATA-",
    "7021": "VRIS-7021 - Verizon Online LLC",
    "7022": "SBT - SBT Accounting Systems",
    "7023": "ICI - The Internet Connection, Inc.",
    "7024": "PIXELGATE - PixelGate",
    "7025": "AMLIBS - Ameritech Library Services",
    "7026": "IME- - Internet Maine",
    "7027": "ENGAGE - ENGAGE games online",
    "7028": "IBS - International Business Software, Inc.",
    "7029": "WINDSTREAM - Windstream Communications Inc",
    "7030": "EXWIRE - Exwire, Inc.",
    "7031": "MOONLIGHT- - Moonlight Media, Inc.",
    "7032": "NMB- - NetManage, Bellevue-WA",
    "7033": "FIREWALL - Eris Free Networking",
    "7035": "ECLIPSE - Eclipse Internet Access",
    "7036": "PRIMUS-7036 - Primus Telecommunications Canada Inc.",
    "7037": "TWTC-7037 - tw telecom holdings, inc.",
    "7038": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "7039": "OAKNET - OAKNET Consulting",
    "7040": "RECKNER - J. Reckner Associates, Inc.",
    "7041": "DALCOMP - Dalcomp",
    "7042": "OLYMPUSNET - Townsend Communications, Inc",
    "7043": "FEB- - FEB",
    "7044": "CSACNETWORKS - Computer Systems Authority",
    "7045": "WEATHER - THE WEATHER CHANNEL",
    "7046": "RFC2270-UUNET-CUSTOMER - MCI Communications Services, Inc. d/b/a Verizon Business",
    "7047": "TDSYS - Trident Data Sytems",
    "7048": "Linha Livre Internet Ltda",
    "7049": "Silica Networks Argentina S.A.",
    "7050": "UW-MILWAUKEE-1 - University of Wisconsin - Milwaukee",
    "7051": "N-SNS - Secure Network Systems",
    "7052": "HTS- - Hi-Tech Services, Inc.",
    "7053": "AIMEDIA-MDSNWI - AT&T Services, Inc.",
    "7054": "MERCK  FOR MERCK",
    "7055": "QIS - Quantum Internet Services, Inc.",
    "7056": "Datanet S.A. de C.V.",
    "7057": "MANAGEDNETWORK - Managed Network Systems Inc.",
    "7058": "WB-DEN - Viasat Communications Inc.",
    "7059": "HOTSITES - Hotsites.net",
    "7060": "EA - Electronic Arts, Inc.",
    "7061": "COGENT-7061 - Cogent Communications",
    "7062": "DE-JAZZD7062 - Windstream Communications Inc",
    "7063": "INSIDE SISTEM DE INFORMACAO LTDA -",
    "7064": "ACI-NET- - Associated Communications Internet, Inc.",
    "7065": "SONOMA - Sonoma Interconnect",
    "7066": "NETWORK-VIRGINIA- - Network Virginia",
    "7067": "TECHINTER - Technology Interface, Inc.",
    "7068": "PFIZERNET - PFIZER INC.",
    "7069": "NORTH-AMERICAN-INT - North American Internet, Inc.",
    "7070": "CLEAR-CHANNEL--7070 - Clear Channel Communications, Inc.",
    "7071": "PENET-N - The Press-Enterprise Co.",
    "7072": "NN-RS00-RS06 - NAP.NET, LLC",
    "7073": "NN-RS00-RS06 - NAP.NET, LLC",
    "7074": "NN-RS00-RS06 - NAP.NET, LLC",
    "7075": "NN-RS00-RS06 - NAP.NET, LLC",
    "7076": "NN-RS00-RS06 - NAP.NET, LLC",
    "7077": "NN-RS00-RS06 - NAP.NET, LLC",
    "7078": "MONMOUTH - Monmouth Internet Corp",
    "7079": "AYRIX - Ayrix Technologies, Inc.",
    "7080": "Electronica y Comunicaciones, S. A.",
    "7081": "CARIN--BLOCK - ISI",
    "7082": "CARIN--BLOCK - ISI",
    "7083": "CARIN--BLOCK - ISI",
    "7084": "CARIN--BLOCK - ISI",
    "7085": "CARIN--BLOCK - ISI",
    "7086": "MISSISSIPPI-STATE-GOVERNMENT - Mississippi, Department of Information Technology Services (ITS)",
    "7087": "Administraci\u00f3n de Redes Colomsat S.A.",
    "7088": "NEONSOFT - New Era of Networks, Inc.",
    "7089": "REALITYON - Reality Online Inc.",
    "7090": "IDNET-2 - Innovative Data Services, Inc.",
    "7091": "VIANET-N - ViaNet Communications",
    "7092": "ICIGAMES - INTERACTIVE CREATIONS INC.",
    "7093": "REM- - REM Computer Consultants, Inc.",
    "7094": "WA-IXA - Washington Internet Services",
    "7095": "NETUSA - Network Internet Services",
    "7096": "DSOURCE - Data Source, L.L.C.",
    "7097": "HWSERVICES--7097 - Hostway Services, Inc.",
    "7098": "CORE1-WWISPNET - WWISP, Inc.",
    "7099": "NORTELRCH - NORTEL",
    "7100": "PTC- - Prodigy Technologies Corporation",
    "7101": "SANDBOX - Sandbox Entertainment Corporation",
    "7102": "APLATFORM- - Aplatform",
    "7103": "CyberMedia - Panama",
    "7104": "APC- - Accesspoint Corporation",
    "7105": "DOWJONES- - Dow Jones & Company, Inc.",
    "7106": "OHIOBRIGHTNET - Com Net, Inc.",
    "7107": "3DO - The 3DO Company",
    "7108": "BIZNEXUS - Biznexus",
    "7109": "DATEK - Datek Securities Corp.",
    "7110": "QUEBEC-NET - Quebec.Net",
    "7111": "PEN-SYSTEMS - Aspen Systems Corporation",
    "7112": "MTSI-N - MTS Internet, Inc.",
    "7113": "NFIC- - New Frontiers Information Corp.",
    "7114": "USFG- - USF&G",
    "7115": "INDEPTH-DATA- - Indepth Data Inc.",
    "7116": "TOYOTA-EXT - Toyota Motor Sales, U.S.A., Inc.",
    "7117": "NETCT - Netcast Communications Corp.",
    "7118": "GIS-7118 - Global Internet Services",
    "7119": "FORSYTHCOUNTY - Forsyth County MIS",
    "7120": "Corporacion en Investigacion Tecnologica e Informatica, S.A. de C.V.",
    "7121": "PALACEGROUP - The Palace Group, Inc.",
    "7122": "MTS-N - MTS Allstream Inc.",
    "7123": "NILENET-T1-0 - NileNet, Ltd.",
    "7124": "LJX - ALM Media Inc.",
    "7125": "Universidad de Monterrey",
    "7126": "UNITEDMEDIA - United Media",
    "7127": "SCE - Southern California Edison",
    "7128": "SABRE--3 - Sabre Inc.",
    "7129": "ANC- - American Network Communications, Inc.",
    "7130": "THEMALL - Internet in a Mall, Inc",
    "7131": "ERX-ITE- IT&E Overseas",
    "7132": "SBIS-  for SBIS-",
    "7133": "NYPP- - New York Independent System Operator, Inc.",
    "7134": "OTBB - Nothing But Net, Inc.",
    "7135": "KOHALA - Kohala Software",
    "7136": "ONLY - Only Networking Inc. (ONLY2-DOM)",
    "7137": "TELEMATIX/ ENITEL",
    "7138": "ENCOMPS-N - Encompass Digital Media, Inc.",
    "7139": "BIZTRAVELCAM - Biztravel.com",
    "7140": "DIMCOM - FORETHOUGHT.net",
    "7141": "AUS- - Koltai Inc",
    "7142": "AZSTARNET - TUCSON NEWSPAPERS",
    "7143": "HHRN - Hughes Hubbard & Reed LLP",
    "7144": "VOYAGERONLINE - Voyager Online, LLC",
    "7145": "MENO - Meno Inc.",
    "7146": "GABN - Georgia Business Net, Inc",
    "7147": "NEWSALERT-NET - News Alert Inc.",
    "7148": "N-GRAPHNET-NET Graphnet Inc.",
    "7149": "Sistemas Aplicados de la C.P., S.A. de C.V.",
    "7151": "BAYAREA- - Bay Area Internet Solutions",
    "7152": "REDCROSS-N - American Red Cross",
    "7153": "N-NEPOOL - NEW ENGLAND POWER POOL",
    "7154": "FDDNET-N",
    "7155": "WB-DEN2 - Viasat Communications Inc.",
    "7156": "AGATE2 - Agate Internet Services, Inc.",
    "7157": "Americatel Colombia S.A.",
    "7158": "NETFEED- - NetEx Online Services",
    "7159": "NTTCNET - New Trier Technology Cooperative",
    "7160": "NETDYNAMICS - Oracle Corporation",
    "7161": "QWEST--7161 - Qwest Corporation",
    "7162": "Universo Online S.A.",
    "7163": "NYLI- - New York Life Insurance",
    "7164": "LIPS- - Local IP Service, Inc.",
    "7165": "AXAFINANCIAL-N - AXA Financial, Inc.",
    "7166": "C-ECOMM - C-E Communications",
    "7167": "Administracion Nacional de Telecomunicaciones",
    "7168": "WB-DEN3 - Viasat Communications Inc.",
    "7169": "WALRUS - Walrus Internet",
    "7170": "MANHA-20 - Manhattan West, LLC",
    "7171": "BIOWAREONLINECA1 - BioWare Austin, LLC",
    "7172": "IPSOFT-US-N2 - IPsoft",
    "7173": "Instituto Nacional de Astrofisica, Optica y Electronica",
    "7174": "ONWARD-N - Onward Technologies, Inc.",
    "7175": "ERX-AUSSIE aussie.net Pty Limited",
    "7176": "GTEIEUROPE- Level 3 Communications",
    "7177": "DFWNET - DFW Internet Services, Inc.",
    "7178": "TLR- - Thomson Reuters (Legal) Inc.",
    "7179": "PCSERVICE - PC Service Source",
    "7180": "HILINESWHITESTAR - HiLine Internet Services, Inc.",
    "7181": "WINDSTEAM-HOSTED-SOLUTIONS-2 - Windstream Hosted Solutions, LLC",
    "7182": "CMGDI-ET - CMG Direct Interactive",
    "7183": "SALLIEMAE - Sallie Mae, Inc.",
    "7184": "Universidad Verecruzana",
    "7185": "QNIS-N - QuadraNet Internet Services",
    "7186": "NETRICS-INC - Netrics Inc.",
    "7187": "RITE- - Regional Internet Traffic Exchange",
    "7188": "ETCNET- - Eastern Telelogic Corporation",
    "7189": "DATALINK - Datalink Corporation",
    "7190": "CYBORGANIC - Cyborganic Corporation",
    "7191": "-7191 - CenturyTel Internet Holdings, Inc.",
    "7192": "VRIS-7192 - Verizon Online LLC",
    "7193": "VRIS-7193 - Verizon Online LLC",
    "7194": "BWP - City of Burbank",
    "7195": "Telecorp Colombia S.A.",
    "7196": "TRINET- - TriNet Services",
    "7197": "SMS - Siemens Medical Services",
    "7198": "SCR - Siemens Corporate Research",
    "7199": "Internet de Colombia S.A",
    "7200": "G1ENGLAB - Global One Private Systems",
    "7201": "TELESCAN - INVESTools Inc",
    "7202": "FAMU - Florida A & M University",
    "7203": "LEEWEB-US - Leaseweb USA, Inc.",
    "7204": "GIS - Galaxy Internet Services Inc.",
    "7205": "POINTBREAK - PointBreak Communications SystemsAG",
    "7206": "NETDIRECT - CoreComm Internet Services Inc",
    "7207": "INTREXNET - Intrex Inc.",
    "7208": "MEGANET - MegaNet",
    "7209": "HOOKUP-NET-WIN-A - HookUp Communications Corporation",
    "7210": "SPRINT-ISP2 - Sprint Multimedia Consumer InternetServices",
    "7211": "GBLNAPSBOSFEED - Global NAPs Inc.",
    "7212": "VANDERBILT - Vanderbilt University",
    "7213": "MONCOMPANIESINC - Mason Companies, Inc.",
    "7214": "CURSUS - CURSUS NETWORK USA",
    "7215": "AHNET- - Affinity Internet, Inc",
    "7216": "RJL- - RjL Systems",
    "7217": "EARTHWEB - Earthweb",
    "7218": "DUNBAR - Dunbar Consulting",
    "7219": "NTULIX - Tulix Systems, Inc.",
    "7220": "DIAMONDMM - Diamond Multimedia Systems, Inc",
    "7221": "TWRS-PHL - Towerstream I, Inc.",
    "7222": "SBIS-KCSYMO - AT&T Internet Services",
    "7223": "CSRLINK - CSRLink, Inc.",
    "7224": "AMAZON- - Amazon.com, Inc.",
    "7225": "GLOBALNETCORP - Global Net Corporation",
    "7226": "DATA393-N2 - Latisys-Denver, LLC",
    "7227": "KPMGL- - KPMG LLP",
    "7228": "-PAETEC-NET - PaeTec Communications, Inc.",
    "7229": "GLOBAL-ONE-RESTON - Global One Communications L.L.C.",
    "7230": "ORBITEL - Orbitel Communications, Inc",
    "7231": "ISP-ZA",
    "7232": "USWEB - USWeb Corporation",
    "7233": "YAHOO-US - Yahoo",
    "7234": "RUSSELL7234 - Frank Russell",
    "7235": "LANMINDS - LanMinds, Inc.",
    "7236": "Universidad Regiomontana, A.C.",
    "7237": "LFCI - Levine, Frayer & Carlson, Inc.",
    "7238": "MACROVISION-CORPORATION - Rovi Corporation",
    "7239": "COMSOURCE- - ComSource, Inc.",
    "7240": "URAEUS - Uraeus Consulting",
    "7241": "INFINEX-SF - Infinex Telelcom, Inc.",
    "7242": "NORTEL-TECHNOLOGY - Nortel Technology Ltd,",
    "7243": "HDS- - HITACHI DATA SYSTEMS",
    "7244": "ALAMEDANET - Alameda Networks",
    "7245": "TECLINK- - TECLink Inc.",
    "7246": "BMS- - Bristol-Myers Squibb Company",
    "7247": "MOJO - Mojo Networks",
    "7248": "SURENET - SureNet Corporation",
    "7249": "SKYSCAPE - SkyScape Communications",
    "7250": "SURRY-TELEPHONE-MEMB-CORP - Surry Telephone Membership Corporation",
    "7251": "SUNBELT- - ThreatTrack Security",
    "7252": "DSR-NY-HQ - DS&R",
    "7253": "MAINSTAY-COMMUNICATIONS - Mainstay Communications",
    "7254": "SURFSOUTH - Surf South, Inc.",
    "7255": "SAFCO - Safco Corporation",
    "7256": "VIACOM- - Viacom Inc.",
    "7257": "PREMIERE-GLOBAL-SERVICES-INC - Premiere Global Services, Inc.",
    "7258": "CATALOG-7258 - Catalog.com",
    "7259": "NETGEN - net.Genesis Corp",
    "7260": "NORLIGHT - Norlight Telecommunications",
    "7261": "JDEDWARDS - J D EDWARDS & COMPANY",
    "7262": "BTN-THREE - Beyond The Network America, Inc.",
    "7263": "GOFTNET - gofast.net Inc.",
    "7264": "SBCC - Santa Barbara Community College District",
    "7265": "WOW-INTERNET - WideOpenWest Finance LLC",
    "7266": "INFOSEEK AfricaINX created auth-num for 7266",
    "7267": "GLOBALCOMMERCE - Global Commerce Link, LLC",
    "7268": "ATHENET - Athenet Internet Services",
    "7269": "ONESOURCE - OneSource Information Services,Inc",
    "7270": "NET2PHONE - IDT Corporation",
    "7271": "LOOK - Look Communications Inc.",
    "7272": "TCIMET - TCI Telephony Services",
    "7273": "TPLNET - Tacoma Public Library",
    "7274": "TKI - Teknowledge Industries, Inc.",
    "7275": "WINGBERLIN - Wing Net",
    "7276": "UNIVERSITY-OF-HOUSTON - University of Houston",
    "7277": "NEWETWIRELESS - NewEast Wireless Telecom Inc.",
    "7278": "ACCRUE - Accrue Software, Inc.",
    "7279": "AMOSPRESS - Amos Press, Inc.",
    "7280": "YAHOO-FC - Yahoo! Inc.",
    "7281": "BOOZ- - Booz Allen Hamilton Inc.",
    "7282": "DXNET- - DXNET",
    "7283": "THERIVER - THE RIVER / INTERNET ACCESS CO",
    "7284": "CDSINTERNET - CDS Internet",
    "7285": "SPACENET - Spacenet, Inc.",
    "7286": "PBI-NET-BLK2 - AT&T Internet Services",
    "7287": "PBI-NET-BLK2 - AT&T Internet Services",
    "7288": "PBI-NET-BLK2 - AT&T Internet Services",
    "7289": "PLATINUM - Platinum Internet Group",
    "7290": "SBIS-BLK - AT&T Internet Services",
    "7291": "SBIS-BLK - AT&T Internet Services",
    "7292": "SBIS-BLK - AT&T Internet Services",
    "7293": "SBIS-BLK - AT&T Internet Services",
    "7294": "SBIS-BLK - AT&T Internet Services",
    "7295": "NETWORKAMERICA - Network America Systems, Inc.",
    "7296": "ALCHEMYNET - Alchemy Communications, Inc.",
    "7297": "APPL- SOCIATED PRESS PROPERTY LIMITED",
    "7298": "HP Enterprise Services Brazil",
    "7299": "PRONET - ProNET Communications Inc.",
    "7300": "-INFOTRAX-SYSTEMS - InfoTrax Systems, L.C.",
    "7301": "N- - National Academy of Sciences",
    "7302": "ADVANCEDINTERNETCOMM - Advanced Internet Communications, Inc.",
    "7303": "Telecom Argentina S.A.",
    "7304": "THECIA - Complete Internet Access, Inc",
    "7305": "INNERSET- - Innerset",
    "7306": "IANDEVBANK - Asian Development Bank",
    "7307": "HIPPOCAMPUS - Hippocampus OSD Inc.",
    "7308": "SPRINT-PCS - Sprint PCS (Personal",
    "7309": "USWO- - The Virtual Marketing Corporation",
    "7310": "GARTNERGROUP - Gartner Group",
    "7311": "FRONTIER - Frontier Networks",
    "7312": "FDM4-CA - FDM4 International Inc.",
    "7313": "Certisign Certificadora Digital S.A.",
    "7314": "TIS-N - Traveller, Inc.",
    "7315": "COLOMBIA TELECOMUNICACIONES S.A. ESP",
    "7316": "NETECH - North East Technologies",
    "7317": "CSPS- - The First Church of Christ, Scientist",
    "7318": "FOCALINK- - Focalink",
    "7319": "WEBSPAN - Webspan Inc",
    "7320": "LANCITY - LANcity Company",
    "7321": "LNET-N - LocalNet Corporation",
    "7322": "MARSWEB - MARSweb, LLP",
    "7323": "ADVEST - Advest",
    "7324": "IFAX-N-1 - iFAX Solutions, Inc.",
    "7325": "Universidad Autonoma De Tamaulipas",
    "7326": "NUNET - Northwestern University",
    "7327": "7THLEVEL - 7th Level, Inc.",
    "7328": "CHOP - The Children's Hospital of Philadelphia",
    "7329": "ATT-CMS - AT&T CMS",
    "7330": "INTERNETLABS - Internet  Laboratories, Inc.",
    "7331": "IARC - Information Architecture",
    "7332": "LIGHTBOUND- - IQuest Internet",
    "7333": "WINNET - WinNET Communications, Inc.",
    "7334": "WALLSTREET - Wall Street On Demand, Inc.",
    "7335": "LOOP - Loop Phone Organization",
    "7336": "COMPS - Compass Communications",
    "7337": "SNIP - Southern NJ Internet Providers (SNIP)",
    "7338": "GLOBALENET - GLOBAL ENTREPRENEURS NETWORK,",
    "7339": "SIEMENS-CREDIT - Siemens Credit Corp",
    "7340": "TELETEL",
    "7341": "VELOCITY - Velocity Network, Inc.",
    "7342": "VERISIGN- - VeriSign Infrastructure & Operations",
    "7343": "VISA-INTERACTIVE - Visa Interactive",
    "7344": "VIVIDNET - Vivid Internet Production Company",
    "7345": "LUCENTTECH - Alcatel-Lucent",
    "7346": "SPIRITONE - Spirit One, Inc.",
    "7347": "USXPRESS - U.S. Xpress Enterprises, Inc.",
    "7348": "CRYSTALBALL - Crystalball software",
    "7349": "WINDSTEAM-HOSTED-SOLUTIONS-1 - Windstream Hosted Solutions, LLC",
    "7350": "METCOMM - MetComm.Net, LLC",
    "7351": "BLARG - Blarg! Online Services, Inc.",
    "7352": "WECOMINCNUM37731 - Wecom Inc",
    "7353": "PRIMUS - Primus Communications Corp.",
    "7354": "PRESIDIUM-INC - Presidium Inc.",
    "7355": "MEITCA- - Mitsubishi Electric ITA (HSL)",
    "7356": "MONDAYRE - Monday Properties",
    "7357": "AMERICANDATANET - American Data Net",
    "7358": "DNB-NBIC - Dun & Bradstreet",
    "7359": "QWEST--7359 - Qwest Corporation",
    "7360": "PUREATRIA - Pure Atria Software",
    "7361": "MEDITREAM - Mediastream",
    "7362": "HST-CHRON - Hearst Newspapers,  LLC",
    "7363": "YOMURA - Lightstream Transmission and Telecom Inc",
    "7364": "GROOVE - Reality Enhancements",
    "7365": "CENTROIN PROVEDOR DE SERV. INTERNET. LTDA",
    "7366": "LEMURIACO - Lemuria Communications Inc.",
    "7367": "SYSONE - Systems One Amadeus",
    "7368": "ST-NETWORK-1 - American Messaging Services L.L.C.",
    "7369": "I-HYPERMALL - Interlink Advertising Services Inc.",
    "7370": "CDSINC - Commercial Data Systems",
    "7371": "COTALCORPORATION - The Coastal Corporation",
    "7372": "IPEXCHANGE-NJ - AV-Network, Inc.",
    "7373": "GORGON-NJ - Gorgon Enterprises, Inc.",
    "7374": "VALUSERVE - ValuServe.Com",
    "7375": "HULANET - Hula Net, Inc",
    "7376": "INFORONICS - Inforonics, Inc.",
    "7377": "UCSD - University of California at San Diego",
    "7378": "CONNETIX - Connetix, Inc.",
    "7379": "VIEWCALL - Viewcall America",
    "7380": "CERTUSBANK - Certus Bank N.A.",
    "7381": "SUSA SunGard Availability Services USA",
    "7382": "TEX-COMMUNICATIONS-ISPDONE2 - Texas Communications, Inc.",
    "7383": "PWDL - Purdy's Wharf Development Limited",
    "7384": "INTUIT - Intuit Inc.",
    "7385": "INTEGRATELECOM - Integra Telecom, Inc.",
    "7386": "ILLINOIS-STATE-UNIV - Illinois State University",
    "7387": "TIOCOM - The Internet Outsourcing Group, TIOcom",
    "7388": "DFXNET - Design FX  Interactive LLC",
    "7389": "NETDOX - NetDox, Inc.",
    "7390": "NLSLAN",
    "7391": "DNIC--07391 - Navy Network Information Center (NNIC)",
    "7392": "DELPHI-INTERNET- - Delphi Internet Services Corporation",
    "7393": "CYBERCON - CYBERCON, INC.",
    "7394": "FLYINGPENGUIN - Flying Penguin Productions Limited",
    "7395": "INTEGRATELECOM - Integra Telecom, Inc.",
    "7396": "OREGON-IX - Univerisity of Oregon (Oregon Exchange)",
    "7397": "DIGILINK--MDR - Digilink, Inc.",
    "7398": "MTS-TEST2- - MTS Allstream Inc.",
    "7399": "Internet Cancun S.A. de C.V.",
    "7400": "WYOMING-UTAH - wyoming.com",
    "7401": "FWINET - Fort Wayne Internet, LLC",
    "7402": "MULTIACTIVE - MultiActive Technologies Inc.",
    "7403": "COLBA - Colba Net Inc.",
    "7404": "ACS - Ameritech Cellular",
    "7405": "GENUITY-XATL - Genuity Inc.",
    "7406": "NETGUIDE - United Business Media LLC",
    "7407": "MCI-SGUM - MCIWorldcom-VANSIS",
    "7408": "COMIMSA",
    "7409": "CONFLUX-NET - Grand Designs, Ltd",
    "7410": "BIGPLANET - big planet, inc.",
    "7411": "WINTERSTORM - StormNet Communications",
    "7412": "ENS-NET - EZ Network Systems, Inc.",
    "7413": "DONNAKARAN - Donna Karan Company",
    "7415": "ADSAFE-1 - Ad Safe Media Ltd.",
    "7416": "UCM - UNICOM",
    "7417": "Ministry of Economy",
    "7418": "TELEF\u00d3NICA CHILE S.A.",
    "7419": "MONMOUTH- - Monmouth University",
    "7420": "ZAMNET-",
    "7421": "SPRINT-GSD- - Sprint Government Systems Division",
    "7422": "JAYHAWK-N - Jayhawk Acceptance Corporation",
    "7423": "PUTNAMFT - Putnam Fiduciary Trust",
    "7424": "USANET - USA.Net",
    "7425": "DAI - Distribution Architects International",
    "7426": "IPS- - Hiway 2000, Inc. dba Passport",
    "7427": "MKTSYS - Market Systems International",
    "7429": "CYBERMEDIA - Cybermedia, Inc.",
    "7430": "HP-EUROPE- Hewlett-Packard Company",
    "7431": "EGIX-CHAMPAIGN- - Egix, Inc.",
    "7432": "EGENIUS - Evil Geniuses for a Better Tomorrow",
    "7433": "CYBERMAX - Cybermax Communications, Inc.",
    "7434": "SEGOFT - SEGoft, Inc.",
    "7435": "ATM-CIN - Attachmate",
    "7436": "IRON - Ironlight Digital",
    "7437": "Rednet",
    "7438": "Pegaso PCS, S.A. de C.V.",
    "7439": "VOYAGER- - CoreComm Internet Services Inc",
    "7440": "TRIPOD - Tripod, Inc.",
    "7441": "PACINFO - PACINFO",
    "7442": "FEDERATED-CA-N - Federated Insurance Company of Canada",
    "7443": "PRIMUS-7443 - Primus Telecommunications Canada Inc.",
    "7444": "SYSTEL- - Systel S.A.R.L.",
    "7445": "TELUS--7445 - TELUS Communications Inc.",
    "7446": "INTERNET-LOGIN - Login Communication Inc.",
    "7447": "ONLINEINTERACTIVE - Online Interactive",
    "7448": "CHOICE-HOTELS - Choice Hotels International, Inc.",
    "7449": "TIOGA-NET - Tioga Communications",
    "7450": "ADVANCED-N - Advanced Network & Services, Inc.",
    "7451": "SHOP-NET - Internet Shop.Net Inc.",
    "7452": "NEIS-NET - New England Internet Services",
    "7453": "ACCELERATION - ACCELERATED DATA WORKS, INC.",
    "7454": "CLICNET - ClicNet Telecom",
    "7456": "INTERHOP - Interhop Network SERVICES Inc.",
    "7457": "THESPHERE- - The Sphere Information Services",
    "7458": "COGENT-7458 - Cogent Communications",
    "7459": "GRANDECOM-1 - Grande Communications Networks, LLC",
    "7460": "LIA-NET",
    "7461": "MTAU- - Minnesota Coalition for Internet Accessability",
    "7462": "ONEWEST - SRVnet, Inc.",
    "7463": "GOPROTO- - Proto Technologies",
    "7464": "I-WAYNET - I-Way Networks, Inc.",
    "7465": "PROCERGS - Cia de Processamento de Dados do RGS",
    "7466": "FRB - Federal Reserve Bank",
    "7467": "SENTENTIA-DC1-AU-AP Sententia Internet",
    "7468": "CYBEREC--AP Cyber Express Communication Ltd.",
    "7469": "NNN1--AP Net Niche Pty Ltd",
    "7470": "TRUEINTERNET--AP TRUE INTERNET Co.,Ltd.",
    "7471": "DAREBIN--AU City of Darebin",
    "7472": "NUS--AP Computer Centre",
    "7473": "SINGTEL--AP Singapore Telecommunications Ltd",
    "7474": "OPTUSCOM-01-AU SingTel Optus Pty Ltd",
    "7475": "UQ-COMMERCIAL-AP The University of Queensland",
    "7476": "QUESTNET-ACADEMIC-AP The University of Queensland",
    "7477": "TEREDONN--AP SkyMesh Pty Ltd",
    "7478": "MACKAY--AP Mackay Telecommunication Inc.",
    "7479": "KDDHK--AP KDD HONG KONG LIMITED",
    "7480": "TIMENET- Timenet International Corp.",
    "7481": "TWIX Data Communication Business Group",
    "7482": "APOL- Asia Pacific On-line Service Inc.",
    "7483": "NETPLUS- Hongkong Telecom Ltd., Taiwan Branch Office",
    "7484": "HKACTL--AP Hong Kong Air Cargo Terminals Ltd.",
    "7485": "MUT-BOARDER--AP Mahanakorn University of Technology (Thailand)",
    "7486": "NEWS-INTERACTIVE--AP News Interactive Australia",
    "7487": "KEANEWORLDZEN--AP KeaneWorldzen India .",
    "7488": "IDC7488 Yahoo Japan Corporation",
    "7490": "DETELEKOM--AP T-Systems Japan K.K.",
    "7491": "PI-PH--AP PI-PHILIPINES",
    "7492": "GIL--AP Global Info-Links",
    "7493": "PEOPLELINK-01-AP  number for Peoplelink Internet Limited",
    "7494": "CERETECHS--AP CeReTechs Co ltd",
    "7495": "AMANET- Amanet is the ISP service of AMA Computer College",
    "7496": "WEBCENTRAL- WebCentral",
    "7497": "CSTNET--AP Computer Network Information Center",
    "7498": "IINET-WA--AP iiNet Limited",
    "7499": "CNS-HK- China Network Services (HK) Ltd",
    "7500": "M-ROOT-DNS WIDE Project",
    "7502": "IP-KYOTO Advanced Software Technology & Management Research Institute of KYOTO",
    "7503": "AIR Air Internet Service Co.,Ltd.",
    "7505": "MEDIAWEB Fujitsu Systems East Limited",
    "7506": "INTERQ GMO Internet,Inc",
    "7509": "HINET Hokkaido University",
    "7511": "SYNAPSE Good Communications Co.,Ltd.",
    "7512": "WITH WITH Network",
    "7513": "NETFORWARD Hitachi Systems, Ltd.",
    "7514": "MEX Media EXchange, Inc.",
    "7515": "GROBAL-OCN NTT Communications Corporation",
    "7516": "TOHKNET Tohoku Intelligent Telecommunication Co., Inc.",
    "7517": "MII ICOMT Inc.",
    "7521": "MFEED INTERNET MULTIFEED CO.",
    "7522": "STCN STNet, Incorporated",
    "7523": "TECHNOW RICOH TECHNOSYSTEMS Co.,LTD.",
    "7524": "HANSHIN ITEC HANKYU HANSHIN CO.,LTD.",
    "7526": "MIND-US Mitsubishi Electric Information Network Corporation",
    "7527": "JPIX Japan Internet Exchange Co., Ltd.",
    "7529": "NETIRD NetIRD Inc.",
    "7530": "IRI BroadBand Tower, Inc.",
    "7531": "GENOME GenomeNet Project",
    "7532": "GAMANIA-TW Gamania Digital Entertainment Network,",
    "7533": "NETO Neto Corporation",
    "7534": "SILKERA-TW NEW SILKERA NETWORK",
    "7535": "TISNET TISNET Technology Inc.",
    "7536": "WONDER WonderNet International Corporation",
    "7537": "PWTW Price Waterhouse Taiwan",
    "7538": "SEEDER--AP Seeder Computer Corporation LTD.",
    "7539": "TANET2-TW TANet2, sponsored by NSC, TAIWAN",
    "7540": "HKCIX--AP HongKong Commercial Internet Exchange",
    "7541": "FICNET--AP FIC Network Service, INC.",
    "7542": "EDGE--AP Edge Technology Pty Ltd",
    "7543": "PI-AU Pacific Internet (Australia) Pty Ltd",
    "7544": "COMCLARK-IXG ComClark Network & Technology Corp",
    "7545": "TPG-INTERNET-AP TPG Telecom Limited",
    "7546": "DREAMTILT-AP Dreamtilt Service Provider Gladstone",
    "7547": "CEIEC-NET-AP The  East China regional network of CEInet",
    "7548": "CEIHN-NET-AP The hainan regional network of CEInet",
    "7549": "CEINC-NET-AP The North China regional network of CEInet",
    "7550": "SBS--AU N for SBS",
    "7551": "CLOUDCENTRAL--AP Cloud Central Pty Ltd",
    "7552": "VIETEL--AP Viettel Corporation",
    "7553": "PETROSYS--AP Petrosys Pty Ltd",
    "7554": "ARUP--AU Arup Australasia",
    "7555": "HEALEY--AP Healey Communications",
    "7556": "UNITED-AP United Telecommunications Internet Services",
    "7557": "KTNET- Korea Trade Network",
    "7558": "KBS- Korean Broadcasting System",
    "7559": "DONGA-NET- The Dong-A Ilbo(DAN)",
    "7560": "CHONBUK- Chonbuk National University",
    "7561": "KIER--KR Korea Institute of Energy Research",
    "7562": "HCNSEOCHO--KR DCC",
    "7563": "EDS National IT Industry Promotion Agency",
    "7564": "KAERINET- Korea Atomic Energy Research Institute",
    "7565": "BDCOM-BD House # 43, Road # 16(New) 27(Old) Dhanmondi, Dhaka",
    "7566": "VOICEDOT--AP Voicedot Networks",
    "7567": "IANONLINEAUS2--AP Nexon Asia Pacific",
    "7568": "CSLOX-IIG--AP CS LOXINFO Public Company Limited.",
    "7569": "AARNET-VIC-RNO Australian Academic and Reasearch Network (AARNet)",
    "7570": "AARNET-NSW-RNO Australian Academic and Reasearch Network (AARNet)",
    "7571": "AARNET-WA-RNO Australian Academic and Reasearch Network (AARNet)",
    "7572": "AARNET-ACT-RNO Australian Academic and Reasearch Network (AARNet)",
    "7573": "UT The University of Tasmania",
    "7574": "AARNET-NT-RNO Australian Academic and Reasearch Network (AARNet)",
    "7575": "AARNET--AP Australian Academic and Reasearch Network (AARNet)",
    "7576": "SGINET ShaoGuan Information Center",
    "7577": "VTC--AP Vocational Training Council Hong Kong",
    "7578": "ADN--AP Access Digital Networks Pty. Limited  Communications Provider",
    "7579": "INTERNEX--AP InterNex Australia Pty Ltd",
    "7580": "TRUMPET--AP Trumpet Software International Pty Ltd",
    "7581": "POWERNET--AP POWERNET INTERNET GROUP",
    "7582": "UMAC--AP University of Macau",
    "7583": "MESSAGELABS-AP MessageLabs - Now Part of Symantec",
    "7584": "TCR--AP TCR Holdings Limted.",
    "7585": "TELWATER--AP Telwater/Quintrex",
    "7586": "PDOX--AP Paradox Digital Pty Ltd",
    "7587": "ACCESSNETWORKS DA-NET::Data:Digital:Dialing:ACCESSNET::ID",
    "7588": "PUBNET-TH- Thailand Public backbone Network",
    "7589": "TELIANET- TeliaNet Hongkong",
    "7590": "COMSATS Commission on Science and Technology for",
    "7591": "DOVE-AUST--AP DOVE Australia Pty Ltd",
    "7592": "COMCEN- P.O. Box 336",
    "7594": "ONQNETWORKS--AP On Q Networks",
    "7595": "READYNET--AP Readyspace Network Pte Ltd, Hosted Solutions Provider,Singapore",
    "7596": "IIR-TH--AP Internet Information Research",
    "7597": "IIX--AP Indonesia Internet Exchange",
    "7598": "WEBSENSE-HOSTED-APAC Websense Hosted Security - AsiaPac region",
    "7599": "AMSNET-NZ-AP Advanced Management Systems Ltd",
    "7600": "ESCAPE-NET- Escape.net",
    "7601": "NETLINK--AP Australian NetLink",
    "7602": "SPT--VN Saigon Postel Corporation",
    "7603": "OMEN--AP Omen Internet",
    "7604": "ZETTANET- Zetta",
    "7605": "STARWON--AP Starwon Internet",
    "7606": "WAIA-AP Western Australian Internet Association",
    "7607": "CA--AP Commerce Australia",
    "7608": "MERLIN--AP Merlin Australia",
    "7609": "AOL--AP Ace on Line",
    "7610": "NUS-GP--AP NUS Gigapop",
    "7611": "WNETWORK--AP W NETWORK Inc,",
    "7612": "STARNET--AP Starnet Internet Services P/L",
    "7613": "DATALINETHAI--AP Data Line Thai Co., LTD. Internet Service Provider",
    "7614": "IAINTERNET--AP Asia Internet Limited, Hong Kong",
    "7615": "FORTANA--AP Fortana Networks Australia Pty Ltd",
    "7616": "JINET-BKK--AP Jasmine Internet Co, Ltd.",
    "7617": "TELEONE-HK TeleTeleOne (HK) Limited",
    "7618": "GIP-TW-AP Orange Business",
    "7619": "NRL--AP 18th Floor, MassMutual Tower,",
    "7620": "JBE--KR Jeollabuk-do Provincial Office of Education",
    "7621": "KYONGGI- Kyonggi University",
    "7622": "N-KAIST-SAL Korea Advanced Institute of Science and Technology",
    "7623": "HCNGYEONGBUK--KR Gyeongbuk Cable TV",
    "7624": "JEONJU- jeonju university",
    "7625": "DAUM- Daum Communication Co.,LTD",
    "7626": "SCOURTFAMILY--KR SCOURTFAMILY",
    "7627": "SBS- SBS ( Seoul Broadcasting System )",
    "7629": "INFOCOM--AP INFOCOM Technologies, Inc.",
    "7630": "THAIFARMERSBANK--AP Progress Software Co., Ltd.",
    "7631": "ANITTEL--AP Anittel Communications Pty Ltd",
    "7632": "LINKNET-EXCHANGE--ID Linknet-Exchange N",
    "7633": "SOFTNET--AP Software Technology Parks of India - Bangalore",
    "7634": "SGNET--AP Singapore Government Network",
    "7636": "FARET--AP Far East Internet Co., Ltd.",
    "7637": "SLVTSD--AP State Library Of Victoria",
    "7638": "INTERWAY BEIJIN TV ENTERPRISE DEVELOPMET FACTION",
    "7639": "CPIPNET--AP Beijing Capital Public Information Platform",
    "7640": "CITICNET China International Trust & Investment Corporation Management Information Center",
    "7641": "CHINABTN China Broadcasting TV Net",
    "7642": "DHIRAAGU-MV-AP Dhiraagu Internet Services",
    "7643": "VNPT--VN Vietnam Posts and Telecommunications (VNPT)",
    "7644": "EFTEL--AP IT Solutions",
    "7645": "DEAKIN--AP Deakin University",
    "7646": "BANKOFAMERICA-ATG-HK Bank of America N.A.",
    "7647": "ONTHENET--AP OnTheNet P/L",
    "7648": "INTERWEB--AP InterWeb Connections",
    "7649": "MAINT-TW-TWNAP Nap Communication Inc.",
    "7650": "HKIED--AP The Hong Kong Institute of Education",
    "7651": "LINGNAN--AP Lingnan University",
    "7652": "EFTEL-AU Vianet Communications Pty Ltd",
    "7653": "PIX--AP Paradox Digital Pty Ltd",
    "7654": "SIAMGLOBE--AP Internet Service Provider Co., Ltd.",
    "7655": "TWNAP-ADMIN--AP Peering",
    "7656": "TWNAP-ADMIN--AP Taiwan Network Access Point",
    "7657": "VODAFONE-NZ-NGN- Vodafone NZ Ltd.",
    "7658": "NETNAME-1-NET-ISP 1-Net Singapore Pte Ltd",
    "7659": "NEWSKY--AP Newsky Internet Limited",
    "7660": "APAN-JP Asia Pacific Advanced Network - Japan",
    "7661": "NORTH Network Organization for Research and Technologyin Hokkaido",
    "7663": "FFNET FUJIMIC INC.",
    "7664": "HARENET Sanyo Computer Corp.Inc",
    "7665": "OKIX Okayama Prefectural Government",
    "7666": "OKIX-1 Mitsubishi Corporation",
    "7667": "KDDLAB KDDI R&D Laboratories, INC.",
    "7668": "HTCN Hokuriku Telecommunication Network Co.",
    "7669": "DTC DIGITAL TECHNOLOGIES CORPORATION",
    "7670": "CTNET Energia Communications, Inc.",
    "7671": "MCNET NTT SmartConnect Corporation",
    "7672": "FITWEB Hokuden Information System Service Co.,Ltd.",
    "7673": "ALLES ejworks corporation",
    "7674": "GOFORS NTT Communications Corporation",
    "7676": "TAM TAM-Internet Service (T.A.M Co., Ltd.)",
    "7677": "DNP Dai Nippon Printing Co., Ltd",
    "7678": "PROX Prox System Design Inc.",
    "7679": "QTNET Kyushu Telecommunication Network Co.,Inc.",
    "7682": "HOTNET HOKKAIDO TELECOMMUNICATIONS NETWORK Co., Inc.",
    "7683": "CRUST- CRUST Co.,Ltd.",
    "7684": "SAKURA-A SAKURA Internet Inc.",
    "7686": "ATNETHOME Technology Networks Inc.",
    "7687": "D-CRUISENET TOYOTA DIGITAL CRUISE.INCORPORATED",
    "7688": "MISH Nippon Internet Access Inc.",
    "7690": "MIRAI Mirai Communication Network Inc.",
    "7692": "CETIN--AP China Engineering Technology Informations Networks",
    "7693": "COMNET-TH KSC Commercial Internet Co. Ltd.",
    "7694": "EFTEL-AU IT Solutions",
    "7695": "JWTNET-HK- WPPNET--AP Company,",
    "7696": "MODICAGROUP--AP Modica Group Limited,",
    "7697": "CSBT--AP Complete Strategic Business Technology",
    "7698": "NETEXPRESS--AP NetExpress Pty Ltd",
    "7699": "XTREMECOMAU1--AP Xtreme.com.au Transit  #1",
    "7700": "SINGTEL-DVBIP--AP SINGAPORE TELECOMMUNICATIONS LTD",
    "7701": "CAIRNSNET--AP CairnsNet Pty Ltd",
    "7702": "THEHUB--AP Hub Communications",
    "7703": "BEKKERS--AP Bekkers Information Technology",
    "7704": "ANSCOMMS--AP ANS Communications",
    "7705": "COMNET-AP-N1 ComNet Telecom International Ltd.  Number",
    "7706": "SAIA--AP South Australian Internet Association",
    "7707": "PHIX--AP PHILIPPINE LONG DISTANCE TELEPHONE COMPANY",
    "7708": "TWNAP--AP Taiwan Network Access Point",
    "7709": "TWNAP--AP Taiwan Network Access Point",
    "7710": "MYNET--AP PRC Technology Co., Ltd.",
    "7711": "TWNAP-TWIX-AP Twain Network Access Point",
    "7712": "CIDC--KH-AP CIDC Information Technology (Sabay)",
    "7713": "TELKOMNET--AP PT Telekomunikasi Indonesia",
    "7714": "NETLINK-NZ--AP TelstraClear Ltd",
    "7715": "SCHOOLNET-TH--AP SchoolNet Network in Thailand",
    "7716": "WORLEY--AP Worley Organisation Australia",
    "7717": "OPENIXP--ID-AP OpenIXP N",
    "7718": "TRANSACT-SDN- TransACT Capital Communications Pty Limited",
    "7719": "UPNAWAY--AP Up n Away Net Solutions",
    "7720": "NETWAY--AP Netway Technologies",
    "7721": "QNET--AP Q-Net Australia",
    "7722": "TELPACIFIC--AP TELPACIFIC P/L",
    "7723": "EMERGENCY24- - Emergency 24",
    "7724": "IECBAL - Internet Enterprise Center",
    "7725": "COMCT-7725 - Comcast Cable Communications Holdings, Inc",
    "7726": "FITC- - FITC - FedEx International Transmission Corporation",
    "7727": "Hondutel",
    "7728": "GRILLO - Grillo Networking, Inc.",
    "7729": "CHI-IX - MCSNet",
    "7730": "NETLAN - NETLAN Inc.",
    "7731": "WEBSTOR - Internet Quality Services",
    "7732": "CDC-2 - Chattanooga Data Connection, Inc.",
    "7733": "FRZRMTN - Frazier Mountain Internet Service",
    "7734": "TDBANK - Toronto Dominion Bank",
    "7735": "REDSHIFT - Red Shift, Inc.",
    "7736": "MARKETGUIDE - MarketGuide",
    "7737": "WELLNET - Aswell Corporation",
    "7738": "Telemar Norte Leste S.A.",
    "7739": "AUTOWEB - AutoWeb Interactive",
    "7740": "WJP - WJP Networking",
    "7741": "CIBC-WORLD-MARKETS - CIBC World Markets",
    "7742": "DOITNOWDOTCOM - InternetNow, Inc.",
    "7743": "-7743 - JPMorgan Chase & Co.",
    "7744": "WCD- - WCD Enterprises",
    "7745": "BIGSKY- - Big Sky Net",
    "7746": "APMTECH - APM Technologies, Inc.",
    "7747": "EXECUTRAIN - Executrain",
    "7748": "SHURE - Shure Incorporated",
    "7749": "VR1 - VR1",
    "7750": "ONSALE - Software Partners, Inc.",
    "7751": "DANCRIS - Dancris Telecom L.L.C",
    "7752": "THRES - THRESHOLD COMMUNICATIONS,INC.",
    "7753": "IPHOUSE-1 - ipHouse",
    "7754": "MCAFEE - McAfee, Inc.",
    "7755": "COMBE - ComBase Communications",
    "7756": "SCRR-7756 - Time Warner Cable Internet LLC",
    "7757": "COMCT-7757 - Comcast Cable Communications Holdings, Inc",
    "7758": "GLOBAL-ONE-NMC - Global One",
    "7759": "OSTER - Oster Communications, Inc.",
    "7760": "STAC - Stac, Inc.",
    "7761": "MORNINGSTAR - Morningstar, Inc.",
    "7762": "NETM - NETMANAGE",
    "7763": "CYBERAMERICACORP - Cyber America Corporation",
    "7764": "CENSUSBUREAU - U. S. Bureau of the Census",
    "7765": "KOUMBIT - Koumbit",
    "7766": "GRINNET - Grin Net, LLC.",
    "7767": "EB - Encyclopaedia Britannica",
    "7768": "TECHNICOLOR Thomson - Technicolor",
    "7769": "WARPED - Internet Extra Corporation",
    "7770": "TRITON - Triton Technologies, Inc.",
    "7771": "AMULET - Amulet Software",
    "7772": "ST-LOUIS-SCHNEIDER-DC - Schneider Automation, Inc.",
    "7773": "SD-NET - South Dakota State Government",
    "7774": "ALKA - University of Alaska",
    "7775": "INVCOINS - The Investment Company Institute",
    "7776": "MEBT7776 - Mebtel Communications",
    "7777": "VIX2 - Mail Abuse Prevention System LLC",
    "7778": "PARACEL - Paracel Online Systems",
    "7779": "LD - Loren Data Corp.",
    "7780": "7780-RTHI - Rogers Cable Communications Inc.",
    "7781": "NETCONNECT - Accelerated Connections Inc.",
    "7782": "ALSK-7782 - Alaska Communications Systems Group, Inc.",
    "7783": "EARTHSTATION - EarthStation Inter.net",
    "7784": "ATLANTECH - Atlantech Online, Inc.",
    "7785": "ALEXUS - Alexus",
    "7786": "NPAC - NeuStar, Inc.",
    "7787": "FAN-NETWORK - Fan Network Consulting",
    "7788": "MAGMA-COMM - Magma Communications Ltd.",
    "7789": "FISHBONE - Fishbone Communications, Inc",
    "7790": "PACIFIER - Pacifier Computers",
    "7791": "EARLY - Early Access",
    "7792": "3M-HDQ- - 3M Company",
    "7793": "JMX- - JMX",
    "7794": "GOLDEN - Golden Triangle On Line",
    "7795": "LUMOS - LUMOS Networks, Inc.",
    "7796": "ATMLINK - ATMLINK, INC.",
    "7797": "YAB - Flatland Center BBS",
    "7798": "SYRLANG - Syracuse Language Systems",
    "7799": "OLYPENN - Olypen, Inc.",
    "7800": "ALLINA - Allina Health System, Inc.",
    "7801": "BOSNET - Bosnet Communications, Inc",
    "7802": "INTELLI - Intelli.com",
    "7803": "Miniphone S.A.",
    "7804": "SOFTWOOD - Softwood",
    "7805": "ICD - ICD Inc.",
    "7806": "N7806 - Binary Net, LLC",
    "7807": "RURALNET - RuralNet",
    "7808": "ECCOMPANY - The EC Company",
    "7809": "SYNOPSYS-RIPE- Synopsys Inc.",
    "7810": "CMPC - CompuCom Systems, Inc.",
    "7811": "ITOCHU - ITOCHU Technology, Inc.",
    "7812": "AEGISSTAR-N1 - Aegis Star Corporation",
    "7813": "NPL - The Northwest PC Link",
    "7814": "CNS-NETWORK - Chenango Net Services",
    "7815": "MADENTECH - Madentech Consulting, Inc.",
    "7816": "CTC - Concurrent Technologies Corporation",
    "7817": "SURFNET - Surfnet",
    "7818": "N-QUEENCREEK - Town of Queen Creek",
    "7819": "GLOBAL-IP-NETWORKS - Global IP Networks INC",
    "7820": "TOWERFCU- - Tower Federal Credit Union",
    "7821": "ZAYO-MN - Onvoy",
    "7822": "AVICENNA - Avicenna Systems Corporation",
    "7823": "DUPONT-N - DuPont",
    "7824": "GWIS-0 - Gateway to Internet Services",
    "7825": "IMAGINENET-1 - imagine.com",
    "7826": "HME-1 - Canada Connect Corp.",
    "7827": "ABII- - American Business Information",
    "7828": "DRMSCPN - Northland Communications",
    "7829": "N-NEXTWEB-R2 - Nextweb, Inc",
    "7830": "VIVIDHOSTING - CommWerks",
    "7831": "WEBWARP - WebWarp Technologies",
    "7832": "PCISYS - WW/Precision Communication",
    "7833": "EXTRA- - Extra.Net",
    "7834": "BTGCOM - L-3 Communications Corporation",
    "7835": "ABRAXIS - Abraxis Networks, Inc.",
    "7836": "XO-16 - XO Communications",
    "7837": "NETHERE - NetHere Inc.",
    "7838": "USAA - USAA",
    "7839": "MARKTRAVEL - The Mark Travel Corp",
    "7840": "TLN- - The Library Network",
    "7841": "DEMINET - Deus Ex Machina, Inc.",
    "7842": "WEBWORLD - WebWorld Inc",
    "7843": "TWCABLE-BACKBONE - Time Warner Cable Internet LLC",
    "7844": "OIS - OIS TECHNOLOGIES",
    "7845": "INTEGRATELECOM - Integra Telecom, Inc.",
    "7846": "RIGHTLINE - Rightline, Inc.",
    "7847": "NA-HPCC-ESS - NA Goddard Space Flight Center",
    "7848": "RCN-2 - RCN",
    "7849": "CROCKERCOM - CROCKER COMMUNICATIONS",
    "7850": "CITYLINKFIBER - iHighway.net, Inc.",
    "7851": "N-ADELPHIA2 - Time Warner Cable Internet LLC",
    "7852": "CALIS - California Internet Services",
    "7853": "COMCT-TELECOMM-2 - Comcast Telecommunications, Inc.",
    "7854": "DSSVAUS - Virginia Department of Social Services",
    "7855": "ERX-TELECOMPLUS Telecom Plus",
    "7856": "EPPROACH-0 - Epproach Communications, LLC",
    "7857": "EMPIRE2-N - Empire Communications, Inc.",
    "7858": "EXECUTELE - Executive Telecard, S.A.",
    "7859": "PAIR-NETWORKS - pair Networks",
    "7860": "UPEI- - University of Prince Edward Island",
    "7861": "TELUS-7861 - TELUS Communications Inc.",
    "7862": "CHEVRONTEXACO-7862 - Texaco Group, Inc.",
    "7863": "ACADIAN - Acadian Internet Access",
    "7865": "SWITCHBOARD-MA - Switchboard, Incorporated",
    "7866": "BTI - Business Telecom, Inc.",
    "7867": "TECHDATA - TECH DATA CORPORATION",
    "7868": "DATA-LIFE - Data Life Associates, Inc.",
    "7869": "DATADEPOT-N - The Data Depot, Inc.",
    "7870": "WHY - The Why? Network",
    "7871": "SEIDATA - SEI Data",
    "7872": "USAP-N - United States Antarctic Program",
    "7873": "MICROTEC- - MICROTEC TECHNOLOGIES INC.",
    "7874": "SHKOO - shkoo consulting",
    "7875": "ENTECH - Entrepreneurial Technologies, Inc.",
    "7876": "DRS-1 - Dominion Resources Services, Inc.",
    "7877": "AGENCY-COM-NY - Online Magic",
    "7878": "TCEL- - Telnet Canada Enterprises, Ltd.",
    "7879": "DIMENSION-NET-1 - Dimension Enterprises, Inc.",
    "7880": "NEURAL- - Neural Applications",
    "7881": "IMGIS - IMGIS",
    "7882": "SPRINT-HAWAII - Sprint Hawaii",
    "7883": "UNITEDSYSTEMSACCESS - United Systems Access",
    "7884": "N-NC-FUCAPMARK - First Union Capital Markets Group",
    "7885": "YUKONCOLLEGE - Yukon College",
    "7886": "EMPIRICAL- - Empirical Media Corporation",
    "7887": "-CCPL - Cuyahoga County Public Library",
    "7888": "CSI-CORP - Component Software International, Inc.",
    "7889": "FULL-ECLIPSE - Full Eclipse, Inc.",
    "7890": "Unilink Redes de Informacoes Ltda",
    "7891": "BELLSOUTH-NET-BLK2 - Bellsouth.Net",
    "7892": "BELLSOUTH-NET-BLK2 - Bellsouth.Net",
    "7893": "BELLSOUTH-NET-BLK2 - Bellsouth.Net",
    "7894": "BELLSOUTH-NET-BLK2 - Bellsouth.Net",
    "7895": "FABRIK - Fabrik Communications Inc.",
    "7896": "UNL- - University of Nebraska-Lincoln",
    "7897": "XINGNET - Xing Technology Corporation",
    "7898": "DNA-N - Digital Network Associates",
    "7899": "EXAMCO - Examco, Inc.",
    "7900": "HOOSIER - Hoosier Online Systems Corp.",
    "7902": "PINS - Public Interest Network Services",
    "7903": "OIS- - GMP CABLE TV",
    "7904": "NISI - National Internet Source, Inc.",
    "7905": "SOONER- - Sooner Technology",
    "7906": "Redes y Consultoria al Comercio Exterior, S.A. de C.V.",
    "7907": "NETWORLDTRON - Networldtron Corp",
    "7908": "BT LATAM Venezuela, S.A.",
    "7909": "N1 - WYN INTERNATIONAL LLC",
    "7911": "LVLT-7911 - Level 3 Communications, Inc.",
    "7912": "STATEFARMINSCO - State Farm Mutual  Automobile Insurance Company",
    "7913": "METROLINK - MetroLink Internet Services Inc.",
    "7914": "CSI - Church of Scientology International",
    "7915": "DAYTONA-STATE-COLLEGE - Daytona State College Inc",
    "7916": "ISDNET - Innovative System Design",
    "7917": "PHS - Pacificare Health Systems",
    "7918": "LARKOM- - Larkom",
    "7919": "DIGITALDATA- - Digital Data Technologies, Inc.",
    "7920": "OPTIMALSATCOM - Optimal Satcom, Inc.",
    "7921": "FRCL-N - Fiduciary Research and Consulting, LLC",
    "7922": "COMCT-7922 - Comcast Cable Communications, Inc.",
    "7923": "UPLANET- - Unwired Planet",
    "7924": "ADVANCEDONLINE - Advanced Online Services Inc.",
    "7925": "WVNET - West Virginia Network for Educational Telecomputing",
    "7926": "FAIR-ISSAC- aut-num for customer fair issac",
    "7927": "Global One Venezuela",
    "7928": "AICOM- - AIC Asia International Services Corporation",
    "7929": "WETWARE - Wetware Services",
    "7930": "TSCNET - TSCNet Online Services",
    "7931": "ACVI - Auburn Cable Vision Inc.",
    "7932": "NUMERIX - Numerix",
    "7933": "BORDERS-GROUP - Borders Group Inc.",
    "7934": "Prima S.A.",
    "7935": "PO-N - Physicians Online",
    "7936": "NPDGROUP - The NPD Group Inc.",
    "7937": "SOUTHTECH - SouthTech.Net",
    "7938": "CIRCLE - Circle Net, Inc.",
    "7939": "UNIVCENTFLA - University of Central Florida",
    "7940": "JCI-INC - JC International Inc.",
    "7941": "INTERNET-ARCHIVE - Internet Archive",
    "7942": "GE-5 - General Electric Company",
    "7943": "TDS-SA-ISP - Trident Data Systems",
    "7944": "DMVOL-N - DELMARVA ONLINE",
    "7945": "CYBERG8T - Cyberg8t Internet Services, Inc.",
    "7946": "MET-NET - Metropolitan Government of Nashville & Davidson County",
    "7947": "RADIO - Susquehanna Radio Corporation",
    "7948": "GEOPLEX - AT&T",
    "7949": "123NET-WEST - 123.Net, Inc.",
    "7950": "HC- - Holland College",
    "7951": "PCEZ - PCs Made Easy, LLC",
    "7952": "PCMAGIC-GATEWAY - PC Magic Network",
    "7953": "Supernet S.A.",
    "7954": "IMMENSE-NETWORKS - Immense Networks, LLC",
    "7955": "AWCC-N - Allied Wireless Communications Corporation",
    "7956": "ONECOM-LTP - One Communications Corporation",
    "7957": "SHOPX - Shoppers Express, Inc.",
    "7958": "IDI - Internet Direct, Incorporated",
    "7959": "VICON - VICON NETWORKS",
    "7961": "RBC - Raw Bandwidth Communications, Inc.",
    "7962": "EXISNET - EXISNET INC",
    "7963": "STDIO - OPEN WORLD, INC.",
    "7964": "ARCFOUR - Arc Four",
    "7965": "Universidad Catolica Andres Bello",
    "7966": "HARBOR - Harbor Communications",
    "7967": "SECUREDOC - Secure Document Systems, Inc.",
    "7968": "LOYOLA-UNIV-CHICAGO - Loyola University Chicago",
    "7969": "CYB-VAN - CYBERION NETWORKING CORP.",
    "7970": "LEON-FL-SCHL - Leon County School District",
    "7971": "IWEBTT",
    "7972": "GPG",
    "7973": "MAYO - Mayo Foundation for Medical Education and Research",
    "7974": "Instituto Mexicano del Petroleo",
    "7975": "CONFERENCE-AMERICA - Conference America, Inc.",
    "7976": "SEDONA- - Wolen Computer Services",
    "7977": "EMCCORP - EMC Corporation",
    "7978": "PRISM - Prism Communications",
    "7979": "BARROWS - The Barrows Network",
    "7980": "Global One",
    "7981": "DIGIMARK - DigiMark",
    "7982": "COGENT-WAN - Cogent software,  Inc.",
    "7983": "DOMAIN - Wayne D. Correia",
    "7984": "Orange Business Services Colombia S.A.",
    "7985": "CHRONICLE - THE CHRONICLE OF HIGHER EDUCATION",
    "7986": "SAVVISCHI - SAVVIS COMMUNICATIONS",
    "7987": "SAVVISDAL - SAVVIS COMMUNICATIONS",
    "7988": "SAVVISLA - SAVVIS COMMUNICATIONS",
    "7989": "SAVVISNY - SAVVIS COMMUNICATIONS",
    "7990": "SAVVISSF - SAVVIS COMMUNICATIONS",
    "7991": "SAVVISSTL - SAVVIS COMMUNICATIONS",
    "7992": "COGECOWAVE - Cogeco Cable",
    "7993": "Global One Chile",
    "7994": "Global One Peru",
    "7995": "Global One Mexico",
    "7996": "LIMITED - Limited Brands Inc.",
    "7997": "EPM Telecomunicaciones S.A. E.S.P.",
    "7998": "CYTEC - Cytec Industries Inc.",
    "7999": "GAMES-ONLINE - Games Online Inc.",
    "8000": "DWX- - Waddell Digital Imaging Center",
    "8001": "NET-ACCESS-CORP - Net Access Corporation",
    "8002": "STEALTH- Stealth Communications",
    "8003": "GLOBAL-01 - Global Resource Systems LLC",
    "8004": "DTG - Diversified Technologies Group",
    "8005": "SUNLINK1 - SunLink",
    "8006": "SYSCI - Systems & Software Consortium, Inc.",
    "8007": "Servicios Administrados Mexis, S.A. de C.V.",
    "8008": "ETC-60- - ENHANCED TELECOMMUNICATIONS CORP.",
    "8009": "TRANSAMERICA - Transamerica Telecommunications Corporation",
    "8010": "DIGICON-CORP - Digicon Corporation",
    "8011": "8011 - CoreComm Internet Services Inc",
    "8012": "PERSHING - The Bank of New York Mellon Corporation",
    "8013": "TELUS--8013 - TELUS Communications Inc.",
    "8014": "BATELNET - Bahamas Telecommunications Corporation",
    "8015": "VISI- - Vector Internet Services, Inc.",
    "8016": "VRIS-8016 - Verizon Online LLC",
    "8017": "VRIS-8017 - Verizon Online LLC",
    "8018": "VEL- - Velocity Networks, Inc.",
    "8019": "ORCALINK - Orca Networking Technologies",
    "8020": "CAVECOMM-N - Cave Communications",
    "8021": "PCNET - Paradigm Communications Inc.",
    "8022": "WTNET - World Trade Network, Inc.",
    "8023": "CTLES - Castles Information Network",
    "8024": "Centro de Investigaciones Biologicas del Noroeste",
    "8025": "BRIGHTOK- - BrightNet Oklahoma",
    "8026": "EMPRESA COLOMBIANA DE PETROLEOS, ECOPETROL",
    "8027": "GBLNAPSBOSMIX - Global NAPs Inc.",
    "8028": "PROAXIS - ProAxis Communications, Inc.",
    "8029": "MSERVE- - Microserve, Inc.",
    "8030": "WORLDNET5-10 - AT&T WorldNet",
    "8031": "WORLDNET5-10 - AT&T WorldNet",
    "8032": "WORLDNET5-10 - AT&T WorldNet",
    "8033": "WORLDNET5-10 - AT&T WorldNet",
    "8034": "WORLDNET5-10 - AT&T WorldNet",
    "8035": "WORLDNET5-10 - AT&T WorldNet",
    "8036": "UTULSA- - The University of Tulsa",
    "8037": "PUB-BGP- - People's United Bank",
    "8038": "SIXCONNECT 6Connect",
    "8039": "CCC-N-1 - Cinergy Communications",
    "8040": "MMD - MMD Entertainment, LLC",
    "8041": "ATW - EarthReach Communications, LLC",
    "8042": "WCS - Wickberg Consulting Services",
    "8043": "LVLT-8043 - Level 3 Communications, Inc.",
    "8044": "SELECT- - Select Ticketing Systems Inc.",
    "8045": "EMIMUSICPUB-NY - EMI Music Publishing",
    "8046": "NAPANET - NapaNet",
    "8047": "GCI - GENERAL COMMUNICATION, INC.",
    "8048": "CANTV Servicios, Venezuela",
    "8049": "POL- - Productivity OnLine",
    "8050": "DNC- - Direct NET Communications",
    "8051": "LSWLLP - Lankler Siffert & Wohl LLP",
    "8052": "SCRR-8052 - Time Warner Cable Internet LLC",
    "8053": "IFX Networks Venezuela C.A.",
    "8054": "Ticsa",
    "8055": "Value4Net do Brasil Servi\u00e7os de Inform\u00e1tica Ltda",
    "8056": "Internet Comunicaciones, c.a.",
    "8057": "VISIONNET - Vision Net, Inc.",
    "8058": "TEX-COMMUNICATIONS-ISPDONE - Texas Communications, Inc.",
    "8059": "N-BWAY - Outernet, Inc.",
    "8060": "BELLSOUTH-NET-BLK3 - Bellsouth.Net",
    "8061": "BELLSOUTH-NET-BLK3 - Bellsouth.Net",
    "8062": "BELLSOUTH-NET-BLK3 - Bellsouth.Net",
    "8063": "BELLSOUTH-NET-BLK3 - Bellsouth.Net",
    "8064": "UABMC - University of Alabama at Birmingham Medical Center",
    "8065": "EPM Telecomunicaciones S.A. E.S.P.",
    "8066": "Inea Internet S.A.",
    "8067": "WSCNET- - Westfield State University",
    "8068": "MICROSOFTEU Microsoft European Data Center",
    "8069": "MICROSOFT-CORP-MSN--BLOCK - Microsoft Corporation",
    "8070": "MICROSOFT-CORP-MSN--BLOCK - Microsoft Corporation",
    "8071": "MICROSOFT-CORP-MSN--BLOCK - Microsoft Corporation",
    "8072": "MICROSOFT-CORP-MSN--BLOCK - Microsoft Corporation",
    "8073": "MICROSOFT-CORP-MSN--BLOCK - Microsoft Corporation",
    "8074": "MICROSOFT-CORP-MSN--BLOCK - Microsoft Corporation",
    "8075": "MICROSOFT-CORP-MSN--BLOCK - Microsoft Corporation",
    "8076": "HUD - Housing and Urban Development",
    "8078": "I-2 - Information Interclear",
    "8079": "TOOTROLLINDLLC - Tootsie Roll Industries, LLC.",
    "8080": "ZIP2 - ZIP2 CORPORATION",
    "8081": "FTLNET - Ft. Lauderdale Network",
    "8082": "WORLDSITE - Worldsite Networks",
    "8083": "CONGQTLY - Congressional Quarterly",
    "8084": "WOLVERINE-EXECUTIONS-SERVICES - Wolverine Execution Services, LLC",
    "8085": "HEQ - HealthEquity, Inc.",
    "8086": "PBD-NET - AT&T Services, Inc.",
    "8087": "NEUMEDIA - NeuMedia, Inc.",
    "8088": "SRTNET - SRT ENTERPRISES",
    "8089": "GRYPHONNETWORKS - GRYPHON NETWORKS",
    "8090": "ENRON - Enron Corp.",
    "8091": "ICOMS - Internet Commerce Services Corp",
    "8092": "YGNITION Ygnition Networks",
    "8093": "PROFOUND MAID plc",
    "8094": "PUKNET",
    "8095": "NETVALUE - Netvalue, Inc.",
    "8096": "R Computadores",
    "8097": "SMOOTHFUSION - Smooth Fusion, Inc.",
    "8098": "IFN - Internet Financial Group",
    "8099": "N-280 - 280, Inc.",
    "8100": "IPTELLIGENT - IPTelligent LLC",
    "8101": "RTCI- - Research Triangle Consultants, Inc.",
    "8102": "FALLON-MPLS - Fallon McElligott",
    "8103": "STATE-OF-FLA - Florida Department of Management Services - Technology Program",
    "8104": "CALFRAC-WELL-SERVICES - Calfrac Well Services Ltd.",
    "8105": "DAKOTACOM - DakotaPro.biz",
    "8106": "SPRINT97 - Sprint",
    "8107": "SPRINT97 - Sprint",
    "8108": "SPRINT97 - Sprint",
    "8109": "SPRINT97 - Sprint",
    "8110": "SPRINT97 - Sprint",
    "8111": "DALUNIV - Dalhousie University",
    "8112": "VRIS-8112-8115 - Verizon Online LLC",
    "8113": "VRIS-8112-8115 - Verizon Online LLC",
    "8114": "VRIS-8112-8115 - Verizon Online LLC",
    "8115": "VRIS-8112-8115 - Verizon Online LLC",
    "8116": "GUIDANT - Guidant Corporation",
    "8117": "DRF - Daily Racing Form",
    "8118": "MAAZ- - Maaznet Directory Services",
    "8119": "DTN- - Data Transmission Network Corporation",
    "8120": "BESTWEB - BestWeb Corporation",
    "8121": "LAYER42 - TCH Network Services",
    "8122": "DQN - Duquesne University",
    "8123": "POLYBE - Polybase",
    "8124": "TUMBLEWEED - Tumbleweed Internet Hub",
    "8125": "CYBERPORTAL-N - Cyberport, LLC",
    "8126": "KENTROX - Kentrox, Inc.",
    "8127": "CONNECTEXPRESS - ConnectExpress",
    "8128": "UOL- - UOL Publishing, Inc",
    "8129": "CAIWIRELESS - CAI Wireless Systems, Inc.",
    "8130": "INFICAD - Inficad Computing and Design, LLC.",
    "8131": "PEPBOYS - Pep Boys",
    "8132": "ENTEX - ENTEX Information Services",
    "8133": "CYBERCOMCORP - Cybercom Corporation",
    "8134": "UP-NET - Baraga Telephone Company",
    "8135": "TROYST - Troy University",
    "8136": "IFSI - Internet Financial Systems Inc.",
    "8137": "DISNEYONLINE- - Disney Online",
    "8138": "JADE - Jade Inc.",
    "8139": "RACALDATAGROUP - Racal Data Group",
    "8140": "Instituto Federal Electoral",
    "8141": "So Software Informatica LTDA",
    "8142": "EAGLEQUEST - EagleQuest, Inc.",
    "8143": "VM1639 - CounterTack Inc.",
    "8144": "WORLDNOWONLINE - WorldNow Online",
    "8145": "GW - Trans-Atlantic Communications",
    "8146": "GNAC - Global Networking and Computing, Inc.",
    "8147": "ERICY - Ericsson Inc.",
    "8148": "TIES - TIES",
    "8149": "ABACUS-GROUP2 - Abacus Group LLC",
    "8150": "MOBILEPS - Mobile Public School System",
    "8151": "Uninet S.A. de C.V.",
    "8152": "BRODERBUND - Broderbund Networks",
    "8153": "NORTEL-NETWORKS NORTEL NETWORKS SA",
    "8154": "GTC - Gulf Telephone Company",
    "8155": "THE-LINK-MGM - The Link",
    "8156": "INTI - Integrated Network Technologies, Inc.",
    "8157": "INTERNETCONNECTUSA - Internet Connection USA",
    "8158": "LUCENT-WHATS - LGS Innovations, LLC",
    "8159": "KANSNET - KansasNet / Fox Business Systems",
    "8160": "ROGERS--8160 - Rogers Cable Communications Inc.",
    "8161": "INSIGHT- - Insight Direct USA, Inc.",
    "8162": "IMPULSEGATEWAY - AZ Digital Enterprises, Inc.",
    "8163": "METROTEL REDES S.A.",
    "8164": "JUNO - Juno Online Services, L.P.",
    "8165": "DATABOSS - DataBoss Inc",
    "8166": "PRISMNET - PrismNet Inc.",
    "8167": "Brasil Telecom S/A - Filial Distrito Federal",
    "8168": "RAVENET-DE - Ravenet Systems, Inc.",
    "8169": "ACCESSINDY - Ameritech Access Indiana",
    "8170": "MICROAGE - MicroAge Computer Centers, Inc.",
    "8171": "ENET - eNET Inc.",
    "8172": "MTI - MTI Internet Services",
    "8173": "N1 - Lepercq, de Neuflize and Co. Inc.",
    "8174": "MHPCC-NET2 - Maui High Performance Computing Center",
    "8175": "HIGHSPEEDWEB - High Speed Web/Genesis 2 Networks",
    "8176": "NETSCAPE-N - Netscape",
    "8177": "QAD - Qadas, Inc.",
    "8178": "AKI S.A.",
    "8179": "SFCU-1 - Stanford Federal Credit Union",
    "8180": "V2-VENTURES-SHUTTER-NET - V2 Ventures, LLC (dba ShutterNet)",
    "8181": "VCINET - Virtual Communications Inc.",
    "8182": "DIGITALRIVER - Digital River, Inc.",
    "8183": "INTERNETSECURE- - InternetSecure Inc.",
    "8184": "LAFFITEMORGAN - Laffite Morgan & Assoc",
    "8185": "THAWEB - Terry Hines And Associates",
    "8186": "HPI - High Plains Internet",
    "8187": "ALIANT - Bell Aliant Regional Communications, Inc.",
    "8188": "BLOOMBERG - Bloomberg Financial Market",
    "8189": "STRATOS - Stratos Internet Group, Inc.",
    "8190": "MDNX MDNX",
    "8191": "WIDOMAKER - Widomaker Communication Services, Inc.",
    "8192": "TM Telematika Ltd",
    "8193": "BRM \"Uzbektelekom\" Joint Stock Company",
    "8194": "VITA V \"Latvijas Valsts radio un televizijas centrs\"",
    "8195": "IONIP 8195",
    "8196": "CLARANETDE Claranet Deutschland GmbH",
    "8200": "COMMERCIAL- Commercial Networks",
    "8201": "EVONET XS4ALL Belgium NV",
    "8203": "Bezeq International-Ltd",
    "8204": "FTA-NET Deutsche Telekom AG",
    "8206": "JUNIK-RIGA-LV JUNIK Ltd.",
    "8207": "8207 PRIVATE JOINT STOCK COMPANY \"DATAGROUP\"",
    "8208": "CAMELOT- Teamware GmbH",
    "8209": "UPC-NL UPC Netherlands - Autonomous System",
    "8210": "TELENOR Telenor Norge",
    "8211": "RABOBANK Cooperatieve Centrale Raiffeisen-Boerenleenbank B.A.",
    "8213": "TDC Sverige AB",
    "8214": "SEEREN-AL Institute of Informatics and Applied Mathematics",
    "8216": "Soluziona Consultoria y Tecnologia",
    "8217": "N-ENI # ENI S.p.A.",
    "8218": "NEO-N Neo Telecoms S.A.S.",
    "8219": "EXPERT-TELECOM- \"IC\"Expert\" Company Limited",
    "8220": "COLT COLT Technology Services Group Limited",
    "8221": "ISABEL ISABEL NV",
    "8222": "NETPLACE netplace Telematic GmbH",
    "8223": "EXITEC- Exitec GmbH",
    "8224": "INTERCOM- Intercom s.r.l.",
    "8225": "TELIT-MSK- Astelit Autonomous System",
    "8226": "AM-NIC- Armenia Network Information Center (AMNIC)",
    "8227": "CODENET- Telenet N.V.",
    "8228": "CEGETEL- Societe Francaise du Radiotelephone S.A",
    "8229": "KIBERNET- KiberNet Kft.",
    "8230": "SEMANTIKA- PE Semantika",
    "8231": "SUNRISE-8231 Sunrise Communications AG",
    "8232": "GXS-EUROPE GXS International Inc.",
    "8233": "TELIANET-UK TeliaNet UK",
    "8234": "RAI- RAI RadioTelevisione Italiana",
    "8235": "TIX-ZH .",
    "8236": "TDC-CE TDC Oy Finland",
    "8237": "DATAWAY- dataway GmbH",
    "8238": "AT&T V IT",
    "8239": "Arrakis, Servicios y comunicaciones, S.L.",
    "8240": "O Autonomous System",
    "8241": "RELLINE- CJSC Relline",
    "8242": "DINFO- Tselevye resursy Ltd.",
    "8243": "Verizon Switzerland AG",
    "8244": "SPARKLENET TELECOM ITALIA SPARKLE S.p.A.",
    "8245": "VIDEOBROADCT- Video-Broadcast GmbH",
    "8246": "GTS-POLSKA- GTS Poland Sp. z o.o.",
    "8247": "CALLTRADE-ZURICH Calltrade Carrier Services AG",
    "8248": "GR-EDUNET Greek High-School Internet Network",
    "8249": "TOTCOM- CJSC Togliatti Telecom",
    "8251": "NFX_ZSPO FreeTel, s.r.o.",
    "8253": "DUTHNET- Democritus University of Thrace",
    "8254": "SCANA- ISP Scana",
    "8255": "EURO-INFORMATION Euro-Information-Europeenne de Traitement de l'Information S",
    "8256": "LODMAN- Technical University of Lodz Computer Centre",
    "8257": "SLOVANET-BROADBAND Slovanet, a.s.",
    "8258": "VISTI-NET- Elektronni Visti Ltd (ElVisti Ltd)",
    "8260": "MEMO SC Memo Network SRL",
    "8261": "ARCHWAY-SAT Archway S.r.l",
    "8262": "LIREXNET- Lirex net EOOD",
    "8263": "PORTAL CJSC Synterra",
    "8264": "TELENOR Astrium Services Enterprises",
    "8265": "FTNET-BKB-N FTnet s.p.a.",
    "8266": "NEXUSTEL Nexus Telecommunications Ltd",
    "8267": "CYFRONET- Metropolitan Area Network Autonomous System",
    "8268": "-TSC",
    "8269": "KUPOL TV Kupol",
    "8270": "RBA- Raiffeisen banka ad Beograd",
    "8271": "CH-IBS-8271 Internet Business Solutions AG",
    "8272": "NETSCALIBUR-UK Netscalibur UK Ltd",
    "8273": "ERTELE- Verdo Tele A/S",
    "8275": "KERSZOV-COM- Kerszov Computer Ltd.",
    "8276": "VONESERVICES Vone Services Ltd",
    "8278": "TUC- Technical University of Crete",
    "8279": "STRATEGIYA Strategiya Ltd.",
    "8280": "SYNAPSECOM- SYNAPSECOM S.A",
    "8281": "MFA- HELLENIC REPUBLIC - MINISTRY OF FOREIGN AFFAIRS",
    "8282": "FIDONET FidoNet Registration Services Ltd",
    "8283": "COLOCLUE- Netwerkvereniging Coloclue, Amsterdam, Netherlands",
    "8285": "Versia Ltd",
    "8286": "ACI-EDU- Zachodniopomorski Uniwersytet Technologiczny w Szczecinie, Akademickie Centrum Informatyki",
    "8287": "TABA- PE Mykola Vitalievich Tabakov",
    "8288": "NEXTRA-SK-2 GTS Slovakia, a.s.",
    "8289": "DATAPHONE IP-Only Telecommunication Networks AB",
    "8290": "EntryNET Autonomous System",
    "8291": "RSNET- RSNET",
    "8292": "CAMDATA Camdata GmbH",
    "8293": "MC-LINK MC-link Spa",
    "8294": "FORNAX ZRt.",
    "8295": "PIRAEUS-CS- Piraeus Banka A.D. Beograd",
    "8296": "H-BAUER-PUBLISHING H Bauer Publishing Ltd",
    "8297": "GIEUROPE TATA Communications (Canada) Ltd.",
    "8298": "GRH SixXS",
    "8299": "INFOTEL- JVC INFOTEL",
    "8300": "TEST--MAIN Swisscom (Switzerland) Ltd",
    "8301": "GIBTELECOMNET www.GIBTELE.COM",
    "8302": "ZATTOO Zattoo Europa AG",
    "8303": "WDR- Westdeutscher Rundfunk Koeln",
    "8304": "ECRITEL-FRANCE ECRITEL Company",
    "8305": "INSAT Autonomous System",
    "8306": "LOGIC-N S.C. LogicNET Solution S.R.L",
    "8307": "Telekom Slovenije d.d.",
    "8308": "NK-COMMERCIAL NAUKOWA I AKADEMICKA SIEC KOMPUTEROWA INSTYTUT BADAWCZY",
    "8309": "SIPARTECH SIPARTECH Sarl",
    "8310": "PACWAN-N PACWAN",
    "8311": "REDESTEL Redestel Networks S.L.",
    "8312": "ZYLON- Zylon Internet Services vof",
    "8314": "UAB Lrytas",
    "8315": "AMSIO Amsio B.V.",
    "8316": "Telenor Czech Republic",
    "8317": "NETACCESS- Netaccess SRL",
    "8318": "CMX- CEMEX ESPANA S.A.",
    "8319": "NETHINKS- NETHINKS GmbH",
    "8322": "TDC TDC A/S",
    "8323": "CYFRONET-2 Metropolitan Area Network Autonomous System",
    "8324": "URC- South Ural State University",
    "8325": "YARSU- OOO FREEnet Group",
    "8326": "PL-BYDMAN-EDU Educational Users",
    "8328": "SIENNAX SaaSplaza Nederland B.V.",
    "8329": "N-ATS FSystems srl",
    "8330": "LONAP LONAP Ltd",
    "8331": "RINET- Cronyx Plus Ltd",
    "8333": "NEXTRA-AT Nextra Telekom GmbH (AT) & customers",
    "8334": "CO-2COM- 2COM Co ltd.",
    "8336": "Federal Node of RUNNET in Kemerovo State University",
    "8337": "GISP- Private Company GISP",
    "8338": "EQUANTRO Orange Romania S.A.",
    "8339": "KABSI- Kabelsignal GmbH",
    "8340": "US-EMB-KIEV Autonomous System",
    "8341": "QUICKNET Ziggo B.V.",
    "8342": "RTCOMM- OJSC RTComm.RU",
    "8343": "DORIS- Private joint-stock company (PrJSC) DORIS",
    "8345": "DSIJSC- DSI Autonomous system",
    "8346": "SONATEL- Autonomous System",
    "8347": "Callcentric Wholesale Inc",
    "8348": "SONERARUS SONERA RUS Closed JSC",
    "8349": "IPI-UA",
    "8350": "COMBELLGA- OJSC \"Vimpelcom\"",
    "8351": "PLANET-DE  for PLANET IC GmbH",
    "8353": "InteS Autonomous System",
    "8354": "TWINWAVE- Twinwave ISP",
    "8356": "NEOTEL-UK Neo-Tel Ltd.",
    "8358": "INTERWARE- GTS Hungary Tavkozlesi Ktf.",
    "8359": "MTS MTS OJSC",
    "8360": "Allianz Managed Operations and Services SE",
    "8361": "UBISOFT- Ubisoft International S",
    "8362": "NordNet",
    "8363": "KOCUNIV- KOC UNIVERSITY",
    "8364": "POZMAN-COM POZMAN-COM",
    "8365": "MANDA Man-da.de GmbH",
    "8367": "PerytNET Ltd",
    "8368": "BENESOL-BACKBONE Belgian Network Solutions B.V.B.A",
    "8369": "INTERSVYAZ- Intersvyaz-2 JSC",
    "8370": "ARIPPS- ARiPPS Ltd",
    "8371": "VIMPELCOM-NN OJSC \"Vimpelcom\"",
    "8372": "COLT-UK- COLT Technology Services Group Limited",
    "8373": "DEUBA-NET Deutsche Bank AG",
    "8374": "PLUSNET Polkomtel Sp. z o.o.",
    "8375": "KDD Deutschland Autonomous System",
    "8376": "Jordan Data Communications Company LLC",
    "8377": "PETERLINK- Awanti Ltd.",
    "8379": "CYBERNET-AG Cybernet AG German-wide Network",
    "8380": "TU-EUROPA-PL-1 TOWARZYSTWO UBEZPIECZEN NA ZYCIE EUROPA SPOLKA AKCYJNA",
    "8381": "N-METROPOLIS  # -METROPOLIS CONVERTED TO N-METROPOLIS FOR RPSL COMPLIANCE Metropolis srl",
    "8382": "IRTEL- OJSC Rostelecom",
    "8383": "CMC- Currency Management Corporation Plc",
    "8384": "Interoute Germany GmbH",
    "8385": "UUNET-SWEDEN- UUNET Sweden",
    "8386": "KOCNET VODAFONE NET ILETISIM HIZMETLERI A.S",
    "8387": "T-SYSTEMS-AT T-Systems Austria GesmbH",
    "8388": "DOLNET Lambrakis Press Organization S.A.",
    "8389": "STVOICE Sabanci Telekom A.S.",
    "8390": "TPN- Interoute Bulgaria JSCo.",
    "8391": "KNIPP- Knipp Medien und Kommunikation GmbH",
    "8393": "NEWTECH- \"TEL\" OJSC",
    "8394": "ALFANETT Alfanett Autonomous System",
    "8395": "ET- East Telecom ISP Autonomous system",
    "8396": "TEE-GR Technical Chamber of Greece",
    "8398": "Tver Region Center of Informatization",
    "8399": "ORNIS- RISC GROUP IT SOLUTIONS S.A.",
    "8400": "TELEKOM- TELEKOM SRBIJA a.d.",
    "8401": "MAILBOX Mailbox Networks",
    "8402": "CORBINA- OJSC \"Vimpelcom\"",
    "8403": "SPOTIFYLTD Spotify Ltd",
    "8404": "CABLECOM UPC Cablecom GmbH",
    "8405": "PE Sontheimer Bernd",
    "8408": "Pixedia SA",
    "8409": "IITP- Institute for Information Transmission Problems",
    "8410": "NIR- LLC \"NovInvestRezerv\"",
    "8411": "State Educational Institution of Higher Professional Education Omsk State University of F.M.Dostoevsky",
    "8412": "TMA T-Mobile Austria GmbH",
    "8414": "International Telecommunication Union",
    "8415": "N-SATKO SATKO Telekomunikasyon Yonetimi A.S.",
    "8416": "INFOLINE- Infoline Ltd.",
    "8418": "Orange S.A.",
    "8419": "HOTCHILLI Maxima Managed Services (Formerly: Hotchilli/DXI)",
    "8420": "ULAKNET",
    "8422": "NETCOLOGNE NetCologne GmbH",
    "8423": "PRINTERR- PRINTER ENGINEERING SRL",
    "8424": "KEYWORLD- GO p.l.c.",
    "8426": "CLARANET- ClaraNET LTD",
    "8427": "MAGINFO- Maginfo JSC",
    "8430": "ALMA-MEDIA-ALMATY- \"Complex Service Company\" LLC",
    "8431": "8431 TEA Internet Service Provider",
    "8433": "ExxonMobil  Internet operations",
    "8434": "TELENOR-SE Telenor Sweden",
    "8435": "Lloyds Banking Group PLC",
    "8436": "UPCHU UPC Magyarorszag Kft.",
    "8437": "UTA- Tele2 Telecommunication GmbH",
    "8438": "HETMANSOFT- Hetman Soft",
    "8439": "AIST CJSC AIST",
    "8440": "SNCNET- Sakhalin Network Communications Co. (SNC)",
    "8441": "GARANTSERVICE- OOO NPP Garant Service University",
    "8442": "SWOL DIG Digitale Medienberatungs- und Produktions- GmbH",
    "8443": "SKHDSV- OJSC Rostelecom",
    "8444": "21ST-CENTURY-NET",
    "8445": "SALZBURG-AG- SALZBURG AG fur Energie, Verkehr und Telekommunikation",
    "8446": "TELEWORLD",
    "8447": "TELEKOM-AT A1 Telekom Austria AG",
    "8448": "PGSM-HU Telenor Hungary plc",
    "8449": "8449-ELCAT \"ElCat\" Ltd.",
    "8450": "FH-WORMS Fachhochschule Worms",
    "8451": "Verisat Autonomous System",
    "8452": "TE- TE-",
    "8453": "ECONIS- Econis AG",
    "8454": "FMO FMO Flughafen Muenster/Osnabrueck GmbH",
    "8455": "ATOM86- Schuberg Philis B.V.",
    "8456": "BOUN Bogazici University",
    "8457": "ABCnet Autonomous System",
    "8458": "BLUENET- Blue Net SC",
    "8459": "NETIA Autonomous System",
    "8460": "ONSAKH- PE Nikonov Evgeniy Vitalevich",
    "8461": "N-TEX-KYIV TOV Trade-Express",
    "8462": "CORYNET1 Tarr Kft.",
    "8463": "Societa per i Servizi Bancari - SSB S.P.A.",
    "8464": "MAINGATE- Wireless Maingate Nordic AB",
    "8466": "BILKENT Ihsan Dogramaci Bilkent University",
    "8467": "BILKENT Ihsan Dogramaci Bilkent University",
    "8468": "ENTANET ENTANET International Limited",
    "8469": "PIRONETNDH- PIRONET NDH AG",
    "8470": "MACOMNET CJSC Macomnet",
    "8472": "VIAG-INTERKOM British Telecommunications plc",
    "8473": "BAHNHOF Bahnhof Internet AB",
    "8474": "8474 Riscom",
    "8475": "State Educational Institute of Higher Professional Education \"Bashkirskiy State University\"",
    "8476": "BVDEP- BVDEP Autonomous System",
    "8477": "ECHOSTARPL- ZTS Echostar Studio Poznan Poland",
    "8478": "N-GIGNETWORKS GIG Networks",
    "8479": "SGN/97 (Scandinavian Gigabit Network -97)",
    "8480": "USATU- State educational institution of higher education \"State Aviation Technical University of Ufa\"",
    "8481": "TRANSNET TRANSNET Internet Services GmbH",
    "8483": "Claranet Benelux B.V.",
    "8484": "SMP-STAR-INTERNET",
    "8485": "SAMSC- SamSC R",
    "8486": "BNK- Baltnetos Komunikacijos, UAB",
    "8487": "PHIBEE Phibee Telecom SARL",
    "8488": "Escortnet's Autonomous System",
    "8489": "PORTAL-TO-WEB EDV Beratung Mersberger",
    "8490": "VERAT--2 Drustvo za telekomunikacije Verat d.o.o, Bulevar Vojvode Misica 37",
    "8491": "BSH- Business Sviaz Holding",
    "8492": "OBIT- \"OBIT\" Ltd.",
    "8493": "URBANET UPC Cablecom GmbH",
    "8494": "for Decathlon",
    "8495": "INTERNET_AG INTERNET AG Global Network",
    "8496": "LIFE-INET- Alesta Ltd",
    "8499": "Space Hellas S.A.",
    "8500": "NTS-NET",
    "8501": "PIONIER- PIONIER, National Research and Education Network in Poland",
    "8502": "CCC Autonomous System",
    "8504": "NEVALINK- Nevalink Autonomous System",
    "8505": "TRNET Orta Dogu Yazilim Hizmetleri A. S.",
    "8506": "Institution of Russian Science Academy of Irkutsk Scientific Centre of Siberian Department of RAN",
    "8507": "LANIT Autonomous System",
    "8508": "SILWEB--EDU Silesian University of Technology, Computer Centre",
    "8510": "Tomsk State University",
    "8511": "8511-AI IAINFO TE",
    "8512": "NIIFI (Nemzeti Informacios Infrastruktura Fejlesztesi Iroda)",
    "8513": "SKYVISION SkyVision Global Networks Ltd",
    "8514": "INODE UPC Austria GmbH",
    "8515": "DATAFORCE- DataForce",
    "8516": "TELIANET-LITHUANIA TeliaNet Lithuania",
    "8517": "ULAKNET National Academic Network and Information Center",
    "8518": "RFERL Radio Free Europe",
    "8519": "ESA-MOSNET ESA OPSNET-INTRANET",
    "8520": "DUNKEL Dunkel GmbH",
    "8521": "Fachhochschule Fulda, Germany",
    "8522": "FORTH- Foundation for Research and Technology",
    "8523": "BEFARM-SE-N Basefarm AB. Stockholm - Sweden",
    "8524": "eg-auc",
    "8526": "TDC TDC A/S",
    "8527": "INTERNETFR Internet Fr",
    "8528": "RENAULT RENAULT S",
    "8529": "OMANTEL- General Telecommunication Organization",
    "8530": "EXCELL Excell Group PLC",
    "8531": "UNI-SB autonomous system",
    "8532": "TELIANET-ECUADOR TeliaNet Ecuador",
    "8534": "INFOSKY- Informatika a.d.",
    "8535": "AGORA Agora TC Sp.z.o.o.",
    "8536": "N-QWERTYNET QwertyNet",
    "8537": "Ural NETworks Service Autonomous System",
    "8538": "ILINK- iLink Ltd",
    "8539": "UNITEDMUSIC United Music S.R.L.",
    "8540": "HAPPYNET- CUS Telecom GmbH",
    "8541": "AIDATANET's Autonomous System",
    "8542": "BKKB BKK Fiber",
    "8544": "NSP-INTL Primetel PLC",
    "8545": "N-PLIX PLIX Sp. z o.o.",
    "8546": "YOUR-COMMS-UK- Thus Group Plc.",
    "8547": "8547 Styria IT Solutions GmbH & Co KG",
    "8548": "8548 Net Northwest Limited",
    "8549": "LHSYSTEMS- Lufthansa Systems AG",
    "8550": "LONAP-MLP LONAP Ltd.",
    "8551": "BEZEQ-INTERNATIONAL- Bezeqint Internet Backbone",
    "8552": "DNEPROPETROVSK core router",
    "8553": "AVENSYS Avensys Networks Ltd",
    "8554": "ATSAT T France",
    "8555": "FX FX Internet SA",
    "8556": "INFOLITE Levantis Hosting GmbH",
    "8557": "ELKATEL- OJSC Rostelecom",
    "8558": "HTTPOOL-NET- HTTPool d.o.o.",
    "8559": "WELLCOM Kabelplus GmbH",
    "8560": "ONEANDONE- 1&1 Internet AG",
    "8561": "KNIPPWORLDWIDE Knipp Medien und Kommunikation GmbH",
    "8562": "DIS- A1 Telekom Austria AG",
    "8563": "DIRECTNET--8563 OJSC \"Vimpelcom\"",
    "8564": "ROL Raiffeisen OnLine GmbH",
    "8565": "BLUEGIX BLUEGIX",
    "8566": "DINO- DINO SYSTEMS LTD",
    "8567": "European Telecommunications Standards Institute (ETSI)",
    "8568": "MMT- OJSC Long Distance and International",
    "8569": "MSYS MGI METRO Group Information Technology GmbH",
    "8570": "LES OJSC Rostelecom",
    "8571": "PARDIS Pardis Ettela Resaan Sepehr",
    "8576": "CW-PAC Cable & Wireless UK P.U.C.",
    "8577": "RACKAGE Rackage Ltd",
    "8578": "GAD-VRNETZE VR Netze GmbH",
    "8579": "Magyar Telekom plc.",
    "8580": "SANDY CJSC \"Comstar-Regions\"",
    "8581": "UOI University of Ioannina",
    "8582": "XENNA- Xenna Services GmbH",
    "8584": "BARAK Netvision 013 Barak - Barak Network",
    "8585": "INTERNET-CG Crnogorski Telekom a.d.Podgorica",
    "8586": "OBSL- TalkTalk Communications Limited",
    "8587": "INFRACOM- Infracom B.V.",
    "8588": "JD_ABRA_EU- Abra S.A.",
    "8589": "Autonomous System of",
    "8590": "Bayerische Motoren Werke Aktiengesellschaft",
    "8591": "AMIS AMiS",
    "8592": "MSUNET Research and production firm \"IMT-Center\" OOO",
    "8594": "OMSKELECOM OJSC Rostelecom",
    "8595": "WESTCALL- Autonomous System of WestCall Ltd",
    "8596": "HOTZE- hotze.com GmbH",
    "8597": "SK-PORSCHE- Porsche Slovakia, spol. s r.o",
    "8599": "State Educational Institution of Higher Professional Education Ulyanovsk State University",
    "8600": "Tula State University",
    "8601": "Telnet Ltd. Networking Center",
    "8603": "Quarta Technologies",
    "8604": "Academy Network Solution",
    "8605": "LANET University of Latvia",
    "8606": "Chita REGION",
    "8607": "TIMICO Timico Ltd Autonomous System",
    "8608": "QINIP EspritXB B.V.",
    "8609": "Universidade Catolica Portuguesa",
    "8611": "Athens University of Economics and Business",
    "8612": "TISCALI-IT Tiscali Italia S.P.A.",
    "8613": "ICM-NETSERV-UK- ICM NetServ Ltd",
    "8614": "ITC- ITC Institutul Pentru Tehnica De Calcul SA",
    "8615": "CNT- OJSC Central telegraph",
    "8616": "Brouwer ICT Services",
    "8617": "University of the Aegean",
    "8618": "Ionion University",
    "8619": "Garant-Service Krasnoyarsk",
    "8620": "TEMPEST a.s. Autonomous System Number",
    "8621": "BBUK-LTD Backbone (UK) Limited",
    "8622": "ISIONUK Namesco Limited",
    "8623": "UNN- Nizhny Novgorod State University",
    "8624": "TENUE- Tenue Oy",
    "8627": "8627 MIXX.DE",
    "8629": "MCNTT- MCNTT Autonomous System",
    "8630": "CHUVSU Fedaral State Educational Institution of higher professional Education 'Chuvash State University'",
    "8631": "MSK-IX-RS ANO CVKS \"MSK-IX\"",
    "8632": "LOL- Luxembourg Online S.A.",
    "8633": "University of Warsaw",
    "8634": "SOLARIS- Solaris Ltd.",
    "8635": "HP-EUROPE--BRINX Hewlett Packard Europe S.A.S.",
    "8636": "MAXNET Autonomous System for",
    "8637": "DPI Autonomous System",
    "8638": "VERSATEL-NRW Versatel Deutschland GmbH",
    "8639": "SURATNET's Autonomous System",
    "8640": "ZFS-GROUP Zurich Insurance Company",
    "8641": "NAUKANET- LLC \"Nauka-Svyaz\"",
    "8642": "B2 B2 Bredband AB (publ)",
    "8643": "ATHENANET University of Athens",
    "8644": "SCARLETBELGIUM Scarlet Belgium",
    "8645": "Business Informational Systems Technology LTD.",
    "8647": "EXFLOYT- TeleMist Ltd",
    "8648": "KAMP-DE KAMP Netzwerkdienste GmbH",
    "8649": "WEBTRAFFIC ZeXoTeK IT-Services GmbH",
    "8650": "TALKLINE Talkline GmbH, Internet Division",
    "8651": "MUSI Mitsubishi UFJ Securities International plc",
    "8652": "DAT- DAT AG",
    "8653": "ACTALIS-N Actalis S.p.A.",
    "8654": "CRIMEAINFOCOM- CrimeaInfocom Ltd",
    "8656": "PSINETEUROPE TELSTRA LIMITED",
    "8657": "CPRM PT Comunicacoes S A",
    "8658": "SITE Company Autonomous System",
    "8659": "8659 United Nations International Computing Centre",
    "8660": "MATRIX- Matrix S.p.A.",
    "8661": "PTK PTK IP/MPLS Network",
    "8662": "LENENERGO Joint-Stock Company Lenenergo",
    "8663": "KUBANNET State educational institution of higher education Kuban State University",
    "8664": "ICM-PUB University of Warsaw, ICM",
    "8665": "ACCESSPEOPLE-DE ISP-Service AG",
    "8666": "MAV INFORMATIKA KFT.",
    "8667": "UBS AG",
    "8668": "TELONE- TelOne Zimbabwe P/L",
    "8669": "TOTALWEBSOLUTIONS Total Web Solutions Ltd",
    "8670": "UTIC_AUTONOMUS_SYSTEM UTIC =20",
    "8671": "Verizon Italia SpA",
    "8672": "ORBITEL Orbitel EAD",
    "8673": "BUSINESSONLINEAG BusinessOnline AG",
    "8674": "NETNOD-IX Netnod Internet Exchange Sverige AB",
    "8675": "_TULATEL OJSC Rostelecom",
    "8676": "PRTSYSTEMS PRT Systems Limited",
    "8677": "8677 Atos Worldline S",
    "8678": "ANKARA-NET Ankara Universitesi Rektorlugu",
    "8680": "Sure Guernsey Limited",
    "8681": "JT JT (Jersey) Limited",
    "8682": "UKIP-PRIVATE New Reg Limited",
    "8683": "NOMINET Nominet UK",
    "8684": "PSU- State Educational Institution of Higher Professional Education \"Perm State University\"",
    "8685": "DORUKNET Doruk Iletisim ve Otomasyon Sanayi ve Ticaret A.S.",
    "8686": "SYSONLINE CloudXL Ltd",
    "8687": "PPP- Pelikan & Partner",
    "8689": "POWERNETUK Power Internet Ltd.",
    "8692": "BRZ Bundesrechenzentrum GmbH",
    "8694": "RET- Rotterdamse Electrische Tram N.V.",
    "8695": "WEBDOOR Webdoor - Content and Service Provider",
    "8696": "INVITEL Invitel Tavkozlesi Zrt.",
    "8697": "JTC-8697 Jordan Telecommunications Company",
    "8698": "Nationwide Building Society",
    "8699": "Ma-Kom Ltd.",
    "8700": "TEI OF LARISSA",
    "8702": "Posten AB",
    "8703": "HP-CH-1 HP-CH Autonomous System",
    "8704": "CHEL-IX- State Educational Institution of Higher Professional Education 'South Ural State University'",
    "8705": "TNN Turk Nokta Net Autonomous System",
    "8706": "VDA- LLC Volga-Dnepr Airlines",
    "8708": "RCS-RDS RCS & RDS SA",
    "8709": "CW-HOSTING Cable & Wireless UK P.U.C.",
    "8711": "MAGTEL- CJSC \"Magistral Telecom\"",
    "8712": "INTA- PE Bystrov V.N.",
    "8714": "LINX-ROUTESRV For use with the LINX Route Servers",
    "8715": "ERNSTYOUNG-NL- Ernst & Young Nederland",
    "8716": "iXguardian Ltd",
    "8717": "SPECTRUMNET MOBILTEL EAD",
    "8718": "Thomson Corporation",
    "8719": "DSU- Dnepropetrovsk National University of Oles Gonchar",
    "8720": "PAN- aspan telecom  number",
    "8721": "Hurriyet Gazetecilik & Matbacilik A.S.",
    "8723": "INTEGRA- Integra France",
    "8725": "NETPOZITIF- Netpozitif  Telekomunikasyon Hizmetleri Ltd. Sti.",
    "8726": "KKI-BCI- Grupa KKI-BCI Sp. Z o.o.",
    "8727": "ADACTA- Adacta d.o.o.",
    "8728": "INFONET",
    "8729": "Credit Suisse Group",
    "8730": "KRU Autonomous System",
    "8731": "N-SGH SGH mbH Internet Division",
    "8732": "COMCOR-  for Moscow Telecommunication Corporation (COMCOR)",
    "8733": "CHELLO-BELGIUM Telenet N.V.",
    "8734": "DZI-BG DZI Obshto Zastrahovane",
    "8735": "ATOS-DE-NUREMBERG Atos Information Technology GmbH",
    "8737": "PT Koninklijke KPN N.V.",
    "8738": "VISA-ISRAEL- Israel Credit Cards Ltd",
    "8739": "ICDSOFT ICDSoft Ltd",
    "8741": "RATIOKONTAKT Ratiokontakt GmbH",
    "8744": "STARTTELECOM- JSC Start Telecom",
    "8745": "-BG-B BNET autonomous system Bulgaria",
    "8746": "Caisse des Depots",
    "8747": "INWAYCZ Dial Telecom, a.s.",
    "8748": "Blekinge Tekniska Hogskola",
    "8749": "REDCOM- Redcom, Khabarovsk, Russia",
    "8751": "MEDIAT Media Sat SRL",
    "8752": "VT-NETWORK OAO \"VT\"",
    "8753": "MEDIATELESET Mediateleset Ltd.",
    "8755": "CITYLINESPB- OJSC \"Vimpelcom\"",
    "8756": "RADIO-MSU RADIO-MSU",
    "8757": "ACCESS11 Access 11 Ltd",
    "8758": "IWAY Iway AG",
    "8760": "ENERGIS-IRELAND Energis Ireland Backbone Network",
    "8761": "ONO--CLIENTES ONO  CLientes",
    "8762": "TEI-OF-CRETE- Technological Educational Institute of Crete",
    "8763": "DENIC- DENIC eG",
    "8764": "TEOLTAB TEO LT AB Autonomous System",
    "8766": "SGH-PL Szkola Glowna Handlowa w Warszawie",
    "8767": "MNET- M-net Telekommunikations GmbH, Germany",
    "8768": "WorldCom S.p.A.",
    "8769": "Calcol Informatica S.r.l.",
    "8770": "UNSPECIFIED",
    "8771": "YUNET- YUnet International d.o.o.",
    "8772": "RIDER PP Legal center \"Rider\"",
    "8773": "8773 OJSC \"Vimpelcom\"",
    "8774": "ETYPE Etype Company, Kaliningrad, Russia",
    "8775": "ICMM Institute of continuous media mechanics of the Ural branch of the Russian Academy of Science",
    "8778": "SLOVANET Slovanet, a.s.",
    "8779": "INFOCOM-KM KhmelnitskInfocom LTD",
    "8780": "Caen lix",
    "8781": "QA-ISP Qatar Telecom (Qtel) Q.S.C.",
    "8782": "GIGABELL-HISPANIA Gigabell Hispania",
    "8784": "8784 Prosodie",
    "8786": "TELENOR-MOBIL Telenor Norge",
    "8787": "THALESIS Amaris Technologies GmbH",
    "8788": "ADAMANT ADAMANT, Ltd.",
    "8789": "NOV- Novosco Limited",
    "8790": "PETRSU- Petrozavodsk State University",
    "8791": "DMG-UK-",
    "8792": "VNET Axel Springer AG",
    "8793": "THINXX thinxx GmbH",
    "8794": "FAZ Frankfurter Allgemeine Zeitung GmbH",
    "8795": "MOBIKOM Radio Telecommunications Company Ltd. / Mobikom",
    "8798": "PAGI- PAGI - General Information Agency",
    "8799": "8799 21 IMCN - IP Service Provider",
    "8800": "TVK Ltd.",
    "8801": "NETSERV Autonomous System of Darest Informatic",
    "8802": "THOMSON-REUTERS Thomson Corporation",
    "8803": "MIGROS Migros-Genossenschafts-Bund",
    "8804": "REGIO- regio[.NET] Holding GmbH",
    "8805": "N-ISC-DE iSC internet Service Center GmbH",
    "8808": "INTECH INTECH Autonomous system",
    "8809": "N-OGILVY Ogilvy & Mather Reklamcilik",
    "8811": "TANAID Limited liability company TANAID",
    "8812": "NMPWFL Nokia Mobile Phones",
    "8813": "VEGA-OD-UA DCS Ltd.",
    "8814": "AZERIN AZERIN",
    "8816": "IT-STCOM Consorzio Metrolink",
    "8817": "OKNO KC OKHO Autonomous System",
    "8818": "TELE Greenland",
    "8819": "PL-METROINTERNET Metro Internet Sp. z o.o.",
    "8820": "TAL-DE TAL.DE Klaus Internet Service GmbH",
    "8821": "TELEZUG WWZ Telekom AG",
    "8822": "Win.Net S.r.l.",
    "8823": "AUTONOMOUSSYSTEMROCKENSTEINAG Rockenstein AG",
    "8825": "NURSAT-REGIONS- JSC Nursat",
    "8826": "Siemens Autonomous System",
    "8827": "CELSA- CELSA IT SERVICES SA",
    "8828": "BURNET- OJSC \"AK Mobiltelecom\"",
    "8829": "PHPOY- PHPOY IPP",
    "8830": "UNET--MK UltraNet d.o.o.",
    "8831": "FINANSBANK FINANSBANK A.S.",
    "8832": "NETVOICE netvoice data security OG",
    "8833": "GPS e-globe technologies AG",
    "8834": "RESMAN Urzad Miasta Rzeszowa",
    "8835": "Might Ltd",
    "8837": "TELIANET-IPX TeliaSonera AB",
    "8838": "STRIPE21 Stripe21 VN Limited",
    "8839": "SDV- SdV Plurimedia",
    "8841": "TAIDE-US-WDBN Astrium Services Enterprises",
    "8842": "PIMS UK Ltd",
    "8843": "FINECOM-MPLS Finecom Telecommunications AG",
    "8844": "COMMUNITY CI-Net Limited",
    "8846": "N-TCO Telecommunication Center Ostankino",
    "8847": "TTL- CJSC \"Telecomm Technology\"",
    "8848": "CFT- ZAO Center of Financial Technologies",
    "8849": "DATALOGIKA JSC Datalogika",
    "8850": "Centre for Civil-Military Relations",
    "8851": "EDGE Edge Telecom Ltd",
    "8853": "KORSTON- Public joint-stock company Hotel complex \"ORLYONOK\"",
    "8854": "P",
    "8855": "N-PROMO PROMO.IT SRL",
    "8856": "UKRNET UkrNet Ltd",
    "8859": "OSN OSN Online Service Nuernberg GmbH",
    "8860": "DIRBG- DIR.BG AD",
    "8861": "TEMP-RELUVA Easynet Nederland B.V.",
    "8865": "N-BIAMAN-EDU Politechnika Bialostocka",
    "8866": "BTC- Bulgarian Telecommunication Company Plc.",
    "8867": "TEHILA- Government of Israel",
    "8868": "GORDION YEDEK NUMARI",
    "8869": "SBS-2 Sim Net Telekomunikasyon Sanayi ve Ticaret Limited Sirketi",
    "8870": "OVDC- Operator of Virtual Data Computing LLC",
    "8871": "CSI-NETWORKS Clements Shine Investments Limited",
    "8872": "International Business Bank",
    "8873": "8873 Tele2 Sverige AB",
    "8874": "for Ferri",
    "8875": "SINMA-N sinma GmbH",
    "8877": "POWERNET- Telehouse EAD",
    "8878": "NFON- nfon AG",
    "8879": "DTS-SYSTEME DTS-Systeme Autonomous System",
    "8880": "AII-0 Agency for Investment Information (AII) Ltd",
    "8881": "VERSATEL Versatel Deutschland GmbH",
    "8882": "RUSERVICE-LLC-2 LLC RU-service",
    "8883": "UBS AG",
    "8884": "CRIF- CRIF S.p.A.",
    "8885": "LAMBDANET-DE- euNetworks Managed Services GmbH",
    "8886": "PSESA- PGE Systemy S.A.",
    "8887": "TESATEL- TESATEL, s.r.o.",
    "8888": "RUSERVICE-LLC- LLC RU-service",
    "8889": "INNOVATE- Innovate Software Ltd",
    "8890": "UW- University of Warsaw",
    "8891": "Orange S.A.",
    "8892": "SKLNK UAB Skylink LT",
    "8893": "ARTFILES- Artfiles New Media GmbH",
    "8894": "NICE- Nice Systems Ltd.",
    "8895": "ISU-RUH King Abdul Aziz City for Science and Technology",
    "8896": "XFIBER",
    "8897": "KCOM-SPN KCOM Group PLC",
    "8899": "INEXIO inexio Informationstechnologie und Telekommunikation KGaA",
    "8901": "Moscow Mayor's Office",
    "8902": "IFB Internet For Business Limited",
    "8903": "8903 BT ESPANA, COMPANIA DE SERVICIOS GLOBALES DE TELECOMUNICACIONES, S.A.",
    "8904": "CBRF Autonomous System",
    "8905": "DIGIT1- Digit One LLC",
    "8906": "M2M-TELEMATIKA- M2M Telematika Ltd",
    "8908": "SBP- SWISSLIFE BANQUE PRIVEE SA",
    "8909": "AMURSU- State Educational Institution of Higher Professional Education Amur State University",
    "8910": "NETALIA Netalia Internet Ltd.",
    "8911": "RINO CIOTTA (P.E.)",
    "8912": "NETBENEFIT Group NBT plc (formerly NetBenefit)",
    "8913": "IPNET Mopos Communications A.S.",
    "8915": "DELFA- Company Delfa Co. Ltd.",
    "8916": "PORTFT Portfast Ltd",
    "8917": "PUBLIKA-TV- STIRI MEDIA GRUP SRL",
    "8918": "CARRIER1- Carrier1 Autonomous System",
    "8919": "CANAD CANAD Systems Internet",
    "8920": "VTC- Vostoktelecom Autonomous System",
    "8921": "FR-OC3NETWORK OC3 NETWORK",
    "8922": "N-TNET T.net S.p.A.",
    "8923": "RELSOFT Autonomous System",
    "8925": "TEUTONET- teuto.net Netzdienste GmbH",
    "8926": "MOLDTELECOM- Moldtelecom SA",
    "8928": "INTEROUTE Interoute Communications Limited",
    "8929": "Ayscough Travel",
    "8930": "N-MEDIAFAX MEDIAFAX SA",
    "8931": "MOLDPAC_ MOLDPAC S.A.",
    "8932": "ICONCOM iCON Communications CJSC",
    "8934": "NITC National Information Technology Center",
    "8935": "INTOUCH-INT- InTouch N.V.",
    "8936": "KUBAN Krasnodar Public Multiprotocol Network Autonomous System",
    "8937": "SALINK- VSE NET GmbH",
    "8938": "ENERGIS-IP Energis Polska Sp. z.o.o.",
    "8939": "ADTECH ADTECH AG",
    "8940": "TISCOVER-AT Tiscover GmbH",
    "8941": "MRSU- N. P. Ogarev's Mordovian State University",
    "8942": "Focus Information Limited",
    "8943": "JUMP Jump Networks Ltd.",
    "8945": "SCANANDTARGET Mesagraph S",
    "8947": "ANADOLUBANK- Anadolubank A.S.",
    "8948": "RERIF_ENTREPRISE Autonomous system",
    "8949": "DK Mattocks Ltd",
    "8950": "LOGICALISUK Logicalis UK Limited",
    "8951": "SYZEYXIS- HellasNet",
    "8952": "NTT-EUROPE NTT Europe Limited",
    "8953": "N-ORANGE-ROMANIA Orange Romania SA",
    "8954": "INTOUCH- InTouch N.V.",
    "8956": "IFS-NET Stadt Flensburg",
    "8958": "SODACLUB- SODA CLUB LTD.",
    "8959": "Emirates Internet Exchange GTE Peer router",
    "8960": "Emirates Internet Exchange UUNET Peer router",
    "8961": "Emirates Telecommunications Corporation",
    "8962": "COKPRM- Centrum Obslugi Kancelarii Prezesa Rady Ministrow",
    "8963": "Intracom S.A Information Technology and Communication Services",
    "8964": "RTK OOO RTK",
    "8966": "ETISALAT- Emirates Telecommunications Corporation",
    "8967": "ISERVICE-BG- Internet Service Ltd.",
    "8968": "BT-ITALIA BT Italia S.p.A.",
    "8970": "WK WROCMAN-EDU educational part of WK network, Wroclaw, Poland",
    "8971": "ATOS IT Solutions and Services GmbH",
    "8972": "PLUSSERVER- intergenia AG",
    "8973": "SSVL Kungliga Tekniska Hogskolan",
    "8974": "ETRUST- Commercial bank \"European trust bank\" (CJSC)",
    "8975": "CLARANETFR Claranet France",
    "8976": "STREAMWIDE- Streamwide Romania SRL",
    "8978": "N-HOLYSEE The Holy See - Vatican City State",
    "8979": "TELIA-MULTINET Telia Multinet",
    "8980": "MAKI- Maki S.r.l.",
    "8981": "VSU State Educational Institution of Higher Professional Education Voronezh State University",
    "8982": "SONET- Sonet DOO Skopje",
    "8983": "ALCATEL- Alcatel-Lucent International S",
    "8984": "INTERNET5-NET Internet5 AB",
    "8985": "JSC Center of Network Cooperation \"MSK-IX\"",
    "8986": "TECH-LT UAB Ekvitula ISP",
    "8987": "Amazon Data Services Ireland Ltd",
    "8989": "MIRAINTERNET Mira Internetsolutions ApS",
    "8990": "AHRT- \"ANTENNA HUNGARIA\" Magyar Musorszoro es Radiohirkozlesi Zartkoruen Mukodo Reszvenytarsasag",
    "8991": "IMBC Autonomous System",
    "8992": "TELERING-AT T-Mobile Austria GmbH",
    "8995": "LM Jogback Datakonsult",
    "8996": "Tele2 Sverige AB",
    "8997": "N-SPBNIT OJSC Rostelecom",
    "8998": "TUMTTL- Closed Joint Stock Company \"Russian company\"",
    "8999": "AXINET-COM Axinet Communication sarl",
    "9000": "ESER-N Eser Telekom",
    "9001": "A1-SI- A1, INVESTICIJSKO UPRAVLJANJE, d.d.",
    "9002": "RETN- RETN Limited",
    "9003": "N-ALTITUDETELECOM COMPLETEL S",
    "9004": "Net Communications Autonomus System",
    "9006": "GEPSPD- ZAO \"Giproenergoprom\"",
    "9007": "DUF- Dumrath & Fassnacht KG (GmbH & Co.)",
    "9008": "9008 Visual Online S.A.",
    "9009": "M247 M247 Ltd",
    "9011": "Mipex.net",
    "9014": "CEF CEF",
    "9015": "DNTIS Autonomous System",
    "9016": "KBS-BANK- Krakowski Bank Spoldzielczy",
    "9017": "Internet Danmark ApS",
    "9018": "Missing-Link Autonomous System",
    "9020": "9020-FRAUNHOFER-IESE-KL Fraunhofer-Gesellschaft zur Foerderung der angewandten Forschung e.V.",
    "9021": "ISNET Is Net Elektonik Bilgi Uretim Dagitim Ticaret ve Iletisim Hizmetleri A.S.",
    "9022": "TWL-KOM- TWL-KOM GMBH",
    "9023": "LOTTERIEN- Oesterreichische Lotterien GmbH",
    "9025": "SIX Group Services AG",
    "9026": "ULI-MAIN Utility Line Italia S.r.l.",
    "9028": "MEDIANET--BG Medianet Ltd",
    "9029": "ICOR",
    "9030": "DEVCON- teuto.net Netzdienste GmbH",
    "9031": "EDPNET EDPNET",
    "9032": "EDUNET- Educational Network Ltd.",
    "9033": "ECIX- Peering GmbH",
    "9034": "Wind Telecomunicazioni spa",
    "9035": "N-WIND Wind Telecomunicazioni spa",
    "9036": "NEURONNEXION- NEURONNEXION",
    "9038": "BAT-9038 Batelco Jordan",
    "9039": "IIAT- IIAT Autonomous System",
    "9041": "RSVPU Russian State Vocational Pedagogical University",
    "9042": "SIX SIX Group Services AG",
    "9044": "SOLNET BSE Software GmbH",
    "9045": "9045 Tele2 Sverige AB",
    "9046": "9046 Tele2 Sverige AB",
    "9047": "9047 TELE2 EUROPE",
    "9048": "FreeDot Net",
    "9049": "ERTH-TRANSIT- CJSC \"ER-Telecom Holding\"",
    "9050": "RTD ROMTELECOM S.A",
    "9051": "IncoNet Data Management sal",
    "9052": "Unidad Editorial S.A.",
    "9053": "NI- CE Online System s.r.o.",
    "9055": "UUNET Ireland Autonomous System",
    "9056": "PSN- Joint SuperComputer Center of the Russian Academy of Sciences",
    "9057": "LEVEL3 Level 3 Communications",
    "9058": "CHARTWELL- Chartwell Telecom Ltd, Riga",
    "9059": "AWS-EU- Amazon Data Services Ireland Ltd",
    "9060": "NXT- Nextage GmbHs",
    "9062": "Verizon Switzerland AG",
    "9063": "SAARGATE- VSE NET GmbH",
    "9064": "IIRUC-DIGICOM-SA IIRUC - DIGICOM GRUP SA",
    "9065": "Robeco Groep NV",
    "9066": "BCC BCC GmbH",
    "9067": "one4vision GmbH",
    "9068": "COMCOR-  for Moscow Telecommunication Corporation (COMCOR)",
    "9069": "Technological Educational Institute (T.E.I.) of Athens",
    "9070": "ITD ITD Network Bulgarian ISP",
    "9071": "ORBOTECH- Orbotech Ltd.",
    "9074": "KOC SISTEM BILGI VE ILETISIM HIZMETLERI ANONIM SIRKETI",
    "9075": "RECOLETOS Recoletos Compania Editorial",
    "9076": "INIT- INIT SRL",
    "9077": "UFSC- Institution of Russian Academy of Sciences Ufa Scientific Centre RAN",
    "9078": "SIBIS- Sibirskie Innovacionnye Sistemy Ltd",
    "9079": "FIRSTNET (First Data Communication Group)",
    "9080": "GIN IPEX/GIN Autonomous System",
    "9081": "9081 B92-NET Autonomous System",
    "9082": "SINUSRZN- SINUS Ltd.",
    "9083": "CARPENET carpeNet Information Technologies GmbH",
    "9084": "GSI- Goldman Sachs International ULC",
    "9085": "SUPERMEDIA- SUPERMEDIA Sp.z.o.o.",
    "9086": "N-DOCKLANDS-DATA-CENTRE-LTD Qi Comm Ltd",
    "9087": "DNT-NETWORK DNT A.O.",
    "9088": "Dalarna University",
    "9089": "ALTO ALTO Network",
    "9090": "OIT PR Newswire Europe Ltd.",
    "9091": "Swedbank",
    "9092": "OPENSYSTEMS- Open Systems AG",
    "9093": "AGONET- Agonet",
    "9094": "BT_SPAIN_INTERNAL BT ESPANA, COMPANIA DE SERVICIOS GLOBALES DE TELECOMUNICACIONES, SA",
    "9095": "Istanbul Teknik Universitesi",
    "9096": "Timber Hill (Europe) AG",
    "9099": "FINANZINFORMATIK--NORD Finanz Informatik GmbH & Co. KG",
    "9100": "PECTRA Aspectra AG",
    "9101": "ODNCH- ODN AG",
    "9103": "ZIELMAN-EDU- Uniwersytet Zielonogorski",
    "9104": "CLIO- Clio S.p.A.",
    "9105": "TISCALI-UK Tiscali UK",
    "9107": "IOS-NET CJSC Internet of Siberia",
    "9108": "ABXNET Abraxas Informatik AG",
    "9110": "AGTELECOM- \"AMT GROUP TELECOM\" Limited Liability Company",
    "9111": "N-PRCNIT State Educational Institution of Higher Professional Education Saratov State University of N.G. Chernyshevsky",
    "9112": "POZMAN POZMAN-EDU",
    "9113": "VLANT- VLANT Ltd.",
    "9114": "Tyumen Sate Oil and Gas University",
    "9115": "INFB-9115 Internet Names For Business",
    "9116": "GOLDENLINES-N 012 Smile Communications Ltd.",
    "9117": "CELLCOM- 013 NetVision Ltd",
    "9118": "BANCO ESPIRITO SANTO SA",
    "9119": "SOFTNET- Softnet d.o.o.",
    "9120": "SURFTOWNNET Surftown A/S",
    "9121": "TTNET Turk Telekomunikasyon Anonim Sirketi",
    "9122": "TECHNOELECTROSERVIS- Technoelektroservis Ltd.",
    "9123": "TIMEWEB- OOO TimeWeb",
    "9124": "IKSUR Federal State Educational Institution of Higher Professional Education Russian State University of Immanuil Kant",
    "9125": "ORIONTELEKOM- Drustvo za telekomunikacije Orion telekom doo Beograd, Gandijeva 76a",
    "9126": "COLT Technology Services Group Limited",
    "9127": "NETISSAT- NETISSAT",
    "9128": "Alpha Bank SA",
    "9129": "KE-NET2000",
    "9130": "HMS- LLC Managing Company Hydraulic Machines and Systems",
    "9131": "USPEKH ChP Uspekh",
    "9132": "BROADNET- QSC AG",
    "9134": "REGMED- Federal goverment entity for Scientific Center on Expertise of Medical Application Products",
    "9135": "ITEMAX- Itemax GmbH",
    "9136": "WOBCOM Wobcom GmbH",
    "9137": "N-UNO Uno Communications S.p.A.",
    "9139": "CYPIX (Cyprus Internet Exchange)",
    "9140": "HYPERNEPH Hyperneph Ltd",
    "9141": "9141 UPC Polska Sp. z o.o.",
    "9142": "Netline UK Ltd",
    "9143": "ZIGGO Ziggo B.V.",
    "9144": "CHEMPIONEBI- Chempionebi 111 Ltd",
    "9145": "EWETEL EWE TEL GmbH",
    "9146": "BIHNET BH Telecom d.d. Sarajevo",
    "9147": "NTT FRANCE Autonomous System",
    "9149": "GIECB Groupement Des Cartes Bancaires CB",
    "9150": "INTERCONNECT ML Consultancy",
    "9152": "MEGADAT Autonomous System",
    "9153": "BURSTFIRE-EU Burstfire Networks Limited",
    "9154": "UNIPHARM- MC-21 Security Systems Ltd.",
    "9155": "QNET QualityNet General Trading & Contracting Co.",
    "9156": "BBC-TRANSIT BBC Internet Services, transit",
    "9157": "SAO-R The Special Astrophysical Observatory (SAO) of",
    "9158": "TELENOR_DANMARK_ Telenor A/S",
    "9159": "Credit Agricole S.A.",
    "9160": "ROKLINK Rokura SRL",
    "9161": "PSL Poundbury Systems Ltd.",
    "9162": "TSTU The State Educational Institution of Higher Vocational Education \"Tambov State Technical University\"",
    "9163": "CETTELEPORT-GERMANY CET Teleport GmbH",
    "9164": "KIROVKA-NET- FOP Styopin Vyacheslav Evgenovich",
    "9165": "SERVICOM2000- PROSODIE IBERICA SL",
    "9166": "HOSTIT-BELGIUM HostIT NV",
    "9167": "WEBPARTNER WEBPARTNER A/S is a Danish Internet Service Provider",
    "9168": "TELINO- Telino SARL",
    "9170": "ROEHM-DA Roehm GmbH, Chemische Fabrik",
    "9171": "NOVOL Novasol a/s",
    "9172": "MK-MOL- Company for Computer Services and Trade MOL KOMUNIKACII DOOEL Skopje",
    "9173": "WHITEBIRD Whitebird New Media",
    "9174": "Trans-It AG",
    "9175": "CIRCIT Verlagsgruppe Handelsblatt",
    "9176": "TOPEDGE TOP EDGE ENGINEERING S.R.L.",
    "9177": "MZRTA- Mezhdurechensk factory of radio equipment repair, Ltd",
    "9178": "FHW",
    "9179": "KNOWTION-LONDON FidoNet Registration Services Ltd",
    "9180": "ALIENOR ALIENOR NET Societe a responsabilite limitee",
    "9182": "COMSPACE COMSPACE GmbH & Co KG",
    "9183": "Robert Bosch GmbH",
    "9185": "ALTAIR \"Altair\" CJSC",
    "9186": "ONI ONITELECOM Autonomous System",
    "9188": "INFOSERVE- infoServe GmbH",
    "9189": "ACCOM NetAachen GmbH",
    "9191": "NEWNET NewNet PLC",
    "9192": "LLEIDANET LleidaNetworks Serveis Telematics S.A.",
    "9193": "CONXIONEU ConXion Corporation Europe East India Dock House, 240 East India Dock Road London, E14 9YY UK",
    "9194": "Verizon UK Limited",
    "9195": "HP-EUROPE--TRADE NonStop eBusiness Network Europe",
    "9196": "NETSOURCE- Magnet Business (formerly netsource)",
    "9197": "BECOMGMBH- becom Systemhaus GmbH, Internet Service Provider",
    "9198": "KAZTELECOM- JSC Kazakhtelecom",
    "9199": "RENAM \"RENAM\" Public Association",
    "9201": "SWAF FMV",
    "9202": "ZSSM- GYUSS PKF LTD",
    "9203": "NOVLINE-PLUS- NovLine Plus Ltd.",
    "9204": "JIS- Jump Internet Services SRL",
    "9205": "SNS- \"SATELIT SERVIS\" Ltd",
    "9206": "MAI Moscow Aviation Institute (MAI)",
    "9207": "TAIDE-KE-NAIROBI Astrium Services Enterprises",
    "9208": "WIN WIN Autonomous System",
    "9210": "CENTR-TELEKOM- Centr-Telekom Ltd",
    "9211": "WORK- n@work Internet Informationssysteme GmbH",
    "9212": "MAZWARE Mazware Ltd",
    "9213": "DITEK Ditek Ltd",
    "9214": "SUNRISE-9214 Sunrise Communications AG",
    "9215": "LINOTYPE- Heidelberger Druckmaschinen AG",
    "9216": "PUNET-AP PUNET Taiwan",
    "9217": "INFONET-AP BT-Infonet",
    "9218": "WISEVANGUARD--AP WISEVAN GUARD  Limited",
    "9219": "THOMSON-LEGAL-N-REG-AP Provider of Legal and Regulatory information.",
    "9220": "INFONET-AU-AP BT-Infonet",
    "9221": "HSBC-HK- HSBC HongKong",
    "9222": "INTEL-ONLINE-SERVICES-IA Intel Online Services Asia",
    "9223": "INDUS-TOWERS Spreaded across 35 locations in india",
    "9224": "CIRRUSCOMMS1-AU-AP Cirrus Communications Pty Ltd",
    "9225": "TELSTRAGLOBAL-NUM Telstra Global - KK",
    "9226": "SGIX--AP 1-Net Singapore Pte Ltd",
    "9227": "ALLEGIS-SERVICES-INDIA-IN RMZ NXT Campus 1B, Unit 401-402, 4th Floor",
    "9228": "CENTRALONLINE-ID--AP PT. Total Info Kharisma",
    "9229": "SPEEDCT-AP SPEEDCT Limited",
    "9230": "BOL-BD-AP Bangladesh Online Ltd.",
    "9231": "IPEOPLESNET--AP China Mobile Hong Kong Company Limited",
    "9232": "CONCENTRIX-PH--AP Concentrix Technologies, Inc",
    "9233": "N-EVENTURES-AP  # -EVENTURES-AP CONVERTED TO N-EVENTURES-AP FOR RPSL COMPLIANCE Eventures Limited",
    "9234": "SOLONE-SG Sol One Application Delivery Network",
    "9235": "FOCUSDIRECT-PH Do\u00c3\u0192\u00c2\u00b1a Ceferina Bldg, 22- Lacson Sts.",
    "9236": "AMPCI--AP AMP Capital Investors NZ",
    "9237": "HUTCHCA- PCCW Global (HK) Ltd.",
    "9238": "TATA- TATA ISP",
    "9239": "SPACENET--AP Perth based ISP",
    "9240": "SWISH--AU-AP Hyperlink Pty. Ltd.",
    "9241": "FINTEL-FJ Fiji International Telecomunications Ltd",
    "9242": "AFE--AP AFE Solutions Limited",
    "9243": "CCHAUSTLTD-AP CCH Australia Limited",
    "9244": "N-DYXNET-TW-AP  # -DYXNET-TW-AP CONVERTED TO N-DYXNET-TW-AP FOR RPSL COMPLIANCE Diyixian.com (TW) Limited",
    "9245": "COMPS-NZ-AP COMPS NZ",
    "9246": "GTA-AP Teleguam Holdings, LLC",
    "9247": "NIE-SG National Institute of Education",
    "9248": "APACHE-AP Apache Networks, Inc.",
    "9249": "VUTELECOM-01-VU-AP Telecom Vanuatu Limited",
    "9250": "FLEETONLINE-AP Network Access via Frame Relay using unbundled (BGP4)",
    "9251": "SPEEDNET-AP PT Speed Internet Digital",
    "9252": "COLONIAL--AP Colonial is a major all-finance institution.",
    "9253": "TVB-HK TVB.COM LIMITED",
    "9254": "DELMONTE--PH-AP Del Monte Philippines, Inc.",
    "9255": "CONNECTPLUS- Singapore Telecom",
    "9256": "YAHOO-PH Gaming firm which will peer directly with different ISPs in the Philippines",
    "9257": "QLD-CEMENT-BRISBANE-AP QLD Cement Internet Connection",
    "9258": "CITEC-NSW-AP CITEC",
    "9259": "WEBHOST--AP Web Host Limited",
    "9260": "MULTINET--AP Multinet Pakistan Pvt. Ltd.",
    "9261": "COMMBANK--AP Commonwealth Bank of Australia",
    "9262": "SANFORD--AP Sanford Securities Pty Ltd",
    "9263": "PCCW-IMSBIZ-AP PCCW Business",
    "9264": "NET Academic Sinica Network",
    "9265": "SPRINT-ONLINE--AP Sprint Online",
    "9266": "MOXROX-AU MOXROX PTY LIMITED",
    "9267": "SPACENET--AP Silknet",
    "9268": "OVERTHEWIRE--AP Over The Wire Pty Ltd",
    "9269": "HKBN--AP Hong Kong Broadband Network Ltd.",
    "9270": "APAN-KR- National Infomation Society Agency",
    "9271": "WKUNET- Wonkwang University",
    "9272": "HANCOMNET- Hangul & Computer Co, Ltd.",
    "9273": "SICC- Ssangyong Information Communication Corp (SICC)",
    "9274": "PUSAN--KR Pusan National University",
    "9275": "KI--KR Korea Astronomy & Space Science Institute",
    "9276": "CHINAE--KR chinae savings bank",
    "9277": "THRUNET--KR Hanaro Telecom Inc.",
    "9278": "DYNAMITE--AP Dynamite Internet",
    "9279": "EDS-AU- EDS (Australia) Pty Ltd",
    "9280": "CIA- Bucan Holdings Pty Ltd",
    "9281": "PNIX-NZ-AP Palmerston North Internet Exchange",
    "9282": "LEXICON- Lexicon Systems Pty Ltd",
    "9283": "INSPIREIT--AP Inspire IT Pty Ltd",
    "9284": "VICONE-AAPT- VicOne",
    "9285": "IBSPLC--AP Technopark, Trivandrum, India",
    "9286": "LGH--KR LGHitachi",
    "9287": "TRUEIDC--AP TRUEINTERNET Co.,Ltd.",
    "9288": "COMCEN--AP Com-Cen Pty Ltd",
    "9289": "MPT-HK-AP M PACIFIC TECHNOLOGY LIMITED",
    "9290": "GOHOSTING--AP  GoHosting",
    "9291": "APACOMM--AP APA Communications",
    "9292": "TEMEK-POLY- Temasek Polytechnic Singapore",
    "9293": "ARCSTAR-HK--AP Arcstar-hk Route server",
    "9294": "GIT--AP Generation IT",
    "9295": "LOGICWORLD--AP Logic World Pty Ltd",
    "9296": "SPIRIT--AP Spirit Networks Pty Ltd",
    "9297": "COLOCITY--AP Colocity Pty Ltd",
    "9298": "GHXTNET Beijing GuanghuanXuntong Digital Technology Co.,LTD.",
    "9299": "IPG--AP Philippine Long Distance Telephone Company",
    "9300": "SOUTHCOM-AP- Southern Computer Services",
    "9301": "EWN--AP Emery Corporation Pty Ltd T/ West Australian Network",
    "9302": "IISGROUP--AP IIS Group Pty Ltd",
    "9303": "KCCS--AP KC Computer Service Ltd.,",
    "9304": "HUTCHISON--AP Hutchison Global Communications",
    "9306": "CIECC--AP China International Electronic Commerce Center",
    "9307": "CMNET China Motion Telecom Development Co.",
    "9308": "CHINA-ABITCOOL Abitcool(China) Inc.",
    "9309": "OZEMAIL-SAT--AP Ozemail/Access One Satellite",
    "9311": "HITRON--AP HITRON TECHNOLOGY INC.",
    "9312": "RBSFM--AP RBS Financial Market, Banking & Finance, Hong Kong",
    "9313": "ONTHENET- Network Technology (AUST) P/L",
    "9314": "MELBPCUG-AP- Melbourne PC User Group Inc",
    "9315": "DOFWA2--AP Department of Finance - Western Australia",
    "9316": "DACOM-PUBNETPLUS--KR DACOM PUBNETPLUS",
    "9317": "ITISNET- Inha University",
    "9318": "HANARO- Hanaro Telecom Inc.",
    "9319": "HCNCHUNGJU--KR CHEONGJU CABLE TV SYSTEMS",
    "9320": "BREGISTRY--KR Ministry of Court Administration",
    "9321": "HYUNET- Hanyang University",
    "9322": "EWHANET1- Institute of Information and Computing, EWHA WOMANS UNIV.",
    "9323": "DGUNET- Dongguk University Information Management Center",
    "9324": "CYNET--AP Cynet & Total Network Support",
    "9325": "XTRA- Telecom XTRA, Auckland",
    "9326": "CENTRIN--AP PT Centrin Utama",
    "9327": "HOPCOUNT Hopcount Limited",
    "9328": "GLOBALCENTER-AU Datacom Victoria",
    "9329": "SLTINT--AP Sri Lanka Telecom Internet",
    "9330": "SATINTSERV--AP SAT Internet Services",
    "9331": "LUVIC--AP Luvic Pty. Ltd.",
    "9333": "INTINFOSHI-AU- Internet Information Super Highway Pty Limited",
    "9334": "TTECH--AP Tridel Technologies, Inc",
    "9336": "WWWIRES-AU World Without Wires Pty Ltd",
    "9337": "HKG-RET--AP UUNET",
    "9338": "NATLIB-NZ--AP National Library of New Zealand",
    "9339": "RESERVE-CSLOXINFO-TH CSLOXINFO",
    "9340": "INDONET--AP INDO Internet, PT",
    "9341": "ICONPLN-ID-AP PT Indonesia Comnets Plus",
    "9342": "ABCNET--AP Australian Broadcasting Commission",
    "9343": "ACTRIX-NZ--AP Actrix Networks Ltd",
    "9344": "VOYAGER-NZ- Voyager NZ Ltd",
    "9345": "PARADISE- Paradise Net",
    "9346": "CYNEX--AP Cynex Communications Corporation",
    "9347": "INOCNET--AP Inocnet  of Patni, for the NOC Project",
    "9348": "SLVTSD-CBN-AP Victorian Cultural Network",
    "9351": "ZLAN ZTV CO.,LTD",
    "9352": "KUMAGAYA KuMaGaYaNet",
    "9353": "MEDIAWARS MEDIAWARS co.,ltd.",
    "9354": "TDNC Community Network Center Inc.",
    "9355": "NICT National Institute of Information and Communications Technology",
    "9357": "FNC NRI SecureTechnologies, Ltd.",
    "9358": "KISWEB Kanden Information Systems Company,Incorporated",
    "9363": "NET-TECH FUJITSU KANSAI-CHUBU NET-TECH LIMITED",
    "9365": "ITSCOM its communications Inc.",
    "9366": "SOLITON SOLITON-NET",
    "9367": "TITECH Tokyo Institute of Technology",
    "9370": "SAKURA-B SAKURA Internet Inc.",
    "9371": "SAKURA-C SAKURA Internet Inc.",
    "9372": "UEC The University of Electro-Communications",
    "9374": "EDION EDION Corporation",
    "9376": "SAKURANET SMARTVALUE Co.,Ltd.",
    "9378": "CABLENET Cablenet SAITAMA",
    "9380": "AITAI-NET Himawari Network Inc.",
    "9381": "NEWTT-IP-AP Wharf T&T Ltd.",
    "9382": "ITFARM-QLD-AP The IT Farm",
    "9383": "DEST- Department of Education Science and Training, Federal",
    "9384": "CYBERONE- Cyberone Pty Ltd",
    "9385": "US-POP1-AP Voicestream Pty Ltd,",
    "9386": "DESTINY--AP Destiny Inc.",
    "9387": "AUGERE-PK AUGERE-Pakistan",
    "9389": "UNSPECIFIED BEIJING SHENZHOU GREATWALL COMMUNICATION",
    "9391": "UNSPECIFIED GUANGDONG HIGHWAY BROADBAND NETWORK SERVICE CENTE",
    "9393": "UNSPECIFIED INFORMATION CENTER OF BEIJING SCIENCE AND TECHNOLOGY COMMISION",
    "9394": "CTTNET China TieTong Telecommunications Corporation",
    "9395": "GUOXIN-BILIN BeiJing Guoxin bilin Telecom Technology Co.,Ltd",
    "9396": "TIKONAINFINET--2 Tikona Infinet Ltd",
    "9397": "INET-TH-AP Internet Thailand Company Limited",
    "9398": "9398-AMCOM-AP Amcom Telecommunications Ltd.",
    "9399": "FRONDE--AP Fronde Systems Group Ltd",
    "9400": "INTERNETACCESS- Internet Access",
    "9401": "NLC-CN- National Library of China",
    "9402": "SIC-CN- State Information Center",
    "9403": "ISTIC-CN- Institute of Scientific and Technical Information of China",
    "9404": "NETSLAND-CN- NETSLAND Center",
    "9405": "TPS-CN- Test platform Service Center",
    "9406": "NSFCNET-CN- NSFC High Speed Testbed",
    "9407": "DRAGONTAP-CN- DRAGONTAP Internet Transit Access Point",
    "9408": "GJAMES--AP G James Glass and Aluminium",
    "9409": "CITYLINE--HK CityLine (Hong Kong) Limited",
    "9411": "NONTRINET--AP Kasetsart University",
    "9412": "HCDS--AP Hostworks Content Delivery System",
    "9413": "FTTH-ISP-TH-AP Fiber To The Home Co., Ltd.",
    "9414": "INNODATA-MNL--PH Innodata-ISOGEN, Inc",
    "9415": "ETWEBS-1-AP ETWebs Taiwan Co. Ltd.",
    "9416": "MULTIMEDIA--AP Hoshin Multimedia Center Inc.",
    "9417": "VERVEENERGY--AP Verve Energy",
    "9418": "CA-IAPAC--AP Computer Associates Asia Pacific",
    "9419": "NTU--AP Nanyang Technological University",
    "9420": "HKC--AP Hong Kong Communications Co. Ltd.",
    "9421": "EISNET--AP eis.net",
    "9422": "SOLNET-ID PT SOLNET INDONESIA",
    "9423": "MRBEAN--AP Mr Bean's Internet",
    "9424": "WIDEBAY2020--AP Qld Dept Local Govt and Planning",
    "9425": "CONCENTRIX-PH--AP Concentrix Technologies, Inc",
    "9426": "WESTPAC--AP Westpac Bank",
    "9427": "TOWER--AP Star Online Services",
    "9428": "NETEFFECT-AU-AP The Net Effect Pty Ltd.",
    "9429": "ACAY-AU-AP Acay Internet Ltd.",
    "9430": "STPI-NOIDA Software Technology Parks of India,Block-IV",
    "9431": "AKUNI-NZ The University of Auckland",
    "9432": "CANTERBURY- University of Canterbury",
    "9433": "MSEY- Massey University",
    "9434": "KRDL-NET-AP Kent Ridge Digital Labs",
    "9435": "SUNCORP--AU-AP SUNCORP",
    "9436": "GLOBENET- Globe.Net",
    "9437": "DESIIN--AP Desiin",
    "9438": "NETRO--AP Netro",
    "9439": "WIX-CITYLINK-NZ-AP Wellington Internet Exchange (Citylink)",
    "9440": "JWT--AP JWT Co Ltd",
    "9441": "NEXT-BD Next Online Limited",
    "9442": "MINDGATE--AP Mindgate Systems, Inc.",
    "9443": "INTERNETPRIMUS--AP Primus Telecommunications",
    "9444": "HKT--AP Hong Kong Telecommunications (HKT) Limited",
    "9445": "N-SATURN-NZ  # -SATURN-NZ CONVERTED TO N-SATURN-NZ FOR RPSL COMPLIANCE Saturn Communications Ltd",
    "9446": "ULTRANET--AP Ultranet",
    "9447": "FORD--AP Ford Motor Company of Australia",
    "9448": "IDNIC-ID Indonesia Network Information Center",
    "9449": "RPI--AP RP Internet Services",
    "9450": "WEBEXAPNIC--AP Webex Communications Inc",
    "9452": "KUNET- Korea University",
    "9453": "SOONGSIL- Soongsil University",
    "9454": "AHA--KR American Home Assurance Korea",
    "9455": "EDUNET- KERIS",
    "9456": "POSCO- POSCO",
    "9457": "DREAMX- DREAMLINE CO.",
    "9458": "BMTC- eyesvision",
    "9459": "KONKUK Konkuk University",
    "9460": "IBM-USF-BH-AP IBM Global Services Australia",
    "9461": "NET2000--AP Net2000 Pty Ltd",
    "9462": "BOLEH-NET-AP BOLEHNET-N",
    "9463": "ESSENTIALENERGY--AP ESSENTIAL ENERGY",
    "9464": "PSU-TH--AP Prince of Songkla University (Sritrang'NET)",
    "9465": "NETSERV--AP PO Box A200",
    "9466": "UUNET-JP-AP UUNET Japan Limited",
    "9467": "UUNET-AU-AP UUNET Australia",
    "9468": "IBLLC-HK INTERACTIVE BROKERS LLC",
    "9469": "N-TERABYTE-NZ-AP  # -TERABYTE-NZ-AP CONVERTED TO N-TERABYTE-NZ-AP FOR RPSL COMPLIANCE Terabyte Interactive Ltd",
    "9470": "N-COMPS-NZ-AP  # -COMPS-NZ-AP CONVERTED TO N-COMPS-NZ-AP FOR RPSL COMPLIANCE Compass Communications",
    "9471": "MANA-PF-AP MANA S.A.",
    "9472": "PSL-AU Level 23, Exchange Plaza",
    "9473": "BOURSEDATA--AP Bourse Data Australia",
    "9474": "SMARTONE--AP SmarTone Telecommunications Ltd.",
    "9475": "WU-TH-AP Walailuk University",
    "9476": "INTRAPOWER--AP IntraPower Pty. Ltd.",
    "9477": "IRG--AP Internet Reach Group",
    "9478": "MICRO2000--AP Micro 2000 Ltd. - Border",
    "9479": "OTG-AU Operations & Technology Group",
    "9480": "SHOALI-OPTUS-AP SHOALHAVEN INTERNET",
    "9481": "DIALONE--AP Dial One Internet Services Pty Ltd",
    "9482": "N-PLATFORM-AP Platform Networks Pty Ltd",
    "9483": "FLATNET--NZ Flatnet Networks",
    "9484": "MOBINET--MN Mobinet LLC.  Mobinet Internet Service Provider",
    "9485": "INTERNETTV- Internet TV Australia Pty Ltd",
    "9486": "KMITL-AP King Mongkut's Institute of Technology Ladkrabang",
    "9487": "JUNGBUVITSSEN--KR tbroad chungbu broadcasting co.,ltd.",
    "9488": "SNU--KR Seoul National University",
    "9489": "KARINET- Korea Aerospace Research Institute",
    "9490": "NIS- Oscar Enterprise",
    "9491": "ABLEX-N ABLEX Co., Ltd.",
    "9492": "MAEKYUNG- Maeil Business Newspaper",
    "9493": "SHS- SHIN HEUNG SECURITIES CO., LTD.",
    "9494": "KOSINET- National Infomation Society Agency",
    "9495": "CLEARVIEW- Clearview Communications",
    "9496": "HAFARI- Hafari Pty Ltd",
    "9497": "DIGITELONE Digital Telecommunications Philippines Inc.",
    "9498": "BBIL-AP BHARTI Airtel Ltd.",
    "9499": "BIGAIR-AU BigAir Group,",
    "9500": "VODAFONE-TRANSIT- Vodafone NZ Ltd.",
    "9501": "PBC-  number of Chemical & Metallurgical Design Co. Ltd. (PBC)",
    "9502": "OOCL-HKG-AP Hong Kong Headquarters",
    "9503": "FX-PRIMARY- FX Networks Limited",
    "9505": "TWGATE-AP Taiwan Internet Gateway",
    "9506": "MAGIX-SG-AP Magix Broadband Network",
    "9508": "THENET--AP The Net Enterprises",
    "9509": "DEWRSB-AU-AP Department of Employment, Workplace Relations",
    "9510": "NETEXCEL--AP Saxby Enterprises T/A NetExcel",
    "9511": "WILSONHORTON--AP Wilson and Horton",
    "9512": "NETLOGISTICS-AU-AP Net Logistics Pty. Ltd.",
    "9513": "HKCABLE-HK-AP HK Cable TV Ltd",
    "9514": "APIC-AP Asia-Pacific Inter-Carrier services",
    "9515": "SMART-NTT--AP Smart-NTT Multimedia, Inc.",
    "9516": "SUNFLOWERTEL  for Sunflower Telecom",
    "9517": "CATHEDBNE--AP Brisbane Catholic Education",
    "9518": "JDV-AU-AP JDV Limited",
    "9519": "VERTELNET Vertical Telecoms Pty Ltd",
    "9520": "DAOHENG--AP DaoHeng Bank",
    "9521": "KATECH--KR Korea Automotive Technology Institute",
    "9522": "GOODCYBER- Good Morning Securities",
    "9523": "MOKWON--KR Mokwon University",
    "9524": "HMC- HYUNDAI MOTOR COMPANY",
    "9525": "DONGBU- DONGBU Securities CO.",
    "9526": "KOSCOM--KR KOSCOM",
    "9527": "PCNTV--KR puchuncablenetwork",
    "9528": "CBE--KR chungcheongbuk-do office of education",
    "9529": "HYUNDAICARD--KR HYUNDAICARD CO.",
    "9530": "SHINSEGAE- SHINSEGAE I&C Co., Ltd.",
    "9531": "GEDU--KR Kwangju City Office Of Education",
    "9532": "SECURITIES- Daewoo Securities Co., Ltd.",
    "9533": "KMITNB--AP King Mongkut's Institute of Technology North Bangkok",
    "9534": "MAXIS-1-AP Binariang Berhad",
    "9535": "ONE-NET-HK INTERNET-SOLUTION -HK",
    "9536": "SONY-HK- Sony Corporation of Hong Kong Ltd",
    "9537": "LEVEL48-NZ-AP Level48 Ltd",
    "9538": "OFTA--AP Office Of The Telecommunications Authority",
    "9539": "KOOS--AP Hoshin Multimedia Center Inc.",
    "9540": "NETWORK-GAMING--AP Australian National Hotels",
    "9541": "CYBERNET-AP Cyber Internet Services (Pvt) Ltd.",
    "9543": "WESTNET--AP Westnet Internet Services",
    "9544": "PIP--AP Clarenston T/A Preferred Internet Provider",
    "9545": "HUTCHISON-PRICELINE--AP HUTCHISON PRICELINE HK",
    "9546": "SNAKER--AP Ministry of University Affairs",
    "9547": "STGEORGE-AU-AP St George Bank Limited",
    "9548": "INET--AP InternetPCI",
    "9549": "BROADBANDNET-ISP--AP BROADBANDNET ISP",
    "9550": "VIVANET-AU-AP Vivanet Pty Ltd",
    "9551": "KMUTT-AP King Mongkut's University of Technology",
    "9552": "DHSNET--AP Department of Human Services",
    "9553": "GLOBALWEB--AP Global Web Pty Ltd",
    "9555": "VZB-AU- Verizon Australia PTY Limited",
    "9556": "ADAM--AP Adam Internet Pty Ltd",
    "9557": "PKTELECOM--PK Paknet Limited Merged into PTCL",
    "9559": "PLAINCOM-NZ Plain Communications Ltd",
    "9560": "APE-NZ Auckland Peering Exchange",
    "9561": "RELAX-AP Relax Internet Enterprises",
    "9562": "MSU-TH-AP Mahasarakham University",
    "9563": "APEX--AP Apex Internet",
    "9564": "ANZ-BANK-AP Australia and New Zealand Banking Group Limited",
    "9565": "WCG-AP Wholesale Communications Group",
    "9566": "WEBEXPRESS--AP Web Express",
    "9567": "VRC--AP Victoria Racing Club",
    "9568": "LOTTECARD--KR LOTTE CARD",
    "9569": "HCNSEOCHOCATV--KR SEOCHO CABLE SYSTEMS CO., LTD.",
    "9570": "DAEDONG--KR Daedong College",
    "9571": "INICIS- INICIS Co., Ltd",
    "9572": "HUFSNET- Hankuk University of Foreign Studies Computer Center",
    "9573": "KRFUTURES--KR KR Futures Inc",
    "9574": "NYLKOREA--KR New York Life Insurance, Ltd.",
    "9575": "KCTC--KR KCTC",
    "9576": "SOOKMYUNG- SOOKMYUNG WOMEN'S UNIVERSITY",
    "9577": "KYOBOTRADE- KYOBO SECURITIES",
    "9578": "CJNET- Cheiljedang.Co.Inc.",
    "9579": "SHINYOUNG- Shinyoung Securities CO ., LTD.",
    "9580": "REED-ELSEVIER-IND-APAC-AP Reed Elsevier multi homes ISP connectivity for India staff (Not Transit)",
    "9581": "TELSTRAGLOBAL-ID--AP TTPL",
    "9582": "TELSTRAGLOBAL-SG--AP Telstra Global - Customer  Number",
    "9583": "SIFY--IN Sify Limited",
    "9584": "GENESIS-AP Diyixian.com Limited",
    "9585": "VISION--AP Vision Internet Services",
    "9586": "HKCL--AP Hong Kong CyberLibrary",
    "9587": "DTACNETWORK-TH-AP 26th Floor  333/3 Moo 14 Chai Building",
    "9588": "BRIDGE-ONLINE--AP Bridge Online Systems",
    "9589": "UUNET--AP UUNET Hong Kong Ltd.",
    "9590": "SEHK-AP The STock Exchange of HK Ltd.",
    "9591": "NIFS National Institute for Fusion Science",
    "9592": "PRISM SOFTBANK TELECOM Corp.",
    "9593": "NIKKEI Nikkei Inc.",
    "9594": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9595": "XEPHION NTT-ME Corporation",
    "9596": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9597": "CPI-NET KDDI Web Communications Inc.",
    "9598": "MPLS-OCN NTT Communications Corporation",
    "9599": "INFOPEPPER EJWORKS CORPORATION",
    "9600": "SONYTELECOM Sony Business Solutions Corporation",
    "9601": "SHIBATA Niigata Communication Service",
    "9602": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9603": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9604": "FSI- FUJI SOFT INCORPORATED",
    "9605": "MOPERA NTT DoCoMo, Inc.",
    "9606": "IS- Institute of Space and Astronautical Science, Japan Aerospace Exploration Agency",
    "9607": "BBTOWER BroadBand Tower, Inc.",
    "9608": "HAPPY JAPAN BiNAL INC.",
    "9609": "EACCESS eAccess Ltd.",
    "9610": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9611": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9612": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9613": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9614": "OCT Oita Cable Telecom Co,ltd.",
    "9615": "TEES TOYOHHI CABLE NETWORK INC.",
    "9616": "MUX WIDE Project",
    "9617": "ZAQ KANSAI MULTIMEDIA SERVICE COMPANY",
    "9618": "TCN catv-tokushima",
    "9619": "SSD Sony Global Solutions Inc.",
    "9620": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9621": "II-OKINAWA Okinawa Telecommunication Network Co.,Inc",
    "9622": "KCT Kurashiki Cable TV",
    "9623": "N-ATHOMEAU-AP  # -ATHOMEAU-AP CONVERTED TO N-ATHOMEAU-AP FOR RPSL COMPLIANCE @Home Network Australia Routing Domain.",
    "9624": "BNP-AUSTRALIA-AP Banque Nationale de Paris",
    "9625": "PACIFIC-INTERNET-INDIA-N Pacific Internet India Pvt. Ltd.",
    "9626": "SEVEN-NETWORK-AP Optus Customer Network",
    "9627": "TCR-AP TCR Holdings Ltd",
    "9628": "SSEM--KR Seoul Education Science Research Institute",
    "9629": "HYUNDAICAPITAL--KR hyundaicapital",
    "9630": "WEBTRADE- SK Securities Limited",
    "9631": "KRC--KR Korean Red Cross",
    "9632": "SDCNET--KR SEOUL DAIRY Co.",
    "9633": "SLC--KR SUDOKWON Landfill Site Management Corp",
    "9634": "SHNS- GOODMORNING SHINHAN SECURITIES Co., Ltd.",
    "9635": "PUFS- Pusan University of Foreign Studies",
    "9636": "SEONAM- SEONAM Infromation Telecom Co., Ltd.",
    "9637": "DANKOOKUNIV--KR Dankook  University",
    "9638": "NH- National Agricultural Cooperative federation",
    "9639": "DIT--KR Dongeui Institute of Technology",
    "9640": "KRCERT--KR Korea Information Security Agency",
    "9641": "KDB--KR Korea Development Bank",
    "9642": "KISA Korea Information Security Agency",
    "9643": "SIGNGATE- Korea Information Certificate Authority",
    "9644": "SKTELECOM-NET- SK Telecom",
    "9645": "HYUNDAIFUTURES- HYUNDAI FUTURES CORPORATION",
    "9646": "EGIOS- eGIOS",
    "9647": "SEOULMETRO- Seoul Metropolitan Government",
    "9648": "N-OZONLINE-AU  # -OZONLINE-AU CONVERTED TO N-OZONLINE-AU FOR RPSL COMPLIANCE Australia On-Line Pty Ltd",
    "9649": "MOPH-TH-AP Information Technology Office",
    "9650": "CITEC-AU-AP QLD Government Business (IT)",
    "9651": "THECITYBANK-BD Jibon Bima Tower (4th Floor)",
    "9652": "ECN--AP ECN Internet",
    "9653": "SUNPHARMA59-IN Acme Plaza",
    "9654": "POWERBANDNET--AP Powerband Networks,",
    "9655": "TPMNETWORK--AP TPM Corp. Berhad,",
    "9656": "T-SYSTEMS-SG T-SYSTEMS SINGAPORE PTE LTD",
    "9657": "MELSANET-ID-AP Melsa-i-net",
    "9658": "ETPI-IDS--AP Eastern Telecoms Phils., Inc.",
    "9659": "VOCUS-DSL- Vocus National DSL Network",
    "9660": "KANNET--AP Telecommunication and ISP company",
    "9661": "MORGANSTOCK-AP Morgan Internet Gateway",
    "9662": "EYNET--AP Easynet Internet",
    "9663": "KARRATHA--AP Karratha Internet Support Services",
    "9664": "INDIGO--AP Indigo Networks",
    "9665": "POSTDEPT--AP Hong Kong Post Office Dept.",
    "9666": "STFYAPACNET-N Stratify Software India Ltd.",
    "9667": "HOSTWORKS--AP Hostworks Pty Ltd",
    "9668": "AMLINK-AP AMLINK Technologies",
    "9669": "ANDOR--AP Andor Systems Aust Pty Ltd",
    "9670": "MANILA-IX Manila Internet Exchange",
    "9671": "TRADEVAN--AP Trade-Van Informaiton Services Co.",
    "9672": "WEST-AUSTRALIAN-NEWSPAPERS-AP Optus Customer Network",
    "9673": "ARUMBA--AP Arumba Investments",
    "9674": "FET-TW Far EastTone Telecommunication Co., Ltd.",
    "9675": "EINVEST-TW Internet Service Provider",
    "9676": "SAVECOM-TW SaveCom Internation Inc.",
    "9677": "TELNET-TW Taiwan Telnet Corporation",
    "9678": "TIPO Taiwan Internet Peering Organization",
    "9679": "IONET IONET Taiwan Co., Ltd.",
    "9680": "HINETUSA HiNet Service Center in U.S.A",
    "9681": "NBEN-TW National Broadband Experiment Network, sponsored by NSC, TAIWAN",
    "9682": "MBF-AP Medical Benefit Funds of Australia",
    "9683": "DIGITALSYSTEM- C&M Kyonggi Cable TV",
    "9684": "HANWHA- HANWHA Corp./Information Service div.",
    "9685": "HANJINSEC- Meritz SECURITIES CO. LTD",
    "9686": "SKKUNET- SungKyunKwan University (SKKU)",
    "9687": "ICU- Korea Advanced Institute of Science and Technology",
    "9688": "ICFC--KR ICFC",
    "9689": "FCABLE- Qrix, Inc.",
    "9690": "SEOUL_SIGN--KR nca",
    "9691": "KYUNGSUNG- KYUNGSUNG UNIVERSITY",
    "9692": "HWS- HANWHA SECURITIES CO .,LTD",
    "9693": "KFTCCA- Korea Financial Telecommunications & Clearings Institute",
    "9694": "SEOKYUNG-CATV--KR Seokyung Cable Television Co..LTD.",
    "9695": "KITINET- KT Solutions Coprporation",
    "9696": "ED- Oscar Enterprise",
    "9697": "CJHAEUNDAEGIJANG--KR CJ CableNet HaeundaeKijang Corp.",
    "9698": "YOUNGDOONG--KR YoungdongBroadcastingSystem,inc",
    "9699": "KFB- Korea First Bank",
    "9700": "KRNIC--KR Korea Network Information Center",
    "9701": "KRLINE- KrLine Internet Service Inc.",
    "9702": "CHB- CHOHUNG BANK",
    "9703": "SHB- Shinhan Bank",
    "9704": "DONGWON- DONGWON SECURITIES CO., LTD",
    "9705": "OKSKHOME- SK C&C",
    "9706": "PETISNET- BUSAN EDUCATION RESEARCH & INFORMATION CENTER",
    "9707": "WORKNET- Korea Employment Information Management Agency",
    "9708": "PKNU- Pukyong National University",
    "9709": "KISVAN--KR KIS Information&Communication,Inc",
    "9710": "NEOWIZ--KR NeoWiz Corporation",
    "9711": "KERINET- Kyonggi provin educational information research institute",
    "9712": "KPIN--KR INet Technologies Co., Ltd.",
    "9713": "VTAC--AP Victorian Tertiary Admissions Centre",
    "9714": "INTERNETPRIMUS--AP Primus Telecommunications",
    "9715": "SCB-BORDER--AP Siam Commercial Bank",
    "9716": "FOXTEL--AP FOXTEL Management Pty Ltd",
    "9717": "MELB-IT-AP Melbourne IT",
    "9718": "KORDIA-AU--AP Kordia Solutions Australia",
    "9719": "IDSAFE-AP ID.Safe Pte Ltd",
    "9720": "MTN-AP MTN Net Design (a division of Dyltax ACN 003 308 361)",
    "9721": "SEEHU--AP GUANGXI  SEEHU TECHNOLOGY CO.,LTD",
    "9722": "PIPE--AP PIPE Networks",
    "9723": "ISEEK--AP ISEEK Ltd",
    "9724": "MISSION--AP Mission Internet",
    "9725": "WINSHOP--AP WinShop Services",
    "9726": "CCI-HK-AP Internet Service Provider",
    "9727": "WOOSHWIRELESSNZ Woosh Wireless Ltd",
    "9728": "MP-AIRZED-MY AIRZED ISP",
    "9729": "IS-AP iAdvantage Limited",
    "9730": "BHARTITELESONIC--IN-AP Bharti Telesonic Ltd",
    "9731": "STTP--SG-AP ST Teleport Pte Ltd",
    "9732": "SCIG--AP CENTRAL INTERNET SERVICES",
    "9733": "NETSPACE--NZ-AP Netspace Services Limited",
    "9734": "SENSATION--AP Sensation Internet Services",
    "9735": "HKDNR--AP Hong Kong Domain Name Registration Co. Ltd",
    "9736": "N-DOMAINZ-NZ  # -DOMAINZ-NZ CONVERTED TO N-DOMAINZ-NZ FOR RPSL COMPLIANCE Domainz",
    "9737": "TOTNET-TH--AP TOT Public Company Limited",
    "9738": "BRENNANIT-9738-AP Brennan IT",
    "9739": "ACIA--AP ACIA Communications Sdn Bhd, Network Service Provider, Kuala Lumpur, Malaysia",
    "9740": "TELSTRAGLOBAL-CWNSS-SG--AP Telstra Global - Customer  Number",
    "9741": "UTCC-TH 126/1  Vibhavadee-Rangsit Road, Bangkok 10400, Thailand",
    "9742": "GVBROADCT--AP GV Broadcast System, Inc., ISP using VSAT Technology with NOC in Angeles City Pampanga",
    "9743": "DATACARDSERVICES-AP Data Card Services",
    "9744": "SIMCENTRIC--AP SIMCENTRIC SOLUTIONS LIMITED",
    "9745": "WANET--AP WAnet  number",
    "9746": "IGOLD--AP Online Interactive gaming solution",
    "9747": "EZINTERNET--AP EZInternet Pty Ltd",
    "9749": "GPKNET--AU GPK Computers Pty Ltd, Internet Service Provider, Melbourne",
    "9750": "FCLNZ-AP Fletcher Challeng Group Internet Access and eCommerce Gateway",
    "9751": "N-SAMOATELCO-AP  # -SAMOATELCO-AP CONVERTED TO N-SAMOATELCO-AP FOR RPSL COMPLIANCE AMERICAN SAMOA TELECOMMUNICATIONS AUTHORITY",
    "9752": "FKNET-IN Flipkart India Pvt Ltd",
    "9753": "DAU- Dong-A Universirty",
    "9754": "CSU- CHOSUN UNIVERSITY",
    "9755": "TT- Today and Tomorrow",
    "9756": "CHEONANVITSSEN--KR Cheonan Broadcast Corporation",
    "9757": "CMBI--KR CMB DONGSEO BROADCTING",
    "9758": "HANNET- KOREA COMPUTER IDC",
    "9759": "CJCYBER- HIINVESTMENT SECURITIES CO., LTD",
    "9760": "KTIS Korea Telecom",
    "9761": "KUMHO- Asiana Airlines",
    "9762": "HCN- HYUNDAI COMMUNICATIONS & NETWORK",
    "9763": "AFFIS- KIC for Agriculture",
    "9764": "DAUM-NET Daum Communication Co.,LTD",
    "9765": "VTOPIA--KR VTOPIA",
    "9766": "SHINHANLIFE1 SHINHAN LIFE INSURANCE CO.,LTD.",
    "9767": "DONGBUIT--KR Dongbulife Insurance co.,LTD",
    "9768": "PUBNET1- KT",
    "9769": "SEJONG- Sejong University",
    "9770": "SPEEDONSTV--KR SOOSUNG CABLE TELEVISION INC",
    "9771": "KISTEP- KISTEP",
    "9772": "SENS--KR Seobu District Office of Education in Seoul",
    "9773": "WOMENPRO--KR KYONGGIDO WOMEN CENTER",
    "9774": "DSU- dongseo university",
    "9775": "HANNAM- Hannam University",
    "9776": "KBSTAR Kookmin Bank",
    "9777": "KJU-NET--KR Gyeongju University",
    "9778": "DAEJIN- DAEJIN UNIVERSITY",
    "9779": "LGFUTURES- LG FUTURES",
    "9780": "INJE- INJE UNIVERSITY",
    "9781": "GCS--KR GREEN CABLE TELEVISION",
    "9782": "WOOSONGEDU WooSong University",
    "9783": "DLA--KR DRIVER'S LICENSE AGENCY",
    "9784": "KGI- KGI SECURITIES",
    "9785": "JATELNET--ID Jasa Terpadu Telematika (Jasatel)",
    "9786": "BELTEK-AU-AP Beltek Australia",
    "9787": "CONCEPT-AU-AP Concept Networks",
    "9788": "IRD-NZ--AP New Zealand Inland Revenue - Te Tari Taake",
    "9789": "N-DATACOM-AP  # -DATACOM-AP CONVERTED TO N-DATACOM-AP FOR RPSL COMPLIANCE Datacom Co.,Ltd",
    "9790": "CALLPLUS-NZ-AP CallPlus Services Limited",
    "9791": "PERDANA-ID--AP PERDANA Network  Content Service Provider",
    "9792": "CIS--AP Corinthian Engineering Pty Ltd",
    "9793": "SMART-HK-AP Smart-bets.com Lmited",
    "9794": "DNET-ID-AP PT. Core Mediatech (D-NET)",
    "9795": "AFFINITYHEALTH--AP Affinity Health, Health Services,  Melbourne Australia",
    "9796": "WIPRO Internet Service Providers",
    "9797": "NEXONIAPACIFIC--AP Nexon Asia Pacific P/L",
    "9798": "RIM-SG 1 International Business Park",
    "9799": "NPGX--AP NPGX Pty Ltd",
    "9800": "UNICOM CHINA UNICOM",
    "9801": "ZGCIE-CNNIC Beijing Zhongguancun Information Technology Co. Ltd",
    "9802": "CHINA-ABITCOOL Abitcool(China) Inc.",
    "9803": "JINGXUN Beijing Jingxun Public Information Technology Co., Ltd",
    "9804": "JIUZHOUFUTURE Beijing JiuZhou Future Technology Co.,Ltd.",
    "9806": "BJENET Beijing Educational Information Network Service Center Co., Ltd",
    "9807": "GOVSTATS Data Management Centre National Bureau of Statistics of China",
    "9808": "CMNET-GD Guangdong Mobile Communication Co.Ltd.",
    "9809": "NOVANET Nova Network Co.LtdRoom 1205, Building A, Science & Technology Innovation Plaza, Tianan Cyber Park, Futian District, District, Shenzhen,China",
    "9810": "TNSNET Beijing Times Netstar Technology Co.,Ltd",
    "9811": "BJGY srit corp.,beijing.",
    "9812": "CNNIC-CN-COLNET Oriental Cable Network Co., Ltd.",
    "9813": "UNSPECIFIED Beijing  Capital-online  science development Co.,Ltd.",
    "9814": "FIBRLINK Beijing FibrLINK Networks Co.,Ltd.",
    "9815": "EPERN Beijing Gold First System Engineering Co.,Ltd",
    "9817": "ETNSBBNETWORK Guangdong Belton Telecommunications Technology Development Co.,Ltd.",
    "9818": "UNIHUB UniHUB Global Network",
    "9819": "WSNET Beijing Teletron Telecom Engineering Co., Ltd.",
    "9820": "PERTHIX3--AP Perth iX",
    "9821": "DOST-PH-AP Department of Science and Technology",
    "9822": "AMNET-AU-AP Amnet IT Services Pty Ltd",
    "9823": "NCS-PEARSON--AP Education Web Hosting",
    "9824": "N-ATHOMEJP # -ATHOMEJP CONVERTED TO N-ATHOMEJP FOR RPSL COMPLIANCE Technology Networks Inc.",
    "9825": "SDNP-BD- Sustainable Development Networking Program",
    "9826": "ILINK-HK-AP iLink.net Ltd",
    "9827": "AGILENT--AP Agilent Technologies Asia-Pacific Zone",
    "9828": "HKCIX-GLOBAL--AP HKCIX  Number for Global Infrastructure",
    "9829": "BSNL-NIB National Internet Backbone",
    "9830": "SWIFTONLINE--AP SWIFT ONLINE BORDER",
    "9831": "UNIGATE--AP  NO. FOR UNIGATE TELECOM INC.",
    "9832": "ISN--AP ISN, Internet Service Provider",
    "9833": "HICOM--AP http://www.plexus.net",
    "9834": "TRADEME--NZ Trade Me Limited",
    "9835": "GITS-TH--AP Government Information Technology Services",
    "9836": "HPCLMUMBAI-IN--AP Hindustan Petroleum Corporation Limited",
    "9837": "POWERTEL-AP Powertel Ltd",
    "9838": "APNIC-DEBOGON--AP APNIC Debogon Project",
    "9839": "MTC-GTEPACIFICA- Micronesian Telecommunications Corp",
    "9840": "UIDUK- UIDUK UNIVERSITY",
    "9841": "KOFIANET--KR Korea Financial Investment Association",
    "9842": "LDCC- Lotte Data Communication Company",
    "9843": "NACFFUTURES- NHINFORMATIONSYSTEM",
    "9844": "HANINTERNET- HaninterNetworks",
    "9845": "CJCKN--KR CJ-CABLENET",
    "9846": "FIRSTDATA--KR FDIK",
    "9847": "KSFC--KR Korea Securities Finance Corporation",
    "9848": "GNG Enterprise Networks",
    "9849": "CWD- Office of the president",
    "9850": "WOWTV- WOW-TV",
    "9851": "KCAC--KR KONGJU COMMUNICATION",
    "9852": "SAMIL- SAMIL ACCOUNTING CORPORATION",
    "9853": "RAYNET- GORayNet",
    "9854": "KTO--KR KTO",
    "9855": "KCCWF--KR KCCWF",
    "9856": "WOORIWM--KR WOORI Investment @ Securities",
    "9857": "KOG--KR KOREA G CORPORATION",
    "9858": "TYFT- Tong Yang Futures Trading co.,Ltd.",
    "9859": "CCCC- ChungCheong College",
    "9860": "TMCNET- TongMyong College",
    "9861": "HIAM--KR HI SET MANAGEMENT CO., LTD",
    "9862": "RAYNET GORayNet",
    "9863": "EDUCAR--KR Teachiworld Auto Insurance",
    "9864": "KSDNET--KR Korea Securities Depository",
    "9865": "CROSSCERT- KECA, Inc.",
    "9866": "LGCAPITAL- LGCAPITAL",
    "9867": "JTC- CHONJU TECHNICAL COLLEGE",
    "9868": "CUTH- Catholic University of DAEGU",
    "9869": "DIRECT1--KR Daum Direct Auto Insurance Co., LTD",
    "9870": "DEUNET- DONG-EUI UNIVERSITY",
    "9871": "KBE--KR Gyeong Sang Buk-Do Office of Education",
    "9872": "ITNET-NZ--AP Actrix Networks Ltd",
    "9873": "TELECOM-LA--AP ISP IN LAO",
    "9874": "STARHUB-IX StarHub Broadband",
    "9875": "PESAT1--AP PT. Pasifik Satelit Nusantara",
    "9876": "AIRNET-HB--AP NOW",
    "9877": "NGEEANN-POLY--AP Ngee Ann Polytechnic Computer Center",
    "9878": "SAFECOM Safecom Solutions",
    "9879": "OGILVY--AP OGILVY IA/PACIFIC",
    "9880": "NEXTGENNET-1-AU-AP NextGen.Net Pty Ltd, North Sydney",
    "9881": "IVOISYS--SG iVoisys Pty Ltd, Sydney, Australia",
    "9882": "NETWORKSMM--AP Networks Multimedia Pty Ltd",
    "9883": "BRITANNICA--AP Encyclopaedia Britannica Australia Inc",
    "9884": "SINGTEL-KR SingTel Korea Limited",
    "9885": "RSMANI-NKN-IN C/0 National Informatics Centre",
    "9886": "N-CAPNET-AU Capital Networks ACT AU",
    "9887": "THEWEB-AP The Web",
    "9888": "SOSYSTEMS--AP Southern Ocean Systems Pty Ltd",
    "9889": "MAXNET-NZ-AP Auckland",
    "9890": "ATOSINFOTECH-SG-AP ATOS Information Technology (Singapore) Pte Ltd",
    "9891": "CSLOX-IDC--AP CS LOXINFO Public Company Limited.",
    "9892": "ICONZ-WEBVISIONS-AP Iconz-Webvisions Pte. Ltd.",
    "9893": "DSE-VIC-GOV- Department of Sustainability & Enivronment,",
    "9894": "PIPE-CANB- PIPE Networks Canberra Internet Exchange.  Used for peering",
    "9895": "POWERCOR--AP Powercor Australia Telecommunications Pty Ltd",
    "9896": "PARADISE-AP Paradise Enterprises",
    "9897": "JSR-AP Monolith Industries",
    "9898": "9898- 9898 IP Services N",
    "9899": "ICARE-AP iCare.com Ltd.",
    "9900": "DOLPHIN-AP Dolphin IT",
    "9901": "TELSTRA-NZTRANSIT- TelstraClear Ltd",
    "9902": "NEOCOMISP-KH-AP NEOCOMISP LIMITED, IPTX Transit and Network Service Provider in Cambodia.",
    "9903": "RIT--AP Rajamangala Institute of Technology",
    "9904": "PI-MY Pacific Internet Malaysia",
    "9905": "LINKNET-ID-AP Linknet N",
    "9906": "ETNET-HK-AP ETNet Limited",
    "9907": "KNX-AP KNX (Asia Pacific) Pty. Ltd.",
    "9908": "HKCABLE2-HK-AP HK Cable TV Ltd",
    "9909": "PACNET-CDN-AP Pacnet CDN",
    "9910": "GLOBALNET-IN--AP NATIONWIDE SERVICE PROVIDER",
    "9911": "CONNECTPLUS-AP Singapore Telecom",
    "9912": "QIS--AP Quality Internet Services",
    "9913": "IIG--AP Internet Information Group",
    "9914": "DAVNET-HK  number for Davnet Digitel HK Ltd",
    "9915": "SAYHI-TW Dome Digital Communications,",
    "9916": "NCTU-TW National Chiao Tung University,",
    "9917": "INTERGEAND-TW NETPOLY Telecom Inc.,",
    "9918": "KGTNET-TW KG Telecommunication Co., Ltd",
    "9919": "NCIC-TW New Century InfoComm Tech Co., Ltd.",
    "9920": "ATL-TW Atlas Internet & Life International, Inc.",
    "9921": "HKT-PORTAL-TW PCCW Hongkong Telecom Ltd., Taiwan Branch.",
    "9922": "WCOM-TW WorldCom Taiwan Co., Ltd.",
    "9923": "EMPHIS-NETWORKS-TW Emphasis Networks Inc.",
    "9924": "TFN-TW Taiwan Fixed Network, Telco and Network Service Provider.",
    "9925": "HKTHOST-AP Powerbase DataCenter Services (HK) Ltd.",
    "9927": "PHILCOMNET-PH A Multihomed ISP Company",
    "9928": "CRYSTAL-AU-AP Crystal Internet",
    "9929": "CNCNET-CN China Netcom Corp.",
    "9930": "TTNET-MY TIME dotCom Berhad",
    "9931": "CAT-AP The Communication Authoity of Thailand, CAT",
    "9932": "HIC-AP Health Insurance Commission",
    "9933": "AHCL-AP AHCL Health Network",
    "9934": "MICOM-MN- Mongolia Telecom",
    "9935": "AGNSCUS-HK AGNS Customer",
    "9937": "DELTANET--AP Delta Networks",
    "9938": "IRESS--SEC-AP IRESS Market Technology",
    "9939": "ANLAI-AP  for Anlai",
    "9940": "LDN--AP LINKdotNET Telecom Limited",
    "9941": "RANBAXY-IN- Ranbaxy Laboratories Limited",
    "9942": "COMINDICO-AP SOUL Converged Communications Australia",
    "9943": "KNCTV- Kangnam Cable TV",
    "9944": "LGESHOP- LG Home shopping Inc.",
    "9945": "YFGC--KR yoido full gaspel church",
    "9946": "CABLENET--KR KCTV JEJU BROADCTING",
    "9947": "SIMNET--KR Simulation Multimedia Network",
    "9948": "NICEMONEY--KR Nice e-Banking Services",
    "9949": "HOSEO- HOSEO UNIVERSITY",
    "9950": "PUBNETPLUS2--KR DACOM",
    "9951": "AMWAYKOREA--KR AMWAYKOREA",
    "9952": "HOSTWAY--KR Hostway Korea",
    "9953": "HDVENTURE- Hyundai Engineering & Construction Co., Ltd.(HDEC)",
    "9954": "KUNSAN- Kunsan National University",
    "9955": "CHEONAN--KR 115, Anseo-dong 330-704",
    "9956": "KONGJU- kongju national university",
    "9957": "KINX- KINX, Inc.",
    "9958": "NEXON- NEXON",
    "9959": "KORETOCKEXCHANGE- KOREA STOCK EXCHANGE",
    "9960": "DGB--KR DaeguBank",
    "9961": "JOIL--KR JOIL CABLE NETWORK",
    "9962": "SUNCHON- Sunchon National University",
    "9963": "MOUMNET- RPK Co.,Ltd.",
    "9964": "PERSNET Korea Telecom Freetel",
    "9965": "ANSAN- ANSAN COLLEGE",
    "9966": "TAEGUTEC--KR TaeguTec",
    "9967": "KEBCS- Korea Exchange Bank of Credit Services",
    "9968": "KYOBO- KYOBO Life Insurance Co., Ltd.",
    "9969": "WMS-NET--KR KOREA RESOURCES RECOVERY AND REUTILIZATION CORPORATION",
    "9970": "KUT- Korea University of Technology and Education",
    "9971": "DONGDAEMUNCABLEINTERNET--KR TBROAD Dongdaemun cable networks,Inc.",
    "9972": "ROOTCA- KISA",
    "9973": "YESFUTURES- KEB Futures Co.",
    "9974": "KRA--KR Korea Racing Association",
    "9975": "KBISE--KR Gyeongsangbuk-do Education Research Institute",
    "9976": "ICNDP--KR Korea Cable TV NamIncheon Broadcasting.co.ltd",
    "9977": "JIGUNET- IOSYSTEM",
    "9978": "UOS- The University of Seoul",
    "9979": "KEB- KOREA EXCHANGE BANK",
    "9980": "HITINET Hyundai Information Technology",
    "9981": "SAERONET--KR Saero Network Service LTD",
    "9982": "PAICHAI- PAICHAI UNIVERSITY",
    "9983": "ABS--AP Australian Bureau of Statistics.",
    "9984": "MICROSOFT-TECHED--AP Microsoft Tech Ed Australia",
    "9985": "NIAUS-AP News Interactive (NI) australian  number",
    "9986": "TMTAPS--AP Telekom Malaysia Access Point Service.",
    "9987": "EXPRESSBBS--AP Express BBS",
    "9988": "MPT-AP Myanma Posts and Telecommunications",
    "9989": "EQUINIX-AP Equinix Singapore Pte Ltd",
    "9990": "NIANDC Nippon Information and Communication Corporation",
    "9991": "SHUDO-U Hiroshima Shudo University",
    "9992": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9993": "CTC-ODC ITOCHU Techno-Solutions Corporation",
    "9994": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "9995": "FIRSTSERVER FirstServer, Inc.",
    "9996": "KDDIIP-VPN KDDI Corporation",
    "9997": "MECHA Suzuka Cable Co.,Ltd",
    "9998": "ISAO ISAO Corporation",
    "9999": "ATTOKYO AT TOKYO Corporation",
    "10000": "NCM Nagasaki Cable Media Inc.",
    "10001": "MICSNET Mics Network Corporation",
    "10002": "ICT IGAUENO CABLE TELEVISION CO.,LTD",
    "10003": "OCT-NET Ogaki Cable Television Co.,Inc.",
    "10004": "-PHOENIX-J JIN Office Service Inc.",
    "10005": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "10006": "SECOMTRUST SECOM Trust Systems Co.,Ltd.",
    "10007": "IPR IP Revolution,Inc.",
    "10008": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "10009": "AREWORKS Rworks, Inc.",
    "10010": "TOKAI TOKAI Communications Corporation",
    "10011": "ADVAN advanscope.inc",
    "10012": "FUSION Fusion Communications Corp.",
    "10013": "FBDC FreeBit Co.,Ltd.",
    "10014": "NIHON-U Nihon University",
    "10015": "CWJ-NET Cyber Wave Japan, Inc.",
    "10016": "MINC Minaminihon Information Processing Center Co Ltd",
    "10017": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "10018": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "10019": "MCTV Matsusaka Cable-TV Station Inc.",
    "10020": "JPNIC-NET-JP--BLOCK Japan Network Information Center",
    "10021": "KVH KVH Co.,Ltd",
    "10022": "DSLAK--AP Internet access for Datacom Systems Auckland",
    "10023": "SNOOPA-TRANSIT--AP Vixtel Pty Ltd",
    "10024": "LGA--SG-AP LGA International",
    "10025": "IUSN--AP The IUSN Foundation",
    "10026": "PACNET Pacnet Global Ltd",
    "10027": "VZB-AU- Verizon Australia PTY Limited",
    "10028": "PTT-GITS-AP Information System Department",
    "10029": "CITYCOMNETWORKS- CITYCOM NETWORKS PVT LTD",
    "10030": "CELCOMNET-AP Celcom Internet Service Provider",
    "10031": "IPIRE-N iPire.net Pte Ltd",
    "10032": "HGC--AP Hutchison Global Crossing Ltd.",
    "10033": "IVANET-TYO-AP iBasis Tokyo ICO",
    "10034": "YOUNGTAEK- YMIR Entertainment",
    "10035": "HYUNDAIDEPT--KR Hyundai Department Store Co., Ltd.",
    "10036": "CNM--KR C&M Communication Co.,Ltd.",
    "10037": "NEXEYE--KR Jeil CATV Co.,Ltd",
    "10038": "NHNENT--KR NHN Entertainment",
    "10039": "KHIDI--KR Korea Health Industry Development Institute",
    "10040": "NICEVAN--KR NICE Information & Telecommunication, Inc",
    "10041": "WILLBES--KR The Willbes & Co.,Ltd",
    "10042": "DPC--KR DAEGU POLYTECHNIC COLLEGE",
    "10043": "MIC--KR Ministry of Information and Communication",
    "10044": "RDA--KR Rural Development Adminstration (RDA)",
    "10045": "TNUTNET- Hanbat National University",
    "10046": "HOWON- HOWON UNIVERSITY",
    "10047": "NSUIDC--KR Namseoul university",
    "10048": "BITTEL- Bittel",
    "10049": "SKNET- SK C&C Co., Ltd.",
    "10050": "NL--KR The National Library of Korea",
    "10051": "ANYSAT- ANYSAT",
    "10052": "KNU- Kyungpook National Univ.",
    "10053": "AYTCNET- Anyang Technical College",
    "10054": "CMBKJ--KR CMB Kwnagju Easten Broadcasting",
    "10055": "KORAIL--KR Korean National Railroad Administration",
    "10056": "HDMF- Hyundai Marin&Fire Insurance",
    "10057": "ESONET ESOCOM",
    "10058": "CU--KR NACUFOK",
    "10059": "KIDC- LG DACOM KIDC",
    "10060": "ACTOZ Actoz Soft Co., Ltd.",
    "10061": "FSS- Financial Supervisory Service",
    "10062": "HAMANNET--KR HamanCableBroadcastingCorporation",
    "10063": "KMA- Korea Meteorological Administration",
    "10064": "KNUS--KR KNUS",
    "10065": "KMTC--KR Korea Marine Transport",
    "10066": "GAYANET--KR CJ-CABLENET",
    "10067": "LGNET-CHINA--KR LG CNS",
    "10068": "PRONET- Honhjin Network",
    "10069": "SMLINE--KR Seoul Metro",
    "10070": "KRISS- Korea Research Institute of Standards and Science",
    "10071": "ANYANG- anyang University",
    "10072": "CHOHUNGBANK- Cho Hung Bank",
    "10073": "KNOU- Korea National Open University",
    "10074": "IVANET-SIN-AP iBasis Singapore ICO",
    "10075": "FORTANA--AP Fortana Networks Australia Pty Ltd",
    "10076": "N-ERDEMNET  # -ERDEMNET CONVERTED TO N-ERDEMNET FOR RPSL COMPLIANCE ERDEMNET ISP",
    "10077": "TIKONAINFINET--1 Tikona Infinet Ltd",
    "10078": "IBC--AP Internet Business Corporation",
    "10079": "PACDUN--AU Pacific Dunlop Group",
    "10080": "WEBSHIELD-ADE--AP Webshield, Internet Service Provider, Adelaide, Australia",
    "10081": "DIGI-MY DiGi Telecommunications Sdn Bhd",
    "10082": "MS-HK--AP Morgan Stanley Asia Limited",
    "10083": "CYNERGIC--AP Cynergic (NSW) Peering  Number",
    "10084": "WAIA-TRANSIT-AP Western Australian Internet Association",
    "10085": "UNIGATE-OVERSEA-IX-AP PEER WITH OVERSEA ISP",
    "10086": "T-SYSTEMS-SG T-SYSTEMS SINGAPORE PTE LTD",
    "10087": "TOPSEARCH-PCB-AP Printed Circuits Manufacturer",
    "10088": "KWANGWOON-UNIV--AP KWANGWOON University in Seoul, Korea",
    "10089": "DTNCORP-TH-AP Total Access Communication PLC.",
    "10090": "LDSCHURCH--AP LDS Church of Jesus Christ",
    "10091": "SCV--AP StarHub Cable Vision Ltd",
    "10092": "AUDOMAINADMIN--AP Australian Domain Administration Limited,",
    "10093": "ACTWEBNET--AP WebOne Internet",
    "10094": "BRUNET-N BruNet - Telekom Brunei Berhad",
    "10096": "EYCALL-PH- Easycall Communications Phils., Inc.",
    "10097": "FLOWCOM Flow Communications 2/541 Kent St Sydney NSW 2000",
    "10098": "HENDERSON-HK Henderson Data Centre Limited",
    "10099": "HKUNICOM1-AP China Unicom (Hong Kong) Operations Limited",
    "10100": "N-AP-UBSW  # -AP-UBSW CONVERTED TO N-AP-UBSW FOR RPSL COMPLIANCE UBS Autonomous System Asia-Pacific",
    "10101": "SIMPUR-BN Simpur ISP",
    "10102": "SG-1IACOM--AP 1Asia Communication Pte Ltd",
    "10103": "HKBN--AP HK Broadband Network Ltd.",
    "10104": "INTERNETDEPOT Internet Depot",
    "10105": "OMNI OMNIconnect Pty Ltd",
    "10106": "GIPPSTAFE--AP Central Gippsland Institute of TAFE",
    "10107": "ATARNET-PH 141 Ayala Street  11th Floor  Unit 1108",
    "10108": "DRESDNERHK-AP DRESDNER KLEINWORT WSERSTEIN,",
    "10109": "TOPNET--MN-AP Topica LLC, Internet Service Provider,Ulaanbaatar, Mongolia",
    "10110": "N-MITNZ-AP  # -MITNZ-AP CONVERTED TO N-MITNZ-AP FOR RPSL COMPLIANCE Manukau Institute of Technology",
    "10111": "DATAONE-MY-AP  for DataOne(Malaysia)",
    "10113": "EFTEL--AP Eftel Limited.",
    "10114": "IANET-AP PT.Medialintas Antar Buana",
    "10115": "ATO-AP Australian Taxation OAffice",
    "10116": "HTCL-WAP-HK-AP Hutchison Telephone Company Limited",
    "10117": "VIEWQWEST-SG--AP Viewqwest Singapore Pte Ltd Broadband Border",
    "10118": "HTCL-I-HK-AP Hutchison Telephone Company Limited",
    "10119": "INFORMATION-SOLUTION-WORKS-AP ISW Head Office in Hobart",
    "10120": "IBM-SG-AP IBM Sinapore Server Farm",
    "10122": "BJJSNET--AP Beijing Jiasheng Lianhua technical Co. Ltd",
    "10123": "TENMARK-CN Guangzhou Tenmark Networks Technology Ltd",
    "10124": "AMAZON-AP-RESOURCES--AP-NRT Amazon Data Services Japan KK",
    "10125": "INTERGLOBE--AP INTERGLOBE IS A LARGE BPO AND IT COMPANY IN TRAVEL DOMAIN",
    "10126": "CHTI-IP-AP Taiwan Internet Gateway",
    "10127": "CLSA--AP CLSA Ltd",
    "10128": "IAG--AP Optus Customer Network",
    "10129": "SSMB--AP Salomon Smith Barney Australia Pty Ltd",
    "10130": "10130 FSM Telecommunications Corporation",
    "10131": "CKTELECOM-CK-AP Telecom Cook Islands",
    "10132": "ETAR-TECHNOLOGY-AP Eastar Technology Data Center in Hongkong",
    "10133": "CHIEF- Chief Telecom Inc.",
    "10134": "WEBCOM-AP We are an P/ISP",
    "10135": "EPNET--AP EPNET Inc.",
    "10136": "PSWITCH-HK Pacswitch Worldwide Transit",
    "10137": "PATRANET-AP Patrakom Internet Service Provider",
    "10138": "IVANET-SYD-AP iBasis-Sydney ICO",
    "10139": "SMARTBRO-PH-AP Smart Broadband, Inc.",
    "10140": "SINGTEL-GRX SingTel GPRS Roaming Exchange",
    "10141": "DFNN--AP DFNN Group of Companies",
    "10142": "WELL-COM-PTY-LTD Well.Com Pre-Press Services",
    "10143": "EXETEL--AP Exetel Pty Ltd",
    "10144": "ECLIPSE-AP Eclipse Telecomunications Australia",
    "10145": "SECUREIP-AP SecureIP",
    "10146": "FORD-MOTOR-CO-SG-AP Ford Motor Company",
    "10147": "DAHSING-HK--AP Dah Sing Bank HK",
    "10148": "UNIMELB--AP The University of Melbourne, Melbourne, Victoria",
    "10149": "MEGAPOP-SG-AP SINGAPORE TELECOMMUNIATIONS LIMITED",
    "10150": "TENNET-AU-AP Optus Customer Network",
    "10151": "ITONE-CSLOXINFO--TH-AP IT One Co., Ltd.",
    "10152": "NEC-MELB-DC--AP NEC Australia Pty Ltd",
    "10153": "ONETELHK--AP ONE.TEL Limited (Hong Kong)",
    "10154": "USE--KR ULSAN Office of Education",
    "10155": "JBCTV--KR CJ CableNet JoongBusan CATV",
    "10156": "SNUE--KR Seoul National University of Education",
    "10157": "YAHOO--KR Yahoo! Korea, Corp.",
    "10158": "KAKAO2 KAKACO",
    "10159": "HAUNET--KR HANKUK Aviation University",
    "10160": "PRISM- Intellicenter",
    "10161": "QIA--KR QIA",
    "10162": "SNUH--KR SNUH",
    "10163": "HANTA- HANKOOK TIRE CO.,LTD.",
    "10164": "GSD--KR TBROAD GANGSEO",
    "10165": "CUSTOMS--KR KOREA  CUSTOMS SERVICE",
    "10166": "KOWANET--KR Korea Water Resources Corporation",
    "10167": "HANVIT- HANVIT BANK",
    "10168": "NSKFB- Korea First Bank",
    "10169": "AMOREPACIFIC--KR AMOREPACIFIC",
    "10170": "BOKNET- The Bank of Korea",
    "10171": "SKTELINK- SKTELINK",
    "10172": "KBBOOK- KYOBO BOOK CENTER",
    "10173": "KSNET- KSNET.Inc",
    "10174": "MBC--KR Munhwa Broadcasting Corporation",
    "10175": "HCNKUMHO--KR Kumho Cable",
    "10176": "TENET- Taejon Institute of Education Science",
    "10177": "GREENCROSSLIFEINSURANCE--KR GREEN CROSS LIFE INSURANCE Co.,Ltd",
    "10178": "KBTUS- Korea Baptist Theological University/Seminary",
    "10179": "DAETOO- Daehan Investment Trust Securities",
    "10180": "CCNUE--KR Chuncheon National University of Education",
    "10181": "KRS--KR Korea Register of Shipping",
    "10182": "ETOMATO- ETOMATO CO.Ltd",
    "10183": "KCISA--KR Korea Culture Information Service Agency",
    "10184": "KFCCC- Korean Federation of Community Credit Cooperatives",
    "10185": "HNB- Hana Bank Co.",
    "10186": "DMT--KR Daejeon Telecom",
    "10187": "KISDI--KR Korea Information Society Developement Institute",
    "10188": "HANMAG--KR HanMag Futures Corporation",
    "10189": "HMM--KR Hyundai merchant marine co., LTD.",
    "10190": "JB--KR Joongbu University",
    "10191": "UYCATV--KR C&M Ulsan Cable TV",
    "10192": "KIWOOM--KR kiwoom.com Securities.co.,Ltd",
    "10193": "WEMADE--KR WEMADE Entertainment",
    "10194": "DOOSANHEAVY--KR Doosan Heavy Industries & Construction Co., Ltd.",
    "10195": "HAIONNET--KR HAIonNet",
    "10196": "HNCBWORLD--KR Kookmin Bank",
    "10197": "CNU--KR Chonnam National University",
    "10198": "CUP--KR Catholic University of Pusan",
    "10199": "TATA- Tata Communications Ltd",
    "10200": "NETSMART-AP Web hosting provider and ISP connectivity.",
    "10201": "DWL--IN Dishnet Wireless Limited. Broadband Wireless",
    "10202": "BOCI-HK-AP BOC International Holdings Limited",
    "10203": "DATACOMWA--AP Datacom MetroIX",
    "10204": "ARCNET-NTTMSC-MY Arcnet NTT MSC ISP",
    "10205": "ONCC--AP ON.CC(HK) LIMITED",
    "10206": "CNCVOIP-CN China Netcom Corp VOIP Sub.",
    "10207": "INTERVOLVE-ADELAIDE--AP Interhost Pacific Pty Ltd t/a Intervolve.",
    "10208": "THENET--ID-AP PT. Millenium Internetindo",
    "10209": "SYNOPSYS--JP-AP Japan HUB and Data Center",
    "10210": "AWAC-AU 8 Clunies Ross Court",
    "10211": "IVANET-KUL-AP iBasis Malaysia-KUL ICO",
    "10212": "CHINAENTERCOM China Enterprise Communications Ltd.",
    "10213": "WORKCOVER--AP Workcover Corporation",
    "10214": "HUINION--AP BEIJING HUINION TECHNOLOGY LIMITED COMPAMY",
    "10215": "MICROLANDNET--AP Microland Limited. IT Infra Service Provider. India",
    "10216": "NMROTHSCHILD--AP NM Rothschild & Sons",
    "10217": "NTT-NET-ID- PT. NTT Indonesia",
    "10218": "MINCOM-LIMITED--AP Optus Customer Network",
    "10219": "SKYCC--MAIN SKY C&C LLC",
    "10220": "SNET-ID-AP PT. Sejahtera  Globalindo",
    "10221": "HEWLETT-PACKARD Multi-homed connections to multiple ISP's providing",
    "10222": "WAVECOMWL-LK Wavecom Wireless Ltd",
    "10223": "UECOMM-AU Uecomm Ltd",
    "10224": "BROADBAND-PH-AP BROADBAND PHILIPPINES",
    "10225": "NETTLINX-IN-AP Nettlinx Limited",
    "10226": "ETL-IX--AP Enterprise of Telecommunications Lao",
    "10227": "SUANDUSIT Institute Rajabhat Suandusit",
    "10228": "YAHOO-CN Internet Content Provider",
    "10229": "YAHOO-TW1 Internet Content Provider",
    "10230": "YAHOO-SG internet content provider",
    "10231": "TECHTRANS-AP Tech-trans System Ltd.",
    "10232": "HUTPLHK--AP Hutchison Priceline HK",
    "10233": "WP-PDOX-AP West Australian Service Providers",
    "10234": "ZURICH-AUSTRALIA--AP Zurich Financial Services Australia",
    "10235": "NATIONAL-AUSTRALIA-BANK National Australia Bank Ltd Network",
    "10236": "FOXGOLD-NET-AU-AP FOXGOLD COMMUNICATIONS",
    "10237": "DUN-AND-BRADSTREET-AP Dun & Bradstreet Australia Provider of Business",
    "10238": "CCI-HK-AP Cyber Channel International Ltd",
    "10239": "CMAX- Comsat Max ISP",
    "10240": "MOTLEYFOOL - The Motley Fool, Inc.",
    "10241": "OCI - Options & Choices, Inc.",
    "10242": "USINTERNET - US Internet Corp",
    "10243": "HERMESNET1 - STRC",
    "10244": "EDIFY - Edify, Inc.",
    "10245": "N-NEXTWEB-R3 - Nextweb, Inc",
    "10246": "AGT - Applied Graphics Technologies",
    "10247": "NETLINE",
    "10248": "BAY-BANKS-OF-VA - BAY BANKS OF VIRGINIA",
    "10249": "EMC08 - Emarketing Center LLC",
    "10250": "INET-SOLUTIONS - INet Solutions",
    "10251": "DIALI - Digital Internet Access Link, Inc.",
    "10252": "DOTNETUNIFIEDNETWORK - Dot-Net, Ltd",
    "10253": "IENG - Internet Engineering Group",
    "10254": "WATSONWYATT - Watson Wyatt Worldwide",
    "10255": "SINISTER - Sinister Networks",
    "10256": "GS-N - Akula Communications Corp.",
    "10257": "IINET-10257 - Infinity Internet, Inc.",
    "10258": "SHN- - Sapient Health Network",
    "10259": "BLUEMOON - Blue Moon Online System",
    "10260": "ACCESS-CHICAGO - ACCESS Chicago Internet Services",
    "10261": "APOLLO-REAL-ESTATE-NET - Apollo Real Estate Management V LP",
    "10262": "IMPROTECH",
    "10263": "MATCHMAKER - MatchMaker/DFW-ISP",
    "10264": "SCOTIACAPTIAL - Scotia McLeod Inc.",
    "10265": "SENECACOLLEGE- - Seneca College of Applied Arts and Technology",
    "10266": "NETWAY- - MDC, Inc.",
    "10267": "GVI- - GlobalVision Systems, Inc",
    "10268": "N-USS - USS.NET",
    "10269": "Belize Telemedia Limited",
    "10270": "NECROMIUM - Idex Technologies",
    "10271": "TCIX - Meganet Communications",
    "10272": "SSIS - South Seas Internet Services",
    "10273": "FPL - Florida Power & Light Company",
    "10274": "EXCELNET - Excel.Net, Inc.",
    "10275": "-UNITEDNETWORK - ABS-CBN International",
    "10276": "GATEKEY - GateKey Solutions",
    "10277": "Ministerio de Cultura y Educacion",
    "10278": "CWWI- - Cable & Wireless (Barbados) Limited",
    "10279": "WCCL- - West Carolina Communications, LLC",
    "10280": "DIALIP-E-SW - GLOBAL ONE",
    "10281": "DIALIP-E-NE - GLOBAL ONE",
    "10282": "ORANGE-BUSINESS-SERVICES-CEEUR Orange Business Services (formerly Equant)  for CEEUR",
    "10283": "DIALIP-AMERIC - GLOBAL ONE",
    "10284": "DIALIP-IA - GLOBAL ONE",
    "10285": "MLS Wireless S/A",
    "10286": "TIESOFT - TIESoft Internet Marketing Ltd.",
    "10287": "XTNNET - East Tennessee Network",
    "10288": "MIN-NET - MetroNet Internet Services, LLC",
    "10289": "WEBNETWORKS - WebNetworks International, Inc.",
    "10290": "RDANET - Readers Digest",
    "10291": "PLANETALL - Sage Enterprises, Inc.",
    "10292": "CWJAM N-CWJAMAICA",
    "10293": "CANTV Servicios, Venezuela",
    "10294": "CCCD- - Coast Community College District",
    "10295": "COMPUTERDOTNET - Computer.Net LLC",
    "10296": "GBNETMPNNETWORK - GBM Corporation",
    "10297": "ENET-2 - eNET Inc.",
    "10298": "10298 - CACI Inc., Federal",
    "10299": "EMCATEL",
    "10300": "NETSPEAK - NetSpeak Corporation",
    "10302": "NEGIA-NET - SNAPPYDSL.NET",
    "10303": "-PRIORI - Priori Networks",
    "10304": "NETCHANNEL - Netchannel, INC.",
    "10305": "VERINET - Verinet Communications, Inc.",
    "10306": "CNETECHNET - CNETech Net, Inc.",
    "10307": "GRENTEL - Grentel",
    "10308": "NEIUNET - Northeastern Illinois University",
    "10309": "MARIN-MID - County of Marin",
    "10310": "YAHOO-1 - Yahoo!",
    "10311": "SCRR-10311 - Time Warner Cable Internet LLC",
    "10312": "HEARTPORT - Heartport Inc.",
    "10313": "PEQUOT - Pequot Systems, Inc.",
    "10314": "WORLDPATH- - WorldPath Internet Services",
    "10315": "EZNETWORK - ez network systems",
    "10316": "CODERO- - Codero",
    "10317": "CUCINT - Cuc International",
    "10318": "CABLEVISION S.A.",
    "10319": "ADVANTANET - Advanta Corporate Technology",
    "10320": "ISPN - Internet Services Provider Network",
    "10321": "MERCOMUSA - Mercury Communications",
    "10322": "ERCOT-ISO - Ercot Independent System Operations",
    "10323": "PLANET - Planet Systems Network, Inc.",
    "10324": "WAZOO- - Wazoo's Computers",
    "10325": "INGRAMMICRO - Ingram Micro Inc.",
    "10326": "WPI - Worcester Polytechnic Institute",
    "10327": "CLAND - ComputerLand of Boise",
    "10328": "IKONUN - IKON/Universal Networks, Inc.",
    "10329": "INFOSHARE - CoreLAN Communications, Inc.",
    "10330": "VOYAGER - CoreComm Internet Services Inc",
    "10331": "MHG",
    "10332": "BROADBAND - MSHOW.com",
    "10333": "DIGITALINSIGHT - Digital Insight Corporation",
    "10334": "NAVISITE-ET - Navisite Internet Services",
    "10335": "RELAYTECH - Relay Technology, Inc",
    "10336": "PFN- - PFN, Inc.",
    "10337": "IBM400DIV - IBM /400 Division",
    "10338": "COBITE - Communications Billing Technologies",
    "10339": "COMMTEL - CommTel Internet",
    "10340": "TELE-TECH - TELE-TECH CO. INC.",
    "10341": "IBC- - IBC",
    "10342": "INETINFOSVCS- - Internet Information Services, Inc.",
    "10343": "NA-AERONET- - National Aeronautics and Space Administration",
    "10344": "GRAMTEL002 - CyrusOne LLC",
    "10345": "INCONNECT - Internet Connect, Inc.",
    "10346": "MIDCOT - MIDCOT INTERNET SOLUTIONS",
    "10347": "RANDMCNALLY - Rand McNally",
    "10348": "HTDC - High Technology Development Corporation",
    "10349": "TULANE - Tulane University",
    "10350": "NETSCHOOLS - NETSchools Corporation",
    "10351": "ENERT - Enertron L.L.C.",
    "10352": "WCTC - Solarus",
    "10353": "STCC-5 - Southwest Tennessee Community College",
    "10354": "GLOBETROTTER - QuebecTel Communications Inc",
    "10355": "DSCGA - Digital Service Consultants",
    "10356": "WINDYCITY - Windy City Ltd.",
    "10357": "JMUNET - James Madison University",
    "10358": "GOTHAMBUS - The Gotham Bus Company, Inc.",
    "10359": "EPICSYS - Epic Systems Corporation",
    "10360": "SOFTWARE-ALBERTA - Software Alberta Society",
    "10361": "BLOOMBERG BLOOMBERG",
    "10362": "UBIK DO BRIL SOL TECNOLOGIA LTDA.",
    "10363": "LEESTL-N-10363 - Lee Enterprises, Inc.",
    "10364": "UAHNET - University of Alabama in Huntsville",
    "10365": "WEBEXPRESS - WEB EXPRESS",
    "10366": "N-NKN1 - National Knowledge Networks, Inc.",
    "10367": "G4-COMMUNICATIONS - Metro2000, Inc.",
    "10368": "RCN-10368 - RCN",
    "10369": "CAMPBELLSOUP- - Campbell Soup Company",
    "10370": "NORTHWEST-AIRLINES - Northwest Airlines",
    "10371": "NA-DARWIN- - National Aeronautics and Space Administration",
    "10372": "NORWEST - Norwest Services, Inc.",
    "10373": "NORWEST - Norwest Services, Inc.",
    "10374": "NORWEST - Norwest Services, Inc.",
    "10375": "NORWEST - Norwest Services, Inc.",
    "10376": "NORWEST - Norwest Services, Inc.",
    "10377": "SOUNDCHOICE - Sound Choice Communications LLC",
    "10378": "NODEWARRIOR - NodeWarrior Networks, Inc",
    "10379": "DELUXE - Deluxe Corporation",
    "10380": "NETXS - Net XS Communications",
    "10381": "SWCP- - Southwest Cyberport",
    "10382": "NPTI - Northwest Pennsylvania Technical Institute",
    "10383": "QWEST--10383 - Qwest Corporation",
    "10384": "TVA - Tennessee Valley Authority",
    "10385": "EIGER - eiger",
    "10386": "IC-N - VoyageurWeb",
    "10387": "CHARIOTNET - cha!, LLC",
    "10388": "ONEUNIFIED - NETinc",
    "10389": "JMC-N - JPMorgan Chase & Co.",
    "10390": "TELECHECK - TeleCheck International, Inc.",
    "10391": "InteRED Panama",
    "10392": "NSB1-NET - New Source Broadband",
    "10393": "MWEB-10393",
    "10394": "ALLWAYS - Allways, Inc.",
    "10395": "VUE-1 - Virtual University Enterprises",
    "10396": "COQUI-NET - DATACOM CARIBE, INC.",
    "10397": "SINGLEPIPE - SinglePipe Communications, Inc.",
    "10398": "GBI - Great Bridge Internet, Inc.",
    "10399": "AMAP-AUSTIN-TX-WALLER - Waller Creek Communications",
    "10400": "THETORONTOSTAR - Toronto Star",
    "10401": "SFAAOA - Society for Accelerated Advancement of Amphetamines",
    "10402": "HSD2- - Harrison School District Two",
    "10403": "DYNTY - Dynasty Online, Inc",
    "10404": "ICN-1 - Interactive Classified Network",
    "10405": "UPRR-N-01 - Union Pacific Railroad Company",
    "10406": "N-TEKTRONIX - Tektronix, Inc.",
    "10407": "IAAVC - IAAVC",
    "10408": "SPECTRUME - Spectrum Enterprises, Inc.",
    "10409": "EYLINK-10409 - Easylink Services Corporation",
    "10410": "AUTO-GRAPHICS - Auto-Graphics, Inc.",
    "10411": "ESRI - Environmental Systems Research Institute",
    "10412": "CIA. DE TECNOL. DA INFOR. E COMUNICA\u00c7\u00c3O DO PARAN\u00c1",
    "10413": "GLOBALLY - Global Net",
    "10414": "QUESTLINK - QuestLink Technology, Inc.",
    "10415": "VSCAPEII - Vscape International, Inc",
    "10416": "EVCOM-N - Evolution Communications, Inc.",
    "10417": "Funda\u00e7\u00e3o de Desenvolvimento da Pesquisa",
    "10418": "TEKNOS - TEKNOS Consulting Corporation",
    "10419": "SOLUTIONWARE - SolutionWare, Ltd.",
    "10420": "Banco de Mexico",
    "10421": "TTUNET - Texas Tech University",
    "10422": "NETEXPLORER - Net Explorer, Inc.",
    "10423": "SPARTAN-NET - Spartan-Net",
    "10424": "QWEST--10424 - Qwest Corporation",
    "10425": "AWG-BOS - Advanced Wireless Group, LLC",
    "10426": "AUTOBAHN - autobahn Internet Solutions",
    "10427": "RAMS-FIE- - Federal Information Exchange",
    "10428": "CWV-NETWORKS - The College of West Virginia",
    "10429": "Telefonica Data S.A.",
    "10430": "WA-K20 - Washington State K-20 Telecommunications Network",
    "10431": "EDGENETWORKS - Edge IT, LLC",
    "10432": "APC--2 - American Personal Communications",
    "10433": "USA-NET - USA-Net Corporation",
    "10434": "SAT-TEL - Satellite Communication Systems, Inc.",
    "10435": "IDCOMM - ID COMMUNICATIONS",
    "10436": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "10437": "UKY - University of Kentucky, Communication Services",
    "10438": "BLUE-HWY - Information Systems, Inc.",
    "10439": "CARINET - CariNet, Inc.",
    "10440": "MERKLE-INC - Merkle Inc.",
    "10441": "CH2M - CH2M HILL",
    "10442": "ED-GOV - Department of Education",
    "10443": "WOLFENET2 - Wolfe Internet Access",
    "10444": "ZIONS-MANAGMENT-SERVICES-COMPANY - Zions Management Services Company",
    "10445": "HTG - Huntleigh Telcom",
    "10446": "AMIGO-NET - Zero Error Networks",
    "10447": "SKYLINKUS-1 - Skylink Networks, Inc.",
    "10448": "VILLANOVA-UNIV - Villanova University",
    "10449": "DISCOVER - DiscoverNet, Inc.",
    "10450": "ADVANTECH - ADVANTECH",
    "10451": "WARPDRIVE - Warpdrive Networks",
    "10452": "FritzWare S.R.L.",
    "10453": "CNIWEB - CREATIVE NETWORK INNOVATIONS, INC.",
    "10454": "Interdotnet do Brasil Ltda",
    "10455": "LUCENT-CIO - Alcatel-Lucent",
    "10456": "ATT-DISCNET - AT&T Services, Inc.",
    "10457": "ILX-N - Thomson Reuters U.S. LLC",
    "10458": "JUNIPER-TEST- - Juniper Networks, Inc.",
    "10459": "WANSN - Web America Networks",
    "10460": "SCOOP- - Scoop, Inc.",
    "10461": "TOWNSENDANALYTICSLTD Realtick, a provider of a broad range of trading and financial market services",
    "10462": "SHADOW - Shadow Infromation Services",
    "10463": "Enlared C.A.",
    "10464": "TEAMTECH - Team Technologies, LLC",
    "10465": "DOCKNET-1 - Aerioconnect",
    "10466": "MAGPI - MAGPI c/o University of Pennsylvania",
    "10467": "NEWMEDIA - New Media Laboratories",
    "10468": "LAN - Aslan Communications, Inc.",
    "10469": "FIRSTNET - FIRST Inc.",
    "10470": "N-PCORDER - pcOrder.com",
    "10471": "TIS- - Thomson Information Services",
    "10472": "CWNET - Communications World Network",
    "10473": "COMPUSA - CompUSA Direct",
    "10474": "MWEB-10474",
    "10475": "VENTURENET - VentureNet, L.L.C.",
    "10476": "Net2Net Corp.",
    "10477": "CEPH - Cephas Multimedia, Inc.",
    "10478": "PTINETCORP - PTI Communications",
    "10479": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "10480": "RA-N002 - Rack Alley LLC",
    "10481": "Prima S.A.",
    "10482": "SHAW-COMMUNICATIONS - Shaw Communications Inc.",
    "10483": "AKPERMFUND - Alaska Permanent Fund",
    "10484": "HRBLOCK- - H&R Block",
    "10485": "UW-STOUT - University of Wisconsin - Stout",
    "10486": "FTRANS - Fastrans Logistics, Inc.",
    "10487": "SIMPLENET - Simple Network Communications, Inc",
    "10488": "TFM-N - tfm associates",
    "10489": "CONVERGENTAZ- - Convergent Internet Solutions",
    "10490": "SOUTHERN-CROSSROADS-SOX - Georgia Institute of Technology",
    "10491": "DIAMONDLINK - Diamond Link, Inc.",
    "10492": "CACMEDIANET - CAC-MediaNet",
    "10493": "GCN- - Grand Central Networks Inc.",
    "10494": "AAI - Accurate Automation, Inc.",
    "10495": "GERAES CONSULTORIA E SISTEM LTDA.",
    "10496": "LIVINGSTON - Livingston Enterprises, Inc.",
    "10497": "WORLDBANK - The World Bank Group",
    "10498": "IWAVE-N - I-Wave Corp.",
    "10499": "IUMC-IT - Rochester Gas and Electric Corporation",
    "10500": "INTA - Internet America, Inc.",
    "10501": "PACLINK - PacLink Communications LLC",
    "10502": "IFX NETWORKS COLOMBIA",
    "10503": "I-55 - Tangipahoa Internet Services",
    "10504": "DHLAIRWAYS - DHL AIRWAYS, INC.",
    "10505": "DOCKSIDE",
    "10506": "PROSPECT - Prospect Innovation Center",
    "10507": "SPCS - Sprint Personal Communications Systems",
    "10508": "ARKNET- - University of Arkansas",
    "10509": "IEWAY - Internet Expressway",
    "10510": "QNIKC - River City Internet Group (Primary Networks)",
    "10511": "COUNTRY-INSURANCE - CC Services, Inc",
    "10512": "EFOREX- - E-FOREX",
    "10513": "RCN-7 - RCN",
    "10514": "SPLITROCK - Splitrock Services Inc.",
    "10515": "CLT-NIC - VeriSign Infrastructure & Operations",
    "10516": "ORB-BIT - Orb-bit Design Group",
    "10517": "MELLONBANK - Mellon Bank",
    "10518": "WALLNET- - Wall Internet LLC",
    "10519": "ANS97 - ANS Communications, Inc.",
    "10520": "EXECULINK - Execulink Telecom Inc.",
    "10521": "MARCOM - MarCom, Inc",
    "10522": "BLUESTAR - BlueStar Communications",
    "10523": "ROADRUNNER-003-ALBANY - Excalibur Group",
    "10524": "GOYAD-02 - GOYA DE PUERTO RICO",
    "10525": "SIMON-SCHUSTER - Simon & Schuster",
    "10526": "DRCORP - Direct Report Corporation",
    "10527": "PULVER - Pulver.com",
    "10528": "INTELISYS - Intelisys Electronic Commerce",
    "10529": "AFSB - Avondale Federal Savings Bank",
    "10530": "interpacket (http://www.interpacket.net)",
    "10531": "Terra Networks Brasil S.A.",
    "10532": "RACKSPACE - Rackspace Hosting",
    "10533": "OTTIX - Hypnovista Network Services",
    "10534": "GOAMERICACOMM - GoAmerica Communications Corp",
    "10535": "USNETWAY - US Netway, Inc.",
    "10536": "INDIVIDUAL - Individual, Inc.",
    "10537": "WINBEAM-INFINITY - Winbeam",
    "10538": "TELALKA - TelAlaska",
    "10539": "NETMORE - Netmore Internet, Inc.",
    "10540": "INFODOOR",
    "10541": "PREDICTIVE - Predictive Systems Inc.",
    "10542": "MSDNSD - Maplecrest Software Development Network Services Division",
    "10543": "UPTIMEWEB - Uptime Computer Services, Inc.",
    "10544": "DLPTECHNOLOGIES - DLP Technologies, Inc.",
    "10545": "LCOL - Lynchburg College",
    "10546": "MSSTATE - Mississippi State University",
    "10547": "FIREB-N - Firebird Management LLC",
    "10548": "LCGM-1 - LCGM, Inc.",
    "10549": "EMINET - The EmiNet Domain",
    "10550": "OTS--10550 - University of Texas System",
    "10551": "RAPID-CITY-REGIONAL - Rapid City Regional Hospital",
    "10552": "CATAPULTNET - Catapult Integrated Systems",
    "10553": "SILVERPLATTER- - Silverplatter Information",
    "10554": "WESTERNU-POMONA - WESTERN UNIVERSITY OF HEALTH SCIENCES",
    "10555": "SCLI - Semi-Custom Logic, Inc",
    "10556": "ATN- - American Telnet",
    "10557": "CNW - Connect Northwest Internet Services, LLC",
    "10558": "BIOLA---BIOLA-UNIVERSITY - Biola University, Inc.",
    "10559": "WEBSTREETSECURITIES - Web Street Securities, Inc.",
    "10560": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "10561": "BRANDEIS - Brandeis University",
    "10562": "AIRNET - AIRnet Internet Services, Inc.",
    "10563": "ROCHELLEUTILITIES - Rochelle Municipal Utilities",
    "10564": "TCSI - TCSI Corporation",
    "10565": "SVCOLO- - Silicon Valley Colocation, Inc.",
    "10566": "VIAGENIE - ViaGenie Inc.",
    "10567": "TNA - Total Network Access",
    "10568": "PROXY-N - Proxy Communications Corporation",
    "10569": "Red CENIAInternet",
    "10570": "HYPNO-NTT - NTT Software",
    "10571": "GEOACCESS- - GeoAccess",
    "10572": "RESROCKET - Res Rocket Surfer, Inc",
    "10573": "WEBNEXUS - WebNexus Communications Inc.",
    "10574": "BJKE - BJK & E, Inc.",
    "10575": "CISP-",
    "10576": "CDNOW - CDnow, Inc.",
    "10577": "WIPC - Worldwide Internet Publishing Corp",
    "10578": "GIGAPOP-NE - Harvard University",
    "10579": "HIGHWAY1- - Highway 1",
    "10580": "GENERAL-INSTRUMENT-SD-NOC - Home business of Motorola Mobility",
    "10581": "TM3 - Thomson Municipal",
    "10582": "MONDONET-USA- - TMI-USA",
    "10583": "CHIME - Connecticut Hospital Assoc.",
    "10584": "TRADEWEB - TradeWeb, LLC",
    "10585": "NETLIMITED - NETLIMITED LLC",
    "10586": "OSI de Guatemala",
    "10587": "FIBERPIPE - Fiberpipe Inc.",
    "10588": "ICSNET - Intelligent Computer Solutions, Inc",
    "10589": "HALNET - Houston Area League of PC Users, Inc. (HAL-PC)",
    "10590": "BOOKSTACKS - Book Stacks Unlimited",
    "10591": "IONSNET - Interact Communications",
    "10592": "CONNECTED-DATA-SYSTEMS - NET1Plus",
    "10593": "AOL-DTC2 - America Online",
    "10594": "CEC - Cutting Edge Communications, Inc.",
    "10595": "MAUSWERKS - Mauswerks, LLC.",
    "10596": "JETNET - Jet.Net Internet Services",
    "10597": "CRUSOE- - Crusoe Communications, Inc.",
    "10598": "CIRR - Central Iowa (Model) Railroad",
    "10599": "MCKESSON - McKesson Corp.",
    "10600": "CD-GRAF PUBLICACOES ELETRONIC LTDA",
    "10601": "ELNET - elNet - Electro Link Network, Inc.",
    "10602": "TDL - THE DIAMOND LANE",
    "10603": "TYPEHOUSE-GROUP - Typehouse Group",
    "10604": "KINKO - Kinkos, Inc.",
    "10605": "Service Net",
    "10606": "TALNET S.A.",
    "10607": "ETHERN - Global Communications INTERNETworking Corp.",
    "10608": "ENS-INTERWEB - Enterprise Network Systems",
    "10609": "TELEVAR - Televar Northwest, Inc.",
    "10610": "APA - American Psychological Association",
    "10611": "REOHR - The Reohr Group",
    "10612": "TUDOR-N - Tudor, Pickering, Holt & Co. Securities, Inc.",
    "10613": "MAUINET - Maui Net, Inc.",
    "10614": "ZHONKA- - Zhonka Broadband, LLC",
    "10615": "PAINEWEBBER-N - UBS AG",
    "10616": "NTIS - National Technical Information Service",
    "10617": "SION S.A",
    "10618": "NBNET - The National Business Network Inc.",
    "10619": "PUBLICONLINE - Public Online Communications Corporation",
    "10620": "Telmex Colombia S.A.",
    "10621": "FIRSTNETHOU - First Internet",
    "10622": "NIEHS - National Institute of Environmental Health Sciences (NIEHS)",
    "10623": "ANNAPOLIS-INTERNET - ANNAPOLIS INTERNET INC.",
    "10624": "Netpoint de Venezuela",
    "10625": "INTERACTIVEDATA-10625 Interactive Data Corporation",
    "10626": "INTRANET-INC - Intranet Technologies Inc.",
    "10627": "CP--10627 - Critical Path Inc.",
    "10628": "VINS--1 - ViaWest",
    "10629": "INTERPAC - Inter-Pacific Network Services",
    "10630": "Avati Seguranca Digital Avancada Ltda",
    "10631": "GEORGIA-STATE - Georgia State University",
    "10632": "PSE- - Puget Sound Energy",
    "10633": "AVIDGDC - Avid Technology, Inc.",
    "10634": "INET-COMPUTERS-INC - iNET Computers, Inc.",
    "10635": "THE-BTILLE - GTE Law Enforcement Services",
    "10636": "CAPGEMINI-US - Capgemini Financial Services USA Inc.",
    "10637": "TROYSAT - Troy Systems",
    "10638": "KANA - Kana.Com",
    "10639": "ALPHABLOX - ALPHABLOX CORPORATION",
    "10640": "DATANET S.A.",
    "10641": "TICKETMTER- - TicketMaster Corp.",
    "10642": "POWERNET - DHM Information Management, Inc",
    "10643": "SUBURBCABLE - Suburban Cable TU CO, Inc.",
    "10644": "ALLIEDSIGNAL-AA - AlliedSignal Automotive Aftermarket",
    "10645": "APPLIEDINNOVATIONS - Applied Innovations, Inc.",
    "10646": "TVCN- - Television Communications Network",
    "10647": "NACM - Nicholas Applegate",
    "10648": "PACIFICBROK - Pacific Brokerage Services",
    "10650": "EXTREME- - Extreme Internet",
    "10651": "INCC - Internet Communications Corp",
    "10652": "NETSIDE - NetSide Corporation",
    "10653": "MVANET - USAI.NET",
    "10654": "CONNECTIONS-COMMUNICATIONS - Connections Communications Sources Corp",
    "10655": "BUREAU-NAT-AFF - BUREAU OF NATIONAL AFFAIRS, INC.",
    "10656": "ECOL - Eau Claire Press Company",
    "10657": "GIANTSTEP - Giant Step",
    "10658": "GEEKLAB - Kollektive lucid ephemeric kaptive syndrome socitey",
    "10659": "SEQUENT-CS2 - IBM",
    "10660": "SYSNET- - SYSNET Communications",
    "10661": "SF-FIN-LP - Steadfast Financial LP",
    "10662": "NORFOLK-SOUTHERN - Norfolk Southern Corporation",
    "10663": "DISCOVERNET-N1 - DiscoverNet, Incorporated",
    "10664": "CP-INTERNET - CP Internet",
    "10665": "SKYNET - SkyNET Corporation",
    "10666": "ALLERGAN - Allergan, Inc.",
    "10667": "FSIWEBS-NET1- - Financial Services Inc",
    "10668": "LEE-N - Lee Enterprises, Inc.",
    "10669": "JOBTRAK- - Jobtrak Corp.",
    "10670": "COMPANHIA DE TECNOLOGIA DA INFORMA\u00c7\u00c3O ESTADO MG",
    "10671": "Comision Nacional de Actividades Espaciales",
    "10672": "REDSTORM - Red Storm Entertainment",
    "10673": "AFFINI - Affinity Internet, Inc",
    "10674": "GRUCOM - Gainesville Regional Utilities",
    "10675": "VIET-MY - Viet-My",
    "10676": "GLOBALEC - Sterling Commerce (America), Inc.",
    "10677": "OMNCS - OMNCS",
    "10678": "TRENDS-NET - @trends.ca",
    "10679": "INET-SVCS- - InterNetwork Services",
    "10680": "IUPUI - Indiana University-Purdue University at Indianapolis",
    "10681": "AOL-DTC1 - America Online",
    "10682": "VISION21N - Vision Twenty-One",
    "10683": "CRUZIO - Cruizo, Inc.",
    "10684": "EMPIRENET - EmpireNet",
    "10685": "A5COM - A5.COM",
    "10686": "MYXA-N - Myxa Corporation",
    "10687": "DISTRIBUTEL-10687 - DISTRIBUTEL COMMUNICATIONS LTD.",
    "10688": "ISM AUTOMACAO S.A.",
    "10689": "FVI-CHI - Fox Valley Internet, Inc.",
    "10690": "NETSCOUT - NETSCOUT SYSTEMS INC.",
    "10691": "ColInterNet",
    "10692": "DLS-LITH - DLS Internet Services",
    "10693": "VSPN-N - First Coast On Line Inc.",
    "10694": "MONST-2 - Monster Worldwide, Inc.",
    "10695": "WAL-MART - Wal-Mart Stores, Inc.",
    "10696": "MICROPATENT - MicroPatent",
    "10697": "Interlink S.R.L.",
    "10698": "WR-TECH - Wood River Technologies",
    "10699": "TELSOFT- - TelSoft Consultants, Inc.",
    "10700": "TECINFO - TECINFO",
    "10701": "FIBERPLUS - Fiber Plus, Inc",
    "10702": "INL- - Idaho National Laboratory",
    "10703": "PENTICS - Quadrunner Communications",
    "10704": "Microlink Telecom (LNCC)",
    "10705": "NU01-WS-NC - NetUnlimited Inc.",
    "10706": "Grupo Empresarial Mexicano en Telecomunicaciones, S.A. de C.V.",
    "10707": "MAGIBOXINC - Magibox, Inc.",
    "10708": "SELECTNET- - SelectNet Internet Services",
    "10709": "NETUSA- - Net USA",
    "10710": "USCATL - Ikon/USConnect Atlanta",
    "10711": "RCONNECT - Rural Connections",
    "10712": "ISTRADA - Strada Internet Services, Inc.",
    "10713": "GIGAN-3 - Insync Internet Services, Inc.",
    "10714": "RIGROUP - The Rock Island Group",
    "10715": "Universidade Federal de Santa Catarina",
    "10716": "OIS - OPTIMAL INTEGRATED SOLUTIONS",
    "10717": "SCHOLTIC - Scholastic Inc.",
    "10718": "CONSECO - Conseco Companies",
    "10719": "VRIS-10719-10720 - Verizon Online LLC",
    "10720": "VRIS-10719-10720 - Verizon Online LLC",
    "10721": "THEAN8 - The Andersons Inc",
    "10722": "ALCOA - Aluminum Co. of America",
    "10723": "MGL-40-N - Meritage Group LP",
    "10724": "HECENTER - Harbor Enterprise Center",
    "10725": "GENENTECH - Genentech, Inc.",
    "10726": "INAV-NET - Internet Navigator, Inc.",
    "10727": "NETACCESS-1 - Netaccess, Inc.",
    "10728": "T-MOBILE-10728 - T-Mobile USA, Inc.",
    "10729": "BUSINESSPRODUCTS - Business Products",
    "10730": "TBCNET - TBC Net, Inc.",
    "10731": "DAEDAL- - Daedal Enterprises, Inc.",
    "10732": "TIERRANET - TierraNet Inc.",
    "10733": "MATRIX INTERNET S.A.",
    "10734": "SVWIRELESS - Sioux Valley Wireless",
    "10735": "DATACOURSE - DataCourse Internet Solutions",
    "10736": "ITLTD - International Telcom, Ltd.",
    "10737": "BACTC - CellularONE",
    "10738": "INTELLETRACE - NACIO Systems, Inc.",
    "10739": "CYBERNET - CyberNET Engineering",
    "10740": "OWO- - Origin Systems, INC.",
    "10741": "WAMNET - Wam Net Enterprises Inc.",
    "10742": "DENIZ - Deniz Corporation",
    "10743": "GLOBALFEED - NTT Multimedia Communication Laboratories",
    "10744": "IBT - Innovative Business Technology, Inc.",
    "10745": "ARIN - ARIN Operations",
    "10746": "TAIS - TOSHIBA AMERICA INFORMATION SYSTEMS",
    "10747": "EFG - Empire Life",
    "10748": "QRC - Quantum Research Corporation",
    "10749": "AFFINET - Affinity Internet, Inc",
    "10750": "COHESIVE - Cohesive Systems",
    "10751": "GTS-N - G.T.S.",
    "10752": "SUPERHIGHWAY - SuperHighway.net, Inc.",
    "10753": "LVLT-10753 - Level 3 Communications, Inc.",
    "10754": "GOV-FRB-BOG - Federal Reserve Board",
    "10755": "DARTMOUTH- - Dartmouth College",
    "10756": "VVM- - VVM, Inc.",
    "10757": "SSD S. A.",
    "10758": "INWAVE- - INWave Internet, Inc",
    "10759": "INFRWITCH - Infraswitch",
    "10760": "THEBEAM - CS Wireless Systems, Inc.",
    "10761": "TRICETEL - Tricetel, Inc.",
    "10762": "CDN-DNS - TestDrive Corporation",
    "10763": "WEBSIDESTORY - Web Side Story, Inc.",
    "10764": "STARTAP - National Center for Supercomputing Applications",
    "10765": "CLOUDNET- - CloudNet",
    "10766": "N-TAIS-CSE - Toshiba America Information Systems, CSE",
    "10767": "HIPERNET- - Hiper Net",
    "10768": "COGENT-10768 - Cogent Communications",
    "10769": "TIDALWAVE - Tidal Wave Internet",
    "10770": "SBIS-N-BLK-2 - AT&T Internet Services",
    "10771": "SBIS-N-BLK-2 - AT&T Internet Services",
    "10772": "SBIS-N-BLK-2 - AT&T Internet Services",
    "10773": "SBIS-N-BLK-2 - AT&T Internet Services",
    "10774": "SBIS-N-BLK-2 - AT&T Internet Services",
    "10775": "CAREERMOSAIC-00 - Bernard Hodes Advertising, Inc.",
    "10776": "NETSCAN - NETSCAN Technology Corporation",
    "10777": "ZEONET - Buzzeo, Inc",
    "10778": "MCL Internet",
    "10779": "FLAGSHIP - Flagship Customs Services",
    "10780": "ONECOM-C1-2 - One Communications Corporation",
    "10781": "VINEYARD - Vineyard.NET, Inc.",
    "10782": "HP-DIGITAL-10782 - Hewlett-Packard Company",
    "10783": "IWSC-1 - Internet Web Service Corporation",
    "10784": "TOTALITY - MCI Communications Services, Inc. d/b/a Verizon Business",
    "10785": "Internet Services S.A.",
    "10786": "CHARTWAY-FCU - Chartway Federal Credit Union",
    "10787": "MOTHER-N - mother.com, Inc.",
    "10788": "CDW - CDW LLC",
    "10789": "BIGNET- - The Bignet",
    "10790": "QS-PHL - Quatro Systems Inc",
    "10791": "PDQNETINC - PDQ NET INCORPORATED",
    "10792": "WEBNETWORLWIDE - WebNet Inc.",
    "10793": "IDSOFT - ID Software",
    "10794": "BANK-OF-AMERICA Bank of America",
    "10795": "Desarrollos Digitales S. A.",
    "10796": "SCRR-10796 - Time Warner Cable Internet LLC",
    "10797": "MICH-COM - MICH.COM, INC.",
    "10798": "SBICSA",
    "10799": "PITTENCRIEF - Pittencrief Communications",
    "10800": "INTERNETARENA-GW - Internet Arena",
    "10801": "REGIONS-N-1 - REGIONS FINANCIAL CORPORATION",
    "10802": "KOPPELNET - KOPPEL STEEL",
    "10803": "ET-COT-ACCESS",
    "10804": "RSCS--1 - Rocket Science Computer Services, Inc.",
    "10805": "XO-10805 - XO Communications",
    "10806": "AFP-NET - AGENCE FRANCE PRESSE",
    "10807": "ERX-HOLE-IN-ONE Hitachi Business International, Ltd.",
    "10808": "THE-GLOBE-AND-MAIL - The Globe and Mail",
    "10809": "NCIA - North Country Internet Access",
    "10810": "HARVESTCOMM01 - Harvest Communications, Inc.",
    "10811": "IENET - Internet Express Network",
    "10812": "UTPB--10812 - University of Texas System",
    "10813": "DELTATHREE - Deltathree",
    "10814": "XSBANDWIDTH - XS Bandwidth Associates",
    "10815": "TURNKEY-INTERNET - Turnkey Internet Inc.",
    "10816": "DESKTALK- - DeskTalk Systems, Inc.",
    "10817": "GACONNECT - Georgia Connection.net",
    "10818": "FULLNETOK - Fullnet Communications",
    "10819": "ICC - IFWORLD Inc.",
    "10820": "MECKLERMEDIA - Mecklermedia Corp.",
    "10821": "PIONEERINTERNET - Pioneer Internet",
    "10822": "UNISTAR - Unistar Entertainment, Inc",
    "10823": "NETCARRIER - NetCarrier, Inc.",
    "10824": "BANQUE DE LA REPUBLIQUE D'HAITI",
    "10825": "QWEST-NBLK-3 - Qwest Corporation",
    "10826": "QWEST-NBLK-3 - Qwest Corporation",
    "10827": "QWEST-NBLK-3 - Qwest Corporation",
    "10828": "QWEST-NBLK-3 - Qwest Corporation",
    "10829": "QWEST-NBLK-3 - Qwest Corporation",
    "10830": "QWEST-NBLK-3 - Qwest Corporation",
    "10831": "QWEST-NBLK-3 - Qwest Corporation",
    "10832": "QWEST-NBLK-3 - Qwest Corporation",
    "10833": "QWEST-NBLK-3 - Qwest Corporation",
    "10834": "Telefonica de Argentina",
    "10835": "VISIONARY - Visionary Communications, Inc.",
    "10836": "N-NJCC - New Jersey Computer Connection",
    "10837": "WELLSFARGO - Wells Fargo & Company",
    "10838": "OCEANIC-INTERNET-RR - Oceanic Internet",
    "10839": "CIN - Computerese Information Network, Inc.",
    "10840": "CAHWNET - Health and Welfare Agency Data Center",
    "10841": "sbc sistema brasileiro de comunica\u00e7\u00f5es ltda",
    "10842": "ESCA- - Cegelec ESCA Corporation",
    "10843": "AITNET - Advanced Internet Technologies",
    "10844": "VTNET - Vastnet Corp",
    "10845": "HITCOMN - HITCOM CORP",
    "10846": "DEERE - Deere & Company",
    "10847": "Podernet, S.A. de C.V.",
    "10848": "DELL-SERVICES - Dell Marketing USA, L.P.",
    "10849": "DCCCD - Dallas County Community College District",
    "10850": "MARC-GROUP - The M/A/R/C Group",
    "10851": "NREP - Nashville Regional Exchange Point",
    "10852": "PREMIER-INTERNET - Premier Internet, Inc.",
    "10853": "ANDERSENCORP - Andersen Corporation",
    "10854": "AIRMEDIA - AirMedia",
    "10855": "AUTO-BY-TEL - AUTO BY TEL",
    "10856": "LINKDATA - LINKDATA COMMUNICATIONS INC",
    "10857": "JCPENNEY- - JCPenney Co., Inc.",
    "10858": "HYPER-BNG-N - Hypertherm Inc.",
    "10859": "COMPUTER-SCIENCES-CORP-NTIS - Computer Sciences Corp - NTIS",
    "10860": "TOWERRECORDS- - MTS Inc",
    "10861": "E-Z-NET - E-Z.Net, Inc",
    "10862": "CURTISMATHES - Curtis Mathes",
    "10863": "WAVEFRONT - WaveFront Communications, Inc.",
    "10864": "ELOGIC - Elogic",
    "10865": "ABACOM-N - Services Internet Abacom",
    "10866": "REDSAT-HOUSTON - Redsat Inc.",
    "10867": "FHDA- - Foothill-DeAnza Community College District",
    "10868": "DOWNCITY - DownCity LLC",
    "10869": "ANX - Bellcore",
    "10870": "LINK-1 - Link-1, Inc.",
    "10871": "NOAANWSERH - DOC/NOAA/NWS-ERH",
    "10872": "DV-N - Digital Visions",
    "10873": "SIEMENS-SMI - Siemens Microelectronics",
    "10874": "SUNSET-DIRECT - Sunset Direct",
    "10875": "FUNDACAO DE APOIO DA UNIVERSIDADE FEDERAL DO",
    "10876": "MAOZ-N - MAOZ.COM",
    "10877": "CHAMBERS - Chambers Multimedia Connection",
    "10878": "IBS- - Internet Broadcasting System",
    "10879": "UHC - Unitedhealthcare",
    "10880": "YAHOO-AN2 - Yahoo",
    "10881": "FUNPAR - Fundacao da UFPR para o DCTC",
    "10882": "CLARITYCONNECT - Clarity Connect Inc",
    "10883": "COMSPANUSA - Comspan Communications Inc.",
    "10884": "FRYIN- - Fry Inc",
    "10885": "AMINI - Amini Enterprises, Inc.",
    "10886": "MAX-GIGAPOP - University of Maryland",
    "10887": "BPSI- - BPSI Internet Services",
    "10888": "EI-AIX - National Aeronautics and Space Administration",
    "10889": "TRENSEN - Trensen Inc.",
    "10890": "PHILADELPHIA-NEWSPAPERS - Philadelphia Newspapers Incorporated",
    "10891": "UTSWEB - Universal Tax Systems Inc",
    "10892": "ISSI - Infinite Software Solutions, Inc.",
    "10893": "NYT-EWR1 - The New York Times Company",
    "10894": "U11912 - WebGenesis, Inc",
    "10895": "Prima S.A.",
    "10896": "VERIFONE - Verifone Incorporated",
    "10897": "Camara dos Deputados",
    "10898": "BI-NET-SA",
    "10899": "RADIOSHACK - RADIOSHACK CORP",
    "10900": "EDUC-NET-PROV - Educational Network Provider",
    "10901": "TERABIT - TERABIT.NET",
    "10902": "INFILINK-CORPORATION - BISYS Creative Solutions",
    "10903": "TARGET-N - Target Corporation",
    "10904": "EQUISTAR- - EQUISTAR Petrochecmical Company",
    "10905": "CITIC-SECURITIES-INTERNATIONAL-USA - CITIC SECURITIES INTERNATIONAL USA, LLC",
    "10906": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "10908": "CLOUDFLOOR - Cloud Floor Corporation",
    "10909": "WHITEELMCAPITALLLC - WHITE ELM CAPITAL, LLC",
    "10910": "INTERNAP-BLK - Internap Network Services Corporation",
    "10911": "INTERNAP-BLK - Internap Network Services Corporation",
    "10912": "INTERNAP-BLK - Internap Network Services Corporation",
    "10913": "INTERNAP-BLK - Internap Network Services Corporation",
    "10914": "BRIN - Broadcast International",
    "10915": "CQL- - CQL Incorporated",
    "10916": "QL-N-WLV - Qlogic Corporation",
    "10917": "THOMSON-TORONTO - Thomson Corporation",
    "10918": "WEIGHTWATCHERS-MADISON - WeightWatchers.com, Inc.",
    "10919": "TROYFP - Troy Corporation",
    "10920": "ILI - Internet Labs, Inc.",
    "10921": "KIHNETWORK - Commonwealth of KentuckyDepartment of Information Systems",
    "10922": "LIVEJOURNAL - Live Journal Inc.",
    "10923": "MONTREAL-COLO - Vonage Holdings, Inc.",
    "10924": "N-GMTN - GANDER MOUNTAIN COMPANY",
    "10925": "SNOWBOUND - Snowbound Software Corporation",
    "10927": "PCH-SD-NAP - Packet Clearing House",
    "10928": "CTI-NETRAX - CTI / Netrax",
    "10929": "NETELLIGENT - Netelligent Hosting Services Inc.",
    "10930": "NOVA-INTERNET - Nova Internet Services, Inc.",
    "10932": "UC2B - UC2B",
    "10933": "ATXNET- - ATX Telecommunications Services",
    "10934": "10934 - JPMorgan Chase & Co.",
    "10935": "RLC-INTERNET - RLC INTERNET",
    "10936": "MARNELL-CORRAO-SOC-MCC1 - Marnell Corrao Assoc.",
    "10937": "CENTENNIAL-PR - Centennial de Puerto Rico",
    "10938": "AGENCIA ESTADUAL DE TECNOLOGIA DA INFORMACAO - ATI",
    "10939": "PMG1 - Paxton Media Group, LLC.",
    "10940": "FONALITY Fonality, Inc.",
    "10941": "ORGAN-1 - Organic, Inc",
    "10942": "DSNET- - Dunlap Services, Inc.",
    "10944": "ABAG-CSG - Association of Bay Area Governments",
    "10945": "DEMATTEO-MONNESS-LLC - DeMatteo Monness LLC",
    "10947": "WERCS-NET - CORE BUSINESS SOLUTIONS",
    "10948": "INTERNET - ING Investment Management",
    "10949": "SMART-CITY-PITTSBURGH - Smart City Networks, L.P.",
    "10950": "DNSCENTRAL-1 - IRIDES, LLC",
    "10951": "MGA-ENTERTAINMENT - MGA ENTERTAINMENT INC.",
    "10952": "ECU- - East Carolina University",
    "10953": "PECO - PECO Energy Company",
    "10954": "SERVICO FEDERAL DE PROCESSAMENTO DE DADOS - SERPRO",
    "10955": "WILPATERSON - WILLIAM PATERSON UNIVERSITY",
    "10956": "TALKFUSION - Talk Fusion, Inc",
    "10957": "REALMED - REALMED CORPORATION",
    "10958": "ROYELLCOMM- - Royell Communications, Inc.",
    "10959": "BAC-NPC - Bank of America",
    "10960": "QWEST--10960 - Qwest Corporation",
    "10961": "BGP- - Boston GigaPoP",
    "10962": "SMS-CORP-N - Siemens Medical Solutions Health Services Corporation",
    "10963": "NTHAIRNET - Nth Air, Inc.",
    "10964": "Red Cooperativa de Comunicaciones",
    "10965": "MRNET - MRNet",
    "10966": "ALKA-AIR - Alaska Airlines, Inc.",
    "10967": "HOMEDEPOTNET - The Home Depot",
    "10968": "CARGILL-NET - Cargill Incorporated",
    "10969": "TRANSCENDENT - Transcendent, LLC",
    "10970": "LIGHTEDGE - LightEdge Solutions",
    "10971": "CSCOMM - Cass Cable TV, Inc.",
    "10972": "NF-CANET2 - Memorial University, NF CAnet 2 gigaPOP",
    "10973": "KALAMA - Scatter Creek InfoNet, Inc.",
    "10974": "-10974 - CUsource, LLC",
    "10975": "NET-AIG - American International Group Data Center, Inc.",
    "10976": "THINKINGPHONES - Thinking Phone Networks, Inc.",
    "10977": "GECKON - Gecko Internet",
    "10978": "TRIS3CT - Tris3ct LLC",
    "10979": "ICWGROUP - INSURANCE COMPANY OF THE WEST",
    "10980": "STAFFORD - Stafford Communications, Inc.",
    "10981": "OPUBCO - The Oklahoma Publishing Company",
    "10982": "TIVO-SJ - TiVo, Inc.",
    "10983": "Telecom Argentina S.A.",
    "10984": "IDS--BAYOU - HuntTel",
    "10985": "CURTIS-NUM - Curtis Instruments, Inc.",
    "10986": "Intermedia Comunicaciones S.A.",
    "10987": "PLUMCREEK- - Plum Creek Marketing, Inc.",
    "10988": "MOHAVE-WIRELESS - CITIZENS MOHAVE CELLULAR DBA MOHAVE WIRELESS",
    "10989": "WINBEAM--2 - Winbeam",
    "10990": "N2TULIX - Tulix Systems, Inc.",
    "10991": "CAPGE-HOSTING-MRO - Capgemini U.S. LLC",
    "10992": "Giga System",
    "10993": "AERIONET-INC - Aerioconnect",
    "10994": "TAMPA2-TWC-5 - Time Warner Cable Internet LLC",
    "10995": "PNCBANK - PNC Bank",
    "10996": "CONCORDE - Concorde inc.",
    "10997": "INTDATA- - Interactive Data",
    "10998": "BAC-MLAMRS - Bank of America",
    "10999": "BAC-MLAMRS - Bank of America",
    "11000": "BAC-MLAMRS - Bank of America",
    "11001": "BAC-MLAMRS - Bank of America",
    "11002": "BAC-MLAMRS - Bank of America",
    "11003": "PANDG - The Procter and Gamble Company",
    "11004": "KNOWLEDGESOFT - KnowledgeSoft",
    "11005": "CHX- - Chicago Stock Exchange, Inc.",
    "11006": "ENTRU-6 - EnTrust Capital Inc.",
    "11007": "JMBM - Jeffer Mangels Butler & Marmaro LLP",
    "11008": "Netverk S.A.",
    "11009": "CARLOWUNIV - Carlow University",
    "11010": "ENI-HOSTING - ENI-Hosting, LLC",
    "11011": "DFTLP - DuPont Fabros Technology LP",
    "11012": "DDC- - The Digital Design Company",
    "11013": "BLUE- - Bluemile, Inc.",
    "11014": "CPS",
    "11015": "TCH- - Texas Children's Hospital",
    "11016": "EXP-EC1999 - Experian",
    "11017": "CSN - CSN Support Services",
    "11018": "GLOBALACCESS - NTT Multimedia Communications Laboratories",
    "11020": "QNET-N - Quantum Networking Solutions, Inc.",
    "11022": "ALABANZA-BALT - Alabanza, Inc.",
    "11023": "SYSSRC - System Source",
    "11024": "COGENT-11024 - Cogent Communications",
    "11025": "COMCT-HOUSTON - Comcast - Houston",
    "11026": "ATTIS-N11026 - AT&T Internet Services",
    "11027": "KEMPER-INSURANCE - Kemper Insurance Companies",
    "11028": "SETIATHOME - SETIATHOME",
    "11029": "BMT999 - Beach Mold & Tool",
    "11030": "QUALCOMM - Qualcomm, Inc.",
    "11031": "ORBIS-INVESTMENTS - Orbis Investments (Canada) Limited",
    "11032": "UQ - Universite du Quebec",
    "11033": "N-LYNXNET-CA - LYNXNET.CA",
    "11034": "INTELEPEER-US - IntelePeer, Inc.",
    "11035": "KCPA1 - The Raymond F. Kravis Center for the Performing Arts, Inc.",
    "11036": "SISCOM - Signal Perfection, Ltd., Inc.",
    "11037": "MSS-97-N01 - Mohawk Shared Services Inc",
    "11038": "TULALIP-TRIBES - The Tulalip Tribes of Washington",
    "11039": "GWU - The George Washington University",
    "11040": "FMR-1 - Fidelity Investments",
    "11041": "INTERNET-CONNECT-FL - Internet Connect Company",
    "11042": "LANDIS-HOLDINGS-INC - Landis Holdings Inc",
    "11043": "SUNRI-45 - Sunrise Brokers",
    "11044": "HPLD - Harvey Public Library District",
    "11045": "STERLING - Sterling Communications, Inc.",
    "11046": "LITTLE-APPLE - Little Apple Technologies",
    "11047": "HHCC-N1 - Hartford Hospital",
    "11048": "4BIS - 4BIS.COM, Inc.",
    "11049": "TZONET - Tzolkin Corporation",
    "11050": "KENT-STATE - Kent State University",
    "11051": "CYBERVERSE - Cyberverse, Inc.",
    "11052": "IHC-NET - Intermountain Health Care",
    "11053": "Sistemas de Tecnologia Avanzada S.A. (STA S.A.)",
    "11054": "LIVEPERSON LivePerson, Inc",
    "11055": "MIDCONTINENT-COMMUNICATIONS - Midcontinent Media, Inc.",
    "11056": "BERGERMONTAGUE - Berger & Montague, P.C",
    "11057": "WTHOMPSONCO - J. Walter Thompson",
    "11058": "CABE Camara Arg de Base de Datos y Serv en Linea",
    "11059": "KANEVA-NETWORK - Kaneva, Inc.",
    "11060": "NEO-RR-COM - Time Warner Cable Internet LLC",
    "11061": "HUGHES-EC - Antelecom, Inc.",
    "11062": "MTCO-COMMUNICATIONS - MTCO Communications",
    "11063": "Microstar S.A.",
    "11064": "STB-N - Simpson Thacher & Bartlett",
    "11065": "NCI - Network Communication Inc.",
    "11066": "CNFNET - Con-way, Inc.",
    "11067": "PTSINET - Panhandle Telecommunications Systems, INC.",
    "11068": "IFORMATA-DYTNOH - Iformata LLC",
    "11069": "EGIX-INDY--11069 - Egix, Inc.",
    "11070": "META- - Metanet Communications, Inc.",
    "11071": "IW-N-11071 - InfoWest, Inc.",
    "11072": "RTS-US - Redflex Traffic Systems, Inc.",
    "11073": "MPR-DUAL-INT - Minnesota Public Radio",
    "11074": "RBS-CHG - Sidera Networks LLC",
    "11075": "BVI-1 - Broadway Video, Inc.",
    "11076": "COMMUNITY-COMPUTER-SERVICE-INC - COMMUNITY COMPUTER SERVICE INC",
    "11077": "XBE-N1 - XBE Technologies Corp.",
    "11078": "BROWN - Brown University",
    "11079": "ALLST-11079 - Allstream Corp.",
    "11080": "YKWC - Yellowknife Wireless Company, LLC",
    "11081": "United Telecommunication Services (UTS)",
    "11082": "BRAINLINK-INTL-INC - BrainLINK International, Inc.",
    "11083": "Ocean Fund International Ltd.",
    "11084": "HURONTEL - Huron Telecommunications Cooperative Limited",
    "11085": "PDI-HQ-INET - Premier Designs, Inc",
    "11086": "PB-EUROPE Pitney Bowes PLC",
    "11087": "Comision Federal de Electricidad",
    "11088": "ICONNECT - iConnect",
    "11089": "ERGON-NETWORK - ERGON",
    "11090": "MTAONLINE- - Matanuska Telephone Association, Inc.",
    "11091": "SCHRYVER-MEDICAL - Schryver Medical Sales and Marketing, Inc.",
    "11092": "HEVANET - Hevanet",
    "11093": "DATAWAY - Dataway",
    "11094": "N-UMDNJ - University of Medicine & Dentistry of New Jersey",
    "11095": "FLORIDANET - FloridaNet",
    "11096": "FLORIDANET - FloridaNet",
    "11097": "EMPRESA BRILEIRA DE PESQUISA AGROPECUARIA",
    "11098": "SBC-NET - SBC Communications, Inc.",
    "11099": "SBC-NET - SBC Communications, Inc.",
    "11100": "DATAPOINTINC - DataPoint",
    "11101": "PALMETTOHEALTH - Palmetto Health",
    "11102": "VYANET-OPERATING-GROUP-INC - VYANET",
    "11103": "EXECULINK-N - Execulink Telecom Inc.",
    "11104": "QWEST--11104 - Qwest Corporation",
    "11105": "SFU- - Simon Fraser University",
    "11106": "WOLFRAM- - Wolfram Research, Inc.",
    "11107": "FREMONT-COMM - Blackfoot Telephone Cooperative, Inc.",
    "11108": "RESTSURED - Rest Assured, LLC",
    "11109": "STATE-OF-ALABAMA-ISD - State of Alabama, Information Services Division",
    "11110": "COLO-CATION - Colo-cation",
    "11111": "THOMSON-HEALTHCARE - Thomson Reuters Holdings Inc",
    "11112": "ACCELPLUS - ACCELPLUS",
    "11113": "XO-11113 - XO Communications",
    "11114": "WINTEK-CORP - Wintek Corporation",
    "11115": "BIZSERVE - Online Tech Inc.",
    "11116": "ONLYINTERNET-BROADBAND-AND-WIRELESS - OnlyInternet Broadband and Wireless",
    "11117": "N-COGENT-QWEST - ENERGY CAPITAL PARTNERS MGMT",
    "11118": "COMTECK - ComTeck",
    "11119": "CA-WMMERCER-11119 - Mercer (Canada) Limited",
    "11120": "ISYS-LLC - iSYS, LLC",
    "11121": "FIRSTDATACORP-DB - FIRST DATA CORPORATION",
    "11122": "CACI-NET - CACI INC",
    "11123": "UIA - Ultimate Internet Access, Inc",
    "11124": "FRIEDKIN - Friedkin Companies, Inc.",
    "11125": "EBIZ",
    "11126": "CARLE-N - Carle Clinic Association",
    "11127": "NETSAT- - NetSat Express, Inc.",
    "11128": "BERRY-2-N - Berry College",
    "11129": "VENTE-OMAHA - Vente Inc.",
    "11130": "TC3NET- - The Computer Care Company Inc.",
    "11131": "UMBC- - University of Maryland Baltimore County (UMBC)",
    "11132": "JDA-EHEALTH-SYSTEMS - JDA eHealth Systems, Inc.",
    "11133": "SORENSON-99 - Sorenson Communications, Inc.",
    "11134": "WEBFIRE-MILTEL - WebFire Internet Services",
    "11135": "CROSS-DEVELOPMENT-MONTGOMERY - Cross Development/Montgomery LP",
    "11136": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "11137": "ACCESSINTERNET - Access Internet",
    "11138": "BEK-COMMUNICATIONS-INTERENET-ROUTER - BEK Communications Cooperative",
    "11139": "CWRIN CW BARBADOS",
    "11140": "BEHRPROCESS - Behr Process",
    "11141": "THE-CLIFTON-GROUP - The Clifton Group",
    "11142": "PRECISION-DATA-SOLUTIONS - Precision Data Solutions, LLC",
    "11143": "OECONNECTION - OEConnection, LLC",
    "11144": "ADVENT-SOFTWARE - Advent Software",
    "11145": "VRIS-11145-11149 - Verizon Online LLC",
    "11146": "VRIS-11145-11149 - Verizon Online LLC",
    "11147": "VRIS-11145-11149 - Verizon Online LLC",
    "11148": "VRIS-11145-11149 - Verizon Online LLC",
    "11149": "VRIS-11145-11149 - Verizon Online LLC",
    "11150": "BRYAN-PRODUCTION - RackHaven",
    "11151": "INTERLIANT- - Interliant",
    "11152": "WHT-ATT-XO - Waverly Hall Telephone, LLC.",
    "11153": "UNISON-1 - Unison Networks LLC",
    "11154": "SWS - Southwest Securities, Inc.",
    "11155": "QUADCITIESONLINE - Quad-Cities Online",
    "11156": "JEROMEGROUP - Jerome Group, Inc.",
    "11157": "ELAB",
    "11158": "NETDEPON - NTT America, Inc.",
    "11159": "LAPL-LAPUBLICLIBRARY - Los Angeles Public Library",
    "11160": "COSTAR-SANDIEGO - COSTAR GROUP",
    "11161": "ATL-NAP-N1 - Lablynx, Inc.",
    "11162": "LN-CHILDRENSHOSPITAL-N - Los Nettos",
    "11164": "INTERNET2-TRANSITRAIL-CPS - National LambdaRail, LLC",
    "11165": "DPI - Toppan Photomasks, Inc.",
    "11166": "JCOM-3 - J2 Global Inc.",
    "11167": "IN-TOUCH-IN-FLIGHT - AirCell, LLC.",
    "11168": "SCC - SMART CHOICE COMMUNICATIONS, LLC",
    "11169": "SECUREFOUNDATIONS - Secure Foundations",
    "11170": "ROLLERNETWORK - Roller Network LLC",
    "11171": "AUTONATION-FTLD - Autonation, Inc",
    "11172": "Alestra, S. de R.L. de C.V.",
    "11173": "NMIX - Oso Grande Technologies, Inc.",
    "11174": "-ATHEN-1 - Athenahealth",
    "11175": "DISTRIBUTEL-11175 - DISTRIBUTEL COMMUNICATIONS LTD.",
    "11176": "SMART-CITY-MINNEAPOLIS - Smart City Networks, L.P.",
    "11177": "QUESTAR - Questar",
    "11178": "ACCESSPLUS-COMMUNICATIONS - AccessPlus Communications, Inc.",
    "11179": "ARYAKA-ARIN - Aryaka Networks, Inc.",
    "11180": "CX-DATA-PUBLIC- - CX-DATA INC.",
    "11181": "VAXXINE - Vaxxine Computer Systems Inc.",
    "11182": "RIMES01 - RIMES TECHNOLOGIES CORPORATION",
    "11183": "MHTC-NET - Mount Horeb Telephone Co",
    "11184": "-ORBZ1 - Orbitz, LLC",
    "11185": "SHIONOGI-GA - Shionogi Inc",
    "11186": "REDPLAID-STL - REDPLAID Managed Hosting, LLC",
    "11187": "GWS-ARIN- - Global Web Solutions, Inc.",
    "11188": "LACOUNTY-ISD - LOS ANGELES COUNTY - INTERNAL SERVICESDIVISION",
    "11189": "CFL-1 - Caliber Funding LLC",
    "11190": "SILCON - Silicon Connections, LLC.",
    "11191": "F2W- - Fire2Wire",
    "11192": "SMARTCITY-LVEG - Smart City Networks, L.P.",
    "11193": "COMNET S.A.",
    "11194": "NUNETPA - NuNet Inc.",
    "11195": "COHO-N - Whiz to Coho, Inc.",
    "11196": "NESTLE-USA - Nestle USA",
    "11197": "DART-HITCH - Dartmouth-Hitchcock Medical Center",
    "11198": "APC - American Power Conversion",
    "11199": "SHOWNETS - showNets LLC",
    "11200": "REGISU - Regis University",
    "11202": "DBNA - Deutsche Bank Group",
    "11203": "CALDSL - CalDSL",
    "11204": "IAI-NET- - Information Access, Inc.",
    "11205": "CITY-OF-PHILADELPHIA - City of Philadelphia",
    "11206": "FSU--1 - Ferris State University",
    "11207": "BOSTONGLOBENET - The Boston Globe",
    "11208": "HCPL- - HALL CAPITAL PARTNERS, LLC",
    "11209": "OFITRI - OppenheimerFunds, Inc.",
    "11210": "CANONICAL-USA- - Canonical USA Inc.",
    "11211": "NCIC - NCIC Operator Services",
    "11212": "COUNTY-OF-SONOMA - COUNTY OF SONOMA",
    "11213": "LVLT - Level 3 Communications, Inc.",
    "11214": "UNIVERSITY-OF-NORTH-FLORIDA - University of North Florida",
    "11215": "LOGIXCOMM- - Logix Communications, Inc.",
    "11216": "HOSTCENTRIC - Peer 1 Dedicated Hosting",
    "11217": "CLM-N - Carter Ledyard & Milburn LLP",
    "11218": "TED-MOUDIS-SOCIATES-INC - Ted Moudis Associates, Inc.",
    "11219": "GLIDEWELL - James R. Glidewell Dental Ceramics Inc.",
    "11220": "COGENT-11220 - Cogent Communications",
    "11221": "WHRONET - WHRO",
    "11222": "PRL - Polo Ralph Lauren",
    "11223": "MECHOSHADE - Mechoshade Systems INC",
    "11224": "SIR - Schaeffer's Investment Research",
    "11225": "QWEST-NBLK-4 - Qwest Corporation",
    "11226": "QWEST-NBLK-4 - Qwest Corporation",
    "11227": "-ROSEMONT - Morningstar, Inc.",
    "11228": "ARINC - ARINC, Inc.",
    "11229": "SUNVALE-2 - Sunvale Inc.",
    "11230": "KOALATECH - KoalaTech LLC",
    "11231": "GETTYSBURG-DOM - GETTYSBURG COLLEGE",
    "11232": "MIDCO-NET - Midcontinent Media, Inc.",
    "11233": "GORGE-NETWORKS - Gorge Networks Inc.",
    "11234": "HYDUKE1 - Hyduke Energy Services Inc.",
    "11235": "ITRONHOSTING - Itron-Hosting",
    "11236": "FUSEMAIL - MailAnyone.net",
    "11237": "UNIVERSIDAD EAFIT",
    "11238": "NWOL- - NetWest Online, Inc.",
    "11239": "SKYCOMP-01 - Skycomp Solutions Inc.",
    "11240": "ATC-BROADBAND - AccessATC",
    "11241": "VPOP-IP-NETWORK - Transera Communications, Inc.",
    "11242": "Universidade Federal de Santa Catarina",
    "11243": "HALAR-ATG1 - Halaris Associates Inc.",
    "11244": "AMAG-N - AMAG Pharmaceuticals, Inc",
    "11246": "MMUSA--SP - MediMedia USA, Inc.",
    "11247": "IBSINC - Internet Business Services, Inc.",
    "11248": "MULTISERVICE-NET - Multi Service",
    "11249": "CONTROLNET - CONTROL NET",
    "11250": "TRI-STATE-G-AND-T - Tri-State Generation and Transmission Association Inc.",
    "11251": "MLB-ADVANCED-MEDIA - Major League Baseball Advanced Media, LP",
    "11252": "ISU-NET- - Idaho State University",
    "11253": "BMWNY01 - BMW of Manahattan, Inc",
    "11255": "SBT-NET - Screamin' Banshee Technologies",
    "11256": "Abaco Soc de Hecho.",
    "11257": "UNIVERSITY-LETHBRIDGE - University of Lethbridge",
    "11258": "NISSINFOODS-USA-GARDCA - Nissin Foods (U.S.A.) Company, Inc.",
    "11259": "ANGOLATELECOM",
    "11260": "ETLINK-HSI - EastLink",
    "11261": "EHI-PROD-SJ- - eHealthInsurance Services Inc.",
    "11262": "WH-TRADING - W.H. Trading, L.L.C.",
    "11263": "KINGSFORD - Kingsford Capital Management",
    "11264": "LIQUIDNET-01 - LIQUIDNET HOLDINGS INC.",
    "11266": "SMUGMUG - SmugMug, Inc.",
    "11267": "PEIRCE-PHELPS - Peirce-Phelps, Inc.",
    "11268": "UBM-US-SF - United Business Media LLC",
    "11269": "CW-BERMUDA- Dummy object for CW-Bermuda",
    "11270": "NETWRIGHT - Net Wright LLC",
    "11271": "BT Latam Brasil Ltda",
    "11272": "TELEPAK-NETWORKS-INC - Telepak Networks Inc",
    "11273": "FDCSGNET - FIRST DATA CORPORATION",
    "11274": "ADHOST - Adhost Internet Advertising, LLC",
    "11275": "NBH-HOLDINGS-CORPORATION - NBH Holdings Corporation",
    "11276": "DATAHUB - DataHUB, Inc.",
    "11277": "NIPSCO - NISOURCE INC",
    "11278": "NINTENDO - Nintendo Of America inc.",
    "11279": "GEORGE-MON-UNIV - George Mason University",
    "11280": "SNAPPYDSL-N1 - SNAPPYDSL.NET",
    "11281": "GTSINCORP - Global Technology Solutions, Inc",
    "11282": "SERVERYOU - SERVERYOU INC",
    "11283": "COSTCO - Costco, Inc.",
    "11284": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "11285": "KW-CORPORATION - K W Corporation, Inc.",
    "11286": "KEYBANK - KeyBank National Association",
    "11287": "REYAOD - The Reynolds and Reynolds Company",
    "11288": "COMMEDIA - Commercial Media Corporation",
    "11290": "RAPIDUS - COGECO Cable Canada Inc.",
    "11291": "HEARTLANDADVISORS - Heartland Advisors inc.",
    "11292": "SUREWEST-CDS - Surewest Internet",
    "11293": "UCOP-N - University of California - Office of the President",
    "11294": "LIFETOUCH-INC - Lifetouch Inc",
    "11295": "BR HOME SHOPPING LTDA",
    "11296": "INDEPENDENT-HEALTH - Independent Health Association, Inc.",
    "11297": "LIPSCOMB - Lipscomb University",
    "11298": "TWC-RENEW - Renew Data Corp.",
    "11299": "DIALISDN - Dial ISDN, Inc",
    "11300": "GLOBECOMM-11300 - Globecomm Services Maryland LLC",
    "11301": "ALKADIGITELCRX - Alaska Digitel, LLC",
    "11302": "GTECH - GTECH Corporation",
    "11303": "DATARETURN - Data Return",
    "11304": "BMH-N - Blount Memorial Hospital, Inc.",
    "11305": "P1DH-1-N - Peer 1 Dedicated Hosting",
    "11306": "NRS-CHI-01 - Virtual Radiologic Corporation",
    "11308": "RGII - The Rockefeller Group",
    "11309": "IMF - International Monetary Fund",
    "11310": "BOSTONPUB - Boston Public Schools",
    "11311": "Sinectis S.A.",
    "11312": "YORKTEL- - York Telecom Corporation",
    "11313": "FANNIEMAE - Fannie Mae",
    "11314": "PRINTABLE - PRINTABLE TECHNOLOGIES, Inc.",
    "11315": "Telef\u00f3nica M\u00f3viles Argentina S.A. (Movistar Argentina)",
    "11317": "GPN - Great Plains Network",
    "11318": "GU - Georgetown University",
    "11319": "ACI- ACI Autonomous System",
    "11320": "LIGHTEDGE--02 - LightEdge Solutions",
    "11321": "EXPANSION-PROGRAMS - Expansion Programs International",
    "11322": "TRMC-MAIN-CAMPUS - Thibodaux Regional Medical Center",
    "11323": "GETTYIMAGES - Getty Images",
    "11324": "PRUFOXROACH - Prudential Fox & Roach",
    "11325": "11325 - Altus Communications Inc.",
    "11326": "N-ETMAN-CHEMICAL - Eastman Chemical Company",
    "11327": "NCI-GROUP-INC - NCI Group, Inc.",
    "11328": "BIO-RAD-N - Bio-Rad Laboratories, Inc.",
    "11329": "N-USI - USinternetworking Inc",
    "11330": "SFOC - Foodland Super Market, Limited",
    "11331": "THLNYC-N - Thomas H. Lee Capital, LLC",
    "11332": "CRESTRON - Crestron Electronics Inc",
    "11333": "CYBERTRAILS - Cyber Trails   / Arizona Public Service",
    "11334": "MIDAMERICAN - MidAmerican Energy Holdings Company",
    "11335": "APIS - Internet Consultoria e Comercio Ltda",
    "11336": "BGLOBAL - Barclays Global Investors",
    "11337": "MARLABS- - Marlabs Incorporated",
    "11338": "ITSA INTERCONTINENTAL TECOMUNICACOES LTDA",
    "11339": "USA-53 - United Sources of America Inc.",
    "11340": "Red Universitaria Nacional",
    "11341": "EYNET-US The Easynet US Network",
    "11342": "PATHWAY - Pathway Communications",
    "11343": "383INCCMHTOWN - 383inc",
    "11344": "-METAWEB - Metaweb Technologies, Inc.",
    "11345": "AKIMA-MANAGEMENT-SERVICES - Akima Management Services, Inc.",
    "11346": "CRITICAL-1 Critical Issue Inc.",
    "11347": "ORC-F2 - ORC",
    "11348": "MST - Missouri University of Science and Technology",
    "11349": "WINDSTREAM - Windstream Communications Inc",
    "11350": "DRUGSOURCE - Drugsource, Inc.",
    "11351": "RR-NYSREGION-N-01 - Time Warner Cable Internet LLC",
    "11352": "STRATCALE-01 - StrataScale, Inc.",
    "11353": "N-ESCXI - Education Service Center Region XI",
    "11354": "CAROLIN-HEALTHCARE-SYSTEM - Carolinas Healthcare System",
    "11355": "SHELL - Shell Information Technology International, Inc.",
    "11356": "Telecom Argentina S.A.",
    "11357": "INFO-IQTINC - InfoQuest Technologies, Inc.",
    "11358": "TPG-AXON-CAPITAL - TPG-Axon Capital Management, LP",
    "11359": "RMCNEVADA - American Fiber Systems, Inc.",
    "11360": "ELECFORIMAG - Electronics for Imaging, Inc.",
    "11361": "BOSCOVS - Boscov's Department Store, LLC",
    "11362": "VECTOR - Vector Data Systems LLC",
    "11363": "FUJITSU-USA - Fujitsu America Inc.",
    "11365": "CREDI-38-N - Credit.com, Inc.",
    "11366": "MINERVA-NETWORK-SYS - Minerva Network Systems, Inc.",
    "11367": "ICENET - WorldNet Telecommunications, Inc.",
    "11368": "CMH-N - CaroNet Managed Hosting, Inc.",
    "11369": "GXCLARKE-JC - G.X. Clarke & Co.",
    "11370": "UNEED - Uneed Solutions Inc.",
    "11371": "UUNET--11371 - MCI Communications Services, Inc. d/b/a Verizon Business",
    "11372": "AGORA - Agora, Inc",
    "11373": "Peoples Network",
    "11374": "WORKSMART-NETWORK-BACKBONE - PanTerra Networks, Inc.",
    "11375": "-MCAD - Minneapolis College of Art and Design",
    "11376": "CHOICE-BGP - Choice Logistics, Inc.",
    "11377": "SENDGRID - SendGrid, Inc.",
    "11378": "SRLLP - Stoel Rives LLP",
    "11379": "WYNDHAMWW-PHX - Wyndham Worldwide Corporation",
    "11381": "NFIS - NEW FRONTIERS INTERNET SERVICES",
    "11382": "WRF-NET - WILEY, REIN & FIELDING",
    "11383": "XAND - Xand Corporation",
    "11385": "NOWYR-1 - Nowyr, inc.",
    "11386": "HEALTH-AND-HOSPITAL-CORPORATION-OF-MARION-COUNTY - HEALTH AND HOSPITAL CORPORATION OF MARION COUNTY",
    "11387": "LAC - La Curacao",
    "11388": "MAXIM - Peer 1 Dedicated Hosting",
    "11389": "HERITAGE-GALLERIES-AND-AUCTIONEERS - Heritage Capital Corporation",
    "11390": "INSTITUTO UNIEMP",
    "11391": "COREL-3 - Corel Corporation",
    "11392": "Nosis Laboratorio de Investigaci\u00f3n y Desarrollo S.A.",
    "11393": "ION247 - ION247",
    "11394": "CITYOFRICHARDSON- - City of Richardson",
    "11395": "THIEL- - Thiel College",
    "11396": "TWC-N - Williams Information Services Corporation",
    "11397": "RIVER-DELTA-WIRELESS - River Delta Wireless",
    "11398": "EMBARQ-LVGS - Embarq Corporation",
    "11399": "WILLIAMSCOLLEGE - Williams College Center for Computing",
    "11400": "LNRP - LNR Property Corp",
    "11401": "CPINTERNET-1 - CP Internet",
    "11402": "CCC-1 - Charlotte Colocation Center, LLc",
    "11403": "NYINTERNET - The New York Internet Company",
    "11404": "-VOBIZ - vanoppen.biz LLC",
    "11405": "EPA-FDMS - Environmental Protection Agency",
    "11406": "CIGNA-1 - CIGNA",
    "11407": "WARP9-TECH - Warp 9 Technologies",
    "11408": "KWE- - Kintetsu World Express",
    "11409": "EFXSECURE - Equifax, Inc.",
    "11410": "REGIONALNETWORK - Regional Network Communications, Inc",
    "11411": "Tournet S.A.",
    "11412": "QWEST--11412 - Qwest Corporation",
    "11413": "IHERB--IHERB-NETWORKS - IHERB INC",
    "11414": "NVIDIA-NET - Nvidia Corporation",
    "11415": "LEVEL3 COMUNICA\u00c7\u00d5ES DO BRIL LTDA.",
    "11416": "METAWIRE - MetaWire",
    "11417": "NIU - Northern Illinois University",
    "11418": "LIGHTEDGE--03 - LightEdge Solutions",
    "11419": "Telefonica Data S.A.",
    "11420": "TRIBUNE-COMPANY - Tribune Company",
    "11421": "DIRECTHOSTNET-N1 - DIRECTHOSTNET, INC.",
    "11422": "CALREN-2 - CENIC",
    "11423": "CALREN-2 - CENIC",
    "11424": "FCCC-EDU - Fox Chase Cancer Center",
    "11425": "CWIE - CWIE, LLC",
    "11426": "SCRR-11426 - Time Warner Cable Internet LLC",
    "11427": "SCRR-11427 - Time Warner Cable Internet LLC",
    "11428": "I-T--SOURCE-CORP - I.T. Source Corporation",
    "11429": "WEST-B2B-SWN01 - West Corporation",
    "11430": "BESTNAP - Austin Bestline",
    "11431": "Planetarium LTDA",
    "11432": "Telium Telecomunica\u00e7\u00f5es Ltda",
    "11433": "CURATEL - Curatel, LLC",
    "11434": "VCS- - Virtacore Systems Inc",
    "11435": "LA-CAPITALE - La Capitale, cie d'assurance generale",
    "11437": "CMM- - ClearSky Technologies, Inc.",
    "11438": "LEMANS-1 - LeMans Corporation",
    "11439": "CANERIS - Caneris Inc.",
    "11440": "NETSVILLE - Netsville, Inc.",
    "11441": "FREDERICK-MEMORIAL-HOSPITAL - Frederick Memorial Healthcare System",
    "11442": "NCSU - North Carolina State University",
    "11443": "OLM - OLM, LLC",
    "11444": "PRIMUSTEL - Primus Telecommunications, Inc.",
    "11445": "N1-SCF - State Compensation Fund",
    "11446": "LAKELAND- - Lakeland Community College",
    "11448": "REFLECTIVE-GROUP - Reflective Group, LLC",
    "11449": "INTERACTIVEBROKERS - Interactive Brokers LLC",
    "11451": "Interlink Network SRL",
    "11452": "MOUNT-SINAI - Mount Sinai School of Medicine",
    "11453": "AVOTUS-CORPORATION - Avotus Corporation",
    "11454": "SOLUTIONS - Noble Americas Energy Solutions LLC",
    "11455": "USTR-N - US Technology Resources, LLC",
    "11456": "NUVOX - Windstream Nuvox, Inc.",
    "11457": "TEXLINK - Tex-Link Communications, Inc.",
    "11458": "ANM-01 - Advanced Network Management, Inc",
    "11459": "THE-TENNESSEAN-GANNETT-SATELLITE-NHVILLE - the Tennessean, a division of Gannett Satellite Information Network, Inc.",
    "11460": "ZALE-NET - Zale Delaware, Inc.",
    "11461": "SPRINTBWG - Sprint Nextel Corporation",
    "11463": "KINDREDHEALTHCARE - Kindred Healthcare, Inc.",
    "11464": "PTPL-2 - Philadelphia Technology Park, LLC",
    "11466": "ANDREWS-FEDERAL1 - Andrews Federal Credit Union",
    "11467": "ERX-UNET-TW-ST Universal Network Technology",
    "11468": "NSDATA - Airfire",
    "11469": "WAVECOM - Wave Communications Inc.",
    "11470": "RSNA-N - Radiological Society of North America",
    "11471": "ETLAND-INTERNET - Eastland Internet",
    "11472": "WILLITSONLINE - WillitsOnline, LLC",
    "11473": "WCOILN - West Central Ohio Internet Link",
    "11474": "BMC - BMC Software, Inc.",
    "11475": "1WIRE-COMMUNICATIONS - 1Wire Communications, LLC",
    "11476": "CLEVER-MACHINE-SF - Clever Machine",
    "11477": "GOC- - GO Concepts, Inc",
    "11478": "OPENFACE - Openface Inc.",
    "11479": "BRM-SUN- - Sun Microsystems, Inc",
    "11480": "MDXNET - Micromedex Inc.",
    "11481": "XPS-SOLUTIONS - XPS Solutions, Ltd.",
    "11482": "CANISIUS-COLLEGE - Canisius College",
    "11483": "CONVIVA- - Conviva, Inc.",
    "11484": "NET-LINK - CoreComm Internet Services Inc",
    "11485": "AIP-CALI-N - American Institute of Physics Incorporated",
    "11486": "COLO-PREM-VZB - Verizon Online LLC",
    "11487": "GREYGROUPNY - Grey Group",
    "11488": "BBN-GW - BBN Technologies Corp.",
    "11489": "BACI - Bell Canada",
    "11490": "ARIN--SILVE-6 - Silverstein Properties, Inc.",
    "11491": "TRIVALENT-GROUP-NEW - Trivalent Group Inc.",
    "11492": "CABLEONE - CABLE ONE, INC.",
    "11493": "HILLSBOROUGH-COUNTY-SHERIFFS-OFFICE - Hillsborough County Sheriff's Office",
    "11494": "KELLOGGCC - Kellogg Community College",
    "11495": "COMNEXIA-CLEC - COMNEXIA Corporation",
    "11496": "CHE-PAYMENTECH-SOLUTIONS-TAMPA-FL - Chase Paymentech Solutions, LLC",
    "11497": "BANCO DO ESTADO DE SANTA CATARINA",
    "11498": "D.I.B.I. S.A.",
    "11499": "WHOI-WOODSHOLE - Woods Hole Oceanographic Institution",
    "11500": "PEAKPEAK - Peak to Peak Internet",
    "11501": "VISTAN - Vista Radiology, P.C.",
    "11502": "NETTUNER- - NetTuner Corp. dba Webmasters.com",
    "11504": "WHITE-CE-1155 - White & Case",
    "11505": "FIBERDIRECT - FiberDirect",
    "11506": "XSIGO-HQ-N - Xsigo Systems, Inc",
    "11507": "COBALTNAP - Cobalt Data Centers",
    "11508": "-CHOOPA2 - Choopa, LLC",
    "11509": "TIERZERO-11509 - Tierzero",
    "11510": "COMMUNICATONS-GROUP-FORTMCMURRAY - Tridon Communications",
    "11511": "CRETE-INTERNET - Crete Carrier Corporation",
    "11512": "PDM - Parsec Data Management Inc.",
    "11513": "INETSERVICES-1 - InetServices, LLC",
    "11514": "Transdatos",
    "11515": "AACI - American Alarm and Communications, Inc.",
    "11516": "N-ESB - Eastern Suffolk BOCES",
    "11517": "BLUE-CROSS-AND-BLUE-SHIELD-OF-MINNESOTA - Blue Cross & Blue Shield of Minnesota",
    "11518": "ROBBINSMORTON - Robins & Morton, L.L.C.",
    "11519": "Banco Mercantil del Norte S.A., Institucion de Banca Multiple, Grupo Financiero Banorte",
    "11520": "ALLSTATE-INSURANCE-CO - Allstate Insurance Company",
    "11521": "MODUSLINK Moduslink  via ARIN",
    "11522": "SUD-WIRED - Greater Sudbury Telecommunications Inc.",
    "11523": "-HLEEM - H. Lee Moffitt Cancer Center & Research Institute, Inc.",
    "11524": "SEGNET - SEG Network Technologies",
    "11525": "HRTC - Hancock Rural Telephone Corp.",
    "11526": "COGENT-11526 - Cogent Communications",
    "11527": "TCS-SOL - TeleCommunication Systems, Inc.",
    "11528": "PHOTRONICS - Photronics Inc.",
    "11529": "NGUS- - National Grid",
    "11530": "EMBARQ-MNFD - Embarq Corporation",
    "11532": "VIANETWORKS11532 - Peer 1 Dedicated Hosting",
    "11533": "VERITY- - Verity, Inc.",
    "11534": "PHILA-SCHOOL-DISTRICT - School District of Philadelphia",
    "11535": "NET-UALNET- - United Airlines",
    "11536": "SRC-N01 - Sunrise Communications LLC",
    "11537": "ABILENE - Internet2",
    "11538": "QWEST--11538 - Qwest Corporation",
    "11539": "LIAISONBGP - Liaison Technologies, LLC",
    "11540": "RTI - Research Triangle Institute",
    "11541": "AIR-ADVANTAGE-N2 - Air Advantage LLC",
    "11542": "EYEMG - EYEMG - interactive media group",
    "11543": "NYS-BOE - NYS BOARD OF ELECTIONS",
    "11544": "RBC1-N6 - Royal Bank of Canada",
    "11545": "AQNT- - aQuantive Inc.",
    "11546": "UNOMAHA- - University of Nebraska at Omaha",
    "11547": "WORKSOFT-01 - Worksoft, Inc",
    "11548": "BLUE-SKY - Blue SKY BROADBAND LLC",
    "11549": "TWRS-TN - Towerstream I, Inc.",
    "11550": "SDL-20- - Smithville Digital, LLC",
    "11551": "SINEP-BROADST- - Sinep Corporation",
    "11552": "PHOENIX-LIFE-INSURANCE-COMPANY - Phoenix Life Insurance, Inc.",
    "11553": "MANNATECH- MANNATECH",
    "11554": "AMERICAN-BIBLE-SOCIETY - American Bible Society",
    "11555": "TRAVEL-SOLUTIONS-INC - TRAVEL SOLUTIONS, INC.",
    "11556": "Cable & Wireless Panama",
    "11557": "RBS-DC - Sidera Networks LLC",
    "11558": "TIU11-ORG - TUSCARORA INTERMEDIATE UNIT",
    "11559": "RSA-BEDFORD - RSA Security Inc.",
    "11560": "SIC-N01 - Sandwich Isles Communications, Inc",
    "11561": "EOL-1 - EDGAR Online, Inc.",
    "11562": "Net Uno, C.A.",
    "11563": "NETENTERPRISE - NetEnterprise Inc.",
    "11565": "N-ALOT - ALOT, INC.",
    "11566": "MTS-TEST- - MTS Allstream Inc.",
    "11567": "GANNETT3-NET - Gannett Co. Inc.",
    "11569": "TICSA-N",
    "11570": "CSLT-BGP - Compusult Limited",
    "11571": "LA NACION",
    "11572": "CCBILL-H - PhoenixNAP LLC",
    "11573": "NACS-2 - New Age Consulting Service",
    "11574": "IRIDIAN-SET-MANAGEMENT-LLC - Iridian Asset Management LLC",
    "11575": "JMC-N1 - Jupiter Medical Center",
    "11576": "THUNDERBIRD-AGSIM - Thunderbird",
    "11577": "GOVNET-N - Vermont Department of Information and Innovation",
    "11578": "GANNETT2-NET - Gannett Co. Inc.",
    "11579": "LANLINE - LANline Communications Inc",
    "11580": "ISLAND_NET N-ISLAND-NET",
    "11581": "TRANSTEL S.A.",
    "11582": "SMART-CITY-RENO - Smart City Networks, L.P.",
    "11583": "RBSLYNK-3 - WorldPay US, Inc.",
    "11584": "IGEUNET Intergate Europe Inc.",
    "11585": "Zupernet",
    "11586": "JOHNSON-OUTDOORS - Johnson Outdoors, Inc.",
    "11587": "EWOL-COM - Northeast Texas Broadband, LLC",
    "11588": "HIGHWINDS - Highwinds Network Group, Inc.",
    "11589": "STOWE-ACCESS - Stowe Access, LLC",
    "11590": "CUMBERLAND-TECH - Cumberland Technologies International",
    "11591": "CAPARIO - Capario, Inc.",
    "11592": "FUNDACAO DE AMPARO A PESQUISA DO ESTADO DE ALAGO",
    "11594": "APUA-AG - APUA",
    "11595": "NETSONIC - Netsonic",
    "11596": "BESTBUY - Best Buy Co., Inc.",
    "11597": "MERCURY-WIRELESS - Mercury Wireless, LLC",
    "11598": "RECOL-CT - Recol",
    "11599": "NETV S.A.",
    "11600": "MOTOR-COACH-INDUSTRIES - Motor Coach Industries",
    "11601": "PICANOC- - Reseau Picanoc.net Inc.",
    "11602": "SDSMT- - South Dakota School of Mines and Technology",
    "11603": "WATERMARK - Watermark Estate Management Services, LLC",
    "11604": "HIS-NOC - Heller Information Services, Inc.",
    "11605": "FLUIDSOFT-14 - Fluidsoft Incorporated",
    "11606": "WOL- - Alteva Inc",
    "11607": "SD-STATE-UNIVERSITY - South Dakota State University",
    "11608": "ACTTG - Accretive Networks",
    "11609": "ELAVON - ELAVON",
    "11610": "INETNEBR-1 - Internet Nebraska Corporation",
    "11611": "TRICUE - Tri-CUE, Inc.",
    "11612": "CW-NC - Community Web, Inc.",
    "11613": "U-SAVE - U-Save Auto Rental of America, Inc.",
    "11614": "VIP-CONNECT - VIP Calling, Inc.",
    "11615": "WEBEXNET - 007names, Inc.",
    "11616": "PEAPOD - Peapod, Inc.",
    "11617": "BT Latam Mexico, S.A. de C.V.",
    "11618": "IGNITION-N - Ignition Bermuda",
    "11619": "ATS-INC - ANDERSON TRUCKING SERVICE, INC.",
    "11620": "SUCCEED-NET - Succeed.Net",
    "11621": "REYESHOLDINGSLLC - Reyes Holdings, L.L.C.",
    "11622": "MOTRICITY - Motricity, Inc",
    "11623": "CTCN - CT Communications Network",
    "11624": "-COLLINS - COLLINS COMMUNICATIONS INC",
    "11625": "MNX-N1 - Monexa Services Inc.",
    "11626": "CONNEXON-TELECOM - ConneXon Telecom",
    "11627": "MCG-N - Mifflin County Commissioners",
    "11628": "OICR-ONTARIO-INSTITUTE-FOR-CANCER-RESEARCHB - Ontario Institute for Cancer Research",
    "11629": "ZENNIOPT - Zenni Optical, LLC",
    "11630": "AOL-RTC2 - America Online",
    "11631": "AOL-DTC - America Online",
    "11632": "PS-HQ-N01 - American Society of Plastic Surgeons",
    "11633": "4LIFERESEARCHUSALLC - 4Life Research USA, LLC",
    "11634": "HHC- - Hilton Hotels Corporation",
    "11635": "LOUIB-NMP - Infinite Blue, LLC",
    "11637": "METRODATAPATH - MetroDataPath, Inc.",
    "11638": "IQSOL-1 - IQ Solutions, Inc.",
    "11639": "AABB - AABB",
    "11640": "GROUP-ONE-TRADING - Group One Trading LLC",
    "11641": "INTUIT-SD - Intuit Inc.",
    "11642": "Sistemas Comerciales Argentinos",
    "11643": "EBAY - eBay, Inc",
    "11644": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "11645": "NPERS",
    "11646": "KIT- - Kansas Independent Telecommunications",
    "11647": "SENTEX-NET - Sentex Communications Corporation",
    "11648": "TECH-AM- - Technicolor, Inc.",
    "11649": "GUNET - Gonzaga University",
    "11650": "PLDI - Pioneer Long Distance Inc.",
    "11651": "-CENTRIC-GROUP-LLC - Centric Group, LLC",
    "11653": "ESS-PR-WEBMTERS - Puerto Rico Webmasters",
    "11654": "RR-BINGHAMTON-N-01 - Time Warner Cable Internet LLC",
    "11655": "RELIANCE-INSURANCE-GP - Reliance Insurance Company",
    "11656": "MMS-83-ANTARES-44122 - Medical Mutual Services",
    "11657": "LEGG-MON-CORP-NET Legg Mason Wood Walker Inc",
    "11658": "NCITECH - NCI Technologies, Inc.",
    "11659": "KUMC - University of Kansas Medical Center",
    "11660": "BANKGATE",
    "11661": "PARCELPRO - Parcel Pro Inc.",
    "11662": "DMG-385 - Diversified Media Group, LLC.",
    "11663": "SUG-1 - State of Utah",
    "11664": "Techtel LMDS Comunicaciones Interactivas S.A.",
    "11665": "INFONOX - Infonox On The Web, Inc.",
    "11666": "NEXICOM-CA - Nexicom Inc.",
    "11667": "WESTEL-N1 - Westel, Inc.",
    "11668": "WCI-NET - WEST COT INTERNET INCORPORATED",
    "11669": "MOVE-SITES - Move Sales, Inc.",
    "11670": "-TORIX - Toronto Internet Exchange Community",
    "11671": "BIGCHARTS - BigCharts Inc.",
    "11672": "ACSIN--1 - Globalvision",
    "11673": "Internet Panama",
    "11674": "HA-TCM-001 - Haas Group International Inc.",
    "11675": "ZEBECDATA - Zebec Data Systems",
    "11676": "11676 - Xerox Business Services",
    "11677": "Instituto Tecnol\u00f3gico y de Estudios Superiores de Monterrey",
    "11678": "DOE-NTS- - USDOE, NV Operations Office",
    "11679": "STIHL-204-124-67 - Stihl Inc.",
    "11680": "CPQ-ALF-IOMC - Hewlett-Packard Company",
    "11681": "INTEGRITY - Integrity Networks",
    "11682": "INSTAVPS-SLC1 - InstaVPS",
    "11683": "ELNK-CHARTER-CONN - Earthlink, Inc.",
    "11684": "TVC-MARKETING - TVC Marketing Associates, Inc.",
    "11685": "HNBCOL- - Huntington National Bank",
    "11686": "ENA - Education Networks of America",
    "11687": "CITY-OF-HOPE - City of Hope Medical Center",
    "11688": "LTSTREAM - Lightstream Communications, Inc.",
    "11689": "NN-JORSM-CHI01 - Egix, Inc.",
    "11690": "COGNIZANT-US - Cognizant",
    "11691": "EVOCATIVE - Evocative, Inc.",
    "11692": "CWH - Carewise Health, Inc.",
    "11693": "NULINK - HC Cable OPCO, LLC",
    "11694": "Universidad Simon Bolivar",
    "11695": "THESTREET-DOT-COM - TheStreet.Com",
    "11696": "NBS11696 - NBS",
    "11697": "NET-SUPERNEWS - SuperNews",
    "11698": "MBCCHG - MBC Telecom, LLC",
    "11700": "CA-WEDNET - WEDnet",
    "11701": "N-BOSTWICK - BOSTWICK LABORATORIES INC.",
    "11702": "CONNEXON2-TELECOM - ConneXon Telecom",
    "11703": "MARS-DISCOVERY-DISTRICT - MaRS Discovery District",
    "11704": "ROBERTSON - Robertson Group Internet Solutions",
    "11705": "UN - Universal Atlantic Systems Incorporated",
    "11706": "Terra Networks Brasil S.A.",
    "11707": "SCRR-11707 - Time Warner Cable Internet LLC",
    "11708": "LINKCITY - City of North Kansas City, MO",
    "11709": "VIC - VIRTUAL INTERACTIVE CENTER",
    "11710": "ABBATECH - ABBA TECHNOLOGIES",
    "11711": "TULAROSA-COMMUNICATIONS - TULAROSA COMMUNICATIONS, INC.",
    "11712": "BELLSOUTH - AT&T Services, Inc.",
    "11713": "GBGDC-IP1 - Granite Block Global Data Center, Inc",
    "11714": "N-UNEB - University of Nebraska Central Administration",
    "11715": "FENWAY-PARTNERS - Fenway Partners Inc.",
    "11716": "WON- - William O'Neil & Company",
    "11717": "-SOLARUS - Solarus",
    "11718": "DG-2009 - DESIGN GROUP STAFFING INC.",
    "11719": "EATON-CORPORATION - Eaton Corporation",
    "11720": "IBCP - Independent Bank Corporation",
    "11721": "TOTAL-MERCHANT-SERVICES - TOTAL MERCHANT SERVICES",
    "11722": "WFC-N - Westelcom Internet, Inc.",
    "11723": "NDAQ-OMX-PHLX-11723 - THE NDAQ OMX GROUP, INC.",
    "11724": "OCC - Comptroller of the Currency",
    "11725": "MUELLER-NET - Mueller Industries, Inc.",
    "11726": "GUIWARE1 - GUIware Inc.",
    "11727": "BMTS - Bruce Municipal Telephone System",
    "11728": "INTERNETXT - Internet Exchange Technology, Inc.",
    "11729": "VHL-1 - Vista Higher Learning, Inc.",
    "11730": "PROGFIN - Progressive Finance",
    "11731": "11731 - Weston Solutions, Inc.",
    "11732": "IEI-LVGN-INET - INGRAM ENTERTAINMENT INC.",
    "11733": "EJGALLO - E. & J. Gallo Winery Inc.",
    "11734": "CONNECTRIA - Connectria",
    "11735": "ITRON-OAKLAND-HOSTING - ITRON",
    "11736": "USD - University of South Dakota",
    "11737": "NMSL-6 - Nu-Age Managed Services, LLC",
    "11738": "MIA-N - Mayo Investment Advisers, LLC",
    "11739": "DF-SEATTLE01 - Digital Fortress, Inc.",
    "11740": "PROGRESSIVE- - Progressive Casualty Insurance Companies",
    "11741": "BENTONREA - BENTON REA POWERNET",
    "11742": "MRKHOSTWINDOW - MRK Hostwindow",
    "11743": "EBSCO - EBSCO Industries, Inc.",
    "11744": "INVESTEC",
    "11745": "USNH - University System of New Hampshire",
    "11746": "WAGGENER-EDSTROM - Waggener Edstrom",
    "11747": "KAGI - Kagi",
    "11748": "JCDNA - JCDecaux North America",
    "11749": "MPINET - MPInet",
    "11750": "Interdotnet Argentina S.A.",
    "11751": "INSTITUTO CYBER DE ENSINO E PESQUISA",
    "11752": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "11753": "PA-ONLINE - Pennsylvania Online",
    "11754": "GUS - ORANGE COUNTY NETWORKS, LLC",
    "11755": "WAYMARKCOMM - Waymark Internet Services, Inc.",
    "11756": "NJVC-RTDC - NJVC, LLC",
    "11757": "WHIRLPOOL-N - Whirlpool Corporation",
    "11758": "IRISNETWORKS - IRIS Networks",
    "11759": "CANINE-COMPANIES - The Canine Companies Inc.",
    "11760": "CHFA - Connecticut Housing Finance Authority",
    "11761": "QBE-AMERIC - QBE Reinsurance Corporation",
    "11762": "NET-CONNECTION - Net Connection",
    "11763": "IBX-CHICAGO - inVision Networks",
    "11764": "PANAMSAT-NET - PanAmSat Corporation",
    "11765": "VENDORSAFE-TECHNOLOGIES - Vendor Safe Technologies LLC",
    "11766": "MERIPLEX-1- - Meriplex Communications, Ltd.",
    "11767": "QTS-MIAMI-1 - Quality Technology Services Miami, LLC",
    "11768": "VONTOBELUS- - Vontobel Asset Management INC",
    "11769": "MOBILENETICS-LA-GW1 - Mobilenetics Corporation",
    "11770": "NET56 - Net56",
    "11771": "SYNACOR-CHARTER - Synacor, Inc.",
    "11772": "CIALLC - Client Instant Access, LLC",
    "11773": "UTMDACC - The University Of Texas M.D. Anderson Cancer Center",
    "11774": "CYPRESSCOMM - Cypress Communications, Inc.",
    "11775": "CRV-INC - CRV, Inc.",
    "11776": "ATLANTICBB-JOHNSTOWN - Atlantic Broadband Finance, LLC",
    "11777": "NCAOC - North Carolina Adminstrative Office of the Courts",
    "11778": "SINEP-PR-NET - Sinep Corporation",
    "11779": "MCC-GROUPZ - Morris Communications Corporation",
    "11781": "NETRADA-NA - Netrada North America, LLC",
    "11782": "-PERFECTO - Perfecto Mobile Inc",
    "11783": "BROOK-LAW - Brooklyn Law School",
    "11784": "N-AV8 - Plain Aivation, Inc",
    "11785": "BROADWAY-BANDWIDTH - Broadway Bandwidth, Inc",
    "11786": "Soluciones Informaticas S.R.L.",
    "11787": "PACOURTS- - Supreme Court of Pennsylvania",
    "11788": "BAJAU-CO-NM-TX - Baja Broadband",
    "11789": "INTERCONSECURITY - Intercon Security, Ltd",
    "11790": "RANDOMHOUSE - Random House, Inc.",
    "11791": "SLC-IDENT- - IdenTrust",
    "11792": "BRIDGESTONE-FIRESTONE - BRIDGESTONE FIRESTONE",
    "11794": "PINEWOOD-TORONTO-STUDIOS - Pinewood Toronto Studios",
    "11795": "989STUDIOS - Sony Computer Entertainment America LLC",
    "11796": "AIRSTREAMCOMM-NET - Airstream Communications, LLC",
    "11797": "AC-NIELSEN- AC NIELSEN",
    "11798": "ACEDATACENTERS--1 - Ace Data Centers, Inc.",
    "11799": "CTHOUGHT - Creative Thought, Inc.",
    "11801": "Opportunity Gestora de Recursos Ltda.",
    "11802": "Centro de Informatica e Automacao do Estado de SC",
    "11803": "OMNICELL - Omnicell Inc.",
    "11804": "AEGDM - AEG Digital Media, LLC",
    "11805": "HDPI - Home Decor Products, Inc.",
    "11806": "LEEPFROG - Leepfrog Technologies, Inc.",
    "11807": "GAMELOFT - Divertissements GameLoft Inc",
    "11808": "UIDAHO - University of Idaho",
    "11809": "NET-ERAU-PRC - Embry-Riddle University",
    "11810": "AWEBER-SYSTEMS - AWeber Systems, Inc.",
    "11811": "OPCO - Oppenheimer & Co. Inc.",
    "11812": "DWS-UTAH - Disney Worldwide Services, Inc.",
    "11813": "NATIXIS-NORTH-AMERICA-LLC - Natixis North America LLC",
    "11814": "DISTRIBUTEL-11814 - DISTRIBUTEL COMMUNICATIONS LTD.",
    "11815": "Cooperativa Telefonica de V.G.G. Ltda.",
    "11816": "SetarNet",
    "11817": "STAFFORDNET - Stafford Associates Computer Specialists, Inc.",
    "11818": "BHN-BIRMINGHAM - BRIGHT HOUSE NETWORKS, LLC",
    "11819": "SMITH-SOC - Smith & Associates",
    "11820": "WIKIMEDIA-FOUNDATION - Wikimedia Foundation, Inc.",
    "11821": "RUCUBENET - RuCube Networks, LLC",
    "11822": "DEBSHOPS - DEB SHOPS INC",
    "11823": "LORDABBETTCO - Lord, Abbett & Co.",
    "11824": "VANCOUVER-COLO - Vonage Holdings, Inc.",
    "11825": "JDRF - JDRF International",
    "11826": "RISS2 - Regional Information Sharing Systems (RISS), Office of Information Technology (OIT)",
    "11827": "WSU- - Washington State University",
    "11828": "SOINET - State of Illinois/CMS",
    "11829": "CADENCE - Cadence Design Systems, Inc.",
    "11830": "Instituto Costarricense de Electricidad y Telecom.",
    "11831": "ESECUREDATA - eSecureData.com",
    "11833": "11833-LEAPFROG-INTERACTIVE - LeapFrog Interactive",
    "11834": "DREXEL-N - Drexel University",
    "11835": "IPE INFORMATICA LTDA",
    "11836": "ICNET-N ICNet LLC",
    "11837": "SAWNET - SAWNET",
    "11838": "FLOCORPINT1 - Flowers Foods Inc.",
    "11839": "OMAHAIX - Mankato Networks LLC",
    "11840": "VGRS-REGISTRY- - VeriSign Infrastructure & Operations",
    "11841": "LINKLINE - LinkLINE Communications, Inc.",
    "11842": "-REGAL - Regal Entertainment Group",
    "11843": "AURA-L3-01 - Auravox, LLC",
    "11844": "NEWSITE INTERNET LTDA",
    "11845": "DPBOL",
    "11846": "BROADVIEWNET - Broadview Networks, Inc.",
    "11847": "MIDMAINE - Mid-Maine Communications, Inc.",
    "11848": "2KNOVATO - 2K GAMES, Inc.",
    "11849": "ALTEC-IT - Altec IT",
    "11850": "MAGSNETLLC - MagsNet LLC",
    "11851": "TMI-CA - The Michener Institute for Applied Health Sciences",
    "11852": "WHCC - White House Custom Colour, Inc",
    "11853": "N-INTERNAP-BLK - Internap Network Services Corporation",
    "11854": "N-INTERNAP-BLK - Internap Network Services Corporation",
    "11855": "N-INTERNAP-BLK - Internap Network Services Corporation",
    "11856": "XCONNECT XConnect auth-num",
    "11857": "AEGON Proxy Object for ARIN",
    "11858": "CM2COM - Cm2.com Inc.",
    "11859": "BRACCO-DIAGNOSITICS-N - Bracco Diagnostics Inc.",
    "11860": "AEGIS-INSURANCE-SERVICES-INC - AEGIS Insurance Services, Inc.",
    "11861": "INTELLIGENT - Intelligent Decisions, Inc.",
    "11862": "GSIC - GSI Commerce Solutions, Inc.",
    "11863": "PLU - Pacific Lutheran University",
    "11864": "VISTO-IT-1 - Visto Corporation",
    "11865": "G222UV2D21EWD27U76VUWHD7V1FH8HT6HE6W7W12 - STERLING SAVINGS",
    "11866": "EL-MALVERN-PA - Ellucian Company LP",
    "11867": "PRIMUSTEL - Primus Telecommunications, Inc.",
    "11868": "ATICLOUD-ATL - SITA",
    "11869": "SYNIVERSE-MESSAGING - Syniverse Technologies, LLC",
    "11870": "ALTICOR-INC - ALTICOR INC",
    "11871": "DUKE-MW-11871 - Duke Energy Corporation",
    "11872": "SYRACUSE-UNIVERSITY - Syracuse University",
    "11873": "MOBILEPOSSE - Mobile Posse",
    "11874": "COLUMBUSREGIONALHOSPIAL - Columbus Regional Hospital",
    "11875": "WILLIAM-HERRIN - William Herrin",
    "11876": "CMS-NET - Crawford Media Services, Inc",
    "11877": "RENTVMINC - RentVm,Inc",
    "11878": "TZULO - tzulo, inc.",
    "11879": "MGI - Advanced Server Management Group, Inc.",
    "11880": "TICKE-19-N - Tickets.com, Inc.",
    "11881": "CNANDC-01 - CNA National Warranty Corporation",
    "11882": "WELLCARE-INET1- - COMPREHENSIVE HEALTH MANAGEMENT, INC.",
    "11883": "KTHV-TV - KTHV-TV",
    "11884": "SMARTHOME - SMARTHOME, INC.",
    "11885": "DYNAMICPACKET - DYNAMIC PACKET CORP",
    "11886": "ALPHALINK - AlphaLink Technologies Inc",
    "11887": "TEKELEC-PLANO-TX - Tekelec",
    "11888": "Television Internacional, S.A. de C.V.",
    "11889": "IVANET-NYC - VIP Calling, Inc.",
    "11890": "IVANET-LA - VIP Calling, Inc.",
    "11891": "MEGAVISION - Community Internet Systems",
    "11892": "NATCOMPSYS - NCS Pearson Inc.",
    "11893": "LOLIGO-N - Loligo Cache Systems, Inc.",
    "11894": "GUESSINC - Guess? Inc.",
    "11895": "KOFAX - Kofax Image Products, Inc.",
    "11896": "MCA INFORMATICA LTDA.",
    "11897": "TULSA-COMMUNITY-COLLEGE - Tulsa Community College",
    "11898": "STG-CT-001 - Soundshore Technology Group, LLC",
    "11899": "MEINC - Measurement Incorporated",
    "11900": "DATACRUZ - Datacruz, Inc.",
    "11901": "COSWAN - County of Sacramento",
    "11902": "WORLD-LINK - World-Link Communications, Inc.",
    "11903": "LINCOLNSHIRE-MANAGEMENT - Lincolnshire Management, Inc.",
    "11904": "ALLENTEL - Allendale Telephone Company",
    "11905": "E-LYNXX-COPORATION - E-Lynxx Corporation",
    "11906": "WISPLB1 - Westelcom Internet, Inc.",
    "11907": "MSXI-INET - MSX International",
    "11908": "VERESTAR - SES Americom Inc.",
    "11911": "PLUK PLUK",
    "11912": "TAMUSIBT-NET - Texas A&M University System",
    "11913": "ARMORNEXUS - Armor Nexus Corporation",
    "11914": "HUMONGOUS - Humongous Entertainment",
    "11915": "TELWEST-NETWORK-SVCS-STATIC - TEL WEST COMMUNICATIONS LLC",
    "11916": "UNDP - UNDP",
    "11917": "FIRSTWIND-B-N - First Wind",
    "11918": "SERVE-VIRTUAL-ENTERPRISES - Serve Virtual Enterprises Inc",
    "11919": "LORAL-SKYNET-AR - Telesat Network Services Inc",
    "11920": "UNK- - University of Nebraska at Kearney",
    "11921": "SECRELNET INFORMATICA LTDA",
    "11922": "RBN - RealNetworks, Inc.",
    "11923": "JCE-RENTOKIL-BGP-1 - JC Ehrlich Co Inc",
    "11924": "MONTANA-OPTICOM - Montana Opticom, LLC",
    "11925": "DDWI - Delta Dental of Wisconsin, Inc",
    "11926": "HARTSOFTWARE - Hart Software, Inc.",
    "11927": "ADVANCE-GW - Advance Publications Inc.",
    "11928": "HBGUSA - Hachette Book Group, Inc.",
    "11930": "FUSION-FISERV - Fiserv Pittsburgh",
    "11931": "ZENITH - Zenith Networking",
    "11932": "TRADE-LIFTS-LLC - Breakwater",
    "11933": "ILS-VB-ATT- - Supply Technologies, LLC",
    "11934": "ESL63 - Enom Solutions LLC",
    "11935": "TALKPOINT-COMMUNICATIONS-11935 - TalkPoint Communications",
    "11937": "TRX-ARIN - TRX Inc.",
    "11938": "WHOLE- - WholesaleBandwidth, Inc.",
    "11939": "MATHWORKS - The MathWorks, Inc.",
    "11940": "DIRECTSCOM - Direct Supply, Inc.",
    "11941": "PWLLP Pillsbury Madison & Sutro, Inc.",
    "11942": "IPGLOBAL - IP Global, LLC.",
    "11943": "GLOBE - Globe Wireless",
    "11944": "WEBTRENDS-CORP - Webtrends Corporation",
    "11945": "FAMSF- - Corporation of the Fine Arts Museums",
    "11946": "N-ADCOPY - AdCopy Inc",
    "11947": "Cablenett Limited",
    "11948": "DEVELOPMENT-GROUP-INC - Development Group, Inc",
    "11949": "COZAD-TELEPHONE-COMPANY - COZAD TELEPHONE COMPANY",
    "11950": "MFXROA-2 - MFX ROANOKE, INC",
    "11951": "MCSP - Medical Computer Systems",
    "11952": "NDAQ-OMX-11952 - THE NDAQ OMX GROUP, INC.",
    "11953": "ARMLS - ARMLS",
    "11954": "BAYVIEW-FINANCIAL-INETOPS - Bayview Financial, LP",
    "11955": "SCRR-11955 - Time Warner Cable Internet LLC",
    "11956": "NOAA-NWN - NOAA / PMEL",
    "11957": "CACHEFLOW- - Bluecoat Systems, Inc.",
    "11958": "WIR-INT-RES - Wyoming Internet Resources",
    "11959": "TOMKINSBP - Tomkins Building Products",
    "11960": "CUBADATA",
    "11961": "MIDRIVERS - Mid-Rivers Telephone Cooperative",
    "11962": "EMPIRE5882300 - Empire Today LLC",
    "11963": "N-PENNWELL - PennWell corporation",
    "11964": "AWAC-HQ - Air Wisconsin Airlines Corporation",
    "11965": "IN-TOUCH-IN-FLIGHT - AirCell, LLC.",
    "11966": "GLOBALDATYSTEMS-N - GLOBAL DATA SYSTEMS INC.",
    "11967": "WTI-PUB-INET - W &T Offshore, Inc.",
    "11968": "LEXISNEXIS-RISK-SETS - ChoicePoint, Inc.",
    "11969": "MACSTEEL - MACSTEEL SERVICE CENTERS USA, INC.",
    "11970": "VCI-MDVL - Vision Communications Inc.",
    "11971": "PFIZERNET-GROTON - PFIZER INC.",
    "11972": "SET-MANAGEMENT-TECHNOLOGIES - Asset Management Technologies, Inc.",
    "11973": "SECUREINDEPENDENCE - Secure Independence, Inc",
    "11974": "CALLTECH - Calltech Communications, Inc.",
    "11975": "WM - The College of William and Mary",
    "11976": "FIDN - Fidelity Communication International Inc.",
    "11977": "GREENFIELDNET-WLT-CT - TOLUNA USA Inc.",
    "11978": "VEG - Greenspun Corporation",
    "11979": "BLUENET - Bluegrass Network LLC",
    "11980": "BDO-SEIDMAN - BDO USA, LLP",
    "11981": "SPECIALSYSTEMS - Special Systems Inc.",
    "11982": "SHWISP - Sandhills Wireless, LLC",
    "11983": "FUTUREQUEST-11983 - FutureQuest, Inc.",
    "11984": "NETWALK - NetWalk",
    "11985": "N-SSA - Social Security Administration",
    "11986": "RIO-NETWORKS - Rio Networks",
    "11987": "INDYWEB - INDY WEB INC",
    "11988": "CEVA-US - CEVA INC.",
    "11989": "WEBINT - Jumpline Inc",
    "11990": "UNLIMITEDNET - Unlimited Net, LLC",
    "11991": "N-WIBAND-2 - WiBand Communications",
    "11992": "CENTENNIAL-PR - Centennial de Puerto Rico",
    "11993": "BANCO DO BRIL S.A.",
    "11994": "CZIO-N - Cruzio",
    "11995": "OHSU - Oregon Health & Science University",
    "11996": "LOBOIS - Lobo Internet Services, Ltd",
    "11997": "FARMERSCOOPERATIVECO - Farmer's Cooperative Company",
    "11998": "PNB - Province of New Brunswick",
    "11999": "REJISCOMM-NET - REJIS Commission",
    "12000": "FMR-4 - Fidelity Investments",
    "12001": "-PNN-NET - Point North Networks, Inc.",
    "12002": "GREAT-POINT-PARTNERS - Great Point Partners, LLC",
    "12003": "INTEGRATELECOM - Integra Telecom, Inc.",
    "12004": "YLEO - Young Living Essential Oils",
    "12005": "SC- - University of South Carolina",
    "12006": "BROADVIEWNET--12006 - Broadview Networks, Inc.",
    "12007": "RAYN - Raytheon Company",
    "12008": "ULTRADNS - NeuStar, Inc.",
    "12009": "EONI - Eastern Oregon Net, Inc.",
    "12010": "IFDS - International Financial Data Services (Canada) Ltd.",
    "12012": "NOV-NET-02 - Novani, LLC",
    "12013": "FAUNET - Florida Atlantic University",
    "12014": "AMERIC-HEALTH-INSURANCE-PLANS - AHIP",
    "12015": "WOW-INTERNET - WideOpenWest Finance LLC",
    "12016": "RETIREMENT-HOUSING-FOUNDATION - Retirement Housing Foundation",
    "12018": "OOCL-SJC - OOCL (USA), Inc.",
    "12019": "NETCOMM - Network Communications",
    "12020": "MHSC-BGP-N - Methodist Hospital of Southern California",
    "12021": "HHES - HAMILTON HYDRO ELECTRIC SYSTEM",
    "12023": "INTELEPEER-US - IntelePeer, Inc.",
    "12024": "N-ACN - Advanced Corporate Network",
    "12025": "IO-DATA-CENTERS - IO Capital Princess, LLC",
    "12026": "WOW-INTERNET - WideOpenWest Finance LLC",
    "12027": "N1 - ActForex Inc.",
    "12028": "MMINTERNET - MM Internet, Inc.",
    "12029": "PRREN - Puerto Rico Regional Educational Network",
    "12030": "PACIFIC-ONLINE-PON - Pacific Online, Inc.",
    "12031": "LORD-CORP-CARY - Lord Corporation",
    "12032": "PSJAISD - Pharr-San Juan-Alamo ISD",
    "12033": "N-ANW - Adams NetWorks, Inc.",
    "12034": "Miditel, S.A. de C.V.",
    "12035": "ATLANTICBB-MIAMI - Atlantic Broadband Finance, LLC",
    "12036": "DIXIE-NET - ISP Associates, Inc. DBA Dixie-Net",
    "12037": "FDIC-GOV - Federal Deposit Insurance Corporation",
    "12038": "PARSONS-TRANSPORTATION-CONSUMER-SVCS - Boingo Wireless, Inc.",
    "12039": "TIMEINC - Time Inc.",
    "12040": "INTELEPEER-US - IntelePeer, Inc.",
    "12041": "AFILI-NST Afilias Limited",
    "12042": "ENVENTIS - Enventis Telecom Inc.",
    "12043": "ROBECOUSA-BOSDC1 - Robeco Investment Management, Inc.",
    "12044": "WVINET - Willamette Valley Internet, L.L.C.",
    "12045": "INTELEPEER-US - IntelePeer, Inc.",
    "12046": "N-CSC-UOM University of Malta - IT Services",
    "12047": "GUNDERSEN-LUTHERAN - Gundersen Lutheran Medical Center, Inc.",
    "12048": "PARLANT - Parlant Technology, Inc.",
    "12049": "ONLINETODAY - On Line Today",
    "12050": "DIRECTV-BROADBAND - DIRECTV-Broadband",
    "12051": "ESCONDIDO-CA - City of Escondido",
    "12052": "VFC - VF Services, Inc. Information Technology Services",
    "12053": "NETFIRMS - Netfirms Inc",
    "12054": "ALAMEDACOUNTYDATAPROCESSING - Alameda County",
    "12055": "CLEARBEARING-00 - Clearbearing Inc.",
    "12056": "YUCCA- - Yucca Telecom",
    "12057": "LIVEVOX-2 - LiveVox, INC.",
    "12058": "12058  for Expedia",
    "12059": "ILAP - Internet Light and Power Inc.",
    "12060": "KROPF - Kropf Computer Services, Inc.",
    "12061": "24HOURFITNESS - 24 Hour Fitness USA, Inc.",
    "12062": "DECISIONONE - Decision One",
    "12063": "FSL-INTERNET - FIRST SERVICES LP",
    "12064": "N-CXA-HR-12064-CBS - Cox Communications Inc.",
    "12065": "MSKY - Mackerel Sky Technology, LLC",
    "12066": "TRICOM",
    "12067": "SHAWNEELINK - ShawneeLink Corporation",
    "12068": "RC-N - Reliance Communications, Inc.",
    "12069": "REV-NET-TECHNOLOGIES - Rev.Net Technologies",
    "12070": "OCLS - OCLS",
    "12072": "AHL-N - Aquiline Holdings, LLC",
    "12073": "CCSINET-1 - Contemporary Computer Services Inc.",
    "12074": "VYAPAR-NY - VCM PARTNERS",
    "12075": "JACOBS - Jacobs Engineering Group",
    "12076": "MICROSOFT - Hotmail Corporation",
    "12078": "ONEEIGHTY-NET2 - One Eighty Networks",
    "12079": "AIRTOUCH-CELLULAR - Cellco Partnership DBA Verizon Wireless",
    "12080": "ARA--2 - Allison Royce & Associates, Inc.",
    "12081": "GREENHECK - Greenheck Fan",
    "12082": "NWN-CORPORATION - NWN Corporation",
    "12083": "WOW-INTERNET - WideOpenWest Finance LLC",
    "12084": "FARM-NY - Gigya, Inc.",
    "12085": "EQUINIX-MA-DC - Equinix, Inc.",
    "12086": "DT-MICRO - DT Micro, inc.",
    "12087": "SALSGIVER - Salsgiver, Inc.",
    "12088": "NABANCARD - North American Bancard",
    "12089": "BROADPLEX-NETWORKS - BroadPlex, LLC",
    "12090": "NET-AAA - AAA National",
    "12091": "MTNNS-",
    "12092": "SONIFI - LodgeNet Interactive Corporation",
    "12093": "UWATERLOO - University of Waterloo",
    "12094": "CELERITYNETWORKS - Celerity Networks, LLC",
    "12095": "ARIZONA-SCIENCE-CENTER - Arizona Science Center",
    "12096": "AMPNET-N - AMP Telephones",
    "12097": "MSCOM - Massillon Cable Communications",
    "12098": "UNIONBANKOFCAL - Union Bank of California",
    "12099": "OAKWOOD-HEALTHCARE - OAKWOOD HEALTHCARE INC",
    "12100": "FEDERATED-PUBLICATIONS-PALLADIUM-ITEM - Palladium Item",
    "12101": "EMS - Electronic Management Systems, Inc.",
    "12102": "CITY-OF-PORTLAND-OR-USA - City of Portland",
    "12103": "KEYNOTE - Keynote Systems, Inc.",
    "12104": "CDE-N - State Farm Mutual  Automobile Insurance Company",
    "12105": "DRS-GNC-001 - DRS Technical Services Inc",
    "12106": "CORBIS - Corbis Corporation",
    "12107": "DEALER-COM - Dealer Dot Com Inc.",
    "12108": "PROFITDEV - PROFIT DEVELOPERS INC",
    "12109": "TECHNOLOGYINVESTORSINC - Technology Investors, Inc.",
    "12110": "-INTER - Internex Inc.",
    "12111": "ONEEIGHTY-NET - One Eighty Networks",
    "12112": "HICKORYTECH - HickoryTech Corporation",
    "12113": "DAWN-FOOD-PRODUCTS - Dawn Food Products, Inc.",
    "12114": "BARNESANDNOBLE-COM - BarnesandNoble.com",
    "12115": "FNI-STL - Financial Network, Inc.",
    "12116": "FHLB - Federal Home Loan Bank of Dallas",
    "12117": "OMNINET - Omni Internet",
    "12118": "WVU - West Virginia University",
    "12119": "ITV-3 - ITV-3",
    "12120": "AAO-AIO - Amphenol Corp",
    "12121": "IERVICE - Internet Access Service, Inc.",
    "12123": "RKENG - R&K Solutions, Inc.",
    "12124": "THORN - Thorn Communications, Inc",
    "12125": "MORRISVILLESD - Morrisville School District",
    "12127": "Telefonica Moviles El Salvador S.A. de C.V.",
    "12129": "123NET - 123.Net, Inc.",
    "12130": "BWCCLEC - Bandwidth.com CLEC LLC",
    "12131": "IJ-NET - Internet Junction Corporation",
    "12132": "QUEBECINTERNET - Quebec Internet Inc",
    "12133": "LISCO - LISCO",
    "12134": "MTB - Manufacturers and Traders Trust Company",
    "12135": "Prointernet do Brasil Ltda",
    "12136": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "12137": "BABYCENTER - BabyCenter, Inc.",
    "12138": "VIRTELA-CUST-VCJC1-VICOR Virtela Communications",
    "12139": "AMNET - AMNET US",
    "12140": "Lanis Ltda",
    "12141": "EPOCHWIDE-01 - Epoch Systems, Inc.",
    "12142": "SULLIVAN-CROMWELL - Sullivan & Cromwell",
    "12143": "STARTEL-",
    "12144": "CLOUD-GRID - Cloud Grid Computing",
    "12145": "COLORADOSTATEUNIV - Colorado State University",
    "12146": "MVS Net, S.A. de C.V.",
    "12147": "DFS-RWD - Discover Financial Services",
    "12148": "CLEMSONU - Clemson University",
    "12149": "NOVARIX - Novarix Technologies LLC",
    "12150": "COTELCAM",
    "12151": "LEARNING-TREE-INTL-OPERATIONS - Learning Tree International, Inc.",
    "12152": "12152 - Ascensus, Inc.",
    "12153": "HBI-N1 - HBI Branded Apparel Enterprises, LLC",
    "12154": "INFOUSA - InfoUSA",
    "12155": "-HMPL - Henderson Municipal Power & Light, Inc.",
    "12156": "STSN-SLC-UT-US - STSN GENERAL HOLDINGS, INC.",
    "12157": "ECM-N - Element Capital Management LLC",
    "12158": "ILLUMINA - ILLUMINA, INC.",
    "12159": "SECURITIESAMERICA - Securities America Inc.",
    "12162": "DATA-DISTIBUTORS- - DATA DISTRIBUTORS",
    "12163": "AMHERST-HOLDINGS - Amherst Holdings LLC",
    "12164": "JBX-COM - JBX Online, Inc",
    "12165": "XACTWARE - Xactware Information Services Inc.",
    "12166": "OWC-NET - Other World Computing - OWC",
    "12167": "OMEGA - Omega Communications, Inc.",
    "12168": "MII-XPC - Mirror Image Internet, Inc.",
    "12169": "IBM-BRS-SERVICE - IBM Business Recovery Service",
    "12170": "PENTELOFAMERICA - Pentel of America, LTD.",
    "12171": "FTENTERPRISES - Fast Enterprises, LLC",
    "12173": "UA - The University of Alabama",
    "12174": "UTILITY-DATACENTER-01 - Flytrap Technologies, LLC",
    "12175": "YELMNET - Yelm Telephone Company",
    "12176": "ICAP-N - ICAP Services North America LLC",
    "12177": "ETS-TELEPHONE-COMPANY - ETS TELEPHONE COMPANY, INC.",
    "12178": "INTERNAP-2BLK - Internap Network Services Corporation",
    "12179": "INTERNAP-2BLK - Internap Network Services Corporation",
    "12180": "INTERNAP-2BLK - Internap Network Services Corporation",
    "12181": "INTERNAP-2BLK - Internap Network Services Corporation",
    "12182": "INTERNAP-2BLK - Internap Network Services Corporation",
    "12183": "RDIO - RDIO, Inc",
    "12184": "FORRESTER-RESEARCH - Forrester Research",
    "12185": "N1 - Thompson, Siegel & Walmsley LLC",
    "12187": "MTAHQ1 - Metropolitan Tranportation Authority",
    "12188": "Q9- - Q9 Networks Inc.",
    "12189": "12189 - PhoenixNAP LLC",
    "12190": "OOCL-NET - OOCL (USA), Inc.",
    "12191": "LEBAN- - City of Lebanon - Lebanon Utilities",
    "12192": "T2-JC-SHN - ThinkTech, Inc",
    "12193": "INVIS- - Invision Inc",
    "12194": "ARAP-DLSTX - American Radiology Associates, P.A.",
    "12196": "ETSY - Etsy Inc.",
    "12197": "DRUGSTORE-COM - Drugstore.Com, Inc.",
    "12198": "THE-NETWORK-GROUP - THE NETWORK GROUP",
    "12199": "UUNET-RD - MCI Communications Services, Inc. d/b/a Verizon Business",
    "12200": "RACKSPACE - Rackspace Hosting",
    "12201": "SCC-LAKELAND - Saddle Creek Corp",
    "12202": "PSCPA - PINEHURST SURGICAL CLINIC, P.A",
    "12203": "TORIA-FEDERAL-SL - TORIA FEDERAL SAVINGS",
    "12204": "SCN-NET - SCN Research, Inc.",
    "12205": "SCSD - Sachem Central School District",
    "12206": "DNPNE - DNP Networks",
    "12207": "COGENT-12207 - Cogent Communications",
    "12208": "TRUVISTA - TruVista Communications",
    "12209": "GIROSOL - Girosol, Corp.",
    "12210": "CWBANKNET - Community West Bank",
    "12211": "NDAQ-OMX-PHLX-12211 - THE NDAQ OMX GROUP, INC.",
    "12212": "RC-01- - Ravand Cybertech Inc.",
    "12213": "LANXE - Lanxess Corporation",
    "12214": "RAPIDDSL--WIRELESS - RapidDSL & Wireless",
    "12215": "RIGHTCENSION - Right Ascension, Inc.",
    "12216": "KRAVET - KRAVET INC.",
    "12217": "UPS - UNITED PARCEL SERVICE",
    "12218": "AMERICAN-INSTITUTES-FOR-RESEARCH - American Institutes for Research",
    "12219": "MILLERSOFFICEPRODUCTS - Miller's Office Products",
    "12220": "I-EVOLVE-TECHNOLOGY-SERVICES - I-Evolve Technology Services",
    "12221": "SCOTTSAVE-COM - Scottsdale Securities, Inc.",
    "12222": "12222 Akamai Technologies",
    "12223": "-EQUIVOICE-COM - Equivoice LLC",
    "12224": "COALF- - Coalfire Systems, Inc.",
    "12225": "CONSUMERINFO1 - Consumerinfo.com, Inc.",
    "12226": "INTRIA-HP - CIBC / INTRIA-HP",
    "12227": "DISPATCH--1 - Dispatch Printing Company",
    "12228": "2CO - 21ST CENTURY ONCOLOGY, INC.",
    "12229": "S-WHQ - S Institute, Inc.",
    "12230": "OKBRIDGE - OKbridge, Inc.",
    "12231": "CONWAYCORP - Conway Corporation",
    "12232": "QONCERT - Qoncert, LLC",
    "12233": "WATER-STREET-SOLUTIONS - Water Street Solutions, Inc.",
    "12234": "UUNET-INT - MCI Communications Services, Inc. d/b/a Verizon Business",
    "12235": "SEN-1 - SmartEdgeNet LLC",
    "12236": "HANOVER - Hanover Insurance Group, Inc.",
    "12237": "APPTIO- - Apptio Inc",
    "12238": "AECOM - AECOM/CCSI",
    "12239": "BLOOMINGTON-SD87 - Bloomington Public School District No. 87",
    "12241": "NCTCNET-1 - Nebraska Central Telephone Company",
    "12242": "-OSITRANSCRIPTION - OSi Transcription",
    "12244": "SUPREME-SECURITY - Supreme Security Systems, Inc.",
    "12245": "PRMC-N - Peninsula Regional Medical Center",
    "12246": "PRODCUTION- - HPM Networks",
    "12247": "TRECA - Tri-Rivers Educational Computer Association",
    "12248": "Oficina Central de Estadistica eInformatica (OCEI)",
    "12249": "YUBACITY - City of Yuba City",
    "12250": "EHSC - EDWARD HEALTH SERVICE CORP",
    "12251": "INVISION - Invision.com, Inc.",
    "12252": "America Movil Peru S.A.C.",
    "12253": "LEONCOUNTYFL - Leon County Board of County Commisioners",
    "12254": "INSTRUCTURE-MAIN - Instructure, Inc",
    "12255": "AMGEN - AMGEN, Inc.",
    "12256": "CITYLINQ - CityLinq Net Services",
    "12257": "EMC EMC",
    "12258": "MWEB-12258",
    "12259": "EBOCOM - EBOCOM LLC",
    "12260": "COLOSTORE - Colostore.com",
    "12261": "DEKALB - DTC Communications, Inc.",
    "12262": "RR-CINCINNATI-N-01 - Time Warner Cable Internet LLC",
    "12263": "STBH - Saint Bernard Hospital",
    "12264": "SkyOnline de Argentina S.A.",
    "12265": "SDSNY-1 - Securities Dealing Systems, Inc.",
    "12266": "VOSTROM - StoreRunner, Inc.",
    "12267": "HORWATH - Horwath International",
    "12268": "ETOWNCOLLEGE-N - Elizabethtown College",
    "12269": "GROUPON-PROD1 - Groupon, Inc.",
    "12270": "RR-TEX-ELPO-N - Time Warner Cable Internet LLC",
    "12271": "SCRR-12271 - Time Warner Cable Internet LLC",
    "12272": "MEDATA-PROD- - Medata Inc.",
    "12273": "TRUELINK - Transunion Interactive, Inc.",
    "12274": "-12274 - Fujitsu Consulting, Inc.",
    "12275": "NETWORKCAR-XO - Networkfleet, Inc.",
    "12276": "SFMIX - San Francisco Metropolitan Internet Exchange (SFMIX)",
    "12277": "NRCAN-SHERBROOKE - Natural Resources Canada",
    "12278": "NCOCC - North Carolina 811, INC",
    "12279": "LAYER-EIGHT - Layer-Eight, Inc.",
    "12280": "VERISWITCH - Veriswitch Technologies Inc.",
    "12281": "APAC- - APAC Customer Services",
    "12282": "GMA - Selectronics Corp.",
    "12283": "FTS-64 - First Technology Services",
    "12284": "IPNS- - Computer Solutions, Inc.",
    "12285": "ONE-ELEVEN - One Eleven Internet Services",
    "12286": "PRINCETON-HEALTHCARE-SYSTEM - Princeton Healthcare System",
    "12287": "AFILI-AMS1-MON Afilias Canada, Corp.",
    "12288": "VFNM-NET datadirect gmbh",
    "12289": "SVYAZEKSPERT \"Svyazekspert\" LLC",
    "12290": "EXONETRIC Exonetric Consulting Ltd",
    "12291": "Deutsche Post AG",
    "12292": "TRANSKOM Transkom Kommunikationsnetzwerke GmbH",
    "12293": "IIL- Digiweb ltd",
    "12294": "TSYSTEMS Comstar-Ukraine LLC",
    "12296": "ADANET-TR ADA-NET Internet ve Iletisim Hizmetleri Tic. A.S.",
    "12297": "ARMENTEL Armenia Telephone Company",
    "12298": "QIAGEN- QIAGEN GmbH",
    "12301": "INVITEL Invitel Tavkozlesi Zrt.",
    "12302": "VODAFONE_RO Vodafone Romania S.A.",
    "12303": "ISZT- Council of Hungarian Internet Providers",
    "12304": "A.I.Alikhanyan National Science Laboratory",
    "12305": "NORTENET G9SA, Telecomunicacoes, S.A",
    "12306": "PLUSLINE Plus.Line AG",
    "12307": "Warburg Dillon Read, Switzerland",
    "12309": "NOUVELLE- Autonomous system for Nouvelle Srl",
    "12310": "INES iNES Group SRL",
    "12311": "IAEA International Atomic Energy Agency",
    "12312": "ECOTEL ecotel communication ag",
    "12313": "VERSATEL-NGN Versatel Deutschland GmbH",
    "12314": "ROPNET- RopNet Autonomous System",
    "12315": "QSP- Quality Service Provider BV",
    "12316": "FITSNET Finanz Informatik Technologie Service GmbH & Co. KG",
    "12318": "FR--EXANE EXANE SA",
    "12319": "IZFE- IZFE SA Informatika Zerbitzuen Foru Elkartea",
    "12321": "ES-IBERCOMTELECOM-BACKBONE Ibercom Telecom S.A.",
    "12322": "PROXAD Free S",
    "12323": "DELTA- Delta Solutions BV",
    "12324": "LUBMAN-EDU- Poland, Lublin",
    "12325": "NET-ZONE- SC SALADEJOCURI SRL",
    "12326": "Hrvatski Telekom d.d.",
    "12327": "IDEAR4BUSINESS-INTERNATIONAL-LTD idear4business international LTD",
    "12328": "ALAN-SYSTEMS-RYBNIK- \"Alan Systems\" SP. Z O.O.",
    "12329": "TMR TMR IP service and TMR customer networks",
    "12330": "BAUDIA-OY Baudia Oy",
    "12331": "AUDI AG",
    "12332": "PRIMORYE- OJSC Rostelecom",
    "12333": "DFINET DFi Service SA",
    "12334": "R Cable y Telecomunicaciones Galicia, S.A.",
    "12335": "TARIO Tario Communications CJSC",
    "12337": "NORIS-NETWORK noris network AG",
    "12338": "EUSKALTEL Euskaltel S.A.",
    "12340": "TZM-NET Wispone S.R.L.",
    "12341": "USPC Ural State Polzunov College",
    "12342": "BRACK- Brack Electronics AG",
    "12343": "N-ARCAN-NETWORKS Focus Consulting S.A.",
    "12344": "DigiCommerce",
    "12345": "12345 General Software s.r.l.",
    "12346": "LUBMAN-COM- Poland, Lublin",
    "12347": "VIRTUALTEC VirtualTec Solutions AG",
    "12348": "12348 ODN OnlineDienst Nordbayern GmbH & Co. KG",
    "12349": "SCHERING- Bayer Business Services GmbH",
    "12350": "VTX-NETWORK VTX Services SA",
    "12351": "TBS-CAEN Tag's Broadcasting Services",
    "12353": "VODAFONE-PT Vodafone Portugal",
    "12354": "BT Italia S.p.A.",
    "12355": "HAMCOM-DE HeLi NET Telekommunikation GmbH & Co. KG",
    "12356": "RAU- UNIVERSITATEA ROMANO-AMERICANA",
    "12357": "COMUNITEL VODAFONE ESPANA S.A.U.",
    "12358": "SOLO FE \"ALTERNATIVNAYA ZIFROVAYA SET\".",
    "12359": "RELCO http://www.relco.es",
    "12360": "KTK KEVAG Telekom GmbH",
    "12361": "PANAFONET- VODAFONE-PANAFON HELLENIC TELECOMMUNICATIONS COMPANY SA",
    "12362": "NETCOM NETPLUS Communication Autonomous System",
    "12363": "DADA- DADA S.p.a.",
    "12364": "UOM University of Macedonia, Economic and Social Sciences",
    "12365": "SARKOR- Sarkor-Telecom",
    "12366": "CIE Autonomous System",
    "12367": "VERIZON-ES Verizon Spain SL",
    "12368": "vwd information solutions AG",
    "12371": "AVENCY avency GmbH",
    "12372": "ACTIVNET",
    "12373": "ENGITEL S.p.A.",
    "12374": "LFNET-01 LF.net GmbH",
    "12375": "OPOY- DNA Oy",
    "12376": "MOF Ministry of Finance",
    "12379": "PIN-NET- IP4 Internet Providing GmbH",
    "12380": "LENSVYAZ OJSC Rostelecom",
    "12381": "RESILANS Resilans AB",
    "12382": "TISCALI-AT-OOE Argentinierstrasse 21",
    "12384": "SLU-UPPSALA Swedish University of Agricultural Sciences",
    "12386": "ALPI Orange Catalunya Xarxes de Telecomunicacions S.A.",
    "12387": "TON TON Total optical Networks AG",
    "12388": "Casey CableVision Ltd.",
    "12389": "ROSTELECOM- OJSC Rostelecom",
    "12390": "KINGSTON-UK- KCOM Group Public Limited Company",
    "12391": "DELTA-INFORMATICS",
    "12392": "BRUTELE Brutele SC",
    "12393": "KPN B.V.",
    "12395": "PANDEMONIUM- ADISTA S",
    "12396": "INAR-ARKHNAGELSK- OJSC MegaFon",
    "12397": "OPTOCOM Optocom Ltd",
    "12399": "SCAN-PLUS- ScanPlus GmbH",
    "12400": "PARTNER- Partner Communications Ltd.",
    "12401": "INTERNIC-12401 INTERNIC Autonomous System",
    "12402": "UOPIRAEUS University of Piraeus",
    "12403": "VIZIT- Teleradiocompany Vizit Ltd",
    "12404": "SZ N",
    "12406": "BN- Business Network JV",
    "12408": "BIKENT- LLC Bi-Kent",
    "12409": "HRNET H.R.Net SARL",
    "12411": "LLNW-GCC Limelight Networks, INC.",
    "12413": "HANSHAKE- Handshake e.V.",
    "12414": "NL-SOLCON SOLCON",
    "12415": "Weblink Telecom Ltd",
    "12417": "INFONET InfoNET d.o.o.",
    "12418": "QUANTUM Quantum CJSC",
    "12421": "GT-FIBER Golden Telecom LLC",
    "12422": "EVONIK- Evonik Services GmbH",
    "12423": "TORMAN Torun Regional Computer Network",
    "12425": "IBYKUS IBYKUS AG fuer Informationstechnologie",
    "12426": "MADNET- Slovanet a.s.",
    "12427": "MIRNET MIRNet project",
    "12428": "UNICREDIT--MI-IT UniCredit Business Integrated Solutions S.C.p.A.",
    "12429": "CYBERNET-CH Swisscom (Schweiz) AG / Autonomous System",
    "12430": "VODAFONE_ES VODAFONE ESPANA S.A.U.",
    "12431": "SYB- SYBCOM GmbH",
    "12433": "ORBTALK Orbtalk Limited",
    "12435": "TELIAMOBILE-DK Telia Mobile DK Autonomous System",
    "12436": "BERGON- Bergon Internet Ltd.",
    "12437": "ICSMEDIA-DE ICSmedia GmbH",
    "12438": "SUNLINE- ISP SunLine",
    "12439": "N-IPX-RO Impromex S.R.L.",
    "12440": "12440 Hughes Network Systems GmbH",
    "12441": "COMMTOUCH-N Commtouch Software Ltd",
    "12442": "PRO-TV- PRO TV S.A.",
    "12443": "RCC-RIGA",
    "12444": "TURPRO- TELNET TELEKOM HIZMETLERI ANONIM SIRKETI",
    "12445": "SPIDERNET- Selene s.p.a.",
    "12446": "ESS-NET- Eastern Space Systems SRL",
    "12447": "KABELINE- Ernst Klingler Kabelfernsehen Gmbh",
    "12448": "Adyghe State University",
    "12449": "DSVR-1 DSVR Autonomous System",
    "12450": "TRANSCOR- Agentia TRANSCOR SRL",
    "12453": "KRAFTCOM- Bernhard Kraft",
    "12455": "JAMBONET",
    "12456": "SHIN- SHOE INNOVATION LLC",
    "12459": "HUM-N Vladimir Hum",
    "12460": "MANDALA- Mandala Internet EDV Service GmbH",
    "12461": "MKREDIT- OAO \"Credit-Moscow Bank\"",
    "12462": "Arrakis, Servicios y comunicaciones, S.L.",
    "12463": "N-SBM S.A. des Bains de Mer et du Cercle des Etrangers a Monaco",
    "12464": "PW-NET Politechnika Warszawska",
    "12465": "Banca di Intermediazione Mobiliare IMI S.p.A.",
    "12466": "BICOS Bicos Computer GmbH",
    "12467": "SafeNet Inc.",
    "12468": "ABANET ABANET",
    "12469": "INFONET-NETHERLAND KPN B.V.",
    "12470": "12470 GLOBE Development GmbH Backbone Germany",
    "12471": "TELSTRAEUROPELTD-DEDICATED-HOSTING Telstra Ltd",
    "12472": "12472 Waycom International SARL",
    "12474": "VIVELAVIE Publicom S.r.l.",
    "12475": "Enron Power Operations Ltd",
    "12476": "TER-CITY-CABLE- TER Sp. z.o.o.",
    "12477": "TNPS Autonomous system",
    "12478": "SITEKSPB- JSC Mastak",
    "12479": "UNI2- France Telecom Espana SA",
    "12480": "ILK ILK Internet GmbH, Karlsruhe, Germany",
    "12481": "TRIVENET Trivenet S.R.L.",
    "12482": "N-ICTNET- Institut Catala de Tecnologia",
    "12483": "Danske Bank Autonomous System",
    "12484": "BORISLTD- Boris Ltd.",
    "12485": "SMARTNET DNS:NET Internet Service GmbH",
    "12486": "YEMENNET TeleYemen",
    "12487": "N-WSNET WSNET Autonomous System",
    "12488": "KRYSTAL Krystal Solutions LLP",
    "12489": "InvestNet Italia S.p.A.",
    "12490": "ROSE- Zur Rose AG",
    "12491": "IPPLANET- Gilat Satcom",
    "12493": "12493 Mobistar SA",
    "12494": "N-POSTLTD OOO \"Post ltd\"",
    "12496": "IDNET Infinity Developments Limited",
    "12497": "SANET-GE Caucasus Online LLC",
    "12498": "FINECO FinecoBank SpA",
    "12499": "CRNS ZAO Garant-Siberia",
    "12500": "RCS-PNZ- CJSC \"Ruscentrosvyaz\"",
    "12501": "NORRNOD An Internet Exchange point and ISP in Umea, Sweden",
    "12502": "NEPUSTILNET-01 Dr.-Ing. Nepustil & Co. GmbH",
    "12503": "Power Team Network Autonomous System",
    "12504": "KABELSERVICE Ziggo B.V.",
    "12505": "BMP Banca Popolare di Milano",
    "12507": "SWIFT-TRACE- Swift Trace Ltd.",
    "12508": "12508 Rainside s.r.o.",
    "12509": "LB- LATVIJ BANKA",
    "12510": "SAP_AG_WDF SAP-AG Walldorf",
    "12511": "CH-POSTNETZ Post CH AG",
    "12512": "CBXNET CBXNET combox internet GmbH",
    "12513": "ECLIPSE KCOM GROUP PLC",
    "12515": "RS Advanced Systems srl",
    "12516": "WEBORAMA Weborama SA",
    "12518": "SHLINK SHLINK Internet Service",
    "12519": "FTNETUK FastNet International Ltd",
    "12521": "NOVA_INTERNET_12521 Nova Internet Network",
    "12522": "TELEDYN-GR Autonomous System",
    "12523": "EUREDIT EUROPAGES SA",
    "12524": "International Data Exchange LLC",
    "12525": "INTERNETLTD INTERNET Ltd.",
    "12526": "Latvijas Krajbanka",
    "12527": "MILLENNIUMBCP- Millennium BCP-Prestacao de Servicos ACE",
    "12528": "BURSTFIRE-MH- Burstfire Networks Ltd",
    "12529": "SALECO Sale For Distribution & Communication Co. Ltd",
    "12530": "GOLDENTELECOM-UKRAINE Golden Telecom",
    "12531": "WLW- Wer liefert was ?",
    "12533": "RMNET RMnet S.R.L.",
    "12534": "On:Line Finance Limited,",
    "12536": "ALLEGRO NETWORKS LIMITED",
    "12538": "TATINCOM- CJSC Nizhegorodskaya Cellular Communications",
    "12539": "PENKI Penki Kontinentai, Ltd.",
    "12540": "IDECNET- IdecNet Spain - Canary Islands Telco",
    "12541": "BTESPANA BT ESPANA, COMPANIA DE SERVICIOS GLOBALES DE TELECOMUNICACIONES, SA",
    "12542": "TVCABO- TVCABO Autonomous System",
    "12543": "KUBTELECOM- KUBTELECOM Ltd.",
    "12545": "TRANSCOM TransCom Ltd",
    "12547": "YCN Infrastructural Serverhousing Telekom",
    "12548": "VIADUK- Viaduk-Telecom, Inc.",
    "12549": "N-COMPUTER-GBG  COMPUTER GBG S.A., ISP in Timisoara/Romania",
    "12551": "-ENEL-IT ENEL S.p.A. Autonomous System",
    "12552": "IPO-EU IP-Only Telecommunication Networks AB",
    "12553": "GRAWEHR Andreas Grawehr",
    "12554": "EYNET-BE Easynet Global Services Limited",
    "12555": "CUBIO-RUS ZAO Cubio Rus",
    "12556": "internet-solutions-ke",
    "12557": "DDB- DDB",
    "12559": "ISIDE- I.S.I.D.E. S.p.A.",
    "12561": "IXN- IX Networks BV io",
    "12563": "LEVICOM-BROADBAND- Levicom Broadband OU",
    "12564": "CMBG- Bulgarian Government Autonomous System",
    "12565": "LDLC LDLC.com SA",
    "12566": "SFR-BUSINESS-TEAM Societe Francaise du Radiotelephone S.A.",
    "12567": "R-U-SURE Autonomous System",
    "12569": "INYCOM INYCOM Autonomous System",
    "12570": "CBCZ itself s.r.o.",
    "12571": "INC- INC GmbH",
    "12572": "BULNET",
    "12573": "WIDEXS WideXS B.V.",
    "12574": "ROUTING http.net Internet GmbH",
    "12576": "ORANGE-PCS Orange Personal Communications Services",
    "12577": "MMC-AT- mmc kommunikationstechnologie gmbh",
    "12578": "APOLLO- LATTELEKOM-APOLLO",
    "12579": "XNC GmbH, Koeln",
    "12580": "OMNITEC Omnitec Sp. z o.o.",
    "12581": "TOPSNET tops.net GmbH & Co. KG",
    "12582": "TSF-DATANET-NGD- TSF MPLS VPN Services",
    "12583": "STANLEY-UK- Stanley UK Services Ltd",
    "12584": "TC Trust Center GmbH",
    "12585": "Verizon Austria GmbH",
    "12586": "GHOSTNET GHOSTnet GmbH",
    "12587": "Aizkraukles Banka",
    "12589": "POSTA-HU- Magyar Posta Zrt",
    "12590": "NTT- NTT Deutschland GmbH",
    "12591": "SMARTCOMBG Smartcom Bulgaria AD",
    "12592": "TTS TransTel Services SRL",
    "12593": "12593 Ukrcom Ltd.",
    "12594": "EXTERNET- Externet Nyrt",
    "12595": "N-MOPSNET Rehwork GmbH",
    "12596": "Esoft / OOCL UK",
    "12597": "GOTANET Gotalandsnatet AB",
    "12598": "HBM-HH- Verlagsgruppe Milchstrasse GmbH",
    "12599": "ATL- Atlas On-Line",
    "12600": "TELECITY-FR TELECITYGROUP INTERNATIONAL LIMITED",
    "12601": "CEGEDIM CEGEDIM S.A.",
    "12605": "LIWEST-AT LIWEST Kabelmedien GmbH",
    "12606": "EYNET-NL Easynet Global Services Limited",
    "12607": "Digital Bros. S.p.A.",
    "12608": "MAXHOSTING- MediaServicePlus Ltd.",
    "12610": "NETBE Rockenstein AG",
    "12611": "RKOM R-KOM Regensburger Telekommunikations GmbH & Co. KG",
    "12613": "FIREBRICK- FireBrick Limited",
    "12614": "NETWORK- SPEEDNIC S.R.L.",
    "12615": "GCN- Global Communication Net Plc",
    "12616": "HOSTER-DH- Filanco, ltd.",
    "12617": "SOLIDO-NET Solido Hosting A/S",
    "12618": "PL-BYDMAN-COM Commercial Users",
    "12619": "YEDIOT- Yediot Information Technologies ltd",
    "12620": "TICINOCOM Ticinocom SA",
    "12621": "ONEANET-BACKBONE 1A Networks Limited",
    "12622": "COMINTERN- JSC Comintern Online",
    "12623": "BCGE Banque cantonale de Geneve",
    "12624": "GIGANET-INFO- SC Giganet-Info SRL",
    "12625": "12625 DEUTSCHE BOERSE AG",
    "12626": "12626 Societe Francaise du Radiotelephone S.A",
    "12627": "Main Computer Center of Russian Federal Aviation Service",
    "12628": "SCREAMING-NET- Jaco Engelbrecht",
    "12629": "OPTION-SERVICE Option Service S",
    "12630": "OVERKKO OVERKKO Autonomous System",
    "12632": "DIGINETMOBIL RCS & RDS SA",
    "12634": "SCARLET CyberComm bv",
    "12635": "12635 Hutchison Drei Austria GmbH",
    "12636": "ONO Cableuropa S.A.U.",
    "12637": "SEEWEB Seeweb s.r.l.",
    "12638": "12638 E-Plus Mobilfunk GmbH & Co. KG",
    "12639": "MARKON- MARKON LTD",
    "12640": "COLT Technology Services Group Limited",
    "12641": "BT_MPLS British Telecommunications plc",
    "12642": "INET- P.W.U. INET Sp. z o.o.",
    "12643": "IGD Fraunhofer-Gesellschaft zur Forderung der angewandten Forchung e.V.",
    "12644": "TELEMACH Telemach Autonomous System",
    "12645": "CAP-MEDIATEL- Cap'Mediatel SARL",
    "12646": "ESOTEL- ESOTEL-Rustelecom Ltd.",
    "12647": "realTech system consulting GmbH Autonomous System",
    "12648": "Infront Limited",
    "12649": "Pictet et Cie",
    "12650": "ILSOLE24ORE Il Sole 24 Ore",
    "12651": "IPWORLDCOM IP worldcom SA",
    "12652": "COTECNA- COTECNA-GVA Autonomous System",
    "12653": "COMTONET KB Impuls Hellas S.A.",
    "12654": "RIPE-NCC-RIS- Reseaux IP Europeens Network Coordination Centre (RIPE NCC)",
    "12655": "12655 Telefonbuch Verlag Hans Mueller GmbH & Co. KG",
    "12656": "TA-GRX-I-AT A1 Telekom Austria AG",
    "12657": "BAYCIX BayCIX GmbH",
    "12658": "DXNET- Dexterity Networks Limited",
    "12659": "BBNWKSCORE European Backbone Networks",
    "12660": "SHARIF-EDU-NET Sharif University of Technology, Tehran,Iran",
    "12662": "NEMI- FOP Petrushenko Sergiy Petrovich",
    "12663": "VODAFONE-GROUP Vodafone Omnitel N.V.",
    "12664": "DAB-AG- DAB Bank AG",
    "12665": "MSH Autonomous System",
    "12666": "INTERXION- InterXion Telecom BV",
    "12668": "MIRALOGIC- LLC \"KomTehCentr\"",
    "12669": "BDUT- \"OAO Brokerage Firm Unity Trust\"",
    "12670": "-COMPLETEL COMPLETEL S France",
    "12672": "N-RINGIER Ringier Print SRL",
    "12673": "University of Pannonia",
    "12674": "Net For You SRL",
    "12675": "UAIC-NETWORK Alexandru Ioan Cuza University",
    "12676": "NCORE- HKN GmbH",
    "12677": "DECK Deck Internet, RO",
    "12678": "BADOO-U Badoo Limited",
    "12679": "N-MOL \"Iceberg Telecom\" Ltd.",
    "12680": "GRUNER-UND-JAHR-1 Gruner + Jahr AG & Co KG",
    "12683": "STATEL- Rostelecom",
    "12684": "SES-LUX- SES TRA S.A.",
    "12685": "SIBITEX Sibitex Ltd.",
    "12686": "Open Joint Stock Commercial Bank Rosbank (OJSC)",
    "12687": "URAN Association of users of Ukrainian Research & Academic Network \"URAN\"",
    "12688": "BAIKALTRANSTELECOM CJSC \"Baikal-TransTeleCom\"",
    "12689": "NL-IO Autonomous System for Internet Online BV",
    "12690": "MKSNET- MKS Autonomous System",
    "12691": "DVNZ Donetsk State Technical University",
    "12692": "3Com Europe",
    "12693": "EDISCOM e.discom Telekommunikation GmbH",
    "12694": "GEORG- Georg Hitsch",
    "12695": "DINET- Digital Networks CJSC",
    "12696": "AXA-TECH GIE AXA Technology Services France",
    "12697": "NECOMM Autonomous System",
    "12698": "DELTANET Astral Telecom S.A. Cluj, sucursala Brasov",
    "12699": "PUBLIMEDIA- PubliMedia International SA",
    "12700": "SC-VEKTOR- Komertsiyno Virobnitcha Firma \"VEKTOR\"",
    "12701": "BARCAP Barclays Bank plc",
    "12702": "UUNET-EMEA-IPV6 Verizon Business EMEA - IPv6 only autonomous System",
    "12703": "PULSANT- Pulsant (Scotland) Ltd",
    "12705": "PFES OJSC Rostelecom",
    "12706": "Public JSC First Ukrainian International Bank",
    "12707": "SHERINGHAM-UK Caberfeidh (UK) Ltd",
    "12708": "ONETEL- TalkTalk Communications Limited",
    "12709": "MELITACABLE Melita plc.",
    "12712": "NIC Elisa Oyj",
    "12713": "OTEGLOBE OTE GLOBAL SOLUTIONS S.A.",
    "12714": "TI- Net By Net Holding LLC",
    "12715": "JAZZNET Jazz Telecom S.A.",
    "12716": "MOBILTEL MOBILTEL EAD",
    "12717": "Tele1Europe, Sweden",
    "12719": "QUIPO- Quipo Internet Provider by Micso s.r.l.",
    "12720": "BT Communications Ireland Limited",
    "12722": "REAL-CONNECT- RECONN. Operator svyazy Ltd.",
    "12723": "Pagini Aurii S.A.",
    "12724": "LERNET- Prokhorov General Physics Institute, Russian Academy of Sciences, R (GPI)",
    "12725": "Khabarovsk Division of the Institute",
    "12726": "LH-AIRPLUS Lufthansa AirPlus Servicekarten GmbH",
    "12727": "CALIXO VIALIS - Regie Municipale de Colmar",
    "12728": "Zendor.com Ltd.",
    "12729": "HSBC_TR_BANK_INTERNET HSBC BANK ANONIM SIRKETI",
    "12730": "INECO_ OJSC Rostelecom",
    "12731": "IPHH IPHH Internet Port Hamburg GmbH",
    "12732": "GUTCON-NET GutCon GmbH",
    "12734": "FIAT- Fiat Group Autonomous System",
    "12735": "TURKNET TurkNet Iletisim Hizmetleri A.S",
    "12736": "IAA- Israel Airports Authority",
    "12737": "EP-RO Electroplus SRL",
    "12738": "KNTELECOM- KN Telecom Ukraine",
    "12739": "NETLINE_ NetLine Ltd",
    "12740": "OMX-NDAQ-NETS OMX Technology AB",
    "12741": "INTERNETIA- Netia SA",
    "12742": "AUDI Audi BANK sal",
    "12743": "PTK-CENTERTEL PTK-Centertel",
    "12744": "KEYRUS KEYRUS S.A.",
    "12748": "IAV IAV GmbH Ingenieurgesellschaft Auto und Verkehr",
    "12749": "Multi-homed service provider",
    "12750": "SOFTEC-MNT Softec AG",
    "12751": "NCI NCI GmbH, Muenchen",
    "12752": "WORLDNET-COMUNICATII Worldnet Comunicatii Srl",
    "12753": "TEVA- Teva Pharmaceutical Industries Limited",
    "12754": "COOLNET Coolnet New Communication Provider",
    "12755": "COLT Technology Services Group Limited",
    "12756": "INFOCOM- Infocom Plc.",
    "12757": "IPTRON IPTRON.NET OU",
    "12758": "FREELER",
    "12759": "SOCO- SOCO Network Solutions GmbH",
    "12760": "Kensington Group",
    "12761": "COLT Technology Services Group Limited",
    "12762": "VTG-AT Vorarlberger Informatik- und Telekommunikationsdienstleistungsgesellschaft mbH",
    "12763": "Honda Europe NV",
    "12764": "AKNET Educational and Science Network",
    "12765": "TOTAL-CONNECT Total S.A.",
    "12766": "MAGNA STEYR Fahrzeugtechnik AG und Co KG",
    "12767": "PRAGONET- T-Systems Czech Republic a.s.",
    "12768": "ER-TELECOM- CJSC \"ER-Telecom Holding\"",
    "12769": "IBER-X LET'S GOWEX, S.A.",
    "12770": "KHB- KCNET Autonomous System",
    "12771": "MEDIAMETRIE- Mediametrie S.A.",
    "12772": "ENFORTA- Enforta  Autonomous System",
    "12773": "SONIKO- Teleradiocompany Soniko-Svyaz Ltd",
    "12774": "PWN-N Wydawnictwo Naukowe PWN S.A.",
    "12775": "JPCINET The JPCINET Autonomous System",
    "12776": "Bank Vontobel AG",
    "12777": "OTHER Eser Telekom",
    "12778": "NETSI Metaling d.o.o.",
    "12779": "ITGATE IT.Gate S.p.A.",
    "12782": "Uppsala Lans Landsting",
    "12783": "ENET-AL- ENET Shpk",
    "12785": "SI-ZVD ZVD Zavod za varstvo pri delu d.d.",
    "12786": "HATTRICK Hattrick Limited",
    "12787": "MII-2 Mirror-Image Internet",
    "12788": "NBI-KIEV Opened Joint Stock Company \"National Bureau of Information\"",
    "12789": "DMG Media Limited",
    "12790": "CEA- LTD.\"TB\"",
    "12792": "CINET- JSC CINET",
    "12793": "ETELAT Telekom Austria TA AG",
    "12794": "AKNET-AKBANK AKBANK T",
    "12795": "CCBANK- Central Cooperative Bank PLC",
    "12796": "INTERBILD- MOBILNO PARKIRANE EAD",
    "12797": "N-ATLANET BT Italia S.p.A.",
    "12798": "VCW- Victor Chandler International Online",
    "12799": "12799 Sunrise Communications AG",
    "12801": "Texas Instruments",
    "12802": "Migdal Insurance Company Ltd",
    "12803": "ONLINEGROUP- ISP Online Technologies GROUP Ltd",
    "12804": "ADISAM Adisam Telecom S.A.",
    "12806": "OCDE",
    "12807": "CVF S.A",
    "12808": "DTMS- dtms Deutsche Telefon- und Marketing Service GmbH",
    "12809": "GEON Norma-press Agency Ltd",
    "12810": "VIPNET- VIPnet d.o.o.",
    "12811": "GIE AUCHAN INTERNATIONAL TECHNOLOGY",
    "12812": "N-AUBNET #-AUBNET CONVERTED TO N-AUBNET FOR RPSL COMPLIANCE American University of Beirut",
    "12813": "WORNET- WorNet AG",
    "12814": "DEL- Davidov Electric Ltd.",
    "12815": "MUSALOFT Musala Soft Ltd.",
    "12816": "MWN- Leibniz-Rechenzentrum",
    "12817": "GEFOEKOM GeFoekoM e.V.",
    "12818": "BIZANGA- Cloudmark Labs",
    "12819": "NA RUSSIAN EXTENTION",
    "12820": "ALITE- Limited Liability Company \"Alite\"",
    "12821": "INFOSYS-NHK- Open Joint-Stock Company \"Information Systems\"",
    "12822": "LYNET- LYNET Kommunikation AG",
    "12823": "KAPPATECH- KAPPATECH DOO Beograd",
    "12824": "HOMEPL- home.pl sp. z o.o.",
    "12826": "CETSI Conseils et Systemes Informatiques",
    "12827": "WIRTUALNAPOLSKA Wirtualna Polska S.A.",
    "12828": "KRSC- Institution of the Russian Science Academy Institute of  Computational Modeling of Siberian RAN Department",
    "12829": "ANGELSOFT AngelSoft ET",
    "12830": "INFRA-MAIN- InfraNet AG",
    "12831": "TK- Technical University of Gdansk",
    "12833": "GIGAPIX GigaPix - Portuguese Internet eXchange",
    "12834": "Danfoss",
    "12835": "INFOTN- Trentino Network S.r.l.",
    "12836": "POISK POISK-TELECOM LLC",
    "12837": "OLDBANK-NET PJSB Starokievsky Bank",
    "12838": "EDPNET EDPNET",
    "12839": "ESI- ESI s.r.l.",
    "12840": "TICARETNET TicaretNet Autonomous System",
    "12842": "INTERNET-OLTENIA Internet Oltenia SRL",
    "12843": "TELEMAXX TelemaxX Telekommunikation GmbH",
    "12844": "N-BOUYGTEL-MOBILE Bouygues Telecom",
    "12846": "OJSC Rostelecom",
    "12847": "LMT-NET Latvijas Mobilais Telefons SIA",
    "12848": "MEGALAN- Bulnet Ltd.",
    "12849": "HOTNET-IL Hot-Net internet services Ltd.",
    "12850": "N-ENTER Enter S.r.l.    http://www.enter.it",
    "12851": "ALVOTECH- Alvotech GmbH",
    "12852": "EYNETES- Easynet Global Services Limited",
    "12853": "GENDORF-DE InfraServ Gendorf, Germany",
    "12854": "PINE- Pine Digital Security",
    "12855": "HOUXOUUK Houxou Ltd",
    "12856": "UNONA- VEGA.NET Ltd.",
    "12857": "TDS TDS Informationstechnologie AG",
    "12858": "MYNET A.S.",
    "12859": "NL-BIT BIT BV",
    "12860": "AXARNET-NETWORK Axarnet Comunicaciones SL",
    "12861": "DEKSAR Vestel Elektronik Sanayi ve Ticaret A.S.",
    "12862": "MUTBI- MUTBI",
    "12863": "BOURSEDIRECT Autonomous System",
    "12866": "SUN_EU_ Sun Microsystems European",
    "12869": "MERLIN-SYSTEM Merlin Communications",
    "12870": "AHSYS Arrowhead Systems Ltd",
    "12871": "NL-CONCEPTS Concepts ICT Autonomous System",
    "12872": "MEGTYLE MegaStyle-Service",
    "12873": "STRATEJI Menkul Degerler A.S.",
    "12874": "FTWEB Fastweb SpA",
    "12875": "CTLE- PE Shumenkov Valerij Vasil'evich",
    "12876": "12876 ONLINE S.A.S.",
    "12877": "RBPL- Raiffeisen Bank Polska S.A.",
    "12878": "COLT Technology Services Group Limited",
    "12879": "OJSC-STN- JSC Svyaztransneft",
    "12880": "DCI- Information Technology Company (ITC)",
    "12883": "UCOMLINE PRIVATE JOINT-STOCK COMPANY \"FARLEP-INVEST\"",
    "12884": "DRW-INVESTMENTS- DRW Investments (UK) Limited",
    "12885": "ARBINET-UK- Arbinet-thexchange Limited",
    "12886": "LEWTELNET LEWTelNet GmbH",
    "12887": "NETIA-TRANSIT- Netia SA",
    "12888": "Amadeus Data Processing GmbH",
    "12889": "INTERNET42 Stiftelsen Folkets Hubb",
    "12890": "SEPTOR-NET-UA Scientific - industrial enterprise Septor Ltd.",
    "12891": "TSK NET",
    "12892": "XDOTNET xdot GmbH",
    "12893": "AVENIR-TELECOM- AVENIR-TELECOM",
    "12894": "DATAPROCESS K+S IT-Services GmbH",
    "12895": "IT-AUSTRIA s IT Solutions AT Spardat GmbH",
    "12896": "ENBA",
    "12897": "HEAGMEDIANET HSE Medianet GmbH",
    "12898": "RIPE Hees riconet GmbH",
    "12899": "GLOBALTRAFFIC Global Traffic Datenkommunikations GmbH",
    "12901": "MAPORAMA- Soci\u00e8t\u00e9 MAPORAMA RCS Paris B 429 646 508",
    "12902": "LUNA Luna.nl B.V.",
    "12903": "GARANTI-TECH Garanti Bilisim Teknolojisi ve Ticaret T.A.S.",
    "12905": "ACS-SK- ACS Ltd.",
    "12906": "DELTATRE- Deltatre S.p.A.",
    "12907": "IPANDMORE ip&more GmbH",
    "12908": "SABANCIUNIV Sabanci University",
    "12910": "THOMSON- Technicolor SA",
    "12912": "TMPL T-MOBILE POLSKA SPOLKA AKCYJNA",
    "12914": "ITCOM-12914-UA TVCOM Ltd.",
    "12915": "EPAG- EPAG Autonomous System",
    "12918": "VERKKOTIETO- DNA Oy",
    "12919": "Agilent Technologies Europe Autonomous System",
    "12920": "DIRECTNETRO S.C. Consultens Networking S.R.L.",
    "12921": "N-ARTNETWORKROMANIA  # -ARTNETWORKROMANIA CONVERTED TO N-ARTNETWORKROMANIA FOR RPSL COMPLIANCE Art Network Group Of Companies",
    "12922": "MULTITRADE- Bank Outsourcer",
    "12923": "WIZARD- Wizard Computersysteme GmbH",
    "12924": "VIAES- VIA NET.WORKS Spain",
    "12925": "SINP-MSU SINP MSU",
    "12926": "ARTELECOMPT Ar Telecom, Acessos e Redes Telecomunicacoes. S.A.",
    "12928": "UNICIBLE Unicible",
    "12929": "NETCOM- TeliaSonera Norge",
    "12930": "CARDCOMPLETE- card complete Service Bank AG",
    "12931": "IDKOM IDKOM Networks GmbH, Kempten, Germany",
    "12932": "TELETEXT-LTD- Teletext Ltd.",
    "12933": "DONBS-IX Donbass Internet eXchange",
    "12934": "Bank Handlowy w Warszawie SA",
    "12935": "NOCOM QD Sverige AB",
    "12936": "ECCE-TERRAM-DE ECCE TERRAM Internet Services GmbH",
    "12937": "Dun and Bradstreet European Head Quarters",
    "12938": "YARCSTI Autonomous System",
    "12939": "HANSE- Hanse Holding AB",
    "12940": "SBS-3 Sim Net Telekomunikasyon Sanayi ve Ticaret Limited Sirketi",
    "12941": "INTERSAAR- intersaar GmbH",
    "12942": "NRB- Network Research Belgium",
    "12943": "EXTRA-M- Extra M Media CJSC",
    "12944": "Big Hit Ltd.",
    "12945": "GAMEPOINT Gamepoint autonomous system",
    "12946": "TELECABLE Telecable de Asturias,SA",
    "12947": "SERVER- Server Ltd.",
    "12951": "TECHSNABEXPORT OJSC Techsnabexport",
    "12952": "IGE Autonomous System",
    "12953": "REUTERS- REUTERS",
    "12954": "SIA SIA S.p.A.",
    "12955": "HALOINT HALO Interactive SRL, Romania",
    "12956": "TELEFONICA Telefonica Backbone Autonomous System",
    "12958": "MCC OJSC \"Moscow Cellular Communications\",",
    "12959": "NETLUX- Teleradiocompany Nadezhda Ltd",
    "12961": "IE-VNET- Internet Telecom SRL",
    "12962": "FIBANK First Investment Bank AD",
    "12963": "VOLZ Scientific -Industrial Firm \"Volz\" Ltd",
    "12964": "DBMG-DE Dr. Buelow & Masiak GmbH",
    "12965": "SEBBANKA  \"SEB banka\"",
    "12966": "Polskie Linie Lotnicze LOT sp. z o.o",
    "12967": "ATT_SOLUTIONS_UK AT&T Solutions UK",
    "12968": "CDP Netia SA",
    "12969": "VODAFONE_ICELAND Fjarskipti ehf",
    "12970": "TENARIA Retena and Reterioja",
    "12971": "BIOS-AT BIOS Internet Handels- und Dienstleistungs GesmbH",
    "12974": "ISGS-N3 Intesa Sanpaolo Group Services S.c.p.A.",
    "12975": "PALTEL- PALTEL Autonomous System",
    "12976": "SVYAZVSD LLC Svyaz VSD",
    "12978": "DOGAN-ONLINE DOGAN TV DIGITAL PLATFORM ISLETMECILIGI A.S.",
    "12979": "TSINET Transinfoset Autonomous System",
    "12980": "AT&T Global Network Services Nederland B.V.",
    "12982": "BULINFO-12982 Bulinfo Ltd.",
    "12985": "TVKWSM- Wielunska Spoldzielnia Mieszkaniowa w Wieluniu",
    "12986": "UKRSPETSCOM Ukrspetskom LLC.",
    "12988": "N-PHOENIX #-PHOENIX CONVERTED TO N-PHOENIX FOR RPSL COMPLIANCE The Phoenix Insurance Company Ltd",
    "12989": "HWNG Eweka Internet Services B.V.",
    "12990": "ONET-PL-1 Grupa Onet.pl S.A.",
    "12991": "LAND-OOE Amt der OOe. Landesregierung",
    "12992": "PROSZYNSKI_MEDIA_ Proszynski Media sp. z o.o.",
    "12993": "DEAC- SIA Digitalas Ekonomikas Attistibas Centrs",
    "12994": "Active 24",
    "12995": "12995 NOMINALIA Autonomous System",
    "12996": "DOMENESHOP Domeneshop",
    "12997": "KTNET OJSC Kyrgyztelecom",
    "12998": "BGNET- BGNet LTD",
    "12999": "FESU_ State Educational institution for High professional education 'Far Eastern State University'",
    "13000": "LEON- Leon sp. z o.o.",
    "13001": "SYSTEMA- Systema Network SARL",
    "13002": "LINKEY- Linkey Ltd",
    "13003": "WEBMATIC Webmatic Kommunikations GmbH",
    "13004": "SOX Serbian Open Exchange",
    "13005": "C2INTERNET C2 Internet Ltd",
    "13007": "Partner Reinsurance Company Ltd.",
    "13008": "BETANDWIN- bWin Interactive Entertainment AG",
    "13009": "INTECHNOLOGY InTechnology Plc",
    "13010": "MTS MTS Internet GmbH",
    "13011": "RA-MONITORUL-OFICIAL- RA MONITORUL OFICIAL",
    "13012": "GENI- Genias Internet",
    "13013": "Hewlett Packard Europe S.A.S",
    "13014": "Hewlett Packard Europe S.A.S.",
    "13015": "Computer Associates",
    "13016": "TELELINE-NET Teleline Ltd.",
    "13017": "CABLE-AND-WIRELESS Cable & Wireless UK P.U.C.",
    "13018": "Banca Monte Dei Paschi Di Siena S.P.A.",
    "13019": "RR-BRETAGNE Autonomous System",
    "13020": "CCCV- Chaos Computer Club Event Network provided by Chaos Computer Club Veranstaltungs GmbH",
    "13021": "AREXIM- Arexim S.A.",
    "13022": "Streams Telecommunicationsservices GmbH",
    "13023": "WEBBER Weber Ltd",
    "13025": "EDO-NETSOURCE- Netsource",
    "13026": "K-WLAN- Manuel Kahr",
    "13027": "UKRINFORM Ukrainian National News Agency (UKRINFORM)",
    "13028": "TUVAKA",
    "13029": "GCSI-CHUVHII- Goscomsvyazinform Chuvashii",
    "13030": "INIT7 Init Seven AG",
    "13031": "N-ARAGO arago Institut fuer komplexes Datenmanagement AG",
    "13032": "13032 Kyiv National Taras Shevchenko University",
    "13033": "FRANCOUDI Francoudi & Stephanou Ltd",
    "13034": "-PAGESJAUNES PAGESJAUNES SA",
    "13035": "IPTELECOM IPTelecom Network",
    "13036": "TMOBILE-CZ T-Mobile Czech Republic a.s.",
    "13037": "ZEN- Zen Internet Ltd",
    "13038": "HELEX-RP HELLENIC EXCHANGES S.A. HOLDING, CLEARING, SETTLEMENT & REGISTRATION",
    "13039": "GLOBAL-VILLAGE Global Village GmbH",
    "13040": "N-FIZ #-FIZ CONVERTED TO N-FIZ FOR RPSL COMPLIANCE Fachinformationszentrum Karlsruhe, Gesellschaft fuer wissenschaftlich-technische Information mbH",
    "13041": "CESCA-AC CESCA - Anella Cientifica RREN Autonomous System",
    "13042": "N-OENB-AT Oesterreichische Nationalbank",
    "13043": "Bayer AG, Leverkusen",
    "13044": "for Fortuneo",
    "13045": "HTP- htp GmbH",
    "13046": "N-ISKON ISKON INTERNET d.d. za informatiku i telekomunikacije",
    "13048": "WPR- WORLD PHONE ROMANIA SRL",
    "13049": "FRONTIER Frontier Software SARL",
    "13051": "Libro Online Autonomous System",
    "13052": "DATAGUARD DataGuard",
    "13053": "SOFTTRONIK Corporate net for Soft-Tronik, Inc.",
    "13054": "FREINET FreiNet GmbH",
    "13055": "CSVLG- JSC \"Comstar-Regions\"",
    "13056": "RT-TMB- OJSC Rostelecom",
    "13057": "A.P. Moller - Maersk A/S",
    "13058": "INTERDOTNET-DE- Inter.Net Germany GmbH Headquarter Berlin",
    "13059": "EXTREME-SOLUTIONS Extreme Solutions SRL",
    "13060": "N-BICNET Basic Net SpA",
    "13062": "LANCK- OJSC \"Mobile TeleSystems\"",
    "13063": "SKF Sverige AB",
    "13064": "CNET CNet Fugger Computertechnik GesmbH",
    "13065": "ZIELMAN-COM- Uniwersytet Zielonogorski",
    "13066": "RETECAL RETECAL SOCIEDAD OPERADORA DE TELECOMUNICACIONES",
    "13067": "CHS- CHS Comunicatii SRL",
    "13068": "Wiener Borse AG",
    "13069": "DATAGUARD DataGuard",
    "13070": "LVSILALE- SIA Electronic Solutions",
    "13073": "IFAT- IFAT - Media Information Center LTD",
    "13074": "TELETEL- Teletel Communication Channels Ltd",
    "13075": "MEGALABS- CJSC Megalabs",
    "13076": "Virgin Media Limited",
    "13077": "NCFU North Caucasian Federal University",
    "13078": "CTINET- CTINET Autonomous System",
    "13079": "ZONDH  for RU-ZNETWORK",
    "13082": "2DAY Telecom LLP",
    "13083": "Vodafone Group Services GmbH",
    "13084": "for Netscape online portal network",
    "13085": "CARPATICA- Banca Comerciala Carpatica SA",
    "13086": "PIK-NET- PiK-Net Autonomous System",
    "13087": "Canad Systems Pitesti",
    "13088": "-ADTS-BE SOCIATED DEXIA TECHNOLOGY SERVICES, S.A.",
    "13089": "13089 UniCredit Business Integrated Solutions S.C.p.A.",
    "13090": "SHE-NET SHE Informationstechnologie AG",
    "13091": "PTT-SRBIJA-NET PTTSRBIJANET",
    "13092": "UB- Akademska mreza Republike Srbije - AMRES",
    "13093": "IBO- Haaretz Daily Newspaper Ltd.",
    "13094": "SFO-IX- Milekom LTD",
    "13095": "CTK-NET- OJSC \"Vimpelcom\"",
    "13096": "Euronet Systems AB",
    "13097": "N-TELEMAR Telemar SPA",
    "13098": "INTESATRADE IntesaTrade SIM S.p.A.",
    "13099": "AET- AzEuroTel J.V.",
    "13100": "TELECITYGROUP INTERNATIONAL LIMITED",
    "13101": "TNG- ennit server GmbH",
    "13102": "Istanbul Bilgi Universitesi",
    "13103": "VALOR- LLC \"TC Valor\"",
    "13104": "SE-VENTELO NUACCES",
    "13105": "LUKOIL-INFORM- LUKOIL Technology Services GmbH",
    "13106": "DONAPEX- Don Apex, Ltd.",
    "13107": "ICM PIK Ltd",
    "13108": "TBSH-V6TEST The Bunker Secure Hosting Ltd",
    "13109": "IPRIMUS European Transit",
    "13110": "INEA- INEA S.A.",
    "13111": "GETRONICS-NL KPN Corporate Market B.V.",
    "13113": "ISILINE- ISI LINE S.r.l.",
    "13114": "Nationwide Building Society",
    "13115": "HOME-OF-THE-BRAVE Home of the Brave Internet Technology Based Solutions GmbH",
    "13116": "TELE2RU Tele2 Sverige AB",
    "13117": "Witchity UK N",
    "13118": "N-YARTELECOM OJSC Rostelecom",
    "13119": "ACI-COM- Zachodniopomorski Uniwersytet Technologiczny w Szczecinie",
    "13120": "BEC Bankernes EDB Central",
    "13121": "NAVIGATOR Navigator Online TOV",
    "13122": "MANX- MANX-TELECOM Autonomous System",
    "13124": "IBGC Blizoo Media and Broadband EAD",
    "13125": "PCE-NET PCE-NET GmbH",
    "13126": "SMS-UK-NET Globecomm Europe B.V.",
    "13127": "VERSATEL Tele 2 Nederland B.V.",
    "13128": "LIT-BERLIN- IT-Dienstleistungszentrum Berlin",
    "13129": "GAT- C.C.D. Cogent Communications Deutschland GmbH",
    "13130": "AUTOSTADT Autostadt GmbH",
    "13132": "CYBERWAYS- cyberways Informationsdienste GmbH",
    "13134": "Instituto de Informatica, IP - Ministerio da Solidariedade e Seguranca Social",
    "13135": "CREW- Wieske's Crew GmbH",
    "13136": "INTERSTROOM- Interstroom Informatietechnologie B.V.",
    "13137": "AGENCIA EFE SA",
    "13138": "TEBBANKA Turk Ekonomi Bankasi Anonim Sirketi",
    "13139": "SPEEDNIC- SPEEDNIC S.R.L.",
    "13140": "WEBM- Webmad GmbH",
    "13141": "IVP",
    "13143": "ARAGON DE CABLE",
    "13144": "VODAFONE-UK- Vodafone UK Limited",
    "13145": "N-BPB #-BPB CONVERTED TO N-BPB FOR RPSL COMPLIANCE UBI SISTEMI E SERVIZI S.c.p.A.",
    "13146": "IX Net UK Ltd",
    "13147": "NETINFO NET INFO.BG JSCo.",
    "13148": "POET POET Service GmbH",
    "13150": "MaroNET SRL",
    "13153": "SINGULARLOGIC_INTEGRATOR SINGULARLOGIC INTEGRATOR SA",
    "13154": "RZZRECHENZENTRUM- RZZ Rechenzentrum AG",
    "13155": "SIBRON- Closed Joint Stock Company COMSTAR-Regiony",
    "13156": "13156 Cabovisao,SA",
    "13157": "GOP- GOP Solutions GmbH",
    "13158": "EDAY- Eday Milan - Italy",
    "13159": "-WINTERTHUR WINTERTHUR Spain Autonomous System",
    "13160": "EMMELIBRI- EMMELIBRI S.R.L.",
    "13161": "TECHNOCOM Technokom Ltd.",
    "13164": "BTGeoverse.com",
    "13165": "SIBINTEK- Siberian Internet Company",
    "13167": "MERCK-KGAA Merck KGaA",
    "13168": "SANOSTRA- Banco Mare Nostrum SA",
    "13169": "ABN AMRO Bank N.V.",
    "13170": "KPO- Kaisanet Oy",
    "13171": "BSU Belarusian State University",
    "13172": "NEK Natsionalna Elektricheska Kompania EAD",
    "13173": "FORESHORE- Foreshore Limited",
    "13174": "MTSNET MTS OJSC",
    "13175": "Multitel S.p.A.",
    "13176": "Enter Print Autonomous System",
    "13177": "TISCALISE Tiscali Sweden Autonomous System",
    "13178": "DIGCOMM Digital communications, LTD",
    "13179": "TPG The Polished Group SA",
    "13180": "CEDACRINORD- CEDACRI S.P.A.",
    "13181": "ISPE Institutul de Studii si Proiectari Energetice SA",
    "13182": "N-ADHOC-NETWORK Made Network Srl",
    "13183": "ISGS- Intesa Sanpaolo Group Services S.c.p.A.",
    "13184": "HANSENET Telefonica Germany GmbH & Co.OHG",
    "13185": "State Educational Institution of Higher Professional Education Orel State Technical University",
    "13186": "BTIGS-BCN-NET BT IGS Autonomous System",
    "13187": "RHEIN-CHEMIE- Rhein Chemie Rheinau GmbH",
    "13188": "BANKINFORM- TOV \"Bank-Inform\"",
    "13189": "LIDERO Liden Data Internetwork AB",
    "13191": "NETAXIS netAxis Autonomous System",
    "13192": "Orta Electronics",
    "13193": "N-NERIM Nerim S",
    "13194": "BITE UAB \"Bite Lietuva\"",
    "13195": "INECO Ingenieria y Economia del Transporte S.A.",
    "13197": "PHIAG Pelikan Hardcopy International AG",
    "13199": "Sincretech Autonomous System",
    "13200": "BANCOBPI Banco BPI SA",
    "13201": "COMHOUSE- ComHouse Autonomous System",
    "13202": "SUMY-NET PP \"POLISAN\"",
    "13204": "SOFTNET SoftNet Services SRL",
    "13205": "British Telecommunications PLC",
    "13206": "REPSOL-YPF",
    "13207": "DMS-UK-N Caprock UK Limited",
    "13208": "NEWTELSOLUTIONS- Newtel Ltd",
    "13209": "ATOM-HOSTING Atom Hosting SRL",
    "13210": "E ACADEMIA DE STUDII ECONOMICE",
    "13212": "VENTELO-COMNET-N Broadnet",
    "13213": "UK2NET- UK2 - Ltd",
    "13214": "DCP- Hans Fredrik Lennart Neij",
    "13215": "CPLUS1- CJSC TK Convey Plus",
    "13216": "ITEX- Itex Guernsey Ltd",
    "13217": "Nevada, Northern Ireland.",
    "13218": "SHAREDKNOWLEDGE- Innovise Solutions Limited",
    "13219": "PANALPINA-IA- Panalpina Welttransport (Holding) AG",
    "13220": "RMR Design Associates Ltd",
    "13222": "ALO ALO COMUNICACIONES S.A.",
    "13223": "COUNCIL-OF-EUROPE- CONSEIL DE L EUROPE",
    "13224": "NAIROBINET",
    "13225": "OOO Renaissance Capital Financial Consultant",
    "13226": "CYBERNET CYBERNET SA",
    "13227": "KRAFT-S Kraft-S JSC autonomous system",
    "13230": "NCPORT Newcom Port Ltd",
    "13231": "BAHARAN Baharan PLC",
    "13232": "WESTLB Portigon AG",
    "13233": "TORR- 21TORR GmbH",
    "13234": "CTITELE- CTI-Telecom Autonomous System",
    "13235": "Axia Netmedia Corporation",
    "13236": "DATACOM-BG- DATACOM LTD",
    "13237": "LAMBDANET- euNetworks Managed Services GmbH",
    "13238": "YANDEX Yandex LLC",
    "13239": "OTHER Gazi University",
    "13240": "for TRENDLINE INFORMATION & COMMUNICATION SERVICES LTD.",
    "13242": "Firat University As Number",
    "13243": "13243 EVRY",
    "13244": "RIETUMU- Rietumu Banka",
    "13245": "SDU As Number",
    "13246": "INETWIRE- InterNetWire Communications GmbH",
    "13247": "ERDENREICH Erdenreich Datentechnik",
    "13249": "ITS-UA IT Systems LLC",
    "13250": "BACKBONE-CH Backbone Solutions AG",
    "13251": "ITNS It-NetService GmbH",
    "13252": "SWEETNET- Freenet Ltd.",
    "13253": "ISGS-N4 Intesa Sanpaolo Group Services S.c.p.A.",
    "13254": "MONDADORI- ARNOLDO MONDADORI EDITORE SPA",
    "13256": "JWT-UK J Walter Thompson, 1 Knightsbridge Green, London UK",
    "13257": "POLARCOM- JSC Polarcom",
    "13258": "Centrica Plc",
    "13259": "DELTA-TELESYSTEMS- Delta Telesystems Ltd.",
    "13260": "Transas Softwehr Haus St.Petersburg Autonomous System",
    "13261": "C1-HOLDING-N C:1 Holding GmbH",
    "13263": "HAYATNET- HayatNet Bilgi ve Iletisim Hizmetleri A.S",
    "13264": "BarakNet",
    "13266": "POR-NET Havenbedrijf Rotterdam n.v.",
    "13267": "Zuercher Kantonalbank",
    "13268": "MULTICOM Multicom Ltd.",
    "13270": "VERSATEL-OST Versatel Deutschland GmbH",
    "13271": "IPRIMUS European Datacenters",
    "13272": "STARMAN Starman",
    "13273": "FRANCE-TEER Open Wide Outsourcing S",
    "13274": "BRE Bank SA",
    "13275": "INXS Cable & Wireless UK P.U.C.",
    "13276": "MAGENTA Nebula Internet international operations",
    "13277": "HP-MS HP-MS Autonomous System",
    "13278": "N-TEITR TEI(TUS MOTOR SANAYI A.S.)",
    "13279": "Omela Ltd.",
    "13280": "O2 Ireland",
    "13281": "HOTELMNGM- TOV Hotel Management",
    "13282": "Finanz Informatik GmbH & Co. KG",
    "13283": "BJB1- Bank Julius Baer & Co. AG",
    "13284": "BRT- Brain Technology S.p.A.",
    "13285": "OPALTELECOM- TalkTalk Communications Limited",
    "13287": "NIXVAL NIXVAL Data Center",
    "13289": "IWELT iWelt AG - Internet Dienste",
    "13292": "BK-DAT Electronics e.U.",
    "13293": "PIONIER--COM PIONIER",
    "13294": "INTERSTRADA INTERSTRADA Autonomous System",
    "13296": "INNOR- Innovative Solutions Ltd",
    "13298": "SOS-KINDERDORF- SOS-Kinderdorf International",
    "13301": "UNITEDCOLO- UNITED COLO GmbH",
    "13302": "N-LINKEY ITSP Linkey Autonomous System",
    "13303": "UNNI- University of Nis",
    "13304": "SURGUTTEL- Net By Net Holding LLC",
    "13305": "TELIT-PITER- MTS OJSC",
    "13306": "UNICS- UNICS Ltd.",
    "13307": "SKIF- SKIF ISP Ltd",
    "13308": "CHORUS- Peter Olsson",
    "13309": "UNUA S.C. 1A S.C.S.",
    "13310": "UKRINTERNET- Ukr-Inter.net Ltd",
    "13312": "ARCORPORATE- - AutoReturn",
    "13313": "BARNES-AND-NOBLE - Barnes & Noble Inc.",
    "13314": "TEMA- - Toyota Motor Engineering and Manufacturing North America, Inc.",
    "13315": "HBSNET - Harvard Business School",
    "13316": "SES Sistemas Electr\u00f3nicos S.A.",
    "13318": "JUJUYTEL",
    "13319": "S-I-S - Storm Internet Services",
    "13321": "BROADWAY-BANDWIDTH2 - Technet International",
    "13322": "FMR-3 - Fidelity Investments",
    "13323": "FMR-2 - Fidelity Investments",
    "13324": "EPC-INC - Executive Personal Computers Inc.",
    "13325": "STOMI - State of Michigan, DMB-CNOC",
    "13326": "TUFTS-UNIVERSITY - Tufts University",
    "13327": "EKU - Eastern Kentucky University",
    "13328": "THE-GAP-INC - Gap, Inc. Direct",
    "13329": "KFN-001 - Kansas Fiber Network, LLC",
    "13330": "TECHNOLOGY-CENTER---SNA - First American Real Estate Solutions",
    "13331": "METAPEER-INC - MetaPeer",
    "13332": "SVWH - Silicon Valley Web Hosting, Inc.",
    "13333": "CCI-PA--1 - Consolidated Communications, Inc.",
    "13334": "MSG-N - Marketing Systems Group",
    "13335": "CLOUDFLARENET - CloudFlare, Inc.",
    "13336": "N-WR-COM - Westar Energy, Inc.",
    "13337": "WI-INET - Wisconsin Internet, Inc.",
    "13338": "HAYGROUP-N - HAY GROUP INC",
    "13340": "RIML-CORP--3 - Research In Motion Limited",
    "13341": "TRANQUILITY - Tranquility Internet Services Inc.",
    "13342": "TRENTON-TV-CABLE-COMPANY - Trenton TV Cable Company",
    "13343": "SCRR-13343 - Time Warner Cable Internet LLC",
    "13344": "NETEX-INC - NetEx Inc.",
    "13345": "ROCKYNET-COM - Rockynet.com, Inc",
    "13346": "CENTURION-MEDICAL-PRODUCTS - Centurion Medical Products Corporation",
    "13348": "CIGNA-2 - CIGNA",
    "13349": "TCU-NET - TEACHERS CREDIT UNION",
    "13350": "WEB-SERVICES-GROUP - WEB SERVICES GROUP",
    "13351": "B-U-C - Barbourville Utility Commission",
    "13352": "MTC-N - Mark G. Thomas Consulting",
    "13353": "Telmex do Brasil Ltda.",
    "13354": "N-EBLGLOBAL - EBL Global Networks, Inc.",
    "13355": "IRDETO-USA - Irdeto USA, Inc.",
    "13356": "ARROW-CAPITAL-MANAGEMENT-LLC - Arrow Capital Management LLC",
    "13357": "Irati Telecomunica\u00e7\u00f5es Ltda.",
    "13358": "DRAZOR - DIGITAL RAZOR, INC",
    "13359": "NTG - North Texas GigaPOP",
    "13360": "TRITONDIGITAL - Triton Digital",
    "13361": "ACPG - American Computer Group, Inc.",
    "13362": "PCWORLD - PCWorld.com",
    "13363": "LANDMARK-SYSTEMS-CORP - ALLEN SYSTEMS GROUP, Inc.",
    "13364": "JIVE-HOSTING - Jive Software Inc.",
    "13365": "BOSTON - THL Credit Advisors, LLC",
    "13366": "CHGNET - Calfee, Halter & Griswold, LLP",
    "13367": "COMCT-13367 - Comcast Cable Communications Holdings, Inc",
    "13368": "JCP - James Cable, LLC",
    "13369": "EFAX- - IGC, Inc.",
    "13370": "LOCALTEL - LocalTel Communications",
    "13371": "DUKE-INTERCHANGE - Duke University",
    "13372": "FEDERATEDINV - Federated Investors",
    "13373": "MEDCO - Medco Health Solutions, Inc",
    "13374": "DYC-DYU - D'Youville College",
    "13375": "PAYLESS-N - Payless ShoeSource",
    "13376": "MERRILL-CORPORATION - Merrill Communications LLC",
    "13377": "DCWISP-N-1 - DC WIRELESS ISP INC",
    "13378": "BIB-INET - BACKGROUND INVESTIGATION BUREAU INC",
    "13379": "BVIG-ORLANDO-FACILITY - Buena Vista Internet Group",
    "13380": "N-CUST - Zix Corporation",
    "13381": "CMET SACI",
    "13383": "ESPH-CORP - Environmental Systems Products Holdings, Inc.",
    "13384": "SECURENET- - SecureNet LLC",
    "13385": "COMCT-TELECOMM - Comcast Telecommunications, Inc.",
    "13386": "SKYRIVER - Skyriver Communications, Inc.",
    "13387": "MEDIAGENERAL - Media General, Inc.",
    "13388": "EGYPTIAN-TELEPHONE - Egyptian Telephone",
    "13389": "AZUKI - AZUKI, LLC",
    "13390": "GENIUS-NETWORK - Genius.com,Inc",
    "13391": "UNOS - United Network for Organ Sharing",
    "13392": "R18ESC - Region 18 Education Service Center",
    "13393": "KCSCOUT - KC Scout - Kansas City ITS Deployment",
    "13394": "LEHIGH-G-CORPORATION - Lehigh Gas Corporation",
    "13395": "SMARTCITY-RSCC - Smart City Networks, L.P.",
    "13396": "LBWL-N - LANSING BOARD OF WATER AND LIGHT",
    "13397": "ITLNET - ITLNet",
    "13398": "K12LINK - WHRO",
    "13399": "MICROSOFT-CORP-MSN--2 - Microsoft Corporation",
    "13400": "CHERNOFFDIAMOND - Chernoff Diamond and Company",
    "13401": "STARWOOD-HOTELS - Starwood Hotels and Resorts",
    "13403": "ALAWEB-INTERNET - ALAWEB Internet Services",
    "13404": "LANETCA-N - Lanetca Technology, Inc",
    "13406": "MCCFL - State College of Florida, Manatee-Sarasota",
    "13407": "ONECOM-CTC - One Communications Corporation",
    "13408": "WPTI-TELECOM - WPTI TELECOM LLC",
    "13409": "PDX - PORTLAND INTERNETWORKS",
    "13410": "MSTRARIN-1 - Microstrategy, Inc.",
    "13411": "KJ1 - K AND J HOLDINGS LLC",
    "13412": "VULCAN-NORTHWEST - Vulcan Northwest, Inc.",
    "13413": "FBW54935 - FastBytes Wireless, Inc.",
    "13414": "TWITTER-NETWORK - Twitter Inc.",
    "13415": "FIRSTDIGITAL - FirstDigital Communications, LLC",
    "13416": "R-GREENBERG-SOC - R/Greenberg Associates",
    "13417": "PUBLISHERS-PRINTING-COMPANY - Publishers Printing Company LLC",
    "13418": "COBIZINC - CoBiz",
    "13419": "HARDCTLE-B2B - Hardcastle Trading USA, LLC",
    "13420": "SBCIS-LUBKTX - AT&T Internet Services",
    "13421": "SBCIS-ABLNTX - AT&T Internet Services",
    "13422": "SBCIS-BUMTTX - AT&T Internet Services",
    "13423": "GALVESTONISD - GALVESTON ISD",
    "13424": "Intercity",
    "13425": "JUNO-DC-1 - Juno Online Services, Inc.",
    "13426": "JUNO-DC-2 - Juno Online Services, Inc.",
    "13427": "SOFTCOM-INTERNET-COMMUNICATIONS - Softcom Internet Communications, Inc.",
    "13428": "CSI-INTERNET-ACCESS - CompuTech Systems, Inc.",
    "13429": "MUSC - Medical University of South Carolina",
    "13431": "MILLENNIUM- - Millennium Partners, L.P.",
    "13432": "N-CXA-LV-13432-CBS - Cox Communications Inc.",
    "13433": "COXNET - Cox Enterprises Inc",
    "13434": "CORVELCORP - CORVEL CORPORATION",
    "13435": "NOBLE-USXLX - NOBLE AMERIC CORP.",
    "13436": "NECESSARYRESOURCES - Necessary Resources LLC",
    "13437": "BRAVE - Brave New Telemedia",
    "13438": "VIVIO-TECHNOLOGIES - Vivio Technologies",
    "13439": "SMOOTHFUSION-LUBBOCK - Smooth Fusion, Inc.",
    "13440": "Alestra, S. de R.L. de C.V.",
    "13441": "SCOTIABANK - Bank of Nova Scotia",
    "13442": "CXLINE - CrosSystem Company",
    "13444": "ATTAIN-DIRECT - All-Tech Investments Group, Inc",
    "13445": "13445 - Webex Communications, Inc.",
    "13446": "-NETZERO - Netzero,INC.",
    "13447": "VIP-01-CHI-01 - VIP Tour Company, Inc.",
    "13448": "WEBSENSE Websense, Inc.",
    "13449": "TALXCO - Talx Corporation",
    "13450": "TIS-DC1 - Touchnet Information Systems",
    "13451": "SMW- - Saddle Mountain Wireless Inc.",
    "13452": "GUGGE-ILDC - Guggenheim Services LLC",
    "13453": "VECLIPSE - Speakerbus Incorporated",
    "13454": "PA-TURNPIKE - PENNSYLVANIA TURNPIKE COMMISSION",
    "13455": "GROUP1 - Reach Marketing LLC",
    "13456": "SPOWA-N - City of Spokane",
    "13457": "13457-WOLVERINE-POWER-SUPPLY - Wolverine Power Supply",
    "13458": "DAVIDSON-KEMPNER David Kempner European Partners LLP",
    "13459": "PHOENIX CONDOR SOLUTION SERVICE INFORMATICA LTDA",
    "13460": "EARTHCAM - EarthCam, Inc.",
    "13461": "THEOCC - The Options Clearing Corporation",
    "13462": "IEEE - Institute of Electrical and Electronics Engineers",
    "13463": "CHE - JPMorgan Chase & Co.",
    "13464": "CPLP-N - Centerbridge Partners, L.P.",
    "13465": "IMAG-BOS01 - Imaginatik PLC",
    "13466": "MUZAK- - Muzak, LLC",
    "13467": "STRATA-CAP-BGP - STRATA CAPITAL MANAGEMENT LP",
    "13468": "KOS-1193 - Kingston Online Services",
    "13469": "FIRAXIS - 2K GAMES, Inc.",
    "13470": "NAVAJOCOUNTYAZ - NAVAJO COUNTY - MIS",
    "13471": "PFSWEB - PFSweb, INC.",
    "13472": "N-ALNYLAM - Alnylam Pharmaceuticals, Inc.",
    "13473": "INTOP-NET - INTOP, Inc.",
    "13474": "Banco de Galicia y Buenos Aires",
    "13475": "WFCU-WW-N - Western Federal Credit Union",
    "13476": "MONTANA-STATE-UNIV - Montana State University - Billings",
    "13477": "13477 - MOJOHOST",
    "13478": "TESSAPORT- - Tessaport Inc.",
    "13479": "WALKER- - Walker Art Center",
    "13480": "OGOPS - Ongoing Operations, LLC",
    "13481": "GPC-AG - Global Bank Of Commerce Limited.",
    "13482": "ZWEIG-DIMENNA - Zweig-DiMenna Associates, LLC.",
    "13483": "INFOR-13483 - INFOR GLOBAL SOLUTIONS (MICHIGAN), INC.",
    "13484": "MUM-2007 - Maharishi University of Management",
    "13485": "GCU - Grand Canyon University",
    "13486": "PIMCL-N - Praesidium Investment Management Company, LLC",
    "13487": "MAILMESSENGER-LA - Mailmessenger Networks, Inc.",
    "13488": "CBWU-13488 - Continental Broadband Florida, Inc DBA WebUnited",
    "13489": "EPM Telecomunicaciones S.A. E.S.P.",
    "13490": "BUCKEYECABLEVISION - Buckeye Cablevision, Inc.",
    "13491": "FSBA - Florida State Board of Administration",
    "13492": "AHNCOLO - American Health Network",
    "13493": "N-CXA-RI-13493-CBS - Cox Communications Inc.",
    "13494": "MORNINGSTAR-COM - Morningstar, Inc.",
    "13495": "NTT DO BRIL TELECOMUNICACOES LTDA.",
    "13496": "BELCAN - Belcan Corporation",
    "13497": "AMBT- - American Broadband & Telecommunications Company",
    "13498": "TSYS - TSYS LOYALTY, INC.",
    "13499": "REVOLWIRELESS - Cleveland Unlimited, Inc",
    "13500": "ATLANCOMP - Integralis",
    "13501": "OARNET--2 - OARnet",
    "13502": "ING-AMERIC - ING NORTH AMERICA INSURANCE CORPORATION",
    "13504": "N-LANET-GP1 - St. Of LA./Office Of TelecommunicationsMngmt/LaNet",
    "13505": "SANDATA-INC - SANDATA Technologies Inc.",
    "13506": "US-DEPARTMENT-OF-THE-TREURY - US Department of the Treasury",
    "13507": "KMARTCORPORATION - Sears Holdings Corporation",
    "13508": "BAKER-BROTHERS - Baker Bros. Advisors, LLC",
    "13509": "XERIU- - Xerium Technologies, Inc.",
    "13510": "BAYSTATEHEALTH - Baystate Health, Inc.",
    "13511": "UNIVI-2-N - Univision Communications Inc.",
    "13512": "MONROETEL-NOC - Monroe Telephone Co.",
    "13513": "INET-SYSTEMS-ATL - iNET Systems Corp.",
    "13514": "ISP Canopus S.A.",
    "13515": "PBA - Palm Beach Atlantic University",
    "13516": "CTCA1336 - Cancer Treatment Centers of America, Inc.",
    "13517": "BAKER-MCKENZIE - Baker & McKenzie",
    "13518": "CDAC--1 - COMMUNICATIONS DESIGN ACQUISITION CORPORATION",
    "13520": "UEIC-BGP - Universal Electronics",
    "13521": "Infonet ISP, Bolivia SRL.",
    "13522": "PUC PR CAMPUS CURITIBA",
    "13523": "SGM-INSTRUST - Southern Group Management Company, LLC",
    "13524": "ARW-MEL - Arrow Electronics",
    "13525": "TCSN-NET - The Computer Shop Netlink",
    "13526": "NTR-METALS---DALL - NTR Metals",
    "13527": "99MAIN - 99MAIN NETWORK SERVICES",
    "13528": "IXPRES-US - Internet Express",
    "13529": "GOHOST-IPADMIN - NetStrategies",
    "13530": "DANA-CORPORATION - Dana Corporation",
    "13531": "EQUINIX-RS-VA - Equinix, Inc.",
    "13532": "NEED-TO-KNOW-NEWS - Need To Know News, LLC",
    "13533": "HJ-NET - HotJobs.com, Ltd.",
    "13534": "RALLS-TECH - Ralls Technologies, LLC",
    "13535": "NING - Ning, Inc.",
    "13536": "TVC-1 - Tech Valley Communications",
    "13537": "MEGACOLO - Mega Colocation, Inc.",
    "13538": "TELEHOUSE - TELEHOUSE International Corp. of America",
    "13539": "AP-BGP-60089 - AP Software Express, Inc.",
    "13541": "MENTORGRAPHICS - Mentor Graphics Corporation",
    "13542": "FISERV-COSTARICA - Fiserv, Inc.",
    "13544": "Resource Recovery",
    "13546": "INNOVATIVE-INTERFACES-INC - Innovative Interfaces, Inc.",
    "13547": "PORTER-HOSPITAL - Porter Hospital",
    "13548": "CHARLESTON- - College of Charleston",
    "13549": "MERCURY - Mercury Network Corporation",
    "13550": "CITYNET-AZ - CityNet Arizona LLC",
    "13551": "THE-GAP-INC - Gap, Inc. Direct",
    "13552": "CEGEPSAINTE-FOY - Cegep de Sainte-Foy",
    "13553": "CBSI-2 - CBS Interactive Inc.",
    "13554": "TPS-TX- - Tenaska Power Services, Co.",
    "13555": "EAGLE-NET-ALLIANCE - EAGLE-Net Alliance",
    "13556": "IVANET-MIAMI - IBIS INC.",
    "13557": "NETIN - NetIn.com, Inc. Dallas Texas US",
    "13558": "CMIC-HO - Church Mutual Insurance Company",
    "13559": "LOVULLON - LoVullo Associates, Inc.",
    "13560": "SCRR-13560 - Time Warner Cable Internet LLC",
    "13561": "LAFARGE-NA - Lafarge Canada Inc.",
    "13562": "GTENS - Verizon Data Services LLC",
    "13563": "VERMONTLAWSCHOOL - Vermont Law School Inc.",
    "13564": "COURT-SQUARE-GROUP - Court Square Group, Inc.",
    "13565": "ORVIS - THE ORVIS COMPANY, INC.",
    "13566": "SIEBERT - Muriel Siebert",
    "13567": "KMB1 - Kimberly-Clark Corporation",
    "13568": "MEDIAWIRE - Mediawire Communications",
    "13571": "VIDEOTRON-LTEE - Le Groupe Videotron Ltee",
    "13572": "LAHEYCLINIC - Lahey Clinic, Inc.",
    "13573": "MDU-ETHERNET-SOLUTIONS - MDU Ethernet Solutions",
    "13574": "ETKYNET - Gearheart Communications",
    "13575": "WISCONSINPUBLICPOWER - Wisconsin Public Power, Inc.",
    "13576": "SDNET - SOUTH DAKOTA NETWORK",
    "13577": "LIVEOPS-DALL-IDC - LIVEOPS, INC.",
    "13578": "MDSOCIATES-MAIN - MDAssociates, Inc.",
    "13579": "Fondo de Informacion y Documentacion para la Industria INFOTEC",
    "13580": "DEPLOYMENT - Deployment Inc.",
    "13581": "SOFTWAREHOUSE - SHI International Corp.",
    "13582": "LDSI - Logistics and Distribution Services Corp",
    "13583": "ACCESS-TECH - Access Technology, Inc.",
    "13584": "TIM NORDESTE SA",
    "13585": "Power VT S.A.",
    "13586": "GALCO- - Galco Industrial Electronics",
    "13587": "CITIDIRECT-GCS - CitiBank",
    "13588": "PAYCHEX - Paychex Incorporated",
    "13589": "PANAMSAT-1 - PanAmSat Corporation",
    "13590": "KPMG-CTEC - KPMG LLP",
    "13591": "Brasil Telecom Comunica\u00e7\u00e3o Multimidia",
    "13592": "N1 - Sidera Networks LLC",
    "13593": "MEDIA3 - Media 3 Technologies, LLC",
    "13594": "MTC - Microtek Corporation",
    "13595": "CLSIC-RESIDENCE-MANAGEMENT-LIMITED-PARTNERSHIP - Classic Residence Management Limited Partnership",
    "13596": "RYMAX-CORP - Rymax Corp",
    "13598": "DAIMLERTRUCKS-NA- - Daimler Trucks North America LLC",
    "13599": "EMR-ESI - Eisai Global Clinical Development",
    "13600": "CONVO - Convo",
    "13601": "N-INNERHOST - Peer 1 Dedicated Hosting",
    "13602": "CYBERZONE-INC - CYBERZONE, INC",
    "13603": "LL-ICN- - Western Iowa Tech Community College",
    "13604": "CITYDUNN - City of Dunnellon",
    "13605": "MEMA-CFMR - Maryland Emergency Management Agency",
    "13606": "CS-KERN - C S KERN INC",
    "13607": "INTUITIVE-ENG - Intuitive Surgical Operations, Inc.",
    "13608": "WOLFCREEKSD - Wolf Creek Public Schools",
    "13609": "ONECOM-C1 - One Communications Corporation",
    "13610": "PROVOCRAFT-NOVELTY - Provo Craft & Novelty, Inc.",
    "13611": "CDC - U.S. Center For Disease Control and Prevention",
    "13612": "SYSMEX - Sysmex",
    "13613": "TRANSPARENT - Transparent Technology",
    "13614": "ALLWEST - All West Communications, Inc.",
    "13615": "HVHS- - Heritage Valley Health System",
    "13616": "DXSTORM- - DXStorm Inc.",
    "13617": "FIT-USA - Freudenberg IT LP",
    "13618": "CARONET-N - Carolina Internet, Ltd.",
    "13619": "BELINE-NY - Thomson Reuters U.S. LLC",
    "13620": "EMBLEMHEALTH - EMBLEMHEALTH SERVICES COMPANY, LLC",
    "13621": "REINSURANCE - Reinsurance Group of America",
    "13622": "UREACH - UREACH TECHNOLOGIES, INC.",
    "13623": "ISTOCKPHOTO - ISTOCKPHOTO INC.",
    "13624": "SNC-SPARKS - Sierra Nevada Corporation",
    "13625": "REDWARNING - CALGAH Computer Systems and Management Ltd",
    "13626": "WALGREESN - Walgreens Co",
    "13627": "RAYS02 - RAYS",
    "13628": "ABSG - AMERISOURCEBERGEN",
    "13629": "REARDEN-COMMERCE - Rearden Commerce, Inc.",
    "13630": "CSXT--1 - CSX Technology",
    "13631": "CITADELGROUP- Citadelgroup",
    "13632": "VWRSP - VWR International, LLC",
    "13633": "OOCL-CHS - OOCL (USA), Inc.",
    "13634": "OOCL-CHI - OOCL (USA), Inc.",
    "13635": "FUSION-MEDIA - Fusion Media",
    "13636": "NEC-LABORATORIES-AMERICA-INC - NEC Laboratories America, Inc.",
    "13637": "NETSTAR - Net Star telecommunications Inc.",
    "13638": "METALINK - Metalink Technologies, Inc.",
    "13639": "ING-AMERIC-WHOLESALE - ING Financial Services, LLC",
    "13640": "ONECOM-CTC - One Communications Corporation",
    "13641": "PDMNET - PDM Net",
    "13642": "CITI-FFG - Citigroup",
    "13643": "Universidad Catolica Corporacion de TV.",
    "13644": "METROPCS-ODNET-PLANO - MetroPCS Wireless, Inc.",
    "13645": "BROADBANDONE - BroadbandONE, Inc.",
    "13646": "13646 UPC Business NL Autonomous System",
    "13647": "TRANQUIL-HOSTING - Tranquil Hosting, Inc.",
    "13648": "VIRGINIA-LOTTERY - Virginia State Lottery Department",
    "13649": "N-VINS - ViaWest",
    "13650": "CORN - City of Redding",
    "13651": "BUCKLANDBGP - BUCKLAND TELEPHONE COMPANY",
    "13652": "HORIZONBLUE - HORIZON BLUE CROSS BLUE SHIELD OF NJ",
    "13653": "CIGA - California Insurance Guarantee Association",
    "13654": "KC-WEB-LLC - KC Web, Inc.",
    "13656": "PROVENAHEALTH - Provena Health",
    "13657": "EGATE-NETWORKS E-Gate Networks",
    "13658": "POINTONE - PointOne",
    "13659": "INTERTECH - InterTECH Corp",
    "13660": "BCBSND- - Blue Cross Blue Shield of North Dakota",
    "13661": "VRIS--BLOCK - Verizon Online LLC",
    "13662": "VRIS--BLOCK - Verizon Online LLC",
    "13663": "VRIS--BLOCK - Verizon Online LLC",
    "13664": "VRIS--BLOCK - Verizon Online LLC",
    "13665": "VRIS--BLOCK - Verizon Online LLC",
    "13666": "VRIS--BLOCK - Verizon Online LLC",
    "13667": "VRIS--BLOCK - Verizon Online LLC",
    "13668": "VRIS--BLOCK - Verizon Online LLC",
    "13669": "VRIS--BLOCK - Verizon Online LLC",
    "13670": "VRIS--BLOCK - Verizon Online LLC",
    "13671": "VRIS--BLOCK - Verizon Online LLC",
    "13672": "FAIRPO-3 - FAIRPOINT COMMUNICATIONS, INC.",
    "13673": "FAIRPO-3 - FAIRPOINT COMMUNICATIONS, INC.",
    "13674": "FAIRPO-3 - FAIRPOINT COMMUNICATIONS, INC.",
    "13675": "FAIRPO-3 - FAIRPOINT COMMUNICATIONS, INC.",
    "13676": "ILAND- - Imagination, Inc.",
    "13677": "PGTTRUCKING - PGT Trucking, Inc.",
    "13678": "PAETEC - PaeTec Communications, Inc.",
    "13679": "Centros Culturales de Mexico, A.C.",
    "13680": "CITY-GUIDE-INTERNET - City-Guide Internet Services Inc.",
    "13681": "CCC-LLC - CONTEMPORARY CLOSET CLSICS LLC",
    "13682": "TELEFONICA MOVILES GUATEMALA S.A.",
    "13683": "AUTO-WARES-N - Auto-Wares Inc",
    "13684": "N-MEDTRONIC-1 - Medtronic, Incorporated",
    "13685": "NEWAYS - Neways Worldwide Inc.",
    "13686": "BARCLAYS-CENTER - AEG",
    "13687": "ALLIANCE-SHIPPERS-INC - Alliance Shippers Inc",
    "13688": "PSEG - Public Service Enterprise Group",
    "13689": "BLUELINX-CORP - BlueLinx Corporation",
    "13690": "AMR - American Medical Response, Inc.",
    "13691": "MCC-EDU - Metropolitan Community College",
    "13692": "DFN-N-1 - Douglas FastNet",
    "13693": "NTS-ONLINE - NTS Communications",
    "13694": "XECUNET - Xecunet, LLC.",
    "13695": "AEP - American Electirc Power Co.",
    "13697": "SHG- - Saber Healthcare Group LLC",
    "13698": "SHAWINDUSTRIES - Shaw Industries Group, Inc.",
    "13699": "SWFLAFC - SWF Associates in Podiatric Medicine & Surgery",
    "13700": "17N01 - Millard Refrigerated Services, Inc",
    "13701": "BENCHMARK-ELECTRONICS - Benchmark Electronics Inc.",
    "13702": "INGRAM-BOOK-GROUP - Ingram Book Group",
    "13703": "BROADRIVER-13703 - BroadRiver Communication Corp.",
    "13704": "CYBERVERSE2 - Cyberverse, Inc.",
    "13705": "IDIRECT-MTL - Internet Direct",
    "13706": "COMPLETEWEBNET - CompleteWeb.Net LLC",
    "13707": "IBGSAC-01 - Inertia Beverage Group Inc.",
    "13708": "DNIC--13708 - Navy Network Information Center (NNIC)",
    "13709": "CUMULUS-MEDIA-INC - Cumulus Media, Inc.",
    "13710": "SYSTEMS-METHODS - Systems & Methods, Inc.",
    "13711": "GEORGIA-PACIFIC - Georgia Pacific Corporation",
    "13712": "SMUMN - Saint Marys University of Minnesota",
    "13713": "ARCOT - Arcot Systems",
    "13714": "AFILI-SEA1-MON Afilias Canada, Corp.",
    "13715": "USL-N - Upsher-Smith Laboratories Inc.",
    "13716": "HEWITT-SOCIATES - Hewitt Associates LLC",
    "13717": "EBC-N - Eveready Battery Company",
    "13718": "SOLUSLP - SOLUS ALTERNATIVE SET MANAGEMENT LP",
    "13719": "AUSTIN - ShoreTel Inc.",
    "13720": "SONY-ONLINE Sony Online Entertainment LLC",
    "13721": "ADMISSION-CORPORATION - AdMission Corporation",
    "13722": "DEFAULTROUTE - Default Route, Inc.",
    "13724": "MFS-BOS-PHX - Massachusetts Financial Services",
    "13725": "LOGISTICARE - LogistiCare Solutions, LLC",
    "13726": "APS- - Atlanta Public Schools",
    "13727": "ND-CA-N - NEXT DIMENSION INC",
    "13728": "DPCOM-N05222010 - D&P Communications, Inc.",
    "13729": "FIDESSA-US - Fidessa Corporation",
    "13730": "VELOCITY- - Velocity Online, Inc.",
    "13731": "BCHARRIS - Harris Connect, LLC",
    "13732": "AXISPOINT-INC - Axispoint Inc",
    "13733": "CENTRE-FOR-ADDICTION-AND-MENTAL-HEALTH - Centre for Addiction and Mental Health",
    "13734": "BEESKY - Bee Sky Consulting Inc.",
    "13735": "CUTTERSOC - Cutter Associates, Inc.",
    "13736": "FACTUAL-DATA - Factual Data Corp",
    "13737": "COATS-N - Coats North America",
    "13738": "MRSTOCK-DOWNERS - Group One Trading LLC",
    "13740": "HYPERNET- - Hypernet Communications, Inc.",
    "13741": "AMTECH - Intermec Technologies, Amtech Systems Division",
    "13742": "CENCOM-NEBR - CENCOM INC",
    "13743": "REGULUS - Regulus Group",
    "13744": "THP-BGP - TYNDALE HOUSE PUBLISHERS",
    "13745": "VENTUSNETWORKS - Ventus Networks, LLC",
    "13746": "AITECH - AITech",
    "13747": "DMIC-N1 - DONEGAL MUTUAL INSURANCE",
    "13748": "RSDC-N1 - RSDC of Michigan, LLC",
    "13749": "N-THEPLANET-2 - ThePlanet.com Internet Services, Inc.",
    "13750": "TNSI- - Transaction Network Services, Inc.",
    "13751": "BRIDGEPOINT-EDUCATION - Bridgepoint Education, Inc.",
    "13752": "VICLINK - Valley Internet Company",
    "13753": "BHI-1 - BHI Advanced Internet Inc.",
    "13754": "TKFT - TkFast Inc",
    "13755": "SPJC - St. Petersburg Jr. College",
    "13756": "INFLOW-NET - Inflow Inc.",
    "13757": "BDS - Blue diamond solutions inc",
    "13759": "WILKES-MULTI-HOME1 - Wilkes University",
    "13760": "SOUTHERN-LIGHT - Southern Light, LLC",
    "13761": "BSI Informatica Ltda",
    "13762": "HUNTERDOUGL - Hunter Douglas",
    "13763": "POYHD - POY Holdings, Inc.",
    "13764": "UFC-BSNY-N - UFC AeroSpace Corporation",
    "13765": "NEDELCO - Nedelco Inc.",
    "13766": "BRADFORD-REGIONAL-MC - Bradford Regional Medical Center",
    "13767": "DBANK - DataBank Holdings, Ltd.",
    "13768": "PEER1 - Peer 1 Network (USA) Inc.",
    "13769": "TRUSTEDID - TrustedID, Inc.",
    "13771": "BOOMERANG - Boomerang.com,INC.",
    "13772": "THINKTECH-3 - ThinkTech, Inc",
    "13773": "TELNETCOMM - Telnet Communications",
    "13774": "Corpbanca",
    "13775": "MATHBOX - Mathbox Inc.",
    "13776": "QX-NET-N-1 - QX.Net",
    "13777": "ACDNET-N2 - ACD.net",
    "13778": "JOHNSON-AND-JOHNSON - Johnson & Johnson",
    "13779": "BISTECH - Basis Technology",
    "13780": "NFL-20- - THE NATIONAL FOOD LABORATORY",
    "13781": "ENERGYNET - Hopkinsville Electric System",
    "13782": "FAFCO - The First American Financial Corporation",
    "13783": "RADFORD-UNIV- - Radford University",
    "13784": "AFOTEC- - 754th Electronic Systems Group",
    "13785": "SMH - SHORE MEMORIAL HOSPITAL",
    "13786": "CODEANDTHEORY - Code & Theory, LLC.",
    "13787": "EMBARQ-JCTY - Embarq Corporation",
    "13788": "USCOURTS - US Courts",
    "13789": "INTERNAP-BLK3 - Internap Network Services Corporation",
    "13790": "INTERNAP-BLK3 - Internap Network Services Corporation",
    "13791": "INTERNAP-BLK3 - Internap Network Services Corporation",
    "13792": "INTERNAP-BLK3 - Internap Network Services Corporation",
    "13793": "T3VOICENET - T3 VoiceNet, LLC.",
    "13794": "QCS - Quality Computer Systems",
    "13795": "KCC- - Kurtzman Carson Consultants, LLC",
    "13796": "UCONN-ARIN - University of Connecticut",
    "13797": "IDG-19 - International Data Group, Inc.",
    "13798": "BRIGHT - Brightfinity, LLC",
    "13799": "3FORM-BGP - 3form Inc.",
    "13800": "AUTOEXPRESO-PR - Transcore Atlantic Inc.",
    "13801": "CONCORD-CARLISLE-MA - Concord-Carlisle Regional School District",
    "13802": "NRCN - North Rock Communications Ltd.",
    "13803": "E-SYNCNET - CRC Inc.",
    "13804": "MARKETDAY - Market Day Corporation",
    "13805": "WORLD-COMMUNICATIONS - World Communications",
    "13806": "NAME-13806 Aut-Num",
    "13807": "GREAT-PLAINS-COMMUNICATIONS - GREAT PLAINS COMMUNICATIONS INC",
    "13808": "-ATMDIRECT-13808 - Acculynk, Inc.",
    "13809": "UAMS-N - University of Arkansas for Medical Sciences",
    "13810": "AFILI-HKG1-MON Afilias Canada, Corp.",
    "13811": "MSLI - Microsoft Corporation",
    "13812": "1999FISHERSYS - FISHER SCIENTIFIC",
    "13813": "BROADSOFT-INC-NORTH-AMERICA - BroadSoft, Inc.",
    "13814": "CHICHESTER-CAPITAL-MANAGEMENT - Chichester Capital Management LP",
    "13815": "TAI-N - Chieftain Capital Management Inc.",
    "13816": "VIGTECH01 - Vigilant Technologies",
    "13817": "CCML-N - Cantillon Capital Management, LLC",
    "13818": "NGIC-N1 - Nebraska Global Investment Company LLC",
    "13819": "FWIN-NET - INDIGITAL TELECOM",
    "13820": "ERTR-N - ERTR LLC",
    "13821": "ACML - AllianceBernstein L.P.",
    "13822": "MILTON-ACADEMY - Milton Academy",
    "13823": "MESH-NET - Mesh.Net",
    "13824": "AZCI-NET - AZCI.net, LLC",
    "13825": "TROYCABLE-NET - Troy Cablevision, Inc.",
    "13826": "DATA-CENTERS-CANADA - DATA CENTERS CANADA INC.",
    "13827": "WPNI- - Washingtonpost.Newsweek Interactive Company, LLC",
    "13828": "I2K - Internet 2000, Inc.",
    "13829": "PIMACOUNTY - Pima County",
    "13830": "PROPERTYFIRST - propertyfirst.com",
    "13831": "OA-BLI-1 - Open Access Network Services LLC",
    "13832": "N-ATG-COM ART TECHNOLOGY GROUP",
    "13833": "N-NOS - Nos Communications",
    "13834": "AGLRSC - AGL Resources Inc.",
    "13835": "IMPSAT FIBER NETWORKS INC",
    "13836": "NDAQ-OMX-13836 - THE NDAQ OMX GROUP, INC.",
    "13839": "P1P3R - Piper Jaffray Companies",
    "13840": "SHERIDAN-HEALTHCORP - SHERIDAN HEALTHCORP, INC.",
    "13841": "IHSENERGY-DENVER - IHS Energy Group",
    "13842": "WINDSTREAM-COMMUNICATIONS - Windstream Communications Inc",
    "13843": "PHOENIX-AMERICAN - Phoenix American Inc.",
    "13845": "VINS- - ViaWest",
    "13846": "LAVALIFE - Lavalife Corp.",
    "13848": "13848 - Ariba Inc",
    "13849": "TEMCO-N - TEMCO SERVICE INDUSTRIES, INC.",
    "13850": "SPS-CORPORATE-NETWORK - Strategic Products and Services, Inc.",
    "13851": "SEVENL - SevenL Networks",
    "13852": "UTILICORP - Utilicorp United Inc.",
    "13853": "ECTISP- - ECTISP Ellis County Texas Internet Service Provider Inc.",
    "13854": "JSE",
    "13855": "CFU-NET - The Municipal Communications Utility of the City of Cedar Falls, Iowa",
    "13856": "INFINETWORX - Infinetworx Caribbean Inc",
    "13857": "ONLINEMAC - Online Northwest",
    "13858": "COLUMBIAGTRANS - NISOURCE INC",
    "13859": "CERNER - Cerner Corporation",
    "13860": "LFG - Lincoln Financial Group",
    "13861": "MARCHNETWORKS-SCOTTSDALE - March Networks Corporation",
    "13862": "ITMET - iTMethods Inc.",
    "13863": "ALVAKA - Alvaka Networks",
    "13864": "CS-DES-PATRIOTES - Commission scolaire des Patriotes",
    "13865": "DUCKBITES01 - Duck Bites",
    "13866": "CCOUNTRY - Computer Country",
    "13867": "CBSI-3 - CBS Interactive Inc.",
    "13868": "PEAK - Peak Internet, LLC",
    "13870": "AAML-N - Aureus Asset Management, LLC",
    "13871": "TELEBYTE-NW - Telebyte NW",
    "13872": "TAMARACK - Tamarack Computers Ltd.",
    "13873": "KAPLAN - Kaplan Educational Centers",
    "13874": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "13875": "ARIN-ADV-FREIGHT - AFN, LLC",
    "13876": "FIBER-64 - FiberLight, LLC",
    "13877": "WENDYS-DUBLIN - Wendy's International, Inc.",
    "13878": "UOL DIVEO S.A.",
    "13879": "SITA-EQUANT-MPLSNET Equant Inc.",
    "13880": "ACI- - american century investments",
    "13881": "CIIS - California Institute of Integral Studies",
    "13882": "HLIC - Hartford Life Insurance Company",
    "13883": "BB-FAX-SERVER - Contractors Register, Inc.",
    "13884": "N-THEPLANET - ThePlanet.com Internet Services, Inc.",
    "13885": "DUNDEE - Dundee Internet Services, Inc",
    "13886": "CLOUD-SOUTH - Cloud South",
    "13887": "RTG-N1 - RoomsToGo.com, Inc.",
    "13888": "BEARCREEK- - Bear Creek Operations Inc",
    "13889": "INTEX-SOLUTIONS - Intex Solutions, Inc.",
    "13890": "-INAPCDN-LAX - Internap Network Services Corporation",
    "13891": "21ST-CENTURY-ONCOLOGY-INC - 21ST CENTURY ONCOLOGY, INC.",
    "13892": "BIPERFORMANCE-N - BI",
    "13893": "EHI-NA--1 - Enterprise Holdings, Inc.",
    "13894": "SECUREWEBS - SECURE WEBS INC",
    "13895": "FIBERCONX- FiberConX Communications Ltd.",
    "13896": "THINKINGPHONES - Thinking Phone Networks, Inc.",
    "13897": "CDC1 - Internet Brands Inc.",
    "13898": "CMDINC01 - CollaborateMD, Inc.",
    "13899": "KRICKET - Kricket Internet Services LLC",
    "13900": "CBN - Christian Broadcasting Network, Inc.",
    "13901": "AFILI-MIA1-MON Afilias Canada, Corp.",
    "13902": "247REALMEDIA-NY - 24/7 Real Media, Inc.",
    "13903": "UNITEDLAYER-2 - Unitedlayer, Inc.",
    "13904": "COSLINK - Cherryland Services Inc",
    "13905": "TEMAJIQ-N-13905 - TietoEnator Majiq Inc.",
    "13906": "3N-GLOBAL - Everbridge, Inc",
    "13907": "NCR-CORPORATION NCR Corporation",
    "13908": "BLOOMBERG-700 - Bloomberg, LP",
    "13909": "TECHIEMEDIA - Techie Hosting, Inc.",
    "13910": "REGISTER - Register.com, Inc",
    "13911": "TERA-BYTE - Tera-byte Dot Com Inc.",
    "13912": "COMMTOUCH-INC - Commtouch Inc.",
    "13913": "AFFILIATED - Affiliated Central Inc.",
    "13914": "CAMARA DE DIRIGENTES LOJIST DE BELO HORIZONTE",
    "13915": "RIA- - Radiology Imaging Associates P.C.",
    "13916": "BLADE-LEX1 - BladeLogic, Inc.",
    "13917": "CORPWEST - Corporate West Computer Systems, Inc.",
    "13918": "CITYOFTUCSON - City of Tucson",
    "13919": "ALLDATA-NET01 - Alliance Data Systems, Inc.",
    "13920": "IMORTGAGE- - iMortgage.com, Inc.",
    "13921": "ANDREWS-INTERNATIONAL - Andrews International, Inc.",
    "13922": "BARLEY-SNYDER-LLC - Barley Snyder LLC",
    "13923": "SMCLOUD - IPCopper, Inc.",
    "13924": "AIS- - Allied Internet Services",
    "13925": "NAVIMEDIX-CARLSTADT - NaviMedix, Inc.",
    "13926": "RBLHST-NY - Reliablehosting.com",
    "13927": "KANOKLA-NETWORKS - KanOkla Communications, LLC",
    "13928": "ITRIG-N1 - IT Right, Inc",
    "13929": "Technisys S.A.",
    "13930": "CMH - The Children's Mercy Hospital",
    "13931": "-MH001 - MONIC CHARITY FOUNDATION OF NEW JERSEY",
    "13932": "WHHS - Washington Hospital Healthcare Sysem",
    "13933": "ANCHOR-STL2 - Anchor Packaging, Inc.",
    "13934": "Diaz Piacenza S.A.",
    "13935": "JEVIN COMERCIO E SERVICOS LTDA",
    "13936": "Universal Soft SA",
    "13937": "UNISERVE-13937 - Uniserve On Line",
    "13938": "SSNC- - SS&C Technologies, Inc.",
    "13939": "SOSSTAFFING - SOS Staffing Services, Inc.",
    "13940": "SJCOE - San Joaquin County Office of Education",
    "13941": "VISP - Visp Technologies, Inc.",
    "13942": "-CSMV - Commission Scolaire Marie-Victorin",
    "13943": "YK-COMMUNICATIONS - YK Communications, Inc.",
    "13944": "BFS-DIVERSIFIED-PRODUCTS-LLC - BFS Diversified Products, LLC",
    "13945": "PRISMTECHNOLOGIESABQ - PRISM Technologies",
    "13946": "ETECHOHIO - eTech Ohio",
    "13947": "SITESTAR-13947 - Sitestar Internet Services",
    "13948": "LINAMAR-CORPORATION - Linamar Corporation",
    "13949": "SLIDE-INC - Slide, Inc.",
    "13950": "DLS-INTERNET-SERVICES - DLS Internet Services",
    "13951": "CENTER-SEVEN - C7 Data Centers, Inc.",
    "13952": "BD-08-99 - Bigdough.com.inc",
    "13953": "SVCC-EDU - Sauk Valley Community College",
    "13954": "STAPLES - Staples, Inc",
    "13955": "ECHO-UPLINKDATA-COM - Echostar Broadcasting Corporation",
    "13957": "MNAA - Metropolitan Nashville Airport Authority",
    "13958": "PZG-FL - THE RIDGEROCK GROUP, LLC",
    "13959": "AUTOPHONE-OF-LAREDO - Autophone of Laredo",
    "13960": "ALENT-N-2 - Alentus Corporation",
    "13961": "AAORTHO - The American Association of Orthodontists",
    "13962": "-HISPEED-1 - World Internet Services",
    "13963": "SKYVIEWSAT - Skyview Networks",
    "13964": "SBCIS-TPKAKS - AT&T Internet Services",
    "13965": "SBCIS-FYTVAR - AT&T Internet Services",
    "13966": "DFO-NFLD- - Department of Fisheries and Oceans",
    "13967": "BUYSEONS - Buyseasons, Inc.",
    "13968": "CAISO-NET-BLK - CALIFORNIA ISO",
    "13969": "IUH-BLOOMINGTON - IU Health Bloomington Hospital",
    "13970": "NORTH-FORK-BANK-MATTITUCK - North Fork Bancorp Inc.",
    "13971": "FDS--NY HedgeServ Corporation",
    "13972": "WADSWORTH-CENTER - Wadsworth Center, NYS Department of Health",
    "13973": "N-REACTION97 - Reaction Systems, Inc.",
    "13974": "SADDL-5 - Saddlebrook Resorts, Inc.",
    "13975": "FLAGSTONE-MANAGEMENT-SERVICES-HALIFAX - Flagstone Management Services (Halifax) Limited",
    "13976": "TOPOCEAN-LAX1 - Topocean Consolidation Service (Los Angeles), Inc.",
    "13977": "CTELCO - FAIRPOINT COMMUNICATIONS, INC.",
    "13979": "ATT-IPFR - AT&T Services, Inc.",
    "13980": "TT-N001 - Twotrees Technologies, LLC",
    "13981": "ITXM - Institute for Transfusion Medicine",
    "13982": "NIBWAN01 - National Industries for the Blind",
    "13983": "EPRIME - New Century Energy",
    "13984": "NETDIRECTIVE-TECHNOLOGIES - netDirective Technologies Inc.",
    "13985": "NCO - NCO",
    "13986": "ECSIS-HST - ECSIS.NET",
    "13987": "IVANET-LONDON - IBIS INC.",
    "13988": "IVANET-FRANKFURT - IBIS INC.",
    "13989": "SCEA-FC-1 - Sony Computer Entertainment America, Inc.",
    "13990": "COUNTYOFORANGE - County of Orange",
    "13991": "Curacao Information Network - A division ofSetel N",
    "13992": "NETALS - ALS Scan, Incorporated",
    "13993": "MOTIVE-COMM - MOTIVE,  INC.",
    "13994": "OMU-1 - Owensboro Municipal Utilities",
    "13995": "PDRINET1 - Personnel Decisions Research Institutes, Inc.",
    "13996": "ECHOSTAR - Dish Network Corporation",
    "13997": "RD-CHI- - Rapid Displays, Inc",
    "13998": "SWMED - UT Southwestern Medical Center at Dallas",
    "13999": "Mega Cable, S.A. de C.V.",
    "14000": "Axtel, S.A.B. de C.V.",
    "14001": "MICROADVANTAGE-INC - Vision Net Ltd",
    "14002": "RAILINC - RAILINC",
    "14003": "VHS-NATN - Vanguard Health Management, Inc.",
    "14004": "FORCE3 - Force3, Inc",
    "14005": "DATATECHHOSTING - Data-Tech",
    "14006": "RAFFERTYCAPITALMARKETS - RAFFERTY CAPITAL MARKETS",
    "14007": "SOHOSKYWAY1 - Skyway West",
    "14008": "KINCARDINE- - Kincardine Cable Tv Ltd.",
    "14009": "APPLESEEDS - Appleseed's",
    "14010": "JACKHENRY - Jack Henry & Associates, Inc.",
    "14012": "PENNYMAC-1 - Private National Mortgage Acceptance Company LLC",
    "14013": "EPSON-ROBOTS - EPSON America (Factory Automation/Robotics)",
    "14014": "CNRAIL- - Canadian National Railway",
    "14016": "PAYSYS - Pay Systems",
    "14017": "BNSF- - Burlington Northern Sante Fe Railway Corp",
    "14018": "EZLINK - EZLink Internet Access",
    "14019": "MORTICEKERNSYSTEMSINC - MKS, Inc.",
    "14020": "LONGWOOD-1 - Longwood Gardens Inc.",
    "14021": "PSECU - Pennsylvania State Employees Credit Union",
    "14022": "BBCOM - Backbone Communications, Inc.",
    "14023": "WILD - Minnesota Wild",
    "14024": "DDCI - Data Dallas",
    "14025": "EWANDBH - EXTREMEWEB LLC",
    "14026": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "14027": "GSC-SALEM - Gannett Supply Corp. - Salem, OR",
    "14028": "FULBRIGHT-JAWORSKI - Fulbright & Jaworski L.L.P.",
    "14030": "FINANCIADORA DE ESTUDOS E PROJETOS - FINEP",
    "14031": "SCXY - Supercomputing XY Committee",
    "14032": "IMATION - Imation Corporation",
    "14033": "RBSLYNK-1 - WorldPay US, Inc.",
    "14034": "SWIRE-COCA-COLA-USA-DRAPER-REDUNDANT-ACCESS - Swire Coca-Cola, USA",
    "14036": "AMERISERVE - Ameriserve",
    "14037": "-DZONEEU Dedicated Zone Ltd",
    "14038": "EXACTOR - Exactor Inc",
    "14039": "BTCONF-VIDEO - BT Conferencing",
    "14040": "XO-N1 - XO Communications",
    "14041": "14041 - University Corporation for Atmospheric Research",
    "14042": "TPSEA1 - thePlatform",
    "14043": "SCANSOURCE - ScanSource, Inc.",
    "14044": "ORBITSYS - Orbit Systems Inc.",
    "14046": "KCOL - KC Online, Inc.",
    "14047": "FERRIS-MFG-CORP - Ferris MFG Corp",
    "14048": "MEMPHIS-EDU - The University of Memphis",
    "14049": "GOLDEN-GATE-UNIV - Golden Gate University",
    "14050": "SYRACUSE-METRONET - Syracuse Metronet Inc.",
    "14051": "SUREWEST - Roseville Telephone Company",
    "14052": "STEPHENS - Stephens, Inc.",
    "14053": "N-LWCL - Long Wharf Real Estate Partners  LLC",
    "14054": "IRONWORK - Marvel Studios LLC",
    "14055": "DFG-LLC - Dougherty Financial Group LLC",
    "14056": "SEI - SEI Investments",
    "14057": "TFIC-1 - TENNESSEE FARMERS MUTUAL INSURANCE COMPANY",
    "14058": "PCT-01 - PointClick Technologies, LLC",
    "14059": "WEBLICATIONS - Weblications, LLC",
    "14060": "NNCGATEWAY - CWA ISP LLC",
    "14061": "DIGITALOCEAN-N - Digital Ocean, Inc.",
    "14062": "AKQA AKQA Limited",
    "14063": "NETNEARU-NETWORK - NetNearU Corp.",
    "14064": "NRECA - NRECA",
    "14065": "ADELPHIA-2 - Time Warner Cable Internet LLC",
    "14066": "TELMETRICS - Telmetrics Inc.",
    "14067": "FOUROVER-GLN-CA - 4 Over, Inc.",
    "14068": "PLAYBOY-BLK-1 - Playboy",
    "14069": "Thomson-CSF Systems Argentina S.A.",
    "14070": "SVH-TVH-1 - Valley Health System",
    "14071": "PQ-CORPORATION - PQ Corporation",
    "14072": "WH-DC-CITY-GOVT - Government of the District of Columbia",
    "14073": "NEXTJUMPINC - Next Jump, Inc.",
    "14074": "COLGATE - Colgate-Palmolive Co.",
    "14075": "NPC-N - National Pen",
    "14076": "FCM360 - Secure Network USA, LLC",
    "14077": "ARSC - Arctic Region Supercomputing Center",
    "14078": "INFINITESOFT - Infinite Software, Inc.",
    "14079": "YANNIX-MTER-FUND - Yannix Master Fund, Ltd.",
    "14080": "Telmex Colombia S.A.",
    "14081": "Q-INTERACTIVE - Q Interactive",
    "14082": "GLOBAL-ONLINE - Global Online Electronic Services",
    "14083": "501STUDIOS - Pegalo Properties Inc",
    "14084": "Multiphone",
    "14085": "LEARN - LEARN",
    "14087": "SULBBS Inform\u00e1tica Ltda.",
    "14088": "WIU7 - Westmoreland Intermediate Unit",
    "14089": "CANNET - CanNet Internet Services, Inc.",
    "14090": "NDTELCO - NORTH DAKOTA TELEPHONE COMPANY",
    "14091": "DSM - DSM Technology Consultants",
    "14092": "NJACCESS - NJ INTERNET ACCESS",
    "14093": "GAINV - General American Investors Company, Inc.",
    "14094": "NO - Big Lots Stores, Inc.",
    "14095": "HCMH-3- - Hugh Chatham Memorial Hospital, Inc.",
    "14096": "FIRSTRATE-ARL-TEX- - First Rate, Inc.",
    "14097": "TELUSA- - Tokyo Electron America, Inc.",
    "14098": "SWGC - Memorial University of Newfoundland",
    "14099": "SPINFISH-1 - ROG, Inc.",
    "14100": "UCIX - Urbana-Champaign Internet Exchange",
    "14101": "EXPRESSION-EMERYVILLE - Ex'Pression College for Digital Arts",
    "14102": "GTVR - Transvision Reseau Inc.",
    "14103": "ACDNET-N1 - ACD.net",
    "14104": "OTS--14104 - University of Texas System",
    "14105": "NO - Secure IP",
    "14107": "PCINW-PN001 - Preferred Connections, Inc. NW",
    "14108": "CPIAN-N - CPIAN Capital Management, LLC",
    "14109": "SIAL - Sigma Aldrich Corporation",
    "14110": "GENESYS-N - Genesys Telecommunications Laboratories,Inc.",
    "14111": "EL SALVADOR TELECOM S.A DE C.V.",
    "14112": "NET-SECURENET-MTL - SecureNet Information Services Inc.",
    "14113": "HOSTINGCOM - WCP/32POINTS INTERMEDIATE HOLDING COMPANY, INC.",
    "14114": "CAMILION- - Camilion Solutions",
    "14115": "AMALGAMATED-BSA",
    "14116": "INFB- - InternetNamesForBusiness.com",
    "14117": "Telefonica del Sur S.A.",
    "14119": "PNG-WYO - PENN NATIONAL GAMING",
    "14120": "ITHS-NY4-BLK-001 - IT Hosting Services, LLC.",
    "14121": "CIBC-WORLD-MARKETS - CIBC World Markets",
    "14122": "Vector Casa de Bolsa, SA de CV",
    "14123": "SFSNET - Sungard Futures Systems",
    "14124": "GEEKWERX-NETWORK - GeekWerx LLC",
    "14125": "THE-JAMES-B-OSWALD-COMPANY - Oswald Companies",
    "14126": "N-VOICESTAR - VoiceStar",
    "14127": "ILAND - Iland Internet Solutions Corporation",
    "14128": "NU-EDU - National University",
    "14129": "NMIA - New Mexico Internet Access",
    "14131": "DONET - DataYard",
    "14133": "USMETROPOLITANTELECOM- - U.S. Metropolitan Telecom, LLC",
    "14134": "NAVISITE-WEST-2 - Navisite, Inc.",
    "14135": "NAVISITE-ET-2 - Navisite, Inc.",
    "14136": "PCCC - PC Connection, Inc.",
    "14137": "MIDMICH - MIDMICH.NET",
    "14138": "OCPS - Orange County Public Schools",
    "14139": "-MAXOR - Maxor Pharmacies",
    "14140": "AUBURN-ESSENTIAL-SERVICES - Auburn Essential Services",
    "14141": "WIRESIX - WireSix, Inc.",
    "14142": "BANKOFBOTETOURT - Bank of Botetourt, Inc.",
    "14144": "N-CI - Cambridge Interactive",
    "14145": "REGIONS-N-3 - REGIONS FINANCIAL CORPORATION",
    "14146": "LEVENGER - Levenger",
    "14148": "ENDINFOSYS - Endeavor Information Systems",
    "14149": "ICONFITNESS-MAIN - Icon Health & Fitness Inc",
    "14150": "PFCL2-N - Partnership Financial Consulting, LLC",
    "14151": "N-ICI-ORG - Investment Company Institute",
    "14152": "NETPULSE-1 - Netpulse Services",
    "14153": "EDGECT-IR - EdgeCast Networks, Inc.",
    "14154": "FAIRPOINT-UNITE - FAIRPOINT COMMUNICATIONS, INC.",
    "14155": "RURAL-TELEPHONE-SVCCO - Rural Telephone Service Co, Inc.",
    "14156": "GRANDECOM-3 - Grande Communications Networks, LLC",
    "14157": "BIRTHDAYALARM-2 - Monkey Inferno, Inc",
    "14158": "FWCU - First West Credit Union",
    "14159": "LAKEFIELD- - Lakefield Communications",
    "14160": "PREMIUMTELECOM - Premium Hosting, Inc.",
    "14161": "LANDOLAKES - Land O'Lakes, Inc.",
    "14162": "FHLB-PITT - FEDERAL HOME LOAN BANK of PITTSBURGH",
    "14163": "SHEARMAN - Shearman & Sterling",
    "14164": "BGPCRX - Bluegrass Cellular Inc.",
    "14165": "FTLINE-PUBLICATIONS - Fastline Publications, LLC",
    "14166": "SOFTCOMCA Softcom Inc",
    "14167": "MULTI-AD - Multi-Ad Services, Inc.",
    "14168": "IRID-POTOMACNET - IRIDES, LLC",
    "14169": "AIRTRAN-AIRWAYS - AIRTRAN AIRWAYS, INC",
    "14170": "DIGITALRIVER-DC20 - Digital River, Inc.",
    "14171": "THOMPUBLISHING-HORSHAM-GW01 - Thomas Technology Solutions Inc.",
    "14172": "X2NSAT-API - X2nSat, Inc",
    "14173": "PHOTOBUCKET - PHOTOBUCKET.COM, INC.",
    "14174": "NCKCN - North Central Kansas Community Network Co.",
    "14175": "HAWORTH - HAWORTH",
    "14176": "LIFETIME-TV2 - LIFETIME ENTERTAINMENT",
    "14177": "PACKETXPRESS-NORTEL - Nortel Networks",
    "14178": "Megacable Comunicaciones de Mexico, S.A. de C.V.",
    "14179": "Interactive Gaming and Wagering N.V.",
    "14180": "INTERNETPRO-GAD - INTERNET SOLUTIONS OF AL LLC",
    "14181": "UBETWIRELESS - UBET Wireless",
    "14182": "EDATA - eData, Inc.",
    "14183": "UALR-N - University of Arkansas at Little Rock",
    "14184": "DATAGLYPHICS - DataGlyphics, Inc.",
    "14187": "COMSAT COLOMBIA",
    "14188": "HLANDFIBERNETWORK - Ashland Fiber Network",
    "14189": "WITT-KIEFFER - Witt-Kieffer",
    "14191": "HSL - Hard Soft Systems Ltd.",
    "14192": "CARTHA-N - Carthage College",
    "14193": "TELNEL - KONGE TECH CORP",
    "14194": "OMH-INET-BLCK - OCONEE MEMORIAL HOSPITAL",
    "14195": "CONTEGO- - Contego Solutions LLC",
    "14196": "YAHOO-S2E - Yahoo",
    "14197": "HMS-N - HEALTH MARKET SCIENCE",
    "14199": "QED - Scholastic Inc.",
    "14200": "MARSHALLUNIV - Marshall University",
    "14201": "TELETECH - TeleTech Holdings, Inc",
    "14203": "JUNIPER-NETWORKS - Juniper Networks, Inc.",
    "14204": "TKS Teleinform\u00e1tica S/C Ltda.",
    "14205": "WANC - WAN Communications, Inc.",
    "14206": "SVCL-N - SureView Capital LLC",
    "14207": "COREBYTE - CoreByte",
    "14208": "BUDCO-PSC - BUDCO",
    "14209": "UT-CHATTANOOGA - University of Tennessee at Chattanooga",
    "14210": "EDGECT-DCA - EdgeCast Networks, Inc.",
    "14211": "GOTHAM-WEB-SERVICES - Gotham Web Services, Inc.",
    "14212": "SANTA-CRUZ-EDNET - Santa Cruz County Office of Education",
    "14213": "MONTEREY-BAY-K12 - Monterey County Office of Education",
    "14214": "MINACS - Minacs Inc",
    "14215": "SABRE-HOLDINGS-CORPORATION - SABRE HOLDINGS CORPORATION",
    "14216": "ISHIP - IShip.com",
    "14217": "DATAFRAMELO - Dataframe Logistics, Inc.",
    "14218": "TREMBLANT-N - Tremblant Capital Group",
    "14219": "SDI-MA - SouthData, Inc.",
    "14220": "14220 - Gozoe Wireless LLC",
    "14221": "WHINGHTON-RD- - University of Washington",
    "14222": "NFCU- - Navy Federal Credit Union",
    "14223": "NYSDOH - New York State Department of Health",
    "14224": "AIRTAP - Airtap Communications, LLC",
    "14225": "IBGNAP-01 - Inertia Beverage Group Inc.",
    "14226": "STIFEL - Stifel Nicolaus and Company  Incorporated",
    "14227": "FORBIN-COM - The Forbin Project",
    "14228": "NEW-DULCINA-AGRIDATA - New Dulcina Agridata LLC",
    "14229": "WMS-CHICAGO - Williams Electronics Games",
    "14230": "INVOLTA - Involta",
    "14231": "Banco de Venezuela",
    "14232": "Cooperativa Telef\u00f3nica Pinamar Ltda.",
    "14233": "ANCESTRY-INC - Ancestry.com., Inc.",
    "14234": "ZONAMERICA",
    "14235": "STATE-NM-US - State of New Mexico",
    "14236": "ADARA-NET - Adara Networks, Inc.",
    "14237": "BEAMSPEED1 - Beamspeed",
    "14238": "INNOVATIVE-NETWORKS - Innovative Networks LLC",
    "14239": "RSD-PA-15904 - Richland School District",
    "14240": "PMC--1 - PMC-Sierra, INC.",
    "14241": "ONE- - Oakland Schools",
    "14242": "EARTHLINK-BUSINESS - LogicalSolutions.net",
    "14243": "CGS-P - CGS",
    "14244": "NSIHOSTING-EQX-VA - NSI Hosting",
    "14245": "SEGAOADC - Sega of America, Inc.",
    "14246": "THALESCOMMINC- - Thales Communications Inc.",
    "14247": "SBIS-WACOTX - AT&T Internet Services",
    "14248": "US-NORWOOD - Instron",
    "14249": "Internet Engine, S.A. de C.V.",
    "14251": "MLSLI - Multiple Lising Service of Long Island, Inc.",
    "14252": "SCHOOLSPECIALTY - School Specialty, Inc.",
    "14253": "AEREO-NYC - Aereo, Inc.",
    "14255": "-USD - University of San Diego",
    "14256": "OTAYWATER - Otay Water District",
    "14257": "EZ-NET - The Iserv Company, LLC",
    "14258": "TAC-ALKA - Arctic Slope Telephone Association Cooperative, Inc.",
    "14259": "Gtd Internet S.A.",
    "14260": "USROYALINS - Royal&Sunalliance Insurance",
    "14261": "USNETWORK-N - US Network Services",
    "14262": "P-MAN - Portland - Metro Area Network (P-MAN)",
    "14263": "SD-NET - South Dakota State Government",
    "14264": "SAU- - Southern Adventist University",
    "14265": "US-TELEPACIFIC - Telepacific Communications",
    "14266": "IPAG - Imerys Pigments",
    "14268": "NCSL - Northern Computer Solutions Ltd.",
    "14269": "VA-DMV - Virginia DMV",
    "14270": "EAGLE-CA-1 - EAGLE.CA",
    "14271": "LAMC-NET - Louisville Academic Medical Center",
    "14273": "ONLINE-RESOURCES - Online Resources Corporation",
    "14274": "NETEE - Mesa Partners, LLC",
    "14275": "WEATHERNET - Freese-Notis Global Internet",
    "14276": "SS-NOC- - Straitshot Communications, Inc.",
    "14277": "NOKIA-IP Nokia IP",
    "14278": "NORSTAN - Black Box Network Services",
    "14279": "HDS-ORL-N1 - HD Supply, Inc.",
    "14280": "NETNATION-NETWORK NetNation Communications Inc.",
    "14281": "NATIONWIDELABS - Nationwide Laboratory Services Inc.",
    "14282": "PERSIS TELECOM",
    "14283": "BLUEONE - blueone.net",
    "14284": "ROCKHURST - ROCKHURST UNIVERSITY",
    "14285": "Banco Mercantil",
    "14286": "Tecnet SA",
    "14287": "TRIAD-TELECOM - Triad Telecom, Inc.",
    "14288": "MPINET - MPInet",
    "14289": "CBTKS- - COMMERCE BANK AND TRUST",
    "14290": "D-ANSWERING-SERVICE-FOR-DIRECTORS - Answering Service for Directors",
    "14291": "ANTIETAM - Antietam Cable Television, Inc",
    "14292": "CSC-VISA - CSC Consular Services Inc.",
    "14293": "WPGINVEST - Robeco Investment Management, Inc.",
    "14294": "14294 - Fuzebox Software Corporation",
    "14295": "LJKCO - LJK Companies, Inc",
    "14296": "3GTY - 3GTY, Inc.",
    "14297": "ACI-WORLDWIDE - ACI Worldwide, Inc.",
    "14298": "EPA-NET - Environmental Protection Agency",
    "14299": "ADP1 - Automatic Data Processing, Inc.",
    "14300": "TOYSRUS - Toys \"R\" Us",
    "14301": "EVEREST-INTERNET - Everest Global Services",
    "14302": "INFINIGON - Infinigon, Inc.",
    "14303": "MEMN1 - City of Memphis",
    "14304": "INTERTRADE-SYSTEMS - Intertrade Systems Inc.",
    "14305": "14305 - Accuray Incorporated",
    "14306": "GLAXOSMITHKLINE - GlaxoSmithKline",
    "14307": "N-ROCNET - ROCK SERVICES, INC.",
    "14308": "COL-ETS - City of Longmont",
    "14309": "G2ANET - Go2America LLC",
    "14310": "SNB-N - Safra National Bank of New York",
    "14311": "XO-N2 - XO Communications",
    "14312": "1-800CONTACTS - 1-800 Contacts, Inc.",
    "14313": "CMCMGMT01 - CLEARVIEW MANAGEMENT CONSULTANTS",
    "14314": "NET4UTB1 - The University of Texas at Brownsville",
    "14315": "CAFEPRESS - CafePress.com",
    "14316": "Twinneyville Corporation N.V.",
    "14317": "ACCNETWORKS - Advanced Computer Connections, Inc.",
    "14318": "PSINet Chile",
    "14319": "FURMAN-2 - Furman University",
    "14320": "MEREDITHCORP - Meredith Corp.",
    "14321": "SERVICIO-UNITELLER - Servicio Uniteller, Inc.",
    "14322": "NYAM-2 - NEW YORK ACADEMY OF MEDICINE",
    "14323": "SVR-CRX - Syniverse Technologies, LLC",
    "14324": "SOUND-SHORE-MANAGEMENT-INC - Sound Shore Management, Inc.",
    "14325": "OSHEAN - OSHEAN, Inc.",
    "14326": "PACKETFABRIC - PacketFabric, Inc.",
    "14327": "PGE-ONLINE - Portland General Electric Company",
    "14328": "RRD - R.R. Donnelley and Sons, Co.",
    "14329": "OPEN-ACCESS-TECH - OPEN ACCESS TECHNOLOGY INTERNATIONAL, INC.",
    "14330": "DIGITAL-INSIGHT - Digital Insight Corporation",
    "14331": "TCM-NETWORKS-0098",
    "14332": "SHOPZILLA - Shopzilla, Inc.",
    "14333": "ON-RAMP-INDIANA - On-Ramp Indiana, Inc.",
    "14334": "PRIMARY - Renaissance Learning Inc.",
    "14335": "VC3 - VC3, Inc.",
    "14336": "MAMLP - Mercator Asset Management, L.P., LTD.",
    "14337": "CVMIN-1 - CVM, INC",
    "14338": "KORE-WIRELESS - KORE Wireless",
    "14339": "SADESA S.A.",
    "14340": "SALESFORCE - Salesforce.com, Inc.",
    "14341": "MARVEL - MARVEL ENTERPRISES INC",
    "14342": "ITCM-UCIN - Integra Telecom, Inc.",
    "14343": "I2-TECHNOLOGIES - i2 Technologies Inc.",
    "14344": "ADVANCEDLEGAL - Advanced Legal Systems, Inc.",
    "14345": "FINALP - Final P, LLC",
    "14346": "Agencia Estado Ltda",
    "14347": "SCCI-1000 - Spectrum Communications & Consulting, Inc.",
    "14348": "URI- - University of Rhode Island",
    "14349": "KCPLN-1 - Kansas City Power & Light",
    "14350": "STROZFRIEDBERG - STROZ FRIEDBERG LLC",
    "14351": "SOUTHWESTERN-EDU - Southwestern University",
    "14352": "SSUITES-1 - ERP Suites",
    "14354": "NET9 - Region 9 Education Service Center",
    "14355": "IWI-TG-FW - Interstate Warehousing, Inc.",
    "14356": "INFOR-14356 - INFOR GLOBAL SOLUTIONS (MICHIGAN), INC.",
    "14357": "KCIT-I-NET - King County IT/I-NET",
    "14358": "MACKENZIEFINANCIAL- - Mackenzie Financial Corp",
    "14359": "ITS-USNET - Ideal Technology Solutions US Inc.",
    "14361": "HOPONE-GLOBAL - HopOne Internet Corporation",
    "14362": "CCIS - California City Internet Inc.",
    "14363": "OUTFITTERS - Infobahn Outfitters, Inc.",
    "14364": "AMEC- - AMEC",
    "14365": "ADOBE-NET - Adobe Systems Inc.",
    "14366": "MTNCABLE - Mountain Cablevision LTD.",
    "14367": "TDS-TELECOM- - TDS TELECOM",
    "14368": "BRAZOS-INTERNET - Brazos Internet",
    "14369": "NMAX - Nmax",
    "14370": "CYPRESSCOMM-14370 - Cypress Communications, Inc.",
    "14371": "PBNET - Paul Bunyan Communications",
    "14372": "ANTENNA-SOFTWARE - Antenna Software",
    "14373": "UTMB - University of Texas Medical Branch",
    "14374": "AGRI-VALLEY - Agri-Valley Services Inc.",
    "14375": "SUNGENGY-NET - SunGard Energy and Commodities",
    "14376": "SSF-12-6-198-0 - Sungard Securities Finance, Inc.",
    "14377": "PSINet Panama",
    "14378": "COMPINFOSYS - Compliance Information Systems, Inc.",
    "14379": "N-T-C - Northern Trust Company",
    "14380": "OPUS-INTERACTIVE - Opus Interactive",
    "14381": "CATERPILLAR-INC - Caterpillar, Inc.",
    "14382": "ESC13 - Education Service Center",
    "14383": "VCS- - Virtacore Systems Inc",
    "14384": "HOSTDESIGNS - HOST DESIGNS, LLC",
    "14385": "ORAMETRIX-RICHARDSON - OraMetrix, Inc.",
    "14386": "COMGRAPHICS-CGICHICAGO - Com-graphics, Inc.",
    "14387": "WHIP - SwitchWorks Technologies Inc.",
    "14388": "BRONCO-WINE - Bronco Wine Co.",
    "14389": "SOLUTIONSITC-COOKEVILLE - Solutions IT Consulting, LLC",
    "14390": "CORENET - Coretel America, Inc.",
    "14391": "WNSC-NET-12-40-212-0-1 - Automatic Data Processing, Inc.",
    "14392": "COFPDC - Capital One Financial Corporation",
    "14393": "CLICKABILITY - Clickability, Inc.",
    "14394": "KBCFP-NYC - KBC BANK N.V.",
    "14395": "FHLBATL - Federal Home Loan Bank Of Atlanta",
    "14396": "IVANET-BURLINGTON - IBIS INC.",
    "14397": "CH - Cedar Hill Capital Partners, LLC",
    "14398": "AUTODESK - Autodesk, Inc.",
    "14399": "HUBRIS2 - Hubris Communications",
    "14400": "VIEGA-NA - Viega LLC",
    "14401": "MEURECOMP - MeasureComp,LLC",
    "14402": "KANSNET-2 - Fox Computers, Inc. d/b/a KansasNet",
    "14403": "TUCKER-USA - Tucker Communications, Inc",
    "14404": "DIRECT-ALLIANCE - Direct Alliance Corporation",
    "14405": "XO-N4 - XO Communications",
    "14406": "XO-N3 - XO Communications",
    "14407": "XO-N5 - XO Communications",
    "14408": "-EMPIRECLS-SECAUCUS - Empire International, Ltd.",
    "14409": "MCSI - Myers Computer Service, Inc.",
    "14410": "HYETECH - Hye Tech Network & Security Solutions, LLC",
    "14411": "1CHFINTL1 - CHF International",
    "14412": "IHOUSEN1 - iHOUSEWEB Inc.",
    "14413": "LINKEDIN - LinkedIn Corporation",
    "14414": "CROSSBRDG-N01 - CrossBridge Solutions Inc.",
    "14415": "HOSTCOLLECTIVE - Host Collective, Inc.",
    "14416": "BRAVO-NET - Internet de Nuevo Laredo, S.A de C.V.",
    "14417": "LANDSTAR - Landstar System Inc",
    "14418": "DTCC-1 - Depository Trust & Clearing Corporation",
    "14419": "MOSSYOAK - HA OUTDOORS, Inc.",
    "14420": "CORPORACION NACIONAL DE TELECOMUNICACIONES - CNT EP",
    "14421": "THERAVANCE - Advanced Medicine Inc",
    "14422": "SIMPLIX - SIMPLIX",
    "14423": "NOVAC- - NOVA CUALTY COMPANY",
    "14424": "ANDERINGERSTA - A.N. Deringer, Inc.",
    "14425": "MENDO-COMMUNITY-NET - Mendocino Community Network",
    "14426": "MACEWAN - Grant MacEwan University",
    "14427": "MEDIAQUEST - MediaQuest",
    "14428": "-POMEROY-CORP - Pomeroy",
    "14430": "BWFN - BalsamWest FiberNET, LLC",
    "14431": "UCC-INET - Umpqua Community College",
    "14432": "GREX - NTRC-Grenada",
    "14433": "SUNY-OSWEGO-N - State University of New York - Oswego",
    "14434": "VIPN1 - VI POWERNET, LLC",
    "14435": "PAA - Plains All American Pipeline, L.P.",
    "14436": "INTUIT-QDC - Intuit Inc.",
    "14437": "FLEMING - C&S WHOLESALE GROCERS INC.",
    "14438": "USA-CHOICE-OIL-CITY - USA CHOICE INTERNET SERVICES,",
    "14439": "SFBNE - Security First Bank",
    "14440": "CITONCOMPUTERCORP - Citon Computer Corp",
    "14441": "NETWORK-SOLUTIONS-14441 - Network Solutions, LLC",
    "14442": "MEDIA-HOSTS - Media-Hosts Inc.",
    "14443": "OTS-YOURACCOUNTS - Output Technology Solutions",
    "14444": "IRESS-INET-02 - IRESS Market Technology Canada LP",
    "14445": "CAWORKS-ABQ - CasaWorks, Inc.",
    "14446": "CNT-N - Central Newspapers Technologies Inc.",
    "14447": "IMTGLOBALTEL - GlobalTel",
    "14448": "HPU-NC - High Point University",
    "14449": "BCBSOM - Blue Cross Blue Shield of Montana",
    "14450": "GEICO01 - GEICO",
    "14451": "GEICO02 - GEICO",
    "14452": "CMA-USA - CMA, Inc.",
    "14453": "-AKN - ADVANCED KNOWLEDGE NETWORKS",
    "14454": "PERIMETER-ESECURITY - Perimeter eSecurity",
    "14455": "SUNGARD-RECOVERY - Sungard Network Solutions, Inc.",
    "14456": "PUC-CA - Peterborough Utilities Commission",
    "14457": "Radins Tecnologia LTDA ME",
    "14458": "WORLDKITCHEN-1 - World Kitchen, LLC",
    "14459": "ENTERTAINMENTPARTNERS--A - Entertainment Partners",
    "14460": "HORIZON - Horizon Media, Inc.",
    "14461": "NTSL - NET SOLUTIONS",
    "14462": "IONGEO-N - ION Geophysical Corporation",
    "14463": "TDKOM INFORMATICA LTDA.",
    "14464": "RINET - Rhode Island Network for Educ. Technology",
    "14465": "HITN--1 - HITN",
    "14466": "ARIBA-PGH - Ariba Inc",
    "14467": "KUA-NET - KUA.net",
    "14468": "RIDER-UNIVERSITY - Rider University",
    "14469": "SWISHMAIL - Swishmail",
    "14470": "BSC-CORP - Boston Scientific Corporation",
    "14471": "AUTOMATED-MEDIA-INC - Automated Media, Inc.",
    "14472": "ATRIA - Atria Networks LP.",
    "14473": "I3N1-200E - Inside The Internet, Inc",
    "14474": "PARISH-COMM-2 - Parish Communications LP",
    "14475": "SWANK-AUDIO-VISUALS - Swank Audio Visuals",
    "14476": "HONDACA- - HONDA CANADA INC.",
    "14477": "FLTG - FINGER LAKES TECHNOLOGIES GROUP, INC.",
    "14478": "IRDETO-SILICON-VALLEY - Irdeto Silicon Valley, Inc.",
    "14479": "DENHAM-UK-LLP Denham Capital Management UK LLP",
    "14480": "ONECOM-CTLI - One Communications Corporation",
    "14481": "BRODARTCO - Brodart Company",
    "14482": "OVERSEE-DOT-NET - Oversee.net",
    "14483": "N-RCG - Ruane, Cunniff & Goldfarb Inc",
    "14485": "GAIAONLINE - Gaia Interactive, Inc.",
    "14486": "OXY- - Occidental College",
    "14487": "WIND-RIVER-INTENET - Wind River Internet",
    "14488": "SPEECHCYCLE - SpeechCycle, Inc.",
    "14489": "DENDRITE - DENDRITE INTERNATIONAL INC",
    "14490": "VIRTELA-CUST-VCJC1-EXTREME Virtela Communications",
    "14491": "FGLIFE--NUMBER - Fidelity and Guaranty Life Business Services",
    "14492": "DATAPIPE - DataPipe, Inc.",
    "14493": "AOA--NUMBER - American Osteopathic Association",
    "14494": "EPINIONS - SHOPPING.COM, INC.",
    "14495": "NDAQ-OMX-14495 - THE NDAQ OMX GROUP, INC.",
    "14496": "AGILENT- - Agilent Technologies",
    "14497": "BITREFINERY-1 - Bit Refinery, LLC",
    "14498": "DYNETICS - Dynetics, Inc.",
    "14499": "ALORICA - ALORICA INC",
    "14500": "GALAXYBROADBAND-01 - Galaxy Broadband Communications Inc.",
    "14501": "ENTERPRISECOMMUNITY - Enterprise Business Partners, LLC",
    "14502": "TRAVEL-NET - Travel-Net Communications Inc",
    "14503": "HOOVERS - Hoover's, Inc.",
    "14504": "SKYLIGHT-SYSTEMS - Skylight Healthcare Systems",
    "14505": "ISLC - ISLC, Inc.",
    "14506": "N-OCML-17 - O.S.S. CAPITAL MANAGEMENT LP",
    "14507": "TTE-2-N - Tastefully Simple",
    "14508": "VFL-BB-1 - Velocity Futures, LLC",
    "14509": "AMCINET - AMC Theatres",
    "14510": "COREEXPRESS - CoreExpress",
    "14511": "POLAR-COMMUNICATIONS - Polar Communications",
    "14512": "BENTLEY- - Bentley University",
    "14513": "DMACC - Des Moines Area Community College",
    "14514": "PHJW - Paul, Hastings, Janofsky & Walker LLP",
    "14515": "STATENET - Statenet",
    "14516": "INVESTEC-2",
    "14517": "REACHONE - ReachONE Internet",
    "14518": "BIMR-LJ - Sanford-Burnham Medical Research Institute",
    "14519": "APPLIEDI - Applied Innovations Corporation",
    "14520": "-TBWACDNY - TBWA Chiat Day",
    "14521": "PACIFIC-LIFE - Pacific Life Insurance Company",
    "14522": "Satnet",
    "14523": "LEWISIG-N-R01 - Lewis ig, Inc",
    "14524": "SERCO-NA - SERCO NA",
    "14525": "TORONTO-UTILITIES - Vertex Data LP",
    "14526": "CLARIS-NETWORKS - Claris Networks LLC",
    "14527": "CABEL - Cabela's Inc.",
    "14529": "SJU-5600 - Saint Joseph's University",
    "14530": "MYC-NET - SwitchWorks Technologies Inc.",
    "14531": "LM-ATL - Lockheed Martin Corporation",
    "14532": "CBOSS - CBOSS INC",
    "14534": "SOMERSETMEDICAL-1 - Somerset Medical Center",
    "14535": "Techtel LMDS Comunicaciones Interactivas S.A.",
    "14536": "N-SOL - sol.net Network Services",
    "14537": "MOHAWK-INTERNET- - Mohawk Internet Technologies",
    "14538": "HEC-NETWORK - Harrisonburg Electric Commission",
    "14539": "VLABS - Vantage Labs LLC",
    "14540": "DIRECTSAT-TV - Direct Sat TV",
    "14541": "GE-AIRCRAFT-ENGINES GE TSG",
    "14542": "CALPOP - CALPOP.COM, INC.",
    "14543": "SRT-N - SRT Communications, Inc.",
    "14544": "RETEK - Retek, Inc.",
    "14545": "ADR-DRIVING-RECORDS - AMERICAN DRIVING RECORDS, INC.",
    "14546": "MIDWESTINTER - Midwestern Intermediate Unit IV",
    "14547": "RPTK - RPTK",
    "14548": "LISTEN-SF-1 - RealNetworks, Inc.",
    "14549": "ITC-GLOBAL-LLC - ITC Global",
    "14550": "MIDDLEBURY-COLLEGE - Middlebury College",
    "14551": "UUNET-SA - MCI Communications Services, Inc. d/b/a Verizon Business",
    "14552": "ACS-SOUTHETDATACENTER - Affiliated Computer Services, Inc.",
    "14553": "FACULDADES CATOLIC",
    "14554": "FIRSTHOP - FirstHop",
    "14555": "NO - LAN Associates",
    "14556": "PTC - Pilot Travel Centers, LLC",
    "14557": "EGINITY - Eginity, Inc.",
    "14558": "FTRETURN - FastReturn",
    "14559": "BRTCC - Ballard Rural Telephone Cooperative Corporation Inc.",
    "14560": "Internet Holding S. A.",
    "14561": "SOCIATED-BANK-INTERNET - Associated Bank",
    "14562": "SHAW-COMMUNICATIONS - Shaw Communications Inc.",
    "14563": "DATAGRAM-PACIFIC - Datagram, Inc.",
    "14564": "-2515 - Alpine Funds",
    "14566": "ACS-INTERNET - Affiliated Computer Services",
    "14567": "SPRINGS - Springs Hosting",
    "14568": "SIRVA - North American Van Lines",
    "14569": "HCT- - HCT",
    "14570": "SAT-TEL2 - Satellite Communication Systems, Inc.",
    "14571": "Internet Group do Brasil SA",
    "14573": "KEYSPANENERGY-NE1 - Keyspan Energy",
    "14574": "RTCCOM - RTC COMMUNICATIONS",
    "14575": "NATURE-MACMILLAN-DATA-CENTER - NATURE AMERICA, INC",
    "14576": "HOSTING-SOLUTIONS - Hosting Solution Ltd.",
    "14577": "-TBWACDLA - TBWA Chiat Day",
    "14578": "APSINC - Automatic Payroll Systems, Inc.",
    "14579": "EDWARDJONES - Edward D. Jones & Co., L.P.",
    "14580": "REGENTEC - Regeneration Technologies, Inc.",
    "14581": "GLOBALCAPACITY- - Vanco Direct USA, LLC",
    "14582": "DICKINSON-FINANCIAL-CORPORATION - Dickinson Financial Corporation",
    "14583": "VITA-VSP-1 - Virginia Information Technologies Agency (VITA)",
    "14584": "BAKER-AND-TAYLOR - Baker & Taylor, Inc.",
    "14585": "CIFNET - CIFNet, Inc.",
    "14586": "ECOP- - Electrolux Home Products, Inc.",
    "14587": "GIANT-CR - Giant, Inc.",
    "14588": "COMSAT-INTERNATIONAL - Comsat International",
    "14589": "DIGITALWEST- - Digital West Networks, Inc.",
    "14590": "DESERTSCHOOLS-N-1 - Desert Schools Federal Credit Union",
    "14591": "CFB17-AR - Community First Bank",
    "14592": "MAKENA - Makena Technologies Inc",
    "14593": "BRAND-INSTITUTE - Brand Institute, Inc.",
    "14594": "CONFLUENT - ConfluentP",
    "14595": "DISTRIBUTEL-14595 - DISTRIBUTEL COMMUNICATIONS LTD.",
    "14597": "DETM10777 - Duke Energy Trading and Marketing, L.L.C.",
    "14598": "YCP-N - York College of Pennsylvania",
    "14599": "SPRINT-CHARTER-CONNECTION - Besser Company",
    "14600": "MXL-PROD - MX Logic, Inc.",
    "14601": "AAL-N - Anchorage Advisors, LLC",
    "14602": "TELIAX - Teliax, Inc.",
    "14603": "VSI - Ability Network Inc.",
    "14604": "DIGITALINSIGHT - Digital Insight Corporation",
    "14605": "ATS-NET - Advanced Technical Solutions, LLC",
    "14606": "TRENDWEST - Wyndham Resort Development Corporation",
    "14607": "OTA - OTA Management LLC",
    "14608": "AFS-1 - Alaska Fiberstar",
    "14609": "EQUINIX-CORP- - Equinix, Inc.",
    "14610": "INTEGRAL- Integral Development Corp.",
    "14611": "HARPERCOLLINSPUBLISHERS - HARPER COLLINS PUBLISHERS INC.",
    "14612": "MAINSTREET-DALL-DATACENTER - MainStreet Solutions, Inc.",
    "14613": "TOCICI - TOCICI LLC",
    "14614": "STARKEY - Starkey Laboratories, Inc.",
    "14615": "ROCK-HILL-TELEPHONE - Comporium Communications",
    "14616": "IBIS IBIS INC.",
    "14617": "GDST-SATCOM - General Dynamics SATCOM Technologies Inc.",
    "14618": "AMAZON-AES - Amazon.com, Inc.",
    "14619": "WESTBROOK - Westbrook Partners",
    "14620": "ITALK - iTalk Global Communications, Inc.",
    "14621": "NPSNET - National Park Service",
    "14622": "EXPRESSJET - EXPRESSJET AIRLINES, INC.",
    "14623": "LCU-NET - Lubbock Christian University",
    "14624": "PSINet do Brasil S.A.",
    "14625": "PGA-TOUR - PGA Tour",
    "14626": "COLUMBIA-HCA - Columbia/HCA Healthcare, Inc.",
    "14627": "VITAL Vitalwerks",
    "14628": "SMUD-ELECTRIC - Sacramento Municipal Utility District",
    "14629": "SOLUCIAN - Solucian Networking, L.L.C.",
    "14631": "EMPIREPAPER-WF - Empire Paper Company",
    "14632": "BIA30N - Brown Advisory",
    "14633": "GLOBAL-DATA-LINK - Global Data Link, Inc",
    "14634": "SPINNNET - SpinnNet",
    "14635": "VERMONT-STUDENT-SISTANCE-CORPORATION - Vermont Student Assistance Corporation",
    "14636": "INTERNAP-BLK4 - Internap Network Services Corporation",
    "14637": "SBM-N - STATER BROS MARKETS",
    "14638": "LCPR-HSD - Liberty Cablevision of Puerto Rico LTD",
    "14639": "ALLEGIANCE-1 - Allegiance Healthcare Corporation",
    "14640": "QWIRELESSBB - Q-Wireless, LLC",
    "14641": "HANNAFORD - Hannaford Bros. Co.",
    "14642": "MOREWAVE - Morewave Communication Inc.",
    "14643": "STEWI - STE Wireless Inc.",
    "14644": "IONCOMPUTER - ION Computer Systems, Inc.",
    "14645": "-CJIS-20 - CJIS-Consortium-20th-Court Administration",
    "14646": "FRANKLINCOVEY - Franklin Covey Co.",
    "14647": "NETOS-N1 - Network O.S., Inc.",
    "14648": "RANDFINANCIAL - Rand Financial Services, Inc.",
    "14649": "NEBS - New England Business Service",
    "14650": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "14651": "RSLCOMCA-1 - RSL COM Canada Inc.",
    "14652": "COSTARGROUPN - COSTAR GROUP",
    "14653": "5280NETWORKSICGBLOCK1 - 5280 Networks, Inc.",
    "14654": "WAYPORT - Wayport, Inc.",
    "14655": "HAMPTONU - Hampton University",
    "14656": "CHARTER-CENTURYLINK - CENTRIC HEALTH RESOURCES",
    "14658": "FLHSI - NEBUTEL, INC.",
    "14659": "ZID-1 - ZiD Internet",
    "14661": "LAURENTIANU - Laurentian University",
    "14662": "CSTONE-NET - Cornerstone Systems Inc.",
    "14663": "TELUS-3 - TELUS MOBILITY",
    "14664": "IFX NETWORKS COLOMBIA",
    "14666": "SPIRIT1 - SpiritBank",
    "14667": "MYLINUXISP-01 - Internet America, Inc.",
    "14668": "COMCT-TELECOMM-6 - Comcast Telecommunications, Inc.",
    "14669": "RGTS-NY - Rockefeller Group Technology Solutions, Inc.",
    "14670": "SOLAR-VPS - Solar VPS",
    "14671": "TACONIC - FairPoint Communications",
    "14672": "CARROLL-NET - Carroll-Net, Inc.",
    "14673": "INTERNET-MANAGEMENT-CORP - Internet Management Corp",
    "14674": "Imagenes Digitales S.A.",
    "14676": "REGUS - Regus Business Center, LLC",
    "14677": "CLICK-NETWORK - City of Tacoma",
    "14678": "YAHOO-HILLSBORO - Yahoo",
    "14679": "WEBMTER - WebMaster, Incorporated",
    "14680": "REALE-6 - Auction.com",
    "14682": "GGS - GGS Information Services",
    "14683": "WILSHIRESOCIATESINC - Wilshire Associates Incorporated",
    "14684": "HICAM - Hitachi Computer Products (AMERICA), Inc.",
    "14685": "BAC-CFC-CW-CREDIT1 - Bank of America",
    "14686": "YISI - Double Dog Communications",
    "14687": "NATIONALLIFE - National Life Insurance Company",
    "14688": "GVSI - GlobalView Software Inc.",
    "14689": "ENFUSION-N - Enfusion LLC",
    "14690": "PEORIAUSD11 - Peoria Unified School District",
    "14693": "BAPTIST-HEALTH- - Baptist Health",
    "14695": "CP-HQ-DTC1 - Cresa Partners, LLC",
    "14696": "GU-LFTC - GLOBALFOUNDRIES U.S. Inc.",
    "14697": "SCS- - SUPERIOR CENTRAL STATION, INC.",
    "14698": "GRANDECOM-2 - Grande Communications Networks, LLC",
    "14699": "N-EVOLUTION-1 - Evolution Markets",
    "14700": "RCG-N - Ridgefield Capital Group GP, LLC",
    "14701": "ELEMENTEK - Peak Colo",
    "14702": "INL-N2 - Idaho National Laboratory",
    "14703": "MAQSNET - MARQUETTE-ADAMS TELEPHONE COOPERATIVE, INC.",
    "14704": "SURFX - SurfXpress, LLC",
    "14705": "PCAL2 - PAUL CAPITAL ADVISORS, L.L.C.",
    "14706": "MBARI-MAIN - Monterey Bay Aquarium Research Institute",
    "14707": "ABSHOU-N - American Bureau of Shipping",
    "14708": "WebHost Chile S.A.",
    "14709": "Telefonica Moviles Panama S.A.",
    "14710": "N-CXA-OM-14710-CBS - Cox Communications Omaha, L.L.C.",
    "14711": "INGERSOLL-IMC - INGERSOLL CUTTING TOOL COMPANY",
    "14712": "-ONESC - One Step Consulting, Inc.",
    "14713": "SAXON- - Saxon Shoes, Inc",
    "14714": "CONCERT-N - CONCERT",
    "14715": "NICORINC - Nicor Inc.",
    "14716": "LIGHTHOUSE - Lighthouse.net",
    "14717": "ECINET EZE Castle Integration Inc.",
    "14718": "DWR- - DESIGN WITHIN REACH",
    "14719": "MICROSOFT-CORP-BCENTRAL - Microsoft Corporation",
    "14720": "GAMMANETWORKING-ET - Gamma Networking Inc.",
    "14721": "LAYER-7-NETWORKS - Layer 7 Consulting, LLC",
    "14722": "TELOSHOST - TelosHost",
    "14723": "ArcelorMittal Sistemas SA",
    "14724": "PROCARERX - BURGESS INFORMATION SYSTEMS",
    "14725": "KEMPER-TECHSERVICES - Kemper Insurance Companies",
    "14726": "TMS-DATA - TMS Data Services, LLC.",
    "14727": "TECHLINE - Techline",
    "14729": "TIER1NET - Tier1Net, inc.",
    "14730": "CAVTEL01 - Cavalier Telephone",
    "14732": "THESTREET-COM-2 - TheStreet.Com",
    "14733": "14733 - Barclays Capital Inc.",
    "14734": "HEARTLAND-COG - Heartland Council of Governments",
    "14735": "LZ - Linkzone, Inc.",
    "14736": "COKCMO - City of Kansas City Missouri",
    "14737": "CCCOES - Colorado Community College and Occupational Education System",
    "14738": "DIGIKEY - Digi-Key Corporation",
    "14739": "SHOWINGTIME01 - Showingtime.com, Inc.",
    "14740": "INNOVATIONSTECH-CORP - NetServe365, LLC",
    "14741": "BIZLAND-SD - The Endurance International Group, Inc.",
    "14742": "INTERNAP-BLOCK-4 - Internap Network Services Corporation",
    "14743": "INTERNAP-BLOCK-4 - Internap Network Services Corporation",
    "14744": "INTERNAP-BLOCK-4 - Internap Network Services Corporation",
    "14745": "INTERNAP-BLOCK-4 - Internap Network Services Corporation",
    "14746": "NOCTEL - NocTel Communications, Inc.",
    "14747": "LEE-COUNTY-CC - Lee County Clerk of Courts",
    "14748": "BIG5CORP - Big 5 Corp.",
    "14749": "RUSSEPB - Russellville Electric Plant Board",
    "14750": "SIERRA-TEL-INTERNET - Sierra Tel Internet",
    "14751": "ONECOM-CVT - One Communications Corporation",
    "14752": "HOOPBR - Hooper Holmes Inc.",
    "14753": "UNIVE-80 - Universal Consulting",
    "14754": "Telgua",
    "14755": "MHO - Mile High Online",
    "14756": "ATMOSPHERE- - Atmosphere",
    "14757": "PCM-DCW-HOSTING - PCM Sales, Inc",
    "14758": "ADVTEL-SOUTH - EATEL",
    "14759": "Informatica El Corte Ingles",
    "14760": "MURRAY-STATE-UNIVERSITY - Murray State University",
    "14761": "SCS-N - SCS Financial Services, LLC",
    "14762": "AMGEN - AMGEN, Inc.",
    "14763": "STKATE - St. Catherine University",
    "14765": "TECHE - Computers-N-Service Internet, Inc.",
    "14766": "UKMAGDIA-BT-YIP - Magnetar Capital LLC",
    "14767": "IOLANI-ACCESS - 'Iolani School",
    "14768": "SERVMATIX - Servmatix Inc.",
    "14769": "i-Solution S.A.",
    "14770": "NOBLE-USSJC - NOBLE AMERIC CORP.",
    "14771": "CITCO-N-1 - Citco Technology Management, Inc.",
    "14772": "UNXCOM - Unx, LLC",
    "14773": "LANLEB-IU13 - Lancaster Lebanon Intermediate Unit 13",
    "14774": "WILLIAM-PENN-FOUNDATION - William Penn Foundation",
    "14775": "KEN-TENN-WIRELESS - Ken-Tenn Wireless LLC",
    "14776": "INKTOMI-LAWSON - Inktomi Corporation",
    "14777": "INKTOMI-LAWSON - Inktomi Corporation",
    "14778": "INKTOMI-LAWSON - Inktomi Corporation",
    "14779": "INKTOMI-LAWSON - Inktomi Corporation",
    "14780": "INKTOMI-LAWSON - Inktomi Corporation",
    "14781": "INKTOMI-LAWSON - Inktomi Corporation",
    "14782": "MAILCHIMP - MailChimp",
    "14783": "NUANCE-BURLINGTON - NUANCE COMMUNICATIONS, INC",
    "14784": "CPR - Computer Products and Resources",
    "14785": "BCBSVT-DOT8-N - BCBSVT",
    "14786": "GHS - Gwinnett Hospital Systems",
    "14787": "N1GUARD23ATTWINSTAR - Guardian Industries Corp",
    "14788": "LALLY-MCFARLAND - Lally McFarland & Pantello",
    "14789": "DONORNETWORK - Donor Network of Arizona",
    "14790": "CAMERON - Cameron Memorial Community Hospital",
    "14791": "N-CENTRAMEDIA-ISP - Centramedia Incorporated",
    "14792": "DST-N - DST Systems, Inc.",
    "14793": "API-DIGITAL - API Digital Communications Group, LLC",
    "14794": "AIRLIANCE - AirLiance Materials, LLC",
    "14795": "Banco Credito e Inversiones",
    "14796": "CVC-INTERNET - CVC Internet, LLC",
    "14797": "QNECTNET - Qnect.net",
    "14798": "GLOBALTECHNOLOGY - Global Technology Solutions Group, Inc",
    "14799": "EXP-EC2000 - Experian",
    "14800": "METRATECH - METRATECH CORP.",
    "14801": "HPU - Hawaii Pacific University",
    "14802": "UMPQUABANK - UMPQUA BANK",
    "14803": "-14803 - Nokia, Inc.",
    "14805": "WESTPOINT-HOME - WestPoint Home, Inc.",
    "14807": "SHNAC1 - Skyhigh Networks Inc",
    "14808": "CITY-OF-LUFKIN-TEX - City of Lufkin Texas",
    "14809": "CCINET - CCI Industries, Inc",
    "14810": "M3-MERIDIANMANAGE - Meridian Billing Management Co",
    "14812": "CNSX-PRIMARY - CNSX",
    "14813": "TELEBARBADOS - Tele (Barbados) Inc.",
    "14814": "TRVNET - Twin Rivers Valley Internet Services, Inc.",
    "14816": "COM-N-HQ-01 - Command Transportation LLC",
    "14817": "SCL-SHAW - Syncrude Canada Limited",
    "14818": "CYBERMESA-N - Cyber Mesa Computer Systems, Incorporated",
    "14819": "AMER-COLLEGE-OF-CARD - American College of Cardiology",
    "14820": "VIRGIN-TECH - Virgin Technologies Inc",
    "14821": "MBA-EQUINIX- - Mortgage Bankers Association of America",
    "14822": "MSKCC - Memorial Sloan-Kettering Cancer Center",
    "14823": "INTA - Internet America, Inc.",
    "14824": "ZYNGA-01 - Zynga Inc.",
    "14825": "VINS--6 - ViaWest",
    "14826": "SURENET-N - SureNet Communications Group",
    "14827": "WSDOT-N - Washington State Department of Transportation",
    "14828": "HBCI-1999TA - Hiawatha Broadband Communication Inc.",
    "14829": "N-IWON - Mindspark Interactive Network, Inc.",
    "14830": "PFA-BETH--1 - ProFund Advisors LLC",
    "14831": "LIMORES-134 - LimoRes, Inc.",
    "14832": "NETWORKUSA - Network USA L.L.C",
    "14834": "UIS- - University of Illinois at Springfield",
    "14835": "PEAK10-N - Peak 10, Inc.",
    "14836": "CITY-OF-TORONTO - City of Toronto",
    "14837": "OSCAR-GRUSS- - Oscar Gruss & Son Incorporated",
    "14838": "DEVIANTART - deviantART, Inc.",
    "14839": "SARCOM - Sarcom, Inc.",
    "14840": "COMMCORP COMUNICACOES LTDA",
    "14841": "AIRWAVE - AIRWAVE BROADBAND WIRELESS. INC.",
    "14842": "BAUD-01 - Baudville, Inc.",
    "14843": "WALLED-NET - 1610851 Ontario Inc.",
    "14844": "SPECTRAN- - Specialized Transportation Inc.",
    "14845": "Universidad Nacional del Sur",
    "14846": "CGNOGE - NBC Internet",
    "14847": "RCG-GLOBAL-SERVICES - RCG Information Technology",
    "14848": "OCB - Ophthalmic Consultants of Boston (OCB)",
    "14849": "SCSD- - Superior Court of California, County of San Diego",
    "14850": "PACE-SUBURBAN-BUS - PACE, the suburban bus division of the Region Transportation Authority",
    "14851": "BANNER-HEALTH-ARIZONA - BANNER HEALTH",
    "14852": "DCX - DaimlerChrysler Corporation",
    "14853": "AOL-MTC3 - America Online",
    "14854": "AOL-MTC2 - America Online",
    "14855": "AOL-MTC1 - America Online",
    "14856": "-VUDU - VUDU, Inc.",
    "14857": "FREESCALE-AZ - Freescale Semiconductor, Inc.",
    "14858": "HISNET - Hanson Information Systems, Inc. / Family Net",
    "14859": "CAC-N - CENTRAL ARIZONA COLLEGE",
    "14860": "SC2000 - SMARTCOM TELEPHONE, LLC",
    "14861": "ISC-GROUP - ISC Group",
    "14862": "OCEANEERING - Oceaneering International, Inc.",
    "14863": "CORBAN - Corban University",
    "14864": "GREENWICH - RBS Securities, Inc.",
    "14865": "SUPRACANADA - SUPRA CANADA TECHNOLOGIES LTD",
    "14866": "VOINETWORKS - Voi Networks Inc.",
    "14867": "SYNAPSIS COLOMBIA S",
    "14868": "COPEL Telecom S.A.",
    "14870": "FLEXERA-SC4 - Flexera Software, LLC",
    "14871": "YOUNG-AMERICA - Young America Corporation",
    "14872": "YNC - @YourNet Connection, Inc.",
    "14873": "ATB - Alberta Treasury Branches",
    "14874": "MEDCENTRAL-MANSFIELD - MedCentral Health System",
    "14875": "NOVATELN - NovAtel Inc.",
    "14876": "DDNET-1 - Data Domain, Inc.",
    "14877": "PENNREN - KINBER",
    "14878": "PIXIUS- - Pixius Communications, LLC",
    "14879": "PARIS- - PARIS ACCESSORIES INC.",
    "14880": "TICKETMTER-NETOPS Ticketmaster Network Operations USA/EU",
    "14881": "NMG-1 - The Neiman Marcus Group, Inc.",
    "14882": "QUAD-GRAPHICS - Quad/Graphics Inc.",
    "14883": "TRACI - TRACI Network Solutions",
    "14884": "ADVANCEDACCESS - Advanced Access",
    "14885": "RAND-GRAPHICS - Rand Graphics, Inc.",
    "14886": "Atos Origin Brasil Ltda",
    "14887": "NETWORKINSTRUMENTSLLC - Network Instruments, LLC",
    "14888": "FNNI-14888 - First National Bank of Omaha",
    "14889": "HOU-MUSTANGENG - Mustang Engineering, L.p.",
    "14890": "HAYBOONET - Haynes and Boone, L.L.P.",
    "14891": "EACOM - Electronic Arts, Inc.",
    "14893": "CHS-MI - Covenant Medical Center, Inc.",
    "14895": "LAWSON-SOFTWARE - Lawson Software",
    "14896": "CSNOC - Computer Solutions",
    "14897": "PKS-INVESTMENTS - Purshe Kaplan Sterling Investments, Inc.",
    "14898": "ODINTERNET - Office Depot",
    "14899": "MOBILEXUSA - MobilexUSA",
    "14900": "FREECLEAR - Free & Clear, Inc.",
    "14901": "TAOSNET-NEWMEX - TAOS NET LLC",
    "14902": "-ACTIV - ACTIV Financial Systems, Inc.",
    "14903": "PILOT-CATTROPHE - Pilot Catastrophe Services, Inc.",
    "14904": "IBMCCH-RTP - IBM",
    "14905": "EMBARQ-CHVL - Embarq Corporation",
    "14906": "EMUSIC - eMusic.com Inc.",
    "14907": "WIKIMEDIA Wikimedia US network",
    "14908": "MAAXB - MAAX Bath Inc.",
    "14909": "PNG-TELECOM - PowerNet Global Communications",
    "14910": "EMBARQ-FTMY - Embarq Corporation",
    "14911": "TMG - Taylor Made Golf Company, Inc.",
    "14912": "IBMCCH-SBY - IBM",
    "14913": "MEDIA-NEWS-GROUP - MEDIA NEWS GROUP",
    "14914": "SYMBIOTIX-LEX - Symbiotix, Inc.",
    "14915": "FDBS-BCS - Financial Database Services",
    "14916": "SUNGARD - SunGard Availability Services",
    "14917": "FBS-NET - Future Business Solutions, Inc.",
    "14918": "UNISERVE-ET - Uniserve On Line",
    "14919": "NETLEDGER - NetLedger, Inc.",
    "14920": "BPOP - Banco Popular",
    "14921": "EMBARQ-HDRV - Embarq Corporation",
    "14922": "IPSOFT-US-N1 - IPsoft",
    "14923": "-COMNET-14923 - COMNET",
    "14924": "NAP-PAIX-VA1 - Merit Network Inc.",
    "14925": "DELTA - Delta Air Lines",
    "14926": "IBMCCH-MIL - IBM",
    "14927": "CREATIVELABS - Creative Labs, Inc.",
    "14928": "ADAMS-CATV - Adams CATV, Inc",
    "14929": "VITELITY - Vitelity, LLC",
    "14930": "ALLANT-GROUP - The Allant Group",
    "14931": "STA- - The St. Paul Travelers Companies, Inc.",
    "14932": "ISC - ISC",
    "14933": "LONDONCONNECT - London Hydro",
    "14934": "UNAVC- - UNAVCO",
    "14935": "MONTICELLO - Monticello Networks, Inc.",
    "14936": "CUP-WN - Cambridge University Press",
    "14937": "DOCUMENT-SYSTEMS - Document Systems, Inc.",
    "14938": "BET- - Bullseye Telecom",
    "14939": "THRES - THRESHOLD COMMUNICATIONS,INC.",
    "14940": "LIGO-ANYCTED-SERVICES - LIGO Livingston Observatory",
    "14941": "INTEGRATED-DOCUMENT-SOLUTIONS - Integrated Document Solutions",
    "14943": "CT-1 - EndPlay, Inc.",
    "14944": "SYNTA-PHARMACEUTICALS-CORP - Synta Pharmaceuticals Corp",
    "14945": "FMC-401NEWING-LOH - FAIRFIELD MEDICAL CENTER",
    "14946": "BMHCC - Baptist Memorial Health Care Corporation",
    "14947": "HIGHLINE- - Highline Capital Management, LLC",
    "14948": "IMS-HEALTH - IMS Health, Inc.",
    "14949": "VSATSYSTEMS-01 - VSAT-Systems, LLC",
    "14950": "LHM-GROUP - Larry H. Miller Management Company",
    "14951": "VMCNET - Vulcan Materials Company",
    "14952": "ACCENTURE - Accenture LLP",
    "14953": "CRYDON - Crydon Technology Corporation",
    "14954": "FHCRC - The Fred Hutchinson Cancer Research Center",
    "14955": "N-V-C - Northern Valley Communications LLC",
    "14956": "BROADVISION-N - Broadvision Inc.",
    "14957": "PREPA-UUNT1 - Puerto Rico Electric Power Authority",
    "14958": "NATIONS-KS - NATIONS HOLDING COMPANY",
    "14959": "MODISPRO - Adecco USA Inc",
    "14960": "TCABGP - TCA Services Corp.",
    "14961": "HYUNDAI-INFORMATION-SERVICE-NORTH-AMERICA - Kia Motors America, Inc.",
    "14962": "NCR-252 - NCR Corporation",
    "14963": "TECHOPS-N-1 - Live Nation Entertainment, Inc.",
    "14964": "AAPINT - Advance Auto Parts, Inc.",
    "14965": "FBRG - Friedman, Billings, Ramsey Group, Inc.",
    "14966": "Larrain Vial S.A",
    "14967": "NORTHMEMORIAL-HEALTHCARE-N - North Memorial Medical Center",
    "14968": "PMI - Public Mobile Incorporated",
    "14969": "JANESTREET JANESTREET",
    "14970": "CAMARA COLOMBIANA DE INFORMATICA YTELECOMUNICACION",
    "14971": "PINETEL - Pine Telephone System, Inc.",
    "14972": "BITPU- - BitPusher, LLC",
    "14973": "ATS-COR-01 - AmeriQuest Transportation Services",
    "14974": "VIRTUAL-INC - Virtual Inc.",
    "14975": "ABN-AMRO-BANK-NV-2 - ABN AMRO Bank N.V.",
    "14976": "SMART-CITY-DENVER - Smart City Networks, L.P.",
    "14977": "STATE-OF-WYOMING-N - State of Wyoming Department A&I",
    "14978": "CSSBB - Consolidated Smart Systems LLC",
    "14979": "AERONET-WIRELESS - Aeronet Wireless",
    "14980": "RTCOL - Rochester Telephone Company, Inc",
    "14981": "KIRKLAND-ELLIS - Kirkland & Ellis LLP",
    "14982": "DQ-N - Dynamic Quest, Inc.",
    "14983": "LSAC- - Law School Admission Council",
    "14984": "MERIT23 - Meriter Hospital, Inc.",
    "14985": "VEROXITY - Veroxity Technology Partners, Inc.",
    "14986": "ULTRAHOST - Ultra Hosting",
    "14987": "RETHEMHOSTING - Rethem Hosting LLC",
    "14988": "BTC-GATE1",
    "14989": "BROADVIEWNET - Broadview Networks, Inc.",
    "14990": "AVNET-NA - Avnet Inc.",
    "14991": "IL2K - ElkhartNet, Inc",
    "14992": "CRYSTALTECH - CrystalTech Web Hosting Inc.",
    "14993": "INTERCONSECURITY - Intercon Security, Ltd",
    "14994": "SOFTB-N - SOFTBANK INC.",
    "14995": "MERGY- - Masergy Communications",
    "14996": "EMS-N - EMS Capital LP",
    "14997": "FLAT- Placeholder",
    "14998": "TSI-GC-NETBLK-01 - TSI, Incorporated",
    "14999": "USERWORLD - Userworld, INC",
    "15000": "GLOBAL-RELAY - Global Relay Communications Inc.",
    "15001": "ITCONVERGENCE-COM - IT Convergence Inc.",
    "15002": "DRUGSTORE - Drugstore.Com, Inc.",
    "15003": "NOBIS-TECH - Nobis Technology Group, LLC",
    "15004": "GTELCO - Gunnison Telephone Company",
    "15005": "H9S-SDC - Hangar9 Solutions",
    "15006": "IBMCCH-STL - IBM",
    "15007": "TSUCHI - Tzu Chi Foundation",
    "15008": "AISG - AISG",
    "15010": "IT-DIMENSIONS - IT Dimensions, Inc.",
    "15011": "JAGUAR-1 - Jaguar Communications",
    "15012": "CRTCAPITAL-001 - CRT Capital Group LLC",
    "15013": "FUSS-ONEILL-TECH - Fuss & O'Neill Technologies, LLC",
    "15014": "TTS-N - Total Tool Supply, Inc.",
    "15015": "SECURITY-CONNECTIONS-INC - Security Connections, Inc.",
    "15016": "RBSLYNK-2 - WorldPay US, Inc.",
    "15017": "CAUTOCOM - CREATIVE AUTOMATION COMPANY",
    "15018": "SEYFARTH-SHAW9 - Seyfarth Shaw Investors, LLC",
    "15019": "ZAPPOS - Zappos.com, Inc.",
    "15020": "WSOL - WebSolutions Technology",
    "15021": "NOOSH - NOOSH, INC",
    "15022": "ADEPT-ZA",
    "15023": "LOTUS-CANTON - Lotus International Company",
    "15024": "PACKET-WORKS - Packetworks Inc.",
    "15025": "CTF - CTF HOLDINGS, INC (dba CTF HOTELS AND RESORTS)",
    "15026": "ACXIOM - Acxiom Corporation",
    "15027": "FOLEY-HOAG - Foley Hoag LLP",
    "15028": "PENTWATER-CAPITAL-MGMT - PENTWATER CAPITAL MANAGEMENT LLC",
    "15029": "TIC-USDHHS - U.S. Department of Health & Human Services",
    "15031": "MAGMA-15031 - Magma Communications Ltd.",
    "15032": "SXC-SCOTTSDALE - Systems Xcellence, Inc.",
    "15033": "XPRES-PDX - XPRESSBET INC.",
    "15034": "TIBA S.A.",
    "15035": "X2NSAT-SVN - IP Access International",
    "15036": "TOWN-OF-PINEVILLE - Town of Pineville",
    "15037": "VIRTELA-CUST-VVAVIE1-REDHAT Virtela Communications Proxy for Redhat",
    "15038": "CAMBINC-1 - Cambridge Incubator, Inc.",
    "15039": "MSCDIRECT-1 - MSC Industrial Supply Co.",
    "15040": "TANGO - TangoMe, Inc.",
    "15041": "ETRN-MKC - ETRN.com, Inc.",
    "15042": "URBN - Urban Communications, Inc.",
    "15043": "N2NET--15043 - New Age Consulting Service",
    "15044": "ECHO-GROUP- - Echo Online Internet Inc.",
    "15045": "KITTELSON - KITTELSON AND SOCIATES, INC.",
    "15046": "SU-COLO - Syracuse University",
    "15047": "CRABEL-CAPITAL-MANAGEMENT-LLC - Crabel Capital Management, LLC",
    "15048": "METLIFE-N - MetLife",
    "15049": "TOCO - Tompkins County",
    "15050": "RF-1 - The Rockefeller Foundation",
    "15051": "TEREX-CORPORATION - TEREX CORPORATION",
    "15052": "SMAQMD-1 - Sacramento Metropolitan Air Quality Management District",
    "15053": "ROLL-GLOBAL-LLC - Roll Global LLC",
    "15054": "NORTHET-TEX-BROADBAND-LLC - Northeast Texas Broadband, LLC",
    "15055": "YOURCOLO-N-1 - YourColo LLC",
    "15056": "XO-N9 - XO Communications",
    "15057": "XO-N6 - XO Communications",
    "15058": "XO-N8 - XO Communications",
    "15059": "BLOODSTOCK-RESEARCH - Bloodstock Research Information Services, Inc.",
    "15060": "XO-N7 - XO Communications",
    "15061": "ICBC-INET - Insurance Corporation of British Columbia",
    "15062": "MERIDIAN-BUSINESS-CENTERS - Meridian Business Centers",
    "15063": "PWEH-N - Pratt and Whitney",
    "15064": "Internet Argentina",
    "15065": "SLIC-COM-INTERNET - Slic Network Solutions, Inc",
    "15066": "SkyNet de Colombia S.A.",
    "15067": "TGN-1 - The Greenville News",
    "15068": "JDV N-JDV",
    "15069": "SBA - Smith Bucklin & Associates Inc",
    "15070": "THEFIND- - TheFind, Inc.",
    "15071": "BAX-BGP - BAX GLOBAL",
    "15072": "NETRIPLEX-CORPORATION - Netriplex Corporation",
    "15073": "CPS-197 - California Physicians' Service",
    "15074": "VIEWSONIC - Viewsonic Corporation",
    "15075": "Wireless Communications Panama",
    "15076": "LERWO34OS - Delgado Industries, LLC",
    "15077": "MAG-TEK - MAG-TEK, INC.",
    "15078": "Telelatina S.A.",
    "15079": "IONIC- - Ionic Capital Management LLC",
    "15080": "VIKINGGLOBAL - Viking Global Investors LP",
    "15081": "N-CROS-1 - Cros.net, Inc.",
    "15082": "VAZIONET - Vazio Network Services, LLC",
    "15083": "INFOLINK-MIA-US - Infolink",
    "15084": "CONVERGYS - Convergys Corp.",
    "15085": "IMMEDION - Immedion, LLC",
    "15086": "QVC - QVC, Inc.",
    "15087": "MEAGTELECOM - MEAG Telecom",
    "15088": "FNG-NET - First Network Group Inc",
    "15089": "MSMUTUAL - Massachusetts Mutual Life Insurance Company",
    "15090": "COMLINK-LLC - Comlink, LLC",
    "15091": "HCCL-5- - Shentel Service Company",
    "15092": "STAR2STAR - Star2Star Communications, LLC",
    "15093": "TMGC - Texas Mid-Gulf Cablevision, LP",
    "15094": "KNOW-TECHNOLOGY - Know Technology, LLC",
    "15095": "THINK-REALTIME - Think Realtime",
    "15096": "SONN - SONN",
    "15097": "WALLSTREETACCESS - Wall Street Access",
    "15098": "CAMBE-13 - Camber Capital Management LLC",
    "15099": "ELCOM - ELCOM.COM",
    "15100": "BEVCOMM-1 - Bevcomm",
    "15101": "CENTRAL1 - Central 1 Credit Union",
    "15102": "N-WIBAND-1 - WiBand Communications",
    "15104": "MBNA-NET-1 - Bank of America",
    "15105": "NETWORKTELEPHONE - Network Telephone Corporation",
    "15106": "LENNOX - Lennox International Inc.",
    "15107": "Grupo Financiero Bancomer",
    "15108": "ALLO-COMM - Allo Communications LLC",
    "15109": "VYNAMICS-SUNGARDDEN2 - CCD",
    "15110": "HILLS-CCC-INET - Hillsborough County -  Clerk of Circuit Court",
    "15111": "HERMANMILLER - Herman Miller, Inc.",
    "15112": "GATX-CORP - GATX Corporation",
    "15113": "AMX-LLC- - AMX, LLC.",
    "15114": "HOSTDEPOT-N - Host Depot, Inc.",
    "15116": "PITT-STATE - Pittsburg State University",
    "15117": "ANHEUSER-BUSCH - Anheuser-Busch Companies Inc.",
    "15118": "SIU-BB-2 - Southern Illinois University - School of Medicine",
    "15119": "SOUTHERN-ILLINOIS-UNIVERSITY - Southern Illinois University",
    "15120": "RHS- - Rockford Health System",
    "15121": "CALTEL-COM - Calaveras Internet Company",
    "15122": "PTPBROADBAND - Point to Point Broadband Inc.",
    "15123": "BCSEC - BRADLEY CENTER SPORTS & ENTERTAINMENT CORPORATION",
    "15124": "CHICAGONET-NET - Chicagonet",
    "15125": "BT LATAM PERU S.A.C.",
    "15126": "MC - American Suzuki Motor Corporation",
    "15127": "CHATHAM-INTERNET-ACCESS - Chatham Internet Access",
    "15128": "COMWAVE-BGP-01 - Comwave Telecom Inc.",
    "15129": "TRICOM-IL - TRI COM",
    "15130": "USDOJ-GOV - United States Department of Justice",
    "15131": "DATERV - DATERV",
    "15133": "EDGECT - EdgeCast Networks, Inc.",
    "15134": "EOS - Electronic Online Systems International",
    "15135": "EVERYDNS - EveryDNS, LLC",
    "15136": "-NSPOF - NSPOF Communications Inc",
    "15137": "JETPAY- - JetPay, LLC",
    "15138": "MOTOROLA-MOBILITY - Motorola Inc",
    "15139": "PANONIC - Panasonic Corporation of North America",
    "15140": "HAWKEYECOLLEGE - Hawkeye Community College",
    "15141": "N-BAUSCH-LOMB - Bausch & Lomb",
    "15142": "ADSNET-COM - Automated Data Systems, Inc",
    "15143": "GAINSCONUMBER - GAINSCO INC",
    "15144": "XYMMETRIX-XYMMETRIX-LLC - Xymmetrix, LLC",
    "15145": "GLOBALSCAPE - GlobalSCAPE, Inc.",
    "15146": "CABLEBAHAM - Cable Bahamas",
    "15147": "DHSINETNOC - DEPARTMENT OF HOMELAND SECURITY",
    "15148": "BLACKBAUD-N - Blackbaud, Inc.",
    "15149": "EZZI-101-BGP - Access Integrated Technologies, Inc.",
    "15150": "BELLTECH- - BELLWETHER TECHNOLOGY CORPORATION",
    "15151": "Center for Genetic Engineering andBiotechnology",
    "15152": "TELIPHONE - TELIPHONE INC.",
    "15153": "STARWIRELESS-15153 - Star Wireless, Inc.",
    "15154": "SBBSNET - Specialized Bulletin Board Systems",
    "15155": "INTELLIMARK - Intellimark, Inc.",
    "15156": "AT-GENOA - Wisconsin Internet, Inc.",
    "15157": "NORWORLD - NORTHWESTERN CORPORATION",
    "15158": "ALGOMA-UNIVERSITY-COLLEGE - Algoma University College",
    "15160": "BMO-SCARB - Bank of Montreal",
    "15161": "STRADLEY - Stradley Ronon Stevens & Young, LLP",
    "15162": "CRICKETCOMM - Cricket Communications Inc",
    "15163": "MTD - MTD Products, Inc",
    "15164": "UPNLLC - Unite Private Networks LLC.",
    "15165": "MTC-LRCOMMUNICATIONS - Mutual Telephone Company",
    "15166": "TCNJ - The College of New Jersey",
    "15167": "DPS-HAMMOND - Data Protection Services, LLC",
    "15168": "15168 - Media Breakaway, LLC",
    "15169": "GOOGLE - Google Inc.",
    "15170": "MATCHNET - Spark Networks Limited",
    "15171": "BLUEGRAVITY - Blue Gravity Communications, Inc.",
    "15172": "REINHARDT-WAL-1 - Reinhardt University",
    "15173": "NEWMA-11 - Newmarket Corporation",
    "15174": "ECHO-STREET - Echo Street Capital Management, LLC",
    "15175": "ACC-1 - Advanced Cabling and Communications",
    "15176": "-INOC - iNOC, Inc.",
    "15177": "STARTOUCH-WA1 - STARTOUCH INC",
    "15178": "XTIUMUSA-1 - Xtium LLC",
    "15179": "RIGHTNOW-TECHNOLOGIES RIGHTNOW TECHNOLOGIES (UK) LTD",
    "15180": "UOL DIVEO S.A.",
    "15181": "IMFT - IM Flash Technologies, LLC.",
    "15183": "QEPRESOURCES - QEP Resources, Inc.",
    "15184": "NRTC-ISP - NRTC",
    "15185": "HIBBERT-ET - The Hibbert Group",
    "15186": "FUTUREGRID - Indiana University",
    "15187": "MOTOROLA-MOBILITY - Motorola Inc",
    "15188": "K12ITC - k12 ITC, Inc.",
    "15189": "HOSTVENTURES - HostVentures.com, Inc.",
    "15190": "CTS-LANGUAGELINK - CTS LanguageLink",
    "15191": "WIN-NET - Western Independent Networks, Inc.",
    "15192": "SA-TX-NET01 - Software Advice, Inc.",
    "15193": "BLUEFLY-1 - Bluefly, Inc.",
    "15194": "CSE- - Commission Scolaire de l'Estuaire",
    "15196": "MDDOT - Maryland Department of Transportation",
    "15197": "CONCORD - Concord Technologies",
    "15198": "CCPI---SITE-1 - Convention Communications Provisioners, Inc.",
    "15199": "WWU - Western Washington University",
    "15200": "HSETT - Hassett Storage Warehouses Inc.",
    "15201": "Universo Online S.A.",
    "15202": "GELLER - Geller & Company LLC",
    "15204": "SI-DAL-N - Security Inspection, Inc.",
    "15206": "MDSG-PACWEST - Pac-West Telecomm, INC.",
    "15208": "Servicio de Impuestos Internos",
    "15209": "COMMVAULT - CommVault Systems",
    "15210": "NNEX-N - Northern Net Exposure",
    "15211": "SQUARE - Square, Inc.",
    "15212": "19061 - Cellular South",
    "15213": "THIGNET - Tower Hill Insurance Group",
    "15214": "MERCURY-INTERACTIVE - Mercury Interactive Inc.",
    "15215": "FARMERS-NETWORK - Farmers Group, Inc.",
    "15216": "15216 Hostway Corporation Europe",
    "15217": "LOUDCLOUD00 EDS Automated Operations/Loudcloud",
    "15218": "N-CXA-OK-15218-CBS - Cox Communications Inc.",
    "15219": "-15219 - ANPI, LLC",
    "15220": "RCG - Rosenthal Collins Group LLC",
    "15221": "FALCON-BB - Vanion, Inc.",
    "15222": "GAROFALO-ET-AL - Garofalo, Schreiber, Hart & Storm Chartered",
    "15223": "TXWES - Texas Wesleyan University",
    "15224": "OMNITURE ====",
    "15225": "PERSECO - Perseco",
    "15226": "CARPATHIA-N Carpathia Hosting, Dulles",
    "15227": "LUMOS - LUMOS Networks, Inc.",
    "15228": "ZONETEL-IP - ZONE TELECOM, INC.",
    "15229": "EDFTNA - EDF Trading North America, LLC",
    "15230": "CURVESINTERNAITONAL - Curves",
    "15231": "STARNOVA-LLC - Starnova LLC",
    "15232": "RODGERSBUILDERS - Rodgers Builders",
    "15233": "WEBDOTCOM-WEBSITEPROS - Website Pros",
    "15234": "MCGENERGY - MCG Energy Solutions LLC",
    "15235": "OLD-MOUNTAIN-CO - The Old Mountain Company Inc.",
    "15236": "Universidad de Colima",
    "15237": "WIDEN - WIDEN ENTERPRISES, INC.",
    "15238": "GATESFOUNDATION - Bill & Melinda Gates Foundation",
    "15239": "CIBER-TELEHOUSE-NET - CIBER INC.",
    "15240": "NO - ACS, Inc (Government Solutions Group)",
    "15241": "Unete de Panama",
    "15242": "NEXTWAVE-CA1 - Nextwave Telecom Inc.",
    "15243": "WIDENER - Widener University",
    "15244": "ADDD2NET-COM-INC-DBA-LUNARPAGES - Lunar Pages",
    "15245": "HARTE-HANKS-15245 - Harte-Hanks Inc.",
    "15247": "RADIANT-VANCOUVER - Radiant Communications Ltd.",
    "15248": "METWITCH-1 Metaswitch Networks",
    "15249": "P-S-B - Presidential Savings Bank, FSB",
    "15250": "USFAMILY-N - USFamily.net",
    "15251": "GRAND-CENTRAL-STATION - Grand Central Station Internet Services, Inc.",
    "15252": "ESCAPE INTERNET PROVIDER S.R.L.",
    "15253": "KNRY-11357 - Kinray, Inc.",
    "15254": "ACCUBID - Accubid Systems",
    "15255": "BISK - Bisk - Totaltape Publishing",
    "15256": "Itau Unibanco S.A.",
    "15257": "NBT-LABS - NBT Labs, LLC",
    "15258": "GBCO - Gilbane Building Company",
    "15259": "ATT-ITSNCS-1 - AT&T Solutions ITS/NCS",
    "15260": "BVIG - Buena Vista Internet Group",
    "15261": "ZT - Zellius Telecommunications Inc.",
    "15262": "TSYS-COLUMBUS-OC3-INTERNET - TSYS",
    "15263": "GALLUP1 - Gallup",
    "15264": "RA1900 - Muehlstein Administrative Services, LLC",
    "15265": "PREVARE-LLC-BEVERLY-MA - Prevare LLC",
    "15266": "THRU - AdJuggler, Inc.",
    "15267": "702COM - 702 Communications",
    "15268": "MDARCHIVES - Maryland State Archives",
    "15269": "PAI- - ConocoPhillips Company",
    "15270": "-PAETEC-NET - PaeTec Communications, Inc.",
    "15271": "FHS-INC-ENT-NET - HEALTH NET INC",
    "15272": "ONLYLINK - Onlylink.com/First Internet Worldwide",
    "15273": "KDDIA-USPEN - KDDI America Inc.",
    "15274": "House Internet S.R.L.",
    "15275": "GREENFIELDNET-WLT-CT - TOLUNA USA Inc.",
    "15276": "SKYBOXIMAGING - Skybox Imaging, Inc.",
    "15277": "HILLINTL-USMRL1 - Hill International, Inc.",
    "15278": "SAVVY-NET - Savvy Networks USA",
    "15279": "PHHMORT- - PHH Mortgage Corporation",
    "15280": "ABMC - Alta Bates Summit Medical Center",
    "15281": "NGCPUB - National Gypsum Company",
    "15282": "COMMTOUCH-INC-2 - Commtouch Inc.",
    "15283": "VIAGENIE-IPV6 - ViaGenie Inc.",
    "15284": "ALLIANZ-OF-AMERICA-INC - Allianz of America, Inc.",
    "15285": "SRLCD - Cash Depot",
    "15286": "SIG-N1 - Senator Investment Group, LP",
    "15287": "BLINK- - RCP",
    "15288": "ALCATEL-NA - Alcanet International NA",
    "15290": "ALLST-15290 - Allstream Corp.",
    "15291": "POLAROID - Polaroid Corporation",
    "15293": "N-ISS-ATL Internet Security Systems",
    "15294": "SENTINELTECH - Sentinel Technologies, Inc.",
    "15295": "UNC-1388600-N - University of Northern Colorado",
    "15296": "NETERA - Cybera Inc",
    "15297": "EPLUS-N - EPLUS, Inc.",
    "15298": "LSB-INDUSTRIES-INC - LSB Industries, Inc.",
    "15299": "CFS-01 - CarsForSale.com",
    "15300": "4IMPRINT - 4imprint",
    "15301": "IOVATION - iovation, Inc.",
    "15303": "NIKE-SECURITIES - First Trust Portfolios L.P.",
    "15304": "WHOE-NET - Washoe County",
    "15305": "SYRINGANETWORKS - Syringa Networks, LLC",
    "15306": "SELLS - Ripon Printers",
    "15307": "CHILDRENS-SEATTLE - Childrens Hospital and Regional Medical Center",
    "15308": "B-A-C-S - Verizon Data Services LLC",
    "15309": "MBAEA- - Mississippi Bend Area Education Agency",
    "15310": "PRNCO-1 - PRN Corporation",
    "15311": "Telefonica Empresas",
    "15312": "HARBINGERGROUP - Harbinger Group Inc.",
    "15313": "PMTL-1 - Pembroke Telephone Company, Inc.",
    "15314": "JENZABAR-N1 - jenzabar  inc",
    "15315": "IVANET-CAMBRIDGE-1 - IBIS INC.",
    "15316": "IVANET-VANCOUVER - IBIS INC.",
    "15317": "UCN-INTERNET-USA-1 - Universal Communications Network Inc.",
    "15318": "MCGILL- - McGill University",
    "15319": "NUCOR-IT - NUCOR IT SOLUTIONS, LLC",
    "15320": "PRIMELINK - PRIMELINK INC",
    "15321": "GROUPE-MKATEL-LP - Groupe Maskatel",
    "15322": "WDNCOM-N - WDN Communications S.A.",
    "15323": "BSD405 - Bellevue School District #405",
    "15324": "BARRACUDA-NETWORKS-INC - Barracuda Networks, Inc.",
    "15325": "CRVDNS - CRVDNS, Inc",
    "15326": "BINARYBROADBAND - BINARY BROADBAND",
    "15327": "EFI-PGH- - Electronics for Imaging, Inc.",
    "15328": "DATAPRISE-INC - Dataprise, Inc.",
    "15329": "CUSTOMEDGE - Custom Edge Incorporated",
    "15330": "WEB-COM-N2 - Web.com, Inc.",
    "15331": "BTC-MT-N - Blackfoot Telephone Cooperative, Inc.",
    "15332": "VIND--1-VINDICIA-INC - Vindicia, Inc.",
    "15333": "MIDMS-H - MPAY, Inc. d/b/a MPAY Software",
    "15334": "RESPONSYS - Responsys Inc.",
    "15335": "KAPLAN-TELEPHONE - KAPLAN TELEPHONE COMPANY, INC.",
    "15336": "CONCOR-1 - Concordia University, St. Paul",
    "15337": "WRHARPER - Wm. Rainey Harper College",
    "15338": "BOSTON - Boston Herald",
    "15339": "DRILLINGINFO - Drilling Info, Inc.",
    "15340": "CVI-BORDER-1 - Community Vision, Inc.",
    "15341": "ALLEGHENYINTEL - Atlantic Broadband Finance, LLC",
    "15342": "DDPMI-1 - DELTA DENTAL PLAN OF MICHIGAN",
    "15343": "AM-EX - AMERIPRISE FINANCIAL SERVICES, INC.",
    "15344": "KARIB-CABLE-KELCOM-INTERNATIONAL - Karib Cable",
    "15345": "EBUDDY1 - eBuddy B.V.",
    "15346": "ODC-ACU-COMP - On Deck Capital, Inc.",
    "15348": "TUCOWS - Tucows.com Co.",
    "15349": "GUGGE-NJDC - Guggenheim Services LLC",
    "15350": "ALGN-N-001 - Algona Municipal Utilities",
    "15351": "VISPERAD-NETWORKS-LLC - VISPERAD NETWORKS, LLC",
    "15352": "TCCC - The Coca-Cola Company",
    "15353": "SIKICH-HOSTING - Sikich LLP",
    "15354": "-BML01 - Bingham McCutchen",
    "15356": "THEBANCORP - Thebancorp.com",
    "15357": "NNC- - Northern Networking Company",
    "15358": "JONESINTERACTIVE - Jones Interactive/JES",
    "15359": "DATTO-DLT - Datto, Inc",
    "15360": "INTERFREE-NET CDC Point SpA",
    "15361": "Union Bancaire Privee",
    "15362": "RISKENGINEERING Risk Engineering Ltd.",
    "15363": "INFOSCORE arvato infoscore GmbH",
    "15364": "N-TECAVIC TECAVIC S.L.",
    "15366": "DNSNET DNS:NET Internet Service GmbH",
    "15368": "INTARES Intares",
    "15369": "Financial Company",
    "15370": "MFISOFT- MFI Soft LLC",
    "15372": "IBH- IBH IT-Service GmbH",
    "15373": "CZESTMAN- Academic  dedicated to Metropolitan Area Network CzestMAN",
    "15375": "DKB Commerzbank Aktiengesellschaft",
    "15376": "DKB Commerzbank Aktiengesellschaft",
    "15377": "FREGAT- ISP \"Fregat\" Ltd.",
    "15378": "DI-EX- UTel",
    "15379": "FLEXIANT- Flexiant Ltd",
    "15380": "ANSCZ Air Navigation Services of the Czech Republic, state enterprise",
    "15383": "CIRB-CIBG Autonomous System",
    "15384": "CD Contact Direct Sp. z o.o.",
    "15385": "CLARANET- Clara.net  Germany",
    "15386": "N-HEALTH Municipal government of health (GUZO)",
    "15388": "OMC- OMCnet Internet Service GmbH",
    "15389": "FAROESE-TELECOM- FO-FOTELECOM-990315 Autonomous system",
    "15390": "SELCUK-NET- Selcuk Universitesi",
    "15391": "ENABLE SA Autonomous system",
    "15392": "ELVIM- Elvim SIA",
    "15393": "MOJNET Moj.Net - Sinfonika d.d.",
    "15395": "Rackspace Ltd.",
    "15396": "ICM-COM University of Warsaw",
    "15397": "TELENORMONTENEGRO Telenor Montenegro",
    "15398": "CYBERCORE- Werft22 AG",
    "15399": "WANANCHI-KE",
    "15400": "MATCO SC Matco Serv 2000 SRL",
    "15401": "EOL- Business & Decision Interactive Eolas",
    "15402": "ONE TEL",
    "15403": "EXTERNALL EXTERNALL SA Paris, France",
    "15404": "COLT Technology Services Group Limited",
    "15405": "ETCORK- \"Malcolm Stead T/A East Cork Broadband\"",
    "15406": "Fatih Universitesi",
    "15407": "SOFTNET Softnet Business Services SRL",
    "15410": "BT Limited Hungarian Branch Office 1",
    "15411": "DANISCO Danisco A/S Enterprise network Copenhagen , Denmark",
    "15412": "FLAG- Flag Telecom Global Internet",
    "15414": "FLHMM DB-DATABANK",
    "15415": "OBIS Oberberg-Online Informationssysteme GmbH",
    "15416": "Donbass State Academy of Civil Engineering and Architecture",
    "15417": "KBIMPULS Autonomous System",
    "15418": "FTHOSTS-INTERNET Fasthosts Internet Ltd. Gloucester, UK.",
    "15419": "LRTC- SC \"LRTC\" Internet services",
    "15420": "Lloyds TSB Bank plc, London",
    "15421": "Internap European Autonomous System",
    "15422": "PPR-15422 PPR SA",
    "15423": "MAERSK A.P. MOLLER - MAERSK A/S",
    "15424": "SAUNALAHTI-GSM Elisa Oyj",
    "15425": "COMA  for Coma s.r.o.",
    "15426": "XENOSITE XenoSite B.V.",
    "15427": "EDVG- Elektronische Datenverarbeitung GmbH",
    "15428": "DAGNET- Regional Public Organization, \"Dagestan computers networks Dagnet\"",
    "15429": "15429 DIGEX UK",
    "15430": "European Dynamics S.A.",
    "15431": "15431 Daisy Communications Ltd",
    "15432": "HIPERTNET Autonomous System Technopark Zuerich, CH",
    "15433": "TISM Telecom Italia San Marino high speed Internet connection.",
    "15434": "BARTELS- mvox AG",
    "15435": "KABELFOON CAIW Diensten B.V.",
    "15436": "WITBE- WITBE NET S.A.",
    "15437": "N-KJWS K.J.W.S. S.r.l.",
    "15438": "ince Technology",
    "15439": "Bank EFG Eurobank Ergasias SA",
    "15440": "15440 Baltnetos Komunikacijos Autonomous System",
    "15442": "PG-EUROPE Procter & Gamble Service GmbH",
    "15443": "Presspublica Sp.z.o.o.",
    "15444": "NETSERVICES NetServices UK Limited",
    "15445": "ICQ- AOL LLC",
    "15446": "XCOMAGNET XCOM AG",
    "15447": "CM_NL ClubMessage B.V.",
    "15448": "Ukrainian Civil Aviation Computer Centre Network",
    "15450": "Alhambra Systems SA",
    "15451": "DATEV eG",
    "15453": "Pesaro Point Autonomous System",
    "15454": "ARBUZ- ARBUZ Co.Ltd",
    "15455": "EMBANK- Energomashbank",
    "15456": "INTERNETX- InterNetX GmbH",
    "15457": "CABOTVM.PT Autonomous System",
    "15458": "TLC TriLogiC Group, Ltd.",
    "15459": "ArtNew Media Autonomous system",
    "15460": "TURKIYE HALKBANKI A.S.",
    "15461": "SOLVERNET- Science Production Enterprise Solver Ltd",
    "15462": "CNET Europe S.A.",
    "15463": "NETWORKI- Network-i Limited",
    "15464": "IHLNET Ihlas Net A.S.",
    "15465": "SIEMENSDE Siemens AG",
    "15466": "N-DTO Ivent Autonomous System",
    "15467": "ENTERNET-LIBERCOM- Enternet 2001 Ltd., Hungary",
    "15468": "KLGELECS- OJSC Rostelecom",
    "15469": "WARINET_NETWORK Warinet Global Services SA",
    "15470": "HYPERION-KIELCE- Hyperion S.A.",
    "15471": "SNR-RO S.N. Radiocomunicatii S.A.",
    "15472": "N-NEWSOFT TERRALINK - Internet Tecnology Company",
    "15473": "PIS BANK ATE",
    "15474": "RHNET SURIS/RHnet",
    "15475": "NOL",
    "15477": "HIGHWAYONEDE Telefonica Germany GmbH & Co.OHG",
    "15479": "FIBRELAC Fibre Lac SA, Switzerland",
    "15480": "VFNL- Vodafone NL Autonomous System",
    "15482": "Easynet Global Services Limited",
    "15485": "GTSNOVERA GTS NOVERA a.s.",
    "15486": "MATERNA- Materna GmbH Information & Communications",
    "15488": "UPV-EHU Universidad del Pais Vasco - Euskal Herriko Unibertsitatea",
    "15489": "ARTFUL- Claranet France",
    "15491": "SILKNET JSC \"Silknet\"",
    "15492": "prego servieces GmbH Autonomous System Number",
    "15493": "RUSCOMP- Closed Joint Stock Company \"Russian company\"",
    "15494": "BT Limited",
    "15495": "BF-IT-SERVICES BF IT Services Holding GmbH",
    "15496": "Aalto University",
    "15497": "COLOCALL Internet Data Center \"ColoCALL\"",
    "15498": "ATUSMEDIA CPSNET Internet Providing",
    "15499": "GECITS-EU Computacenter AG & Co. oHG",
    "15500": "OJSC Rostelecom",
    "15501": "PHNET DNA Oy",
    "15502": "VODAFONE-IRELAND-N Vodafone Ireland",
    "15503": "MULTINET-SA SwiatInternet",
    "15504": "TRADENETWORKS Trade Networks - Developments Services (2007) Ltd",
    "15505": "KAU King Abdulaziz University (KAU) - Deanship of Information Technology",
    "15506": "TODO todo GmbH",
    "15507": "IT3GNS- 3G Network Services sp. z o.o.",
    "15508": "NOVOSOFT- Novosoft Ltd.",
    "15509": "PLANT Plant Holding GMBH",
    "15510": "CWCS-PS Compuweb Communications Services Limited",
    "15511": "of Voyager.Com",
    "15512": "MISTRAL UPC Ceska Republica, s.r.o.",
    "15513": "RTC-CH RTC Real Time-Center AG",
    "15514": "N-TELEACTION  # -TELEACTION CONVERTED TO N-TELEACTION FOR RPSL COMPLIANCE Teleaction Software GmbH, Oberursel",
    "15515": "UNICREDIT--VR-IT UniCredit Business Integrated Solutions S.C.p.A.",
    "15516": "DK-ARROWHEAD Arrowhead A/S",
    "15517": "NETSTREAM-CH Netstream AG",
    "15518": "CIRC- circular Informationssysteme GmbH",
    "15519": "IW-NET- Venda Limited",
    "15520": "N-TELEEST TELEEST SRL",
    "15521": "MEDIATEL-WORLD- Elterix S.A.",
    "15522": "ROUNDABOUT Roundabout Network",
    "15524": "MEDTELECOM- MED TELECOM Autonomous System",
    "15525": "PTPRIMENET PT Comunicacoes S.A.",
    "15526": "INTERWISE- Interwise Ltd",
    "15527": "ANVIA Anvia Oyj",
    "15529": "SGS-BP- SOCIETA' GESTIONE SERVIZI BP S.P.A.",
    "15531": "CET-NET CET Teleport GmbH",
    "15532": "Raiffeisen Schweiz Genossenschaft",
    "15533": "SEUROPE SunGard Availability Services (UK) Ltd",
    "15534": "DATAMAXBG Datamax AD",
    "15535": "VIRTUALXS- VirtualXS Internet BV, The Netherlands",
    "15536": "CEDEFOP- European Centre for the Development of Vocational Training (CEDEFOP)",
    "15537": "PL-NET Sp. z o.o.",
    "15539": "BATELCO-CORE-IP-NETWORK Bahrain Telecommunication Company",
    "15540": "GED-DE- operational services GmbH & Co. KG",
    "15541": "CETI- CETI s.c.",
    "15542": "ZEELANDNET ZeelandNet BV",
    "15543": "ODDO- ODDO ET CIE SCA",
    "15544": "DATAWAYS-GR Dataways Hellas A.E.",
    "15545": "MT- Magyar Telekom plc.",
    "15547": "NETPLUS netplus.ch SA",
    "15548": "CCR- CAJ RURALES UNID, SOCIEDAD COOPERATIVA DE CREDITO",
    "15549": "National information technologies JSC",
    "15550": "Hessische Elektrizitaets AG",
    "15552": "SANI-C- Co. Ltd. SaNi-C",
    "15553": "CERVED- CERVED GROUP S.p.A.",
    "15554": "15554 Hutchison Drei Austria GmbH",
    "15555": "MT-DC- Magyar Telekom plc.",
    "15556": "ABSSYS Autonomous system",
    "15557": "LDCOMNET Societe Francaise du Radiotelephone S.A",
    "15558": "TIMEWARP- Timewarp UK ISP",
    "15559": "ENERGOPOLIS- JSC Intouch Insurance",
    "15562": "SNIJDERS Job Snijders",
    "15563": "MERITUM- Meritum Bank ICB S.A.",
    "15565": "Easynet Global Services Limited",
    "15566": "Infotechna Ltd",
    "15568": "EBRD European Bank for Reconstruction and Development",
    "15570": "Internap European Autonomous System",
    "15572": "CYBERTRUST Verizon UK Limited",
    "15573": "Sierre Energie Autonomous System",
    "15575": "FREITAG- Freitag lab. AG",
    "15576": "NTS NTS workspace AG",
    "15577": "RDR- JV Renaissance-DR Ltd.",
    "15580": "Allianz Managed Operations & Services SE",
    "15581": "DBPB Services SA",
    "15582": "AKADO-STOLITSA- \"AKADO-Stolitsa\" JSC",
    "15583": "Getronics Belgium NV/SA (G-NET) Autonomous System Number",
    "15584": "SIAG SIAG Autonomous System",
    "15585": "BEWAN- Finanzdirektion Kanton Bern",
    "15586": "GEKKONNET Gecko Company",
    "15587": "CDPP Netia SA",
    "15588": "GLBUZ GLOBALNET LTD",
    "15589": "N-CLOUDITALIA CLOUDITALIA TELECOMUNICAZIONI S.P.A.",
    "15590": "FIDUCIA FIDUCIA IT AG",
    "15591": "Rational Software Europe",
    "15592": "GNISIM-N Banca Sella S.p.A.",
    "15593": "FinFin Autonomous system",
    "15594": "NETZQUADRAT netzquadrat GmbH",
    "15595": "SKYLINE- Skyline Electronics Ltd.",
    "15596": "INTERLINK TOV Company Interlink",
    "15597": "TANGRAM-CA-INC Tangram Canada Inc",
    "15598": "QSC-AG-IPX QSC AG",
    "15599": "ROILCOM-NB ROILCOM LTD",
    "15600": "FINECOM Finecom Telecommunications AG",
    "15601": "Baring asset Management 155 Bishopsgate London UK",
    "15604": "MILLENNIUM BANK SA",
    "15605": "ICTVALLEUMBRA- ICT Valle Umbra s.r.l.",
    "15606": "NK-TRANSIT NAUKOWA I AKADEMICKA SIEC KOMPUTEROWA INSTYTUT BADAWCZY",
    "15607": "BANCA CARIGE S.p.A.",
    "15608": "Banco Inversis S.A.",
    "15610": "SMR-C-IX Kraft-s jsc.",
    "15611": "IROST- Iranian Research Organization for Science & Technology",
    "15612": "SERVECENTRIC ServeCentric Ltd.",
    "15613": "COLOGNE-FRANKFURT Interactive Data Managed Solutions AG",
    "15614": "DRAGON Dragon Internet a.s.",
    "15615": "INEC",
    "15616": "ES-IBERCOMTELECOM-BACKBONE Ibercom Telecom S.A.",
    "15617": "WIND-HELL WIND HELL TELECOMMUNICATIONS SA",
    "15618": "PLIVA- PLIVA Krakow Zaklady Farmaceutyczne S.A.",
    "15619": "RAFO- RAFO S.A.",
    "15620": "INTBEL Autonomous System",
    "15621": "ADANET- Azerbaijan Data Network",
    "15623": "CYBERLINK Cyberlink AG",
    "15624": "OKITECH Okitech Krzysztof Kusnierczyk",
    "15625": "ING- ING Bank N.V.",
    "15626": "ITL ITL Company",
    "15628": "DVG Sparkasseninformatik Baden-Wuerttemberg GmbH & Co. KG",
    "15629": "CSNSYSTEMS csn.Systems Informatics Ltd.",
    "15630": "UNED Universidad Nacional de Educacion a Distancia - UNED",
    "15631": "Euronet Spain",
    "15632": "ALFA-BANK- Alfa-Bank Moscow Russia",
    "15633": "UOC- UOC is a virtual University based in Barcelona (ES).",
    "15635": "YAHOO-UKL Yahoo! Europe",
    "15636": "COLLINGWOOD Collingwood Business Solutions Limited",
    "15637": "Euro909",
    "15638": "UTL Ussuri-Teleservice Ltd. Ussuriysk",
    "15639": "uk.diexnet  for London UK",
    "15640": "FPIC- CJSC \"COMSTAR-regions\"",
    "15641": "ARQIVA Arqiva Communications Ltd",
    "15642": "GURAL INTERNET VE BILGISAYAR HIZMETLERI TOPRAK SANAYI VE TICARET ANONIM SIRKETI",
    "15643": "ITONLINE IT Online LTD",
    "15644": "FRESENIUS Fresenius SE & Co. KGaA",
    "15645": "15645 Ukrainian National Internet Exchange Autonomous System",
    "15646": "ING Belgique SA",
    "15647": "BANIFSERV Banif - Banco International Do Funchal S.A.",
    "15652": "_HOSTLAB HOSTLAB Turkiewicz i Wspolnicy Spolka Jawna",
    "15653": "NETSUMO NetSumo  Number",
    "15654": "COMINO Civica UK Ltd.",
    "15655": "ONLAW MANZ Solutions GmbH",
    "15656": "ANET Nano Iletisim Bilisim Hizmetleri Teknoloji Sistemleri Sanayi ve Ticaret Ltd Sirketi",
    "15657": "SPEEDBONE- Speedbone Internet & Connectivity GmbH",
    "15658": "INETCOMM- Digit One LLC",
    "15659": "NEXTGENTEL NEXTGENTEL Autonomous System",
    "15660": "FINDOMESTIC- Findomestic Banca S.p.A.",
    "15661": "Bank J. Safra Sarasin AG",
    "15663": "UMBRIA_NET Umbrianet srl Internet Service Provider",
    "15664": "SI-BUSINESS Business Solutions d.o.o.",
    "15665": "WOLA- Instytut Geofizyki PAN",
    "15666": "LAIKI  of Popular Bank of Cyprus",
    "15667": "NET2PHONE- IDT Corporation",
    "15668": "CEDACRIOVEST",
    "15669": "BIX-BG Bulgarian Internet eXchange (BIX.BG ltd.)",
    "15670": "BBNED- #1 Tele 2 Nederland B.V.",
    "15672": "TZTELECOM OOO Telecom TZ",
    "15673": "TELESETI-PLUS- Teleseti Plus Ltd.",
    "15674": "SMARTJOG S",
    "15675": "ETAT-DE-VAUD Etat de Vaud",
    "15676": "VOXEO-UK Voxeo Europe Limited",
    "15677": "MBA Systems Ltd",
    "15679": "CIS Information Technology Authority",
    "15681": "GAZDEFRANCE Gaz de France",
    "15682": "ITERANET- ITERANET Autonomous System",
    "15683": "DOMHKA- Domashnya Merezha LLC",
    "15684": "OptiCom",
    "15685": "CABLANCA- Casablanca INT Autonomous system",
    "15686": "ADAMNETN Adamnet Israeli ISP",
    "15687": "15687 NNIT A/S",
    "15688": "EVRY",
    "15689": "NUM-ORG-AISN1-RIPE Advanced IT Services Nottingham LTD",
    "15690": "NOANET National Observatory of Athens",
    "15691": "LEONET--IT Leonet srl",
    "15692": "RAZORBLUE Razorblue Ltd",
    "15693": "BUSINESSCONNECT BusinessConnect B.V.",
    "15694": "ATMAN-ISP- ATM S.A.",
    "15695": "EXPEREO Global  ExpereoInternational",
    "15696": "ARIAN- Communication and information technology network Arian Rasaneh Pars \"Ltd.\"",
    "15697": "BT-BS BT Ignite Intercontinental Satellite Video Streaming",
    "15698": "EnBW Systeme Infrastruktur Support GmbH",
    "15699": "_ADAM OGIC Informatica S.L. - ADAM Internet",
    "15700": "SPK- Capital Markets Board of Turkey",
    "15701": "Czech Airlines",
    "15702": "ONSTAGENET Onstage-Online",
    "15703": "TRUESERVER- TrueServer BV  number",
    "15704": "15704 Xtra Telecom, S.L.",
    "15705": "MAXDATA-DE MAXDATA IT-Services",
    "15706": "Sudatel",
    "15707": "INGOSSTRAKH- Open Joint Stock Compay INGOSSTRAKH Insurance Company",
    "15708": "ALADDIN- Safenet Data Security (Israel) Ltd",
    "15709": "15709 Vodafone D2 GmbH",
    "15711": "IBERDROLA Autonomo System of Iberdrola Company",
    "15713": "GCN-UA LLC Global-City-Net",
    "15714": "N-WORKUP WorkUp Srl",
    "15715": "EDSPA- HP Enterprise Services  for SPC Project",
    "15716": "SYGROUP Adfinis SyGroup AG",
    "15717": "VERSATEL-VPN Versatel Deutschland GmbH",
    "15718": "Evesto AG",
    "15719": "BUPA",
    "15720": "Postecom s.p.a. Autonomous System",
    "15721": "CTCO C.T.CO. Ltd Autonomous System",
    "15722": "MKDESIGN- MKdesign e.K.",
    "15723": "AZERONLINE Azeronline Information Services",
    "15724": "Cofunds Ltd",
    "15725": "IKS IKS Service GmbH",
    "15726": "MARCANT- Marcant Internet Services GmbH",
    "15727": "KEME-IPSWICH KeConnect Ipswich legacy",
    "15728": "RMF-KRAKOW-PL Radio Muzyka Fakty Sp. z o.o.",
    "15730": "I-SERVICES-PROVIDER I-Services Provider SRL",
    "15731": "BELCOM BELCOM- JSC \"BelcomRus\"",
    "15732": "IBERBANDA-SPAIN Iberbanda  for Spanish operations",
    "15733": "ZUMTOBEL- Zumtobel AG",
    "15734": "IDH Telvent Global Services S.A.",
    "15735": "DATTREAM-NET GO p.l.c.",
    "15736": "ARNA- JSC \"Arna\"",
    "15738": "UAEXPRESS TOV BF Express Ltd",
    "15740": "ABN AMRO Bank N.V.",
    "15741": "NETEXPILINE Expiline Ltd.",
    "15742": "PRIVATONLINE P Privat Online",
    "15743": "NETDE net.de AG",
    "15744": "SILWEB--COM Silesian University of Technology, Computer Centre",
    "15746": "N-MERCURIO72 IL SENTIERO SERVIZI SOC.COOP. A R.L.",
    "15747": "OSNATEL EWE TEL GmbH",
    "15751": "METEORMOBILECOMMS- Meteor Mobile Communication Ireland",
    "15752": "BP-US-1 BP International Ltd",
    "15753": "BP-US-2 BP International Ltd",
    "15754": "DOL-DIGITAL DOL Digital Autonomous System",
    "15755": "ISPRONET ISPRO Autonomous System Izmir,TURKEY",
    "15756": "CARAVAN CJSC Caravan-Telecom",
    "15757": "GCOM-NET Open Joint Stock Company Gazprom Space Systems",
    "15759": "DIN- OJSC Rostelecom",
    "15760": "Intel IIMS Europe Autonomous System",
    "15762": "CREDIT-COOP- Credit Cooperatif",
    "15763": "DOKOM DOKOM Gesellschaft fuer Telekommunikation mbH",
    "15764": "PEGUS Pegasus Interactive SA",
    "15765": "MIMER Tafjord Marked",
    "15766": "DOMICILIUM- Domicilium (IOM) Limited",
    "15767": "ABANKA- Abanka Vipa d.d.",
    "15768": "WORLDPAY WorldPay (UK) Limited",
    "15769": "Deutsche Bank AG",
    "15770": "DERWENTSIDE Derwentside District Council",
    "15772": "WNET LLC \"WNET UKRAINE\"",
    "15773": "INCLARITY Inclarity plc",
    "15774": "TTK-RTL Closed Joint Stock Company TransTeleCom",
    "15775": "LDZ- Latvijas Dzelzcels",
    "15776": "International Business Machines of Belgium Ltd",
    "15777": "LINIA- LINIA Autonomous System",
    "15778": "Ofin Signal",
    "15779": "SYSKOPLAN Reply Deutschland AG",
    "15780": "eurostream",
    "15781": "VM- VMedia LTD",
    "15782": "PERSPEKTIV- Perspektiv Bredband AB",
    "15783": "SUNSITE The Archive - SunSITE Northern Europe - sunsite.org.uk",
    "15785": "TELEPORTSV PrivateJSC DataGroup",
    "15787": "MAGO- PAGI S.A. Powszechna Agencja Informacyjna",
    "15788": "EFLUXA Fullsix spa",
    "15790": "FINANZINFORMATIK--OST Finanz Informatik GmbH & Co. KG",
    "15791": "15791 The BtoB Company GmbH",
    "15792": "CELIK-NET  NUMBER",
    "15793": "Donator main networks. Located in Gothenburg, Sweden",
    "15795": "PROXYS AUTONOMOUS SYSTEM",
    "15796": "ORANGE-CH-AUTONOMOUS-SYSTEM Orange Communication SA",
    "15797": "ERICSSON-TURKEY Ericsson Telekomunikasyon Anonim Sirketi",
    "15798": "OLMAN-EDU- OLMAN, Metropolitan Area Network (educational )",
    "15799": "BF BF IT Services Holding GmbH",
    "15800": "COORDINATOR- PP \"Koordinator\"",
    "15801": "MARKETORG MARKETORG Autonomous System",
    "15802": "DU-1 Emirates Integrated Telecommunications Company PJSC (EITC-DU)",
    "15803": "MC-LINK MC-link Spa",
    "15804": "UNSPECIFIED",
    "15805": "SKYNET-CY- MTN Cyprus Limited",
    "15806": "ORG-IG30-RIPE Irish Government",
    "15807": "WEBLINK Weblink P autonomous system",
    "15808": "ACCESSKENYA-KE ACCESSKENYA GROUP LTD is an ISP serving",
    "15810": "BBVA- Banco Bilbao Vizcaya Argentaria, S.A.",
    "15811": "Hally Computers Autonomous System",
    "15814": "15814 Clearstream Services S.A.",
    "15815": "INTRANS- IntraNS",
    "15817": "MITTWALD- Mittwald CM Service GmbH & Co. KG",
    "15818": "LATVIJGAZE- latvijas gaze",
    "15819": "GLOBALMENKUL-NET Global Menkul Degerler SA",
    "15820": "SUNRIZENET SC SUNRIZE NET SRL",
    "15821": "TRAL- Joint Ukrainian-Austrian Venture Astral-Kiev Ltd. TOV",
    "15822": "AGEN- Javna agencija Republike Slovenije za energijo",
    "15823": "RADWARE- Radware Ltd.",
    "15824": "A1-TA-AG A1 Telekom Austria AG",
    "15825": "UNSPECIFIED",
    "15826": "NFRANCE NFRANCE CONSEIL",
    "15827": "TURIBA- SIA 'Biznesa augstskola Turiba'",
    "15828": "Phone.com",
    "15829": "EUTELSAT EUTELSAT S.A.",
    "15830": "TELECITY-LON TELECITYGROUP INTERNATIONAL LIMITED",
    "15831": "N-NETVALLEY Security Reply s.r.l.",
    "15832": "TRIGLAV-OSIGURANJE TRIGLAV OSIGURANJE ADO BEOGRAD",
    "15835": "MAP Moscow Network Access Point",
    "15836": "AXAUTSYS ARAX I.S.P.",
    "15838": "FIRSTGATE- CBS GmbH",
    "15839": "Cobweb Solutions Ltd",
    "15840": "ATT-INF001-A11 AT&T-GNS-15840",
    "15842": "BYERS GlobInform Ltd.",
    "15843": "GSU-NET",
    "15844": "TGC- true global communications GmbH",
    "15845": "CITC_IRS_SERVICE_15845 Computers in the City Ltd",
    "15846": "COFACE COFACE S.A.",
    "15847": "INTERFACES Interfaces SARL",
    "15848": "DART DART IMPEX SRL",
    "15849": "AGROUP corporate num",
    "15850": "15850 cyberplat.com",
    "15851": "WK-COM WROCMAN-COM non-educational part of WK network, Wroclaw,Poland",
    "15853": "NATSEC NBG Securities SA",
    "15854": "HP_WEBSERVICES Hewlett Packard GmbH",
    "15855": "AERO2 Aero 2 sp. z o.o.",
    "15856": "LTING-INTERNET LTING System S.R.L.",
    "15857": "DIALOG- Telefonia Dialog sp.z.o.o.",
    "15858": "RIVULUS- IPN Telecom SRL",
    "15859": "DSRACK DSRack ApS",
    "15860": "Slamon UK N",
    "15861": "LEGEND BusinessServe customer transit  for 15861 customers",
    "15862": "VOLNA- Volna Ltd",
    "15863": "IBIS- IVANET-PAR Autonomous System",
    "15864": "IBIS- Roterdam",
    "15865": "ELLIOTT-UK- Elliott Advisors UK (Ltd)",
    "15866": "-PEGUS pegasus GmbH",
    "15867": "ED-PARTNER- ED-PARTNER LLC",
    "15868": "NALTEL- Nalchik-Telecom Ltd",
    "15869": "EDS-SE Eds Sweden AB",
    "15871": "BGNET Ltd.",
    "15872": "ABERGER Aberger Software GmbH",
    "15873": "OGILVY Ogilvy & Mather Advertising S.R.L.",
    "15874": "INTERKAM \"InterKAM\" S.C. ZBIGNIEW KOWALEWSKI, SYLWIA SZCZEPANIK, DOMINIK SZCZEPANIK",
    "15877": "Silicon Solutions Comp.descr:        ISP in Egypt",
    "15878": "WMC-NET WMC-NET Centrum Systemow Teleinformatycznych Sp. z o.o.",
    "15879": "N-IS IS Group B.V.",
    "15880": "CHIKALIN- Private entrepreneur Chikalin Anatoly Nikolaevich",
    "15882": "MMC M&M Computers SRL",
    "15885": "INTERCOMM Inter Comm",
    "15886": "REKKON- limited liability company \"Konnectika\"",
    "15887": "INFOGROUP- Infogroup S.p.A.",
    "15888": "Marelli Autonomous System",
    "15889": "SRC-SI- SRC.SI sistemske integracije d.o.o.",
    "15890": "CEGETEL-DTI-FR- Societe Francaise du Radiotelephone S.A",
    "15891": "NETDEPOT NetDepot Internet Services und Datensysteme GmbH",
    "15892": "MITTS-NET Malta Information Technology Agency (MITA)",
    "15894": "LEITWERK- LEITWERK AG",
    "15895": "KSNET- \"Kyivstar\" PJSC",
    "15896": "YAHOO-DEA Yahoo! Europe",
    "15897": "VODAFONETURKEY Vodafone Telekomunikasyon  A.S",
    "15898": "CityLine-Tyumen Autonomous System",
    "15899": "Citigroup Internet operations London",
    "15900": "Chocolate Internet",
    "15902": "maque maciej grzeszczuk",
    "15904": "HALLERTAU-DE Hallertau.Net e.V.",
    "15905": "HLOPTIC- ISP Hloptic, Ltd",
    "15908": "AB \"Ukio bankas\"",
    "15909": "TLK Distributions GmbH",
    "15910": "FABOFT-AT- Fabasoft AG",
    "15911": "SEIM- Lietuvos Respublikos Seimo kanceliarija",
    "15912": "CL- Ricoh Sverige AB",
    "15913": "IACP- Institute for Automation and Control Processes of",
    "15914": "British Airways plc",
    "15915": "IBERCOM World Wide Web Ibercom S.A.",
    "15916": "ABN AMRO Bank N.V.",
    "15917": "CSC-UK-MWH CSC Computer Sciences Ltd",
    "15918": "Ibasis Autonomous System",
    "15919": "INTERHOST Servicios de Hosting en Internet S.A.",
    "15922": "QWEB- Qweb Full-Service Hosting",
    "15923": "N-LOGOS Logos S.P.A.",
    "15924": "BORUSANTELEKOM- VODAFONE NET ILETISIM HIZMETLERI ANONIM SIRKETI",
    "15925": "NEXIU Mega Access GmbH",
    "15926": "IKOM \"Interaktivne Kablovske Objedinjene Mreze - I.KOM\" D.O.O.",
    "15927": "OeKM Verlagsgesellschaft",
    "15929": "EMPLOT-2 Emplot Ltd. Kiev, Ukraine",
    "15930": "WIPLINE- WIPLINE  Corp",
    "15932": "TGS-INT-NETWORK Telenor Global Services",
    "15933": "ITH ith Kommunikationstechnik GmbH",
    "15934": "ZEBRA- JSC Zebra Telecom",
    "15935": "HA-VEL-LOCAL- ha-vel internet s r.o.",
    "15936": "UTN Ukrtrans Network LLC",
    "15937": "ADIF  ADIF",
    "15938": "15938 element 5 GmbH",
    "15939": "DELOITTEAT- Deloitte Services Wirtschaftsprufungs GmbH",
    "15941": "BURDENIS- BURDENIS-COM EOOD",
    "15942": "LIBRATEL Libratel IP Communications GmbH",
    "15943": "WTNET- wilhelm.tel GmbH Norderstedt",
    "15944": "BIG - Banco de Investimento Global S.A.",
    "15945": "PFALZKOM-NET PfalzKom GmbH Autonomous System Number",
    "15946": "BANKA-KOPER- Banka Koper d.d.",
    "15947": "CCBISP- Cork Community Broadband Limited",
    "15948": "ICE/HT fundamental and technological research",
    "15950": "MPLS Henrik Hansson",
    "15951": "DJUK Dow Jones & Company, Inc.",
    "15952": "SKNET- SK NET SRL",
    "15953": "_KBCGS_CEDC KBC Group NV",
    "15954": "TECNOCRATICA Soluciones Dinamicas de la Red, S.L.",
    "15955": "SUPRANET Supranet AG",
    "15957": "WTG- Web Technology Group",
    "15958": "TELENOR_DOO_ Telenordoo-NET",
    "15959": "CPLUS-DE Computer Plus GmbH",
    "15960": "GLOBALACCESS Global Access Internet Services GmbH",
    "15961": "ATTENDA-NET Attenda Limited",
    "15962": "OSK-DNI ORANGE Slovensko - ISP IP backbone",
    "15963": "GUACANET GUACANET Ltd.",
    "15964": "CAMNET-",
    "15965": "15965 CEGECOM SA - Luxembourg",
    "15966": "EMANGO Emango Internet Services BV",
    "15967": "NETART NetArt Spolka Akcyjna Spolka Komandytowo-Akcyjna",
    "15968": "NETPILOT NETpilot GmbH",
    "15969": "SYSTEMIA- Systemia.pl Sp. z o.o.",
    "15970": "KPY- DNA Oy",
    "15971": "ECOSOFT- EcoSoft Autonomous System",
    "15974": "VTT- JSC \"Volgatranstelecom\"",
    "15975": "HADARA- Hadara Technologies Private Shareholding Company",
    "15976": "ORDERNET- Ordernet Ltd.",
    "15977": "Pershing Limited",
    "15978": "Bobst SA",
    "15980": "Uppsala University",
    "15981": "CSEBO-NET C.S.E. Consorzio Servizi Bancari Soc. Cons. a r.l.",
    "15982": "VERAT--1 Drustvo za telekomunikacije Verat d.o.o, Bulevar Vojvode Misica 37",
    "15983": "CARREFOURBELGIUM-BE- Carrefour Belgium",
    "15984": "The Joint-Stock Commercial Bank CentroCredit.",
    "15985": "N-PIPENET PipeNet Communications Autonomous System",
    "15987": "PORTUNITY- Portunity GmbH",
    "15988": "AKHTERNET Akhter Computers Ltd.",
    "15989": "NYSE TECHNOLOGIES LIMITED",
    "15990": "ITXC-UK ITXC",
    "15991": "SWEDISH_TAX_AGENCY Swedish Tax Agency",
    "15992": "VISA-EUROPE Visa Europe Services INC.",
    "15993": "BNP Paribas Bank Polska SA",
    "15994": "N-DCM VIPnet d.o.o.",
    "15995": "AB SEB bankas",
    "15996": "DTAG-ENX Deutsche Telekom AG",
    "15997": "ITSA ITSA Autonomous System",
    "15998": "SPECIFICMEDIA-UK- Specific Media UK",
    "15999": "KRIX- Kirovograd-Ukraine Exchange Autonomous System",
    "16000": "16000 M.C.I. Autonomous system",
    "16001": "AAREON- Aareon Deutschland GmbH",
    "16003": "Mediaparks Autonomous System",
    "16004": "MIXITA- MIX S.r.L.",
    "16005": "ITCENTROFHOUSING SPSC IT Center of housing and communal services",
    "16006": "RUPKKI-SK- Rupkki s.r.o.",
    "16007": "N-KANCOM KANCOM Fiber-Optic Network",
    "16008": "CPB-Software (Austria) GmbH",
    "16009": "Alcyonis Global Internet",
    "16010": "RUSTAVI2ONLINE Caucasus Online LLC",
    "16011": "FIBER-WELDERS- FIBER WELDERS SRL",
    "16012": "TELMOS- MTS OJSC",
    "16013": "UNISYSTEMSP UniSystems SA",
    "16014": "EE-EMT  EMT",
    "16015": "CIB- CIB bank e-commerce provider Budapest, Hungary",
    "16016": "VOLJATEL- Tusmobil d.o.o.",
    "16017": "HAGER- Hager Electro GmbH & Co. KG",
    "16018": "ANSARBANK- Bank Ansar Public JSC",
    "16019": "VODAFONE-CZ- Vodafone Czech Republic a.s.",
    "16020": "TCOM ZAO Tascom",
    "16022": "COSMOLINE COSMOLINE TELECOMMUNICATION SERVICES S.A.",
    "16023": "NETSONIC Academica Oy",
    "16024": "GELSEN-NET GELSEN-NET Kommunikationsgesellschaft mbH",
    "16026": "PETROM-NET OMV PETROM SA",
    "16027": "PHOENIX-INFORMATICA-BANCARIA Phoenix Informatica Bancaria S.p.A.",
    "16028": "Orange S.A.",
    "16029": "PIS Autonomous Syatem",
    "16030": "ALTECOM Alta Tecnologia en Comunicaciones, S.L",
    "16031": "RLS RomLotuS Computers SRL",
    "16032": "TIBUS-HQ The Internet Business Ltd",
    "16033": "ITBU State Educational Institution of Higher Professional Education \"Russian State University of Innovations and Business\"",
    "16034": "KEME Timico Ltd (Legacy KeConnect N)",
    "16035": "ECITY NETKA - Italy",
    "16036": "THOMSON-CORPORATION Thomson Corporation",
    "16037": "TETRAPAK- AB Tetra Pak",
    "16038": "LSV- LSV Ltd.",
    "16039": "KNET Comunicaciones S.L.",
    "16041": "EDGIX-UK Autonomous System",
    "16042": "16042 Terra S.p.a.",
    "16043": "SAMARA-TELECOM- Samara Telecom Autonomous System",
    "16044": "IPORT-NET IPORT LLC",
    "16045": "SPEKTAR-AD Spektar AD",
    "16046": "16046 Navlink",
    "16047": "YAR-TT- CJSC YarTranzitTelecom",
    "16048": "Alcatel-Lucent International S",
    "16049": "CPB-Software (Austria) GmbH",
    "16050": "REUTERS-DOCKLANDS-RES- Thomson Corporation",
    "16051": "NET-PRO- Net Professionals GmbH",
    "16052": "N-SELECTA Selecta S.p.A.",
    "16054": "NSOELSV- OJSC Rostelecom",
    "16055": "DEVK Autonomous System",
    "16056": "IBIS- IVANET Autonomous System",
    "16057": "AGELIA- Agelia Autonomous System",
    "16058": "Gabon-Telecom",
    "16059": "CODIX",
    "16060": "KUWAIT-MOF- Kuwait Ministry of Finance",
    "16061": "ISRACARD- Isracard  Ltd.",
    "16062": "Latvijas tikli, SIA",
    "16063": "PIPEMEDIA Autonomous System",
    "16064": "INFOPAC- Joint-Stock Company INFOPAC",
    "16065": "16065 Redimi",
    "16066": "TEST-UA \"T.E.S.T.\" Ltd",
    "16068": "MAIL-SELECT- MAIL*SELECT GmbH",
    "16069": "ARMADA ARMADA BILGISAYAR SISTEMLERI SANAYI VE TICARET A.S",
    "16071": "GRPLEG LEGRAND FRANCE",
    "16072": "FDD First Data Deutschland GmbH",
    "16073": "ACCELANCE--FR-1 Open Wide Outsourcing S",
    "16074": "CAPGEMINI_OUTSOURCING_NL Capgemini Nederland B.V.",
    "16075": "TAZ- taz die tageszeitung autonomous system",
    "16076": "IPERV- IperV. Padova NOC.",
    "16077": "Regus Paris S",
    "16079": "NESTEC_CLGO Nestle Operational Services Worldwide SA",
    "16080": "RENTABILIWEB Rentabiliweb Telecom",
    "16081": "16081 IBM Osterreich Internationale Buromaschinen Gesellschaft m.b.H.",
    "16082": "SPITFIRE Spitfire Network Services Autonomous System",
    "16083": "STACK- Stack Ltd",
    "16084": "EON-IS E.ON IT GmbH",
    "16085": "N-INFOBOLSA INFOBOLSA S.A.",
    "16086": "DNA DNA Oy",
    "16087": "SUP TELECOM INTERACTIVE is an ISP that serves people all around",
    "16089": "NEW TECHNOLOGY INCORPORATION NETWORK serves customers all around",
    "16091": "SATEC SATEC",
    "16092": "YESILEGE-EFESNET EfesNet Autonomus System",
    "16093": "ECONET- ECONET",
    "16094": "ROILCOM- ROILCOM LTD",
    "16095": "JAYNET jay.net a/s",
    "16096": "BETFAIR The Sporting Exchange Ltd",
    "16097": "HLKOMM HL komm Telekommunikations GmbH",
    "16098": "N-IDC Netesi S.p.A.",
    "16099": "SOZVERS-NET Hauptverband der oesterreichischen Sozialversicherungstraeger",
    "16100": "BNS- Blocul National Sindical BNS",
    "16101": "ORDIPAT ORDIPAT S",
    "16104": "SKB- SKB Banka d.d. Ljubljana",
    "16105": "-DIAMOND-DOGS diamond dogs web consulting GmbH",
    "16107": "COMDIRECT COMDIRECT Bank AG",
    "16108": "Deutsches Institut fuer Normung e.V.",
    "16110": "PODKARPACKI-NET- Podkarpacki.net Rafal Czarny",
    "16111": "ONLINE-CONSULTING Online Consulting AG",
    "16112": "MEDIALINK- MEDIA LINK UKRAINE ltd",
    "16113": "number for Internoc",
    "16114": "UBPAM- Trade Development Finance TDB SA",
    "16115": "VERIZON-LUNDAIDC- OMX Technology AB",
    "16116": "Pelephone Communications Ltd.",
    "16117": "GAVLENET se.gavlenet Autonomous System",
    "16118": "NNT-MOSCOW- Thyphone Communications LLC",
    "16119": "BICIX BICIX Autonomous System",
    "16120": "UMFT Universitatea de Medicina si Farmacie Timisoara - Romania",
    "16121": "N-ONLINE RC TEAM SA",
    "16122": "IT-PRADAINDUSTRIAL- Prada S.p.A.",
    "16123": "DEMISGROUP- CJSC \"Demis Group\"",
    "16124": "16124 JSC \"Ukrtelecom\"",
    "16125": "DC- UAB Duomenu Centras",
    "16126": "INFO-ZVYAZOK Info-Zvyazok",
    "16127": "EUROINTEGRA EuroIntegra Ltd.",
    "16128": "AGARIK-BULLPI-NETWORK AGARIK and  BULLPI provide WEB, Servers Hosting and dedicated Internet Connection",
    "16129": "RIX Autonomous System",
    "16130": "FiberLink Networks",
    "16131": "GRAFIX-IS Voiceworks BV",
    "16132": "SES-SIRIUS-NET SES SIRIUS AB",
    "16133": "AXA Technology Services Switzerland AG",
    "16134": "NEODIGIT_ Neodigit, S.L.",
    "16135": "TURKCELL- TURKCELL ILETISIM HIZMETLERI A.S.",
    "16136": "POLIRIS- POLIRIS",
    "16138": "INTERIAPL INTERIA.PL Sp z.o.o.",
    "16139": "LOWERTHAN16150 -HEMLIGT",
    "16140": "IMADIFF-N IMA'DIFF s.a.r.l.",
    "16141": "NETHOUSE AUTOMATICA SRL",
    "16142": "ING-BANK-SK ING Bank N.V., pobocka zahranicnej banky",
    "16143": "RADIONET- NIIR-RadioNet Moscow region network",
    "16144": "Sapient Spa",
    "16145": "INECCO-LANACO- Lanaco Kompjuteri & Komunikacije Ltd. with P.O. Banja Luka",
    "16146": "N-TECNOGRANDA Tecnogranda S.P.A.",
    "16147": "voorziening tot samenwerking Politie Nederland",
    "16148": "NETWORK-TEAM- Network Team GmbH",
    "16149": "COFIDIS- SC COFIDIS IFN SA",
    "16150": "PORT80-GLOBALTRANSIT Availo Networks AB",
    "16151": "BRODOS Brodos AG",
    "16152": "TRONICPLANET CLG Computerdienst fur Landwirtschaft und Gewerbe GmbH",
    "16153": "SCS- Servei Catala de la Salut",
    "16154": "TELECOMS- Telecoms-Net Ltd.",
    "16156": "INTERNEXT- INTERNEXT SRL",
    "16157": "STARNETIS S.R.L.",
    "16158": "COMVERSE- Comverse Ltd",
    "16160": "SWAN SWAN a.s.",
    "16161": "BANCALOMBARDA UBI SISTEMI E SERVIZI S.c.p.A.",
    "16162": "LONDONWEB- London Web Ltd",
    "16163": "AGRAMBROKERI Agram Brokeri d.d.",
    "16164": "SOHONET- Sohonet Limited",
    "16165": "SSU Social Strategy of Ukraine",
    "16166": "WORLDPAY2 WorldPay (UK) Limited",
    "16167": "BREBANK-MBANK-MULTIBANK- BRE BANK SA",
    "16168": "GENETSIS Genetsis Internet Partners",
    "16169": "BUILD2BUILD Autonomous System",
    "16170": "VIPNET Prime Telecom srl",
    "16171": "STRENCOM Fulnett Limited",
    "16172": "DSA JET-ERP Betriebsgesellschaft mbH",
    "16173": "CQGI-RUS OOO CQGI Rus",
    "16174": "INTUITIV- Intuitiv Autonomous System",
    "16175": "SIGNAL Signal Bredband",
    "16176": "DELTACOM- Deltacom Ltd.",
    "16177": "EQUENS-ITALIA- Equens S.P.A.",
    "16178": "LOGOSOFT- Logosoft d.o.o.",
    "16179": "JSC \"Digital channels network\"",
    "16181": "MEREZHA Merezha autonomous system",
    "16182": "KBSA Kredyt Bank S.A.",
    "16184": "LUKAKP- Luka Koper pristaniski in logisticni sistem, delniska druzba",
    "16185": "RINGNETT-NORWAY RingNett  Autonomous System",
    "16186": "N-SSC IP Group",
    "16187": "FORTISBANK FORTIS BANK A.S.",
    "16188": "PUNKT punkt.de GmbH",
    "16189": "KLEE SA",
    "16190": "16190  for AM.WEB LIR,",
    "16191": "ICANET- ICA-NET S.r.l.",
    "16192": "ROM-ELECTRONIC- Rom Electronic Company SRL",
    "16193": "BankService AD",
    "16194": "REALDOLMEN RealDolmen NV",
    "16195": "IXBONE IXBONE Telekom Service GmbH",
    "16197": "TOLLON Tollon",
    "16199": "MEGADATA- SC Megadata SRL",
    "16201": "ALISEO Aliseo S.r.l.",
    "16202": "PRIMACOM- PrimaCom Berlin GmbH",
    "16203": "Caixa Galicia",
    "16204": "MSM MSM Ent Ltd.",
    "16205": "DSINET-N DSI GmbH Daten Service Informationssysteme",
    "16206": "ABRARED NEO-SKY 2002 Autonomous System 1",
    "16209": "16209 J.P. Morgan Fleming Asset Management Luxembourg",
    "16210": "GRUPPOIH- Visiant Outsourcing Srl (formerly Gruppo IH Srl)",
    "16211": "STELLA-NET Stella Net",
    "16212": "LORAL-SKYNET-N Loral Skynet - Aflenz ES (Telekom Austria)",
    "16213": "MICRODATAUA- Microdata Ltd.",
    "16214": "CERIST",
    "16215": "N-GENOTEC green.ch AG",
    "16217": "LONGPHONE LONGPHONE",
    "16218": "N-IACD IACD Autonomous System",
    "16219": "SEP Servizi e Progetti S.p.A.",
    "16220": "UTCBNET Civil Engineering University of Bucharest",
    "16221": "PIPELINE CH-PIPELINE Autonomous System",
    "16222": "LIBECOM LIBECOM Autonomous System, specializing in",
    "16223": "BITTERNET \"BitterNet\" Ltd",
    "16224": "Data Return - UK",
    "16225": "BUSINESS PROCESS MANAGEMENT",
    "16226": "NEWGEN Internet & Telecom Solutions Ltd.",
    "16227": "Autonomous System of",
    "16228": "-VERKKOPALVELUT Pohjoisen Keski-Suomen Verkkopalvelut Oy",
    "16229": "PRIMETEL PrimeTel PLC Ltd",
    "16230": "SKYNET- LLC Skynet, Ekaterinburg, Russia",
    "16231": "DEKNET DEK-optics LTD",
    "16232": "N-TIM TIM (Telecom Italia Mobile) Autonomous System",
    "16233": "KIRCHMEDIA KirchMedia GmbH & Co KG a.A. i.I.",
    "16234": "STAYON Stayon",
    "16235": "POUYANAZM- Pouya Nazm Najafabad Computer Co(PJS)",
    "16236": "Peugeot Citroen Automobile SA",
    "16237": "NXS IS Group B.V.",
    "16238": "TELECOM2- Telecom2 Ltd.",
    "16239": "LORER- TOO Zebra Telecom",
    "16240": "SMART-SOLUTIONS- Dassault systemes Israel ltd",
    "16241": "MAPORAMA",
    "16242": "MHS mhs internet AG",
    "16243": "VIRTU- Virtu Secure Webservices B.V.",
    "16245": "NGDC NetGroup A/S",
    "16246": "16246 RIOMEDIA Autonomous system",
    "16247": "DATTATE VENUS BUSINESS COMMUNICATIONS LIMITED",
    "16248": "AccessME-jordan  number",
    "16249": "RT-CENTER- JSC \"RT Center\"",
    "16251": "Hogskolan i Gavle",
    "16252": "CERTIUR-P CERTI-UR",
    "16253": "BORDERLIGHT- se.Borderlight",
    "16254": "LYRECO- Lyreco Management S",
    "16255": "WRAX Wrax Ltd.",
    "16256": "RECOM- MTS OJSC",
    "16257": "REGDOM Servizi Internet Srl",
    "16259": "XENETIC Elisa Oyj",
    "16260": "PX-MRP GTT - EMEA Ltd.",
    "16261": "GlobeCom Autonomous System",
    "16262": "DELTA-LTD- Delta Ltd",
    "16263": "RAMAN Politechnika Radomska Im.Kazimierza Pulaskiego",
    "16264": "What's Up Informations",
    "16265": "LEEWEB LeaseWeb B.V.",
    "16266": "N-CANON-NL Canon Europa N.V.",
    "16267": "AZ Medien Gruppe AG",
    "16269": "POSTABANK",
    "16270": "DDB Warszawa Sp. z.o.o.",
    "16271": "ADB- ADB Ukraine LTD",
    "16273": "F-SECURE- F-Secure Oyj",
    "16274": "BSKNET ING Bank Slaski S.A.",
    "16275": "Methodes et Solutions Informatiques",
    "16276": "OVH OVH Systems",
    "16277": "TOC Contec Datentechnik GmbH",
    "16279": "\"Citadele banka\"",
    "16280": "BCRT BORSODCHEM Zrt",
    "16281": "UTELISYS Utelisys Communications B.V.",
    "16282": "AIB--1 Allied Irish Banks Plc",
    "16283": "LODMAN-2 Technical University of Lodz Computer Centre",
    "16284": "UNSPECIFIED",
    "16285": "N-UMN CJSC \"Ural-TransTeleCom\"",
    "16286": "BBAG Osterreichische Brau-Beteiligungs-AG",
    "16287": "KUZBSNET OJSC Rostelecom",
    "16288": "KABUM_ Sfires Software & Hardware Dariusz Swiderski",
    "16289": "ING-DIRECT-SPAIN ING Direct N.V.",
    "16290": "TARMAN Tarnowski Osrodek Informacyjny Aleksander Rajski",
    "16291": "GRUDNIK-KRK-PL Grudnik Sp. z o.o.",
    "16293": "N-INTERCEA-UK Daisy Data Centre Solutions Limited",
    "16294": "PORTHUS Zemblaz n.v.",
    "16295": "ETEL-SK GTS Slovakia, a.s.",
    "16296": "TWINIX- TWINS NET Sp. z o.o.",
    "16297": "WIIT-IT- WIIT S.p.A.",
    "16298": "INTERBOX- InterBox Internet",
    "16299": "XFERA Xfera Moviles SA",
    "16300": "INTERTAX-AREA JSC Intertax",
    "16301": "DATACOM- OJSC Rostelecom",
    "16302": "SUOMICOMMUNICATIONS Suomi Communications Oy",
    "16303": "IPSwitch Networks Ltd",
    "16304": "HTK HTK Ltd",
    "16305": "mobilkom austria AG",
    "16306": "WALDONET WALDONET Autonomous System",
    "16308": "State Educational institution for High professional education 'Southern Federal University'",
    "16311": "HEROLD- Herold Business Data GmbH",
    "16313": "LBB- Landesbank Berlin AG",
    "16314": "WIENKAV KAV Wien",
    "16315": "LUCID Absolute Clarity Limited",
    "16316": "TMT TMT GmbH & Co. KG",
    "16317": "SK-4CALL PEG Wireless, s.r.o.",
    "16319": "TELSERVICE- TelService Ltd.",
    "16320": "ENIAC-TECH- FANAVARAN ENIAC RAYANEH (ENIAC-TECH) (Private JS)",
    "16321": "AICONET- Aiconet Ltd.",
    "16322": "PARSONLINE PARSONLINE Autonomous System",
    "16323": "INFORM-SYSTEMY-I-TECHNOLOGII- Informatsionniye Systemy i Technologii CJSC.",
    "16324": "DANTELECOM- PE Dan Company",
    "16325": "Phone.Com",
    "16326": "SMALS-MVM SmalS-MvM",
    "16327": "PAVLABOR- Pavlabor LTD",
    "16328": "UACEG- University of Architecture Civil Engineering and Geodesy",
    "16330": "Sportal Ltd",
    "16331": "TELE-ENTRE-FI- Tele-entre Oy",
    "16333": "ONNET--OWN ONE Telecommunications Services DOOEL Skopje",
    "16334": "SURELINE-COMMUNICATIONS-UK Sureline Communications Limited",
    "16338": "ONO-2 Cableuropa - ONO",
    "16339": "VI-UK Virtual Internet (UK) Ltd",
    "16340": "IS-N IS-NET Autonomous System",
    "16342": "TOYA Toya sp.z.o.o",
    "16344": "IS-BG- Information Services Plc.",
    "16345": "BEE- OJSC \"VimpelCom\"",
    "16346": "Elcom International SA",
    "16347": "RMI-FITECH ADISTA S",
    "16348": "PWC-FR PricewaterhouseCoopers Services GIE",
    "16349": "FON--2 Fon Wireless LTD",
    "16350": "ECHELON- Echelon BV",
    "16351": "JUNO- Juno Records Ltd.",
    "16352": "Espin Autonomous System",
    "16353": "MERULA Merula Limited",
    "16354": "CITICOM-SK- Citicom, s.r.o.",
    "16355": "SWISS- Swiss Intl. Air Lines Ltd.",
    "16356": "RDE Ricoh Deutschland GmbH",
    "16357": "AJARCH- Ajar SA",
    "16358": "Attenda Limited",
    "16360": "SATLYNX_GMBH Signalhorn Trusted Networks GmbH",
    "16361": "N-EBIMNET Sistem Co. Ltd.",
    "16362": "SEVEN- 7 Global Systems Limited",
    "16363": "AXIALYS Axialys SA",
    "16364": "SONY-DADC Sony DADC Austria AG",
    "16365": "COMMERZBANK Commerzbank Aktiengesellschaft",
    "16366": "TER-KRAKOW- TER  Krakow Sp. z o.o.",
    "16367": "SALAMON SALAMON INTERNET, s.r.o.",
    "16368": "CONSORS",
    "16369": "will be used for Online travel",
    "16370": "RANDOM-LOGIC- Random Logic Ltd.",
    "16371": "ACENS_ acens Technologies, S.L.",
    "16372": "OWS Orange Web Services S.L.",
    "16373": "CEPSA Compania Espanola de Petroleos S.A.",
    "16374": "BCIX BCIX e.V",
    "16376": "4MEDiA GROUP AG",
    "16378": "OTTO-NET Otto (GmbH & Co KG)",
    "16379": "UNICREDIT--MUC-DE UniCredit Business Integrated Solutions S.C.p.A.",
    "16380": "MILLENNIUM-DM- Millennium Dom Maklerski S.A.",
    "16381": "Osterreichischer Automobil, Motorrad und Touringclub (OAMTC) Verband",
    "16382": "SUGARD Init Corporation",
    "16383": "LACAIXA- IT Now S.A.",
    "16384": "SMCVT - St Michael's College",
    "16385": "CESG-16385 - BNY ConvergEx Execution Solutions LLC",
    "16386": "PROGRESSIVEPRODUCE - Progressive Produce Corporation",
    "16387": "HEALTHYDIRECTIONS - Healthy Directions, LLC",
    "16388": "-PTI - Protronics Technologies, Inc.",
    "16389": "ST-INTERNET- - Shurtape Technologies, LLC",
    "16390": "RIVERSIDE-SUPERIOR-COURT - Riverside Superior Court",
    "16391": "CELITO-1 - Celito Communications Inc.",
    "16393": "BARRYU- - Barry University",
    "16394": "KILLEEN-INDEPENDENT-SCHOOL-DISTRICT - Killeen ISD",
    "16395": "MBIX-NET - Manitoba Internet Exchange Inc",
    "16396": "PIGGLY-WIGGLY-CAROLINA - Piggly Wiggly Carolina Company",
    "16397": "ALOG SOLUCOES DE TECNOLOGIA EM INFORMATICA S.A.",
    "16398": "EPSON-AMERICA - Epson America, Inc",
    "16399": "FIRSTCOMM-2 - First Communications LLC",
    "16400": "SINET - School Improvement Network LLC",
    "16401": "NETN-SAINTVS - St. Vincent Hospital and Health Care Center, Inc.",
    "16402": "HKUSA - Human Kinetics, Inc.",
    "16403": "BOISE-CCADE - Boise Cascade Corporation",
    "16404": "ALBRIGHT-COLLEGE - Albright College",
    "16405": "BEAER- - BE AEROSPACE, INC.",
    "16406": "-INTERMEDIA - Intermedia.net, Inc.",
    "16407": "LINDEN-ADVISORS - Linden Investors LP",
    "16408": "LN-DREWU-N - Los Nettos",
    "16409": "PBW-COMMUNICATIONS - PBW Communications, LLC",
    "16410": "DKM3-ARIN - The Reynolds and Reynolds Company",
    "16411": "NREL--NATIONAL-RENEWABLE-ENERGY-LABORATORY - National Renewable Energy Laboratory",
    "16412": "MSHA - Mountain States Health Alliance",
    "16413": "TELEBERMUDA - Telebermuda International Limited",
    "16414": "MHSN- - My High Speed Networks Inc",
    "16415": "ALORICA - ALORICA INC",
    "16416": "MYCOMAX",
    "16417": "IRONPORT-SYSTEMS-INC - Cisco Systems Ironport Division",
    "16418": "Noanet S.A.",
    "16419": "NET-SHIFT-2008 - Shift Networks 2008 Inc.",
    "16420": "MMCL-10 - Mac Mini Colos, LLC",
    "16421": "NRT-HAWAII - Realogy Group LLC",
    "16422": "NEWSKIES-NETWORKS SES WORLD SKIES ARIN , for routing RIPE space.",
    "16423": "NETTOGO-BLK - NETTOGO",
    "16424": "MVN-NET - Mt. Vernon.Net, Inc.",
    "16425": "SOVER2-N - SoVerNet, Inc.",
    "16426": "CITYOFCOLUMBUSOHIO - City of Columbus",
    "16427": "PALM-HQ - Palm",
    "16428": "SFS-1 - Store Financial Services, LLC",
    "16429": "GSC-PORTLANDME - Gannett Supply Corp. - Portland, ME",
    "16430": "USM - University of Southern Mississippi",
    "16431": "CLARK-CONSTRUCTION - The Clark Construction Group, Inc.",
    "16432": "DFS-NAO - Discover Financial Services",
    "16433": "NCTC-ISP - North Central Communications",
    "16434": "HCM - Hitachi Cable Manchester, INC",
    "16435": "FLUKE-ELECTRONICS - Fluke Electronics",
    "16436": "MARBLE-ARCH - Marble Arch Investments, LP",
    "16437": "FORUM-HEALTH - FORUM HEALTH",
    "16438": "SATLCMINT01 - Satelcom Internet Inc.",
    "16439": "AMTRAK-IB - Amtrak",
    "16440": "ISPACE - Wave2Wave Communications, Inc",
    "16441": "ISPACE - Wave2Wave Communications, Inc",
    "16442": "ISPACE - Wave2Wave Communications, Inc",
    "16443": "ISPACE - Wave2Wave Communications, Inc",
    "16444": "ISPACE - Wave2Wave Communications, Inc",
    "16445": "ISPACE - Wave2Wave Communications, Inc",
    "16446": "ISPACE - Wave2Wave Communications, Inc",
    "16447": "ISPACE - Wave2Wave Communications, Inc",
    "16448": "ISPACE - Wave2Wave Communications, Inc",
    "16449": "ISPACE - Wave2Wave Communications, Inc",
    "16450": "ISPACE - Wave2Wave Communications, Inc",
    "16451": "ISPACE - Wave2Wave Communications, Inc",
    "16452": "ISPACE - Wave2Wave Communications, Inc",
    "16453": "ISPACE - Wave2Wave Communications, Inc",
    "16454": "ISPACE - Wave2Wave Communications, Inc",
    "16455": "MLATTTW - MeridianLink, Inc.",
    "16456": "ISPACE - Wave2Wave Communications, Inc",
    "16457": "ISPACE - Wave2Wave Communications, Inc",
    "16458": "ISPACE - Wave2Wave Communications, Inc",
    "16459": "ISPACE - Wave2Wave Communications, Inc",
    "16460": "ISPACE - Wave2Wave Communications, Inc",
    "16461": "N-UTEP - The University of Texas at El Paso",
    "16462": "UVIC- - University of Victoria",
    "16463": "DPSINET - Data Processing Solutions, Inc.",
    "16464": "CT-CORPORATION-SYSTEM - CT Corporation System",
    "16465": "ADFITECH-INC - ADFITECH, Inc.",
    "16466": "AVAYA AVAYA",
    "16467": "N-NEXTWEB-R1 - Nextweb, Inc",
    "16468": "AX- - Armani Exchange",
    "16469": "BANKOFAMERICAGCIB - Bank of America",
    "16470": "WINGNET-1 - WingNET Internet Services",
    "16471": "Adexus S.A.",
    "16472": "16472 - Webex Communications, Inc.",
    "16473": "TNII - BellSouth.net Inc.",
    "16474": "RESPONSYS-1 - Responsys Inc.",
    "16475": "BROCKU - Brock University",
    "16476": "TYCO Tyco",
    "16477": "ACNIELSEN  for A C Nielsen",
    "16478": "COLONIAL-IU-20 - Colonial IU 20",
    "16479": "NORDEABANKFINLANDPLC - Nordea Bank Finland Plc",
    "16480": "FHMI - FLOYD HEALTHCARE MANAGEMENT, INC.",
    "16481": "BABSON-GNET - Babson College",
    "16482": "PEAK10-LOU - Peak 10, Inc.",
    "16483": "SAVO - The SAVO Group, Ltd.",
    "16484": "BROADVIEWNET--16484 - Broadview Networks, Inc.",
    "16485": "CBA-OTT - The Canadian Bar Association",
    "16486": "WYOMING-MEDIA-GROUP - Wyoming Media Group, LLC.",
    "16487": "PARTNER-SOLUTIONS - Partner Solutions Inc.",
    "16488": "MAKINOMON-1 - MAKINO, INC",
    "16489": "WEBSTER - Webster University",
    "16490": "MTB - Manufacturers and Traders Trust Company",
    "16491": "VIAT - ViaSat, Inc.",
    "16492": "DECHERT-LLP - Dechert LLP",
    "16493": "ABERCROMBIE-FITCH - Abercrombie & Fitch",
    "16494": "EME - En Masse Entertainment Inc.",
    "16495": "CABLEAM-AZ- - CableAmerica Corporation",
    "16496": "COLORADOSTATEUNIV-SCONE - Colorado State University",
    "16497": "N-SMM - The Science Museum of Minnesota",
    "16498": "LALLE - LaSalle University",
    "16499": "LN-VHF-N - Los Nettos",
    "16500": "APCI - Air Products & Chemicals, Inc.",
    "16501": "I2C-N - i2c Incorporated",
    "16502": "PHXGOV - City of Phoenix",
    "16503": "N-W-TELEPHONE - Northwest Telephone, Inc.",
    "16504": "GRANITE - Granite Telecommunications LLC",
    "16505": "TDX - Tradentrix LLC",
    "16507": "DELWEBBCORP - Del Webb Corporation",
    "16508": "PARIO-HOSTED-DATA - Pario Solutions",
    "16509": "AMAZON-02 - Amazon.com, Inc.",
    "16510": "IHSENERGY-FIELDDIRECT - IHS Energy Group",
    "16511": "IT-FREEDOM - IT Freedom LLC",
    "16512": "FMHDC - BannerHealth dba Fairbanks Memorial Hospital",
    "16513": "COXMEDIA - Cox Newspapers/AJC",
    "16514": "TRIPOS-INC - Certara USA, Inc.",
    "16515": "ALTAVISTA - AltaVista Company",
    "16516": "COMTECH-MOBILE-DATACOM - Comtech Mobile Datacom Corporation",
    "16517": "LEEPROCESS - LEE & SOCIATES LLC",
    "16518": "FIBERCLOUD-BHAM - OSDataCenters (currently changing to FiberCloud)",
    "16519": "CUDENVER - University of Colorado Denver",
    "16520": "SCFEDERAL - South Carolina Federal Credit Union",
    "16521": "HARRISBURG-BRANCH - CIBER INC",
    "16523": "TRUTEL - Trutel Inc.",
    "16524": "METTEL - Metropolitan Telecomm",
    "16525": "KBR - KBR",
    "16526": "BIRCH-TELECOM - Birch Telecom, Inc.",
    "16527": "GVTCINTERNET - Guadalupe Valley Telephone Cooperative, Inc.",
    "16528": "IMPSAT FIBER NETWORKS INC",
    "16530": "POWERSHIFT - Power Shift Computer Services, Inc.",
    "16531": "Protel I-Next, S.A. de C.V.",
    "16532": "B2B2C - B2B2C Inc",
    "16533": "-SAFETY-INSURANCE - Safety Insurance Company",
    "16534": "HANWECK-SOCIATES-LLC - Hanweck Associates LLC",
    "16535": "ECHOS-3 - Echostar Holding Purchasing Corporation",
    "16536": "HPES - Hewlett-Packard Company",
    "16537": "VENDIO - Vendio Services, Inc.",
    "16538": "PDC - Pacific Disaster Center",
    "16539": "MERCANTILCB - Mercantil Commercebank, N.A.",
    "16540": "BLUEROOSTER-N - Blue Rooster Telecom, Inc.",
    "16541": "ERICKSON- - Erickson Retirement Communities, LLC",
    "16542": "MGIC - Mortgage Gauranty Insurance Corp",
    "16543": "GATEWEST- - Gate West Communications Inc.",
    "16544": "CHANNING-BETE - Channing L. Bete Company",
    "16545": "OSSDS - OSSDS, LLC",
    "16546": "VNU-USA - VNU USA",
    "16548": "ET-PENN-MANUFACTURING - East Penn Manufacturing",
    "16549": "AMI1 - AMI Communications, Inc.",
    "16550": "AEREO-DAL - Aereo, Inc.",
    "16551": "FRBSF - Federal Reserve Bank of San Francisco",
    "16552": "TIGGEE - Tiggee LLC",
    "16553": "STERILMED - Sterilmed, Inc.",
    "16554": "ANP - ADVANCED NETWORK PRODUCTS INC.",
    "16555": "MEDSHOPPE-K1 - Medicine Shoppe International",
    "16556": "TOTALCHOICE - TotalChoice Hosting, LLC",
    "16557": "COLOSOLUTIONS - Colo Solutions, Inc.",
    "16558": "TOWERGROUP - TOWER GROUP INTERNATIONAL",
    "16559": "REALCONNECT-01 - RealConnect, Inc",
    "16560": "IDM- - Information Distribution and Marketing, Inc.",
    "16561": "ARIBANETWORK Ariba Inc. Autonomous System",
    "16562": "MVT - Mountain View Telephone Company",
    "16563": "NEXUM-N - Nexum, Inc.",
    "16564": "ADAMS-WELLS-INTERNET - Adamswells Internet",
    "16565": "FIRST-HAWAIIAN-BANK - First Hawaiian Bank",
    "16566": "DESERTSKY - Desert Sky Software",
    "16567": "NETRIX-16567 - Netrix LLC",
    "16568": "PROMEGA - PROMEGA CORPORATION",
    "16569": "N-CITY-OF-CALGARY - City of Calgary",
    "16570": "TELOIP-SW-N - AgniCorp Inc.",
    "16571": "KDMC1 - Kings Daughters Medical Center",
    "16572": "ATT-MOBILITY-LLC-16572 - AT&T Mobility LLC",
    "16573": "SMCC - Santa Monica Community College District",
    "16574": "GTEK-COMMUNICATIONS - Gtek Computers LLC",
    "16575": "HANOVER-COLLEGE - Hanover College",
    "16577": "DIGITALEDGE-2 - DIGITAL EDGE VENTURES INC.",
    "16578": "DATANOC - Lanset America Corporation",
    "16579": "RADIANZ - RADIANZ Americas, Inc.",
    "16580": "ATHABCA-U - Athabasca University",
    "16581": "L3ITS-XNET - Enterprise IT Solutions Div.",
    "16582": "NEXTLEVELINTERNET - NEXT LEVEL INTERNET, INC.",
    "16583": "CFCS - Care Factor Computer Services Inc",
    "16585": "SUL-4- - STORCK USA",
    "16586": "CLEARWIRE - CLEAR WIRELESS LLC",
    "16587": "FECLRO9234 - Friday, Eldredge & Clark, LLP",
    "16588": "IRID-SPIDER - IRIDES, LLC",
    "16589": "ELV-ANYCT-NET ANYCT-",
    "16590": "DGF-SERVICES - DGF Services, LLC",
    "16591": "GOOGLE-FIBER - Google Fiber Inc.",
    "16592": "ICOMSA S.A. de C.V.",
    "16593": "FMCIN - First Merchants Corporation",
    "16594": "COMPUGRAF Servi\u00e7os Ltda",
    "16595": "TORO - The Toro Company",
    "16596": "Universidad Autonoma del Estado de Baja California",
    "16597": "SPC - South Plains College",
    "16598": "BCAA- - BCAA",
    "16599": "BENTLEY-SYSTEMS-INTERNATIONAL BENTLEY SYSTEMS INTERNATIONAL LTD",
    "16600": "UTHEALTHCENTER-TYLER - University of Texas Health Center at Tyler",
    "16601": "SRF--LA-MC - Self-Realization Fellowship Church",
    "16602": "LA-BROADBAND - LA Broadband LLC",
    "16603": "BELLAMIA - Bella Mia, Inc.",
    "16604": "HUNTEL-NET - HUNTEL.NET",
    "16605": "TELSTEP-N - Telephone de St-Ephrem inc.",
    "16607": "Universidad Nueva Esparta",
    "16608": "KENTEC - Kentec Communications, Inc.",
    "16609": "THE-AERO-GROUP-16609 - The Aero Group, Inc.",
    "16610": "BLUEBIRD-WIRELESS - Bluebird Wireless Broadband Services, L.L.C.",
    "16611": "PARAMOUNT-GROUP - Paramount Group Inc.",
    "16612": "PRIME- - Prime Alliance Solutions, Inc.",
    "16613": "SYNERGYBROADBAND-IL-01 - SYNERGY BROADBAND",
    "16615": "PSI- - PROPHET SYSTEMS INNOVATION",
    "16617": "COMMUNITYISP - CISP",
    "16618": "-HFS-CAVION - Harland Financial Solutions, Inc.",
    "16619": "GTRI-RSRCH - Georgia Institute of Technology",
    "16620": "ALCAZAR-ET - Alcazar Networks, Inc",
    "16621": "DARKHORSE - Dark Horse Networks, LLC",
    "16622": "NOVARAD - Novarad Corporation",
    "16623": "CALGARY-HEALTH-REGION - Calgary Health Region",
    "16624": "HYDRO-QUEBEC - Hydro Quebec",
    "16625": "AKAMAI-N1 Akamai Technologies European",
    "16626": "GNAXNET- - Global Net Access, LLC",
    "16627": "BCCA- - Board of Commissioners of the County of Allen",
    "16629": "CTC. CORP S.A. (TELEFONICA EMPRES)",
    "16631": "COGENT-16631 - Cogent Communications",
    "16632": "EDLIO - Edlio Inc",
    "16633": "I-3 - Internet Integration, Inc.",
    "16634": "AM-EX2 - AMERIPRISE FINANCIAL SERVICES, INC.",
    "16635": "OTHERWORLDNET - Otherworld Enterprises, Inc.",
    "16637": "MTNNS-",
    "16638": "CORNINGINC01 - Corning Incorporated",
    "16639": "IRONBOW-N - Iron Bow Technologies, LLC",
    "16640": "SILICON-VALLEY-BANK - Silicon Valley Bank",
    "16641": "ACBB-BITS-N - ACBB-BITS, LLC",
    "16642": "OGILVY-MATHER-EU  for Ogilvy & Mather Europe",
    "16643": "VCU-N1 - Virginia Commonwealth University",
    "16644": "SUNGARDPUBLICSETOR-16644 - Sungard Bi-Tech Inc",
    "16645": "EPIQSYSTEMS - EPIQ Systems, Inc",
    "16646": "BI-LO- - BI-LO LLC",
    "16647": "PERIMETERWATCH - Perimeterwatch Technologies, INC",
    "16648": "PCSIA-NET - Professional Computer Solutions, Inc.",
    "16649": "IUPR- - Interamerican University of Puerto Rico",
    "16650": "-MERCHANTS-GATE - Merchants Gate Capital, L.P.",
    "16651": "SOCKET-2 - Socket Internet Services Corporation",
    "16652": "RISEUP - Riseup Networks",
    "16653": "CVENT - Cvent, Inc.",
    "16654": "PEAKINTERNETCO - Peak Internet",
    "16655": "AACAC-CORPN - Advance America Cash Advance Centers, Inc.",
    "16656": "IVANET-HAWAII - IBIS INC.",
    "16657": "FIBERTECH-NETWORKS--ROC-NY-US - Fibertech Networks, LLC",
    "16658": "PV-01 - Panavision International, L.P.",
    "16659": "CROWN--1 - Crown Castle USA",
    "16660": "FEBOX - FeBox LLC",
    "16661": "N-ROGERS-CORPORATION - Rogers Corporation",
    "16662": "AZUS01 - AstraZeneca Pharmaceuticals LP",
    "16663": "Uol Colombia",
    "16664": "CC-COMMUNICATIONS - CC Communications",
    "16666": "ALLIEDWALLET - Allied Wallet Inc",
    "16668": "GBPSW- - GBP Software, LLC",
    "16669": "APPLIED-MATERIALS - Applied Materials",
    "16670": "REG8-ESC - Region 8 Education Service Center",
    "16671": "SITESOUTH - Xilogix, LLC",
    "16672": "FEDBID - FedBid, Inc.",
    "16673": "BAYER-US-N Bayer Corporation",
    "16674": "COMPSGROUP-USA - Compass Group USA Inc",
    "16675": "CYGCOM - Cygnus Communications Corporation",
    "16676": "BARCHARTCOM - Barchart.com, Inc.",
    "16677": "AZO - AutoZone Inc",
    "16678": "AUSRAD - Austin Radiological Association",
    "16679": "WHI-N08 - Wheeling Hospital, Inc.",
    "16680": "RTL- - Redwood Toxicology Laboratory, Inc.",
    "16681": "ETS - Educational Testing Service",
    "16682": "HAGGAR - Haggar Clothing Co.",
    "16683": "MERCERGLOBAL - Mercer Global Advisors, Inc.",
    "16684": "PORTONE - Port One Internet, Inc.",
    "16685": "TIVIT TECNOLOGIA DA INFORMA\u00c7\u00c3O S.A.",
    "16686": "EYDNS EasyDNS Technologies, Inc.",
    "16687": "KTC-INET - Windstream Communications Inc",
    "16688": "PEOPLENET-COMM- - PeopleNet Communications Corp",
    "16689": "TV Azteca, S.A.B. de C.V.",
    "16690": "ANADARKO - Anadarko Petroleum Corporation",
    "16691": "KFORCE - KForce.com",
    "16692": "HHMI - Howard Hughes Medical Institute",
    "16694": "ICSI - ICSI",
    "16695": "WESCANRIC - Westminster Canterbury Corporation",
    "16696": "ITELNETWORKS - iTel Networks Inc",
    "16697": "CITY-OF-COLUMBIA-MO - City of Columbia, MO",
    "16698": "BRIGHTNET - Bright Net of Indiana",
    "16699": "ENTER-N - Enter.Net",
    "16700": "ROSENET-1 - City of Thomasville Utilities",
    "16701": "ADMINISTRACION FEDERAL DE INGRESOS PUBLICOS(AFIP)",
    "16702": "AKAMAI- - Akamai Technologies, Inc.",
    "16703": "N-CHUBBCORP - The Chubb Corporation",
    "16704": "DATAEX-CAM1 - Data Exchange Corporation",
    "16705": "WESTTEL-GRANDCAYMAN - TeleCayman",
    "16706": "ORTHONE - NORTHET ORTHOPAEDIC CLINIC, LLP",
    "16707": "UNIFI-INC - Unifi, Inc",
    "16709": "COMITYHOU - Comity Communications, LLC",
    "16710": "PBS - Public Broadcasting Service",
    "16711": "EHI-NA--2 - Enterprise Holdings, Inc.",
    "16712": "Seven Internet",
    "16713": "NOANET-WA - Northwest Open Access Network",
    "16714": "TENNANT-COMPANY - Tennant",
    "16715": "ARISTOTLE-N - Aristotle Internet Access",
    "16716": "TOMORROWNOW - TomorrowNow, Inc.",
    "16717": "CRAWKANINTERNET - Craw-Kan Telephone Coop. Inc.",
    "16718": "EMBARQ-HMBL - Embarq Corporation",
    "16719": "ND - Financial Industry Regulatory Authority, Inc.",
    "16720": "CHANCE - Chance Telecom",
    "16721": "ROBECOUSA-BOSTON1 - Robeco Investment Management, Inc.",
    "16722": "VPKK-REDUNDANT-INTERNET - Vedder Price Kaufman & Kammholz, P.C.",
    "16723": "ENSO-CAPITAL - Enso Capital Management LLC",
    "16724": "ESC-TPA-CW-AP - E Solutions Corporation",
    "16725": "TAP-PUBLISHING - TAP Publishing Company",
    "16726": "ROCHE-NUTLEY - Hoffmann LaRoche, Inc.",
    "16727": "WOW-INTERNET - WideOpenWest Finance LLC",
    "16728": "HIT-ENTERTAINMENT HIT ENTERTAINMENT",
    "16729": "16729 - Royal Bank of Canada",
    "16730": "16730 - Royal Bank of Canada",
    "16731": "16731 - Royal Bank of Canada",
    "16732": "VELOCOM",
    "16733": "SYMANTEC-CORPORATION - Symantec Corporation",
    "16734": "TALKFREE - TalkFree, Inc.",
    "16735": "COMPANHIA DE TELECOMUNICACOES DO BRIL CENTRAL",
    "16736": "Javali Informatica Ltda",
    "16737": "NERDIE-NETWORKS - Nerdie Networks LLC",
    "16738": "LMI - Logistics Management Institute",
    "16739": "INVISIMAX--GF - InvisiMax Inc.",
    "16740": "N-DYNAMIC - Dynamic Concepts, Inc.",
    "16741": "LUXCOMMUNICATIONS - Lux Communications, LLC",
    "16742": "Universidad Catolica de Valparaiso",
    "16743": "FTSBROADBAND - FTS Broadband",
    "16744": "85FIFTH-N - 85 Fifth Holdings, LLC.",
    "16745": "NOVUSINT- - Novus International, Inc.",
    "16746": "RELIANTENERGY - RELIANT ENERGY",
    "16747": "REAL-TIME - Real Time Enterprises, Inc.",
    "16748": "COMCT-TELECOMM-4 - Comcast Telecommunications, Inc.",
    "16749": "AUTOLIVP1 - Autoliv asp",
    "16750": "ECPI - Electronic Corporate Pages, Inc",
    "16751": "OPEN-TEXT-1 - Open Text Corporation",
    "16752": "EZX - EZX, Inc.",
    "16753": "BELO - BELO Corporation",
    "16754": "TTL-31 - TRILLIUM TRADING LLC",
    "16755": "TOPICA - Topica, Inc.",
    "16757": "CPI-CORP-STL - CPI Corp.",
    "16758": "IKON - IKON Office Solutions",
    "16759": "SWA-MKT-INET - Southwest Airlines Co.",
    "16760": "CBOE - Chicago Board Options Exchange",
    "16761": "FEDMOG-N-01 - Federal-Mogul Corporation",
    "16762": "Grupo Bimbo, S.A.B. de C.V.",
    "16763": "TIDEWORKS - Tideworks Technology",
    "16765": "BHN-INDIANAPOLIS - BRIGHT HOUSE NETWORKS, LLC",
    "16766": "PETFOOD - Pet Food Wholesale, Inc",
    "16767": "SPI-TC-AZO - Summit Polymers, Inc.",
    "16768": "PCS-BGP - Pacific Crest Securities Inc.",
    "16769": "SOTHEBYS-INC - Sotheby's Inc.",
    "16770": "TGEN - Astoria Generating Company, L.P.",
    "16771": "KPCB - KPCB",
    "16772": "Telefonica Data Uruguay",
    "16773": "BFG - Big Fish Games, Inc.",
    "16774": "MERCURYINS - Mercury Insurance Group",
    "16775": "QUICKLOGIC-BGP - QUICKLOGIC CORPORATION",
    "16776": "MOVE-CORP - Move Sales, Inc.",
    "16777": "NET-PROVPHP - Providence Health Plan",
    "16779": "IBL-JC - Interactive Brokers LLC",
    "16780": "Banco SantanderSantiago",
    "16781": "ARS-NATIONAL - ARS National Services, Inc.",
    "16782": "CORELAB- - Core Laboratories",
    "16783": "INVITE-US - INVITE Networks Incorporated",
    "16784": "INETZ - Inetz Media Group",
    "16785": "USANA-INC - USANA Inc",
    "16786": "ART-COM - Art.com, Inc.",
    "16787": "CHARTER-16787 - Charter Communications",
    "16788": "TCW-AR - The Computer Works of Arkansas, Inc.",
    "16789": "RENTGROW - Rentgrow Inc",
    "16790": "TNBCI-TRANSNATIONAL-BANK-CARD - TransNational Bank Card",
    "16791": "DIGITAL-AGENT - Digital Agent",
    "16792": "VWNA-1 - Volkswagen Group of America, Inc.",
    "16793": "DATA-TRONICS - Data-Tronics Corp",
    "16794": "N-LUX-NYC-01 - Luxor Internet LLC",
    "16795": "ADBE - Ad-base Systems, Inc.",
    "16796": "MERLIN-NET - MERLIN",
    "16798": "IAC-SEARCH-MEDIA - IAC Search & Media Inc",
    "16799": "PAYMTER - Hughes Aircraft Employees FCU",
    "16800": "NBS90",
    "16801": "SUG-NET - Panhandle Energy",
    "16802": "16802 - Independent Electricity System Operator",
    "16803": "MYAKKATECH1 - Myakka Technologies, Inc.",
    "16804": "SEI-ISS - SEI INFORMATION TECHNOLOGY",
    "16805": "LAYER3-N-2 - Layered Technologies, Inc.",
    "16806": "AVLNA-INTERNET - AVL North America, Inc.",
    "16807": "IBM-EI - IBM - Events Infrastructure",
    "16808": "MERCURY-INTERACTIVE-MSP - Mercury Interactive Inc.",
    "16809": "DOLLARBANK - Dollar Bank",
    "16810": "CAVTEL02 - Cavalier Telephone",
    "16811": "SPACENET-GTH - Spacenet, Inc.",
    "16812": "SPACENET-ENT - Spacenet, Inc.",
    "16813": "AMNH - American Museum of Natural History",
    "16814": "NSS S.A.",
    "16815": "CITRIX_ONLINE_LLC-16815 Citrix Online LLC",
    "16816": "S-NETCOM - S-Net, Inc.",
    "16817": "BHN-BAKERSFIELD - BRIGHT HOUSE NETWORKS, LLC",
    "16818": "CORESYS - Core Services",
    "16819": "HAWAII-DENTAL - Hawaii Dental Service 2b. Street",
    "16820": "FREEBORN - Freeborn & Peters",
    "16821": "DUQUESNELIGHT - Duquesne Light Company",
    "16822": "GORTO-US01 - Gortons Inc.",
    "16823": "NORTEXNET - Nortex Communications",
    "16824": "HARLANNET-N - Harlan Municipal Utilities",
    "16825": "DIRECTLINK - Directlink Technologies Corp.",
    "16826": "JCCC - Johnson County Community College",
    "16827": "MULTIPHONE-LA - Multiphone Latin America, Inc.",
    "16828": "DGA-SECURITY - DGA Security Systems, Inc.",
    "16829": "TESSCO-MD - Tessco Technologies",
    "16831": "FUJITSU - Fujitsu Network Communications, Inc.",
    "16832": "SECOM-1 - Secom, Inc",
    "16833": "PREBONYAMANEUSA - Tullett Prebon Americas Corp.",
    "16834": "WEBSTER-BANK - Webster Bank",
    "16835": "CENTURYLINK-16835 - CenturyTel Internet Holdings, Inc.",
    "16836": "UDATA - UData",
    "16837": "VABB - VIRGINIA BROADBAND LLC",
    "16838": "VERISIGN-CORP - VeriSign Infrastructure & Operations",
    "16839": "SNC Service-now.com  Number",
    "16840": "DAKOTACARE - Dakotacare",
    "16841": "GBLIT-N1 - GLOBAL IT",
    "16842": "5DL- - 5Nines Data, LLC",
    "16843": "CELLTEX-NETWORKS - Celltex Networks, LLC",
    "16844": "PSI-DALL - Property Solutions International, Inc.",
    "16845": "MAILERMAILER-N - MailerMailer LLC",
    "16847": "Servicios Informativos EMOL S.A.",
    "16848": "NEXG-NOC - NexG",
    "16849": "NewPlanet S.A",
    "16850": "SMITH-WESSON - Smith & Wesson",
    "16851": "NEBRKALINK - NebraskaLink",
    "16852": "LVLT-16852 - Level 3 Communications, Inc.",
    "16854": "HCCU-2 - Hapo Community Credit Union",
    "16856": "BLESSING-HEALTH-SYSTEM- - Blessing Hospital",
    "16857": "CENTEX - Central Texas Communications",
    "16858": "PTC-TUL-N - Perimeter Technology Center, LLC",
    "16859": "NAPHCARE-INC - NaphCare, Inc.",
    "16860": "HPS-TAMPA-INTERNET-SERVICES - HealthPlan Services, Inc.",
    "16861": "REVELEX - Revelex.com",
    "16862": "KANS-WICHITA- - Kansas Hosting, LLC",
    "16863": "HOMESC - Home Telephone Company, Inc.",
    "16865": "PERSONTEL - PERSON TEL INC",
    "16866": "TRAIL-NETWORKS - Columbia Networks Inc.",
    "16867": "-BANDWIDTH - Bandwidth.com Inc. - Engineering",
    "16868": "PRAXAIR-INC - Praxair Inc",
    "16869": "MIRAPOINT-RDOM - Critical Path Inc.",
    "16870": "PERSPECT20 - Perspectrix LLC",
    "16872": "MMDS-OKC - Meridian Data Systems",
    "16873": "-HARTS - HART SYSTEMS INC",
    "16874": "SONDA S.A.",
    "16875": "AON-BGP - AON",
    "16876": "ICANN-DC - ICANN",
    "16877": "VITAL - Vital Processing Services, LLC",
    "16878": "ISERVE - iServe Technologies, Inc.",
    "16879": "SUSQ-CTALK - Susquehanna Partners",
    "16880": "TRENDMICRO Global IDC and Backbone of Trend Micro Inc.",
    "16881": "PRALL-DAVID-C-INTERNET - Prall, Inc., David C",
    "16882": "CHMAN-EQUIPMENT-CO-N - CHMAN EQUIPMENT COMPANY",
    "16883": "WEBUNITED - Continental Broadband Florida, Inc DBA WebUnited",
    "16884": "TOURM-3 - Tourmaline Partners LLC",
    "16885": "TELEF\u00d4NICA BRIL S.A",
    "16886": "HEB--PRIMARY - HEB Grocery Company LP",
    "16887": "AETHERNETSANANTONIO - Aethernet LLC",
    "16888": "ADEC-AK20 - Alaska Distance Education Consortium",
    "16889": "STEVENS-TECH - Stevens Institute of Technology",
    "16890": "EDI-N1 - Executive Director, Inc.",
    "16891": "Sociedade Mineira de Cultura",
    "16892": "UCS-NETWORKS - Universal Computer Systems, Inc.",
    "16893": "TZOO - Travelzoo Inc.",
    "16894": "ECGLOBAL-COM - Motorola, Inc.",
    "16895": "SAN-BRUNO-CABLE - San Bruno Cable",
    "16896": "NCN - NCN",
    "16897": "RSI-AUS - Renaissance Systems, Inc.",
    "16898": "LOG-NET - Global Technology Services, Ltd.",
    "16900": "SEDGWICK-CMS - Sedgwick Claims Management Services, Inc.",
    "16901": "MUTUAL - MUTUAL OF ENUMCLAW",
    "16902": "TXU2 - TXU Business Services, Inc.",
    "16903": "TEX-SOUTHERN-UNIVERSITY - Texas Southern University",
    "16904": "ARVIG - Arvig Enterprises Inc.",
    "16905": "NTG - North Texas GigaPOP",
    "16906": "El Salvador Network, S. A.",
    "16907": "ISPKENYA",
    "16908": "ATRGNJ01 - Advanced Technologies Research Group, Inc.",
    "16909": "OAKRIDGEINVEST - Oak Ridge Investments, LLC",
    "16910": "FARM-CREDIT - Farm Credit Financial Partners, Inc.",
    "16911": "TELEF\u00d4NICA BRIL S.A",
    "16912": "4-LESS-NETWORK - 4 Less Communications, Inc.",
    "16913": "LOYNO-EDU - Loyola University New Orleans",
    "16914": "MBHARCH - MBH ARCHITECTS",
    "16915": "MINNESOTATWINSLLC - Minnesota Twins, LLC",
    "16916": "IPHONE-16916 - Michigan ComNet, Inc",
    "16917": "RYSTEC1-NET - Rystec Inc.",
    "16918": "CHRSOLUTIONS - CHR SOLUTIONS INC",
    "16919": "CBNY - The College Board",
    "16920": "WINDRIVER - Wind River Systems, Inc.",
    "16921": "INTELIGLOBE-1 - Inteliglobe USA, Inc.",
    "16922": "OUHSC-EDU - University of Oklahoma HSC",
    "16923": "CMA-11 - CMA CABLEVISION",
    "16924": "REGAL-NET-CHGO - REGAL SECURITIES, INC.",
    "16925": "-DBA-28 - Don Buchwald and Associates, Inc.",
    "16926": "INTERSTATE-BRANDS - Interstate Brands Corporation",
    "16927": "IHOP-KC - International House of Prayer",
    "16928": "UTCNET - United Technologies Corp",
    "16930": "IDLEPATTERN - Idle Pattern Communications, LLC",
    "16931": "GLOBAL-PAYMENTS-1 - Global Payments, Inc.",
    "16932": "FUTURE-ELECTRONIQUE-INC - Future Electronique Inc",
    "16933": "ADVANT - Advantas Internet Solutions",
    "16934": "LEACO-INTERNET - Leaco Rural Telephone",
    "16935": "KSC-NETWORKS - Kingland Systems Corp.",
    "16936": "TECHNORATI - Technorati, Inc.",
    "16938": "EXCEL-NET-01 - Excelsior College",
    "16939": "CARETECH-SOLUTIONS - CARETECH SOLUTIONS INC",
    "16940": "VOXEO - Voxeo Corporation",
    "16942": "CITIZENS - Citizens Telephone Cooperative",
    "16943": "REDCONDOR - Red Condor",
    "16944": "XYSTOS-PROD - Aerobic Technologies inc.",
    "16945": "CIMCO4 - CIMCO Communications, Inc.",
    "16946": "OBLONG - OBLONG INDUSTRIES, INC.",
    "16947": "MIMEOCOMINC - Mimeo.com, INC.",
    "16948": "STRATUSWAVE - StratusWave Communications",
    "16949": "EDAP - Edaptivity.com Inc",
    "16950": "STONE-LION-CAPITAL - Stone Lion Capital Partners L.P.",
    "16951": "IVANET-LIMA - IBIS INC.",
    "16952": "LIGHTSPEED - Lightspeed Datalinks",
    "16953": "ENCOMPS-DIGITAL-MEDIA-INC - Ascent Media Group, LLC",
    "16954": "TRT-NET - Three River Telco",
    "16955": "GETCO-CAR - Getco, LLC",
    "16956": "CATTARAUGUS-COUNTY - Cattaraugus County",
    "16957": "IDACORP-NETWORK - IDACORP INC",
    "16958": "BCIU-22 - Bucks County Intermediate Unit #22",
    "16959": "SBIS-AMRLTX - AT&T Internet Services",
    "16960": "Cablevision Red, S.A de C.V.",
    "16961": "HIPCS-DALL-SERVER-OFFICE - AT&T Internet Services",
    "16962": "HIPCS-IRVINE-ACCESS-OFFICE - AT&T Internet Services",
    "16963": "HIPCS-SOUTHFIELD-ACCESS-OFFICE - AT&T Internet Services",
    "16964": "HIPCS-NEW-YORK-ACCESS-OFFICE - AT&T Internet Services",
    "16965": "SBIS-SPFDMO - AT&T Internet Services",
    "16966": "SBCIDC-LSAN03 - AT&T Internet Services",
    "16967": "SBCIDC-DLLSTX - AT&T Internet Services",
    "16968": "ARC-N - Architectural Resources Cambridge, Inc.",
    "16969": "PICTORIALOFFSET - Pictorial Offset Corporation",
    "16970": "INFOSTEWARDS - InfoStewards, Inc.",
    "16971": "CHOICE-COMM - Choice Communications, LLC",
    "16972": "WEBFEAT - ProQuest LLC",
    "16973": "Corporacion Hostarica S.A.",
    "16974": "SUNWAVE - Sun Country Cablevision Ltd.",
    "16975": "Altocity.com",
    "16976": "FIVEK - Five K Technologies",
    "16977": "DODSONGROUP - The Dodson Group, Inc.",
    "16978": "MOVIECLIPS - Movieclips, Inc",
    "16980": "UNITEDGUARANTY - United Guaranty",
    "16981": "EMMIS-1 - Emmis Communications Corp.",
    "16982": "SUSQUEHANNA-26 - Susquehanna Bank",
    "16984": "N-AHPHOSTINGATL - AHPHosting, Inc.",
    "16985": "LIGHTYEAR-NETWORK-SOLUTIONS-LLC - Lightyear Network Solutions, LLC.",
    "16986": "CSM- - City of Santa Monica",
    "16987": "UHAUL-NET - UHAUL INTERNATIONAL, INC.",
    "16988": "IPAPER - International Paper",
    "16989": "UTMEM - The University of Tennessee, Memphis",
    "16990": "TRANSBANK S.A.",
    "16991": "CBTS--DC1 - Cincinnati Bell Technology Solutions",
    "16992": "FLT-15 - FIRST LINK TECHNOLOGY, INC.",
    "16993": "N-CFI - Cumberland Farms, Inc.",
    "16994": "VISTA-BANK - Vista Bank",
    "16995": "QL-N-KOP - Qlogic Corporation",
    "16997": "EPICOR - EPICOR",
    "16998": "ZEUSINC- - Zeus Industrial Products, Inc.",
    "16999": "WFSCORP - World Fuel Services Corporation",
    "17000": "LONSDALE- - Lonsdale Telephone Company, INC",
    "17001": "UMANITOBA - University of Manitoba",
    "17002": "AVISTA-CAPITAL - Avista Capital, Inc.",
    "17003": "ZOETIS-INC - Zoetis Inc.",
    "17004": "BROADBANDONDEMAND - KENTUCKYWIMAX",
    "17005": "NFL3 - National Football League",
    "17006": "EWNY - Executive Workspace, LLC",
    "17007": "ORBITAL - Orbital Sciences Corporation",
    "17008": "ADNET-SBU-00 - Booz Allen Hamilton",
    "17009": "SHOPKO-N - ShopKo Stores Operating Co., LLC",
    "17010": "HOOSIER-ENERGY - Hoosier Energy Rural Electric Cooperative, Inc.",
    "17011": "PPG-INDUSTRIES - PPG Industries, Inc.",
    "17012": "PAYPAL - PayPal, Inc.",
    "17013": "AIRG - AIRG INC",
    "17014": "NAIILLC - North Atlantic Internet, LLC",
    "17015": "VIBRANT-NJ - Vibrant Media Inc",
    "17016": "VOWNET-BROADBAND - The MEDIA COTTAGE Inc.",
    "17017": "DYNAMO-SERVERS - Dynamo Servers",
    "17018": "QTS-SACRAMENTO-1 - Quality Investment Properties Sacramento, LLC",
    "17019": "JCHOST-NET - JCHost Internet Services, LLC",
    "17020": "COMP-SCIENCE - Computer Sciences Corporation",
    "17021": "UNXCOM1 - Unx, LLC",
    "17022": "CELADON-TRUCKING-N - Celadon Trucking Services",
    "17023": "MORNEAU-SOBECO - MORNEAU-SOBECO, LP",
    "17024": "PIMC-HSF - PRIDE INTERNATIONAL MANAGEMENT COMPANY",
    "17025": "ABOVENET-CUSTOMER - Abovenet Communications, Inc",
    "17026": "ARBELLA - Arbella Insurance Group",
    "17027": "PEAK10ATL - Peak 10",
    "17028": "HR40W - Herzfeld & Rubin, P.C.",
    "17029": "CHP-NET - California Highway Patrol",
    "17030": "PRIMERICA-17030 - PRIMERICA LIFE INSURANCE COMPANY",
    "17031": "WINSTON-SALEM-SCHOOLS - Winston-Salem/Forsyth County Schools",
    "17032": "QUALCOMM-QWBS-SD - Qualcomm, Inc.",
    "17034": "STRATOGENT - Stratogent LLC",
    "17035": "NBCUNI-17035 - NBC UNIVERSAL",
    "17036": "LEWTAN-01 - Lewtan Technologies Incorporated",
    "17037": "GOINET - goINet, Inc.",
    "17038": "FLORI-62 - FTD",
    "17039": "SUPPLYPRO - SupplyPro, Inc.",
    "17040": "SEATTLE-TIMES - The Seattle Times",
    "17041": "-LRCOMM-ORIG - L.R. Communications, Inc.",
    "17042": "PANTHER-EXPEDITED-SERVICES - Panther II Transportation, Inc.",
    "17043": "AERIS-SJC-BGPNET - Aeris Communications, Inc.",
    "17044": "TRUENORTHCOMM - True North Communications",
    "17046": "ACTION-COMM - Action Communications, Inc.",
    "17047": "CENTURYTELECOMM - CenturyTel Solutions, LLC",
    "17048": "AWKNET - Awknet Communications, LLC",
    "17049": "MBO-NET - MBO Video, LLC",
    "17050": "MCVP--NO - TAC Partners, Inc.",
    "17051": "PURDUEPHARMA - Purdue Pharma LP",
    "17052": "TARGET - Target Corporation",
    "17053": "DADEPAPER - DADE PAPER CO",
    "17054": "17054 - CONTINENTAL BROADBAND PENNSYLVANIA, INC.",
    "17055": "UTAH - University of Utah",
    "17056": "CIPHERSPACE - CipherSpace, LLC",
    "17057": "BHUYNH - Best Audio Video Service Inc",
    "17058": "INTELLIVERSE - Intelliverse",
    "17059": "FOR-MSP - Fitness On Request LLC",
    "17060": "E-NETWORKS - E! Networks",
    "17061": "ROYALEENERGY - Royale Energy Inc",
    "17062": "HPES - Hewlett-Packard Company",
    "17063": "BFM-OB-CUST-US - Bloomberg Financial Market",
    "17064": "TISD-VIC - Testengeer Inc",
    "17065": "REALMED-PROD - REALMED CORPORATION",
    "17066": "MISSISSAUGA-OFFICE - Vonage Holdings, Inc.",
    "17067": "REALTRACS-NETWORKS - MTRMLS, Inc.",
    "17068": "N-OMIG - Ohio Mutual Insurance Company",
    "17069": "Cooperativa Telefnica y Otros Servicios deVilla Ge",
    "17070": "UBSW-CHICAGO - UBS AG",
    "17071": "UBSW-STAMFORD - UBS AG",
    "17072": "Iusacell PCS de Mexico, S.A. de C.V.",
    "17073": "ALLEGISGROUP7312 - Allegis Group",
    "17074": "SEPHIL-YIPES-65-175-52-0-A - Saul Ewing LLP",
    "17075": "PARA-1 - Parago Inc",
    "17076": "PIXELPUSHERS - PIXEL PUSHERS, INC.",
    "17077": "NETSTEP - Netstep Access Services",
    "17078": "ALLENCO - Allen & Company LLC",
    "17079": "Telemovil El Salvador S.A.",
    "17080": "SCRPRO-001 - The Screening Pros, LLC",
    "17081": "NKTR-02 - Nektar Therapeutics",
    "17082": "SMART-CITY-MIAMI-BEACH - Smart City Networks, L.P.",
    "17083": "SKYAUCTION - SKYAUCTION.COM",
    "17085": "-STOPLLC - SATELLITE TRACKING OF PEOPLE",
    "17086": "MILLICOM CABLE EL SALVADOR S.A. DE C.V.",
    "17087": "ROMANI - Roman, Inc.",
    "17088": "CURRENEX - Currenex, Inc.",
    "17089": "CINCCHILDRENS - Childrens Hospital",
    "17090": "DATABEBYDESIGNLLC - Database by Design, LLC",
    "17091": "HOLLCORP - Hollister Incorporated",
    "17092": "E-GREETINGS - E-Greetings Network",
    "17093": "FAIRPOINT - FAIRPOINT COMMUNICATIONS, INC.",
    "17094": "MUTOMAHA-I - Mutual of Omaha Insurance Company",
    "17095": "RVMCORP - Renal Ventures Management LLC",
    "17096": "SUMMITRACING - SUMMIT RACING",
    "17097": "AIGLP-N - Archview Investment Group, LP",
    "17098": "BROWNRICE-INTERNET-1 - Brownrice Internet, Inc.",
    "17099": "CALLIS-COMMUNICATIONS- - Callis Communications",
    "17100": "REMAT - Rematics LLC",
    "17101": "POLA- - PORT OF LOS ANGELES",
    "17102": "IIX-LABS - IIX Corp.",
    "17103": "JRC-NETWORK-SERVICES - Jensen Research Corporation",
    "17104": "NORTHERN-LEING-SYSTEMS-INC - Northern Leasing Systems, Inc.",
    "17105": "NISA-STL - NISA Investment Advisors",
    "17106": "MIDWESTWIRELESS - Cellco Partnership DBA Verizon Wireless",
    "17107": "AHP-N - Adams Hill Capital LLC",
    "17108": "Honos Data Exchange Inform\u00e1tica Ltda",
    "17109": "HARDSOFT - HardSoft Solutions Inc.",
    "17110": "YAHOO-US2 - Yahoo",
    "17111": "MEGAPATH4-US - MegaPath Corporation",
    "17112": "BBDO-NY - BBDO New York",
    "17113": "COMMRAIL - Access Northeast Inc.",
    "17114": "BANKLINK - Banklink",
    "17115": "THEWIREINT - The Wireless Inter-net Inc",
    "17116": "BHPHOTO - B & H Foto & Electronics Corp.",
    "17118": "VIMS - Virginia Institute of Marine Science",
    "17119": "KAMPUNG - Kampung Communications",
    "17120": "NBDOE - New Brunswick Department of Education",
    "17121": "KGBCORPN - INFONXX, INC.",
    "17122": "PATRINA-N - Patrina Corporation",
    "17123": "TEAM-HEALTH - Team Health, Inc.",
    "17124": "SOUTHARK - South Arkansas Community College",
    "17125": "LOGIS-N-01 - Logistics Plus, Inc.",
    "17126": "E-money",
    "17127": "KGI-NV - Konami Gaming, Inc.",
    "17128": "THL-PARTNERS - Thomas H. Lee Management Co., LLC",
    "17129": "FIDALGO-NET-1 - Fidalgo Networking, Inc.",
    "17130": "JONESDAY - Jones, Day, Reavis & Pogue",
    "17131": "VIBRANT-CA - Vibrant Media Inc",
    "17132": "MPOOLJXN1 - The Modem Pool",
    "17133": "NEXTEL-DEV - Nextel Communications, Inc.",
    "17134": "BEDFORDSTMARTINS - Bedford/St. Martin's",
    "17135": "OHIOU - Ohio University",
    "17136": "SPANGROUP-UTI - Span Manufacturing Ltd.",
    "17137": "HAWKEYE-SYNIVERSE - Hawkeye Switching LLC.",
    "17138": "EBG - Epstein Becker & Green, P.C.",
    "17139": "CORPCOLO - Corporate Colocation Inc.",
    "17140": "CBRE-US - CBRE, INC.",
    "17141": "TELIUVO-TOR - Teliuvo, Inc.",
    "17142": "THEROFTONLINE - Therasoft Online Inc",
    "17143": "WINNTELECOM - Winn Telecom",
    "17144": "NUANCE-NOD - NUANCE COMMUNICATIONS, INC",
    "17145": "TEAJAX - THE ENERGY AUTHORITY",
    "17147": "Ministerio del Interior y de Seguridad Publica - Gobierno de Chile",
    "17148": "FIRST-NATIONAL",
    "17149": "GCN- - Global Caribbean Network",
    "17150": "AFCU - America First Credit Union",
    "17151": "VONAGE - Vonage Holdings, Inc.",
    "17152": "BATES - Bates College",
    "17153": "NMT- - New Mexico Institute of Mining and Technology",
    "17154": "ALLST-17154 - Allstream Corp.",
    "17155": "LYDALL - Lydall, Inc.",
    "17156": "ZIXI - Zix Corporation",
    "17157": "CLEAR-CHANNEL--17157 - Clear Channel Communications, Inc.",
    "17158": "DATTO-DSS - Datto, Inc",
    "17159": "LNT-INFOTECH-FSTI - L&T Infotech Financial Services Technologies Inc.",
    "17160": "MB-BGP-VEREXP - Mango Bay Communications, Inc.",
    "17161": "MARSH Marsh Inc.",
    "17163": "AFGINC-1 - Great American Insurance Company",
    "17164": "CENTRACAREHEALTHSYSTEM - St. Cloud Hospital",
    "17165": "THE-PALEY-CENTER-FOR-MEDIA - The Paley Center for Media",
    "17166": "TRAVELERSPC - Travelers Property Casualty Corp.",
    "17167": "MCSNOC01 - Microchip Computer Solutions, Inc.",
    "17168": "TFO-BOSTON - Thomson Reuters U.S. LLC",
    "17169": "VINCI-N - Vinci Consulting, Corp",
    "17170": "STAGENET - Stage Networks LLC",
    "17171": "Q-1720 - Quantum Aviation Solutions, Inc.",
    "17172": "FJDPNET - FIFTH JUDICIAL DISTRICT OF PA",
    "17173": "PPE - NetLink Services, Inc.",
    "17174": "WALMARTLABS - Cosmix Corporation",
    "17175": "NSS-UK New Skies Satellites UK",
    "17176": "NETAPPSERV - Network Application Services, Inc.",
    "17178": "MOTIONINDUSTRIES - Motion Industries",
    "17179": "ETS104 - ExpressPoint Technology Services Inc.",
    "17180": "MFS-TKY - Massachusetts Financial Services",
    "17181": "YYC - The Calgary Airport Authority",
    "17182": "ISP Proveedora S.A.",
    "17183": "RAPIDVPS-COM - Infinitum Technologies Inc.",
    "17184": "ATL-CBEYOND - CBEYOND COMMUNICATIONS, LLC",
    "17185": "QUONIXNET - Quonix Networks Inc.",
    "17186": "DSTHS-N - DST Health Solutions",
    "17187": "EMC-17187 - EMC Corporation",
    "17188": "ACS-OAK - ACS Inc.",
    "17190": "WMATA - Washington Metropolitan Area Transit Authority",
    "17191": "PTS-TONTITOWN - P.A.M. Transportation Services Inc.",
    "17192": "LEK - LEK Internet Services, Inc.",
    "17193": "NETLINC-SERVICES - Superior Consultant Company",
    "17194": "LPGAHQ - LPGA",
    "17195": "JAMES-TOWER - James Tower Media Design",
    "17196": "COD-GE-IL - College of duPage",
    "17197": "DAEDELUS - The Daedelus Group",
    "17198": "INNOVATIONSLAB - Nortel Networks",
    "17199": "SWAGELOK - Swagelok Company",
    "17200": "SEATTLECOLL - Seattle Community College District",
    "17201": "GGC-6 - Georgia Gulf Corporation",
    "17202": "FGCU-FTM1 - Florida Gulf Coast University",
    "17204": "Nominum Global NameServer network",
    "17205": "CORP BANCA, C.A.",
    "17207": "COLOR-COLL - Colorado College",
    "17208": "PROJESOM INTERNET LTDA",
    "17209": "NORTHWEST-EVALUATION-SOCIATION - NORTHWEST EVALUATION SOCIATION",
    "17211": "GTEC-ORG-ARIN - Grafton Technologies, Inc.",
    "17212": "UHC1700 - University Healthsystem Cosortium",
    "17213": "FILTRONAPT-RIC - Filtrona Porous Technologies, Corp.",
    "17214": "GUIDEWIRE - Guidewire Software, Inc.",
    "17215": "AMEREN-3 - Ameren Corp.",
    "17216": "DC74- - DC74 LLC",
    "17217": "ADMWORLD - ARCHER DANIELS MIDLAND",
    "17218": "-DIGITAL-HIGHWAY-LLC - Digital Highway, LLC",
    "17221": "GRAUBARD - Graubard, Mollen & Miller, LLP.",
    "17222": "Mundivox do Brasil Ltda",
    "17223": "LATISYS-CHICAGO - Latisys-Chicago, LLC",
    "17224": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17225": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17226": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17227": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17228": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17229": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17230": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17231": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17232": "AT&T US",
    "17233": "ATT-CERFNET-BLOCK - AT&T Enhanced Network Services",
    "17234": "GAC - Gustavus Adolphus College",
    "17235": "COMTIME - Commercial Timesharing, Inc.",
    "17236": "TULSAL-74103 - Tulsa City-County Library",
    "17238": "CSEG-1 - Columbia Southern Education Group, Inc.",
    "17239": "HIGHSPEEDWEB - High Speed Web/Genesis 2 Networks",
    "17240": "CLSMATES-1 - Classmates Online Inc.",
    "17241": "QUANTALGO - Quantalgo Ventures, Inc.",
    "17242": "UNIPAC - UNIPAC Service Corporation",
    "17243": "BRTRC - BRTRC",
    "17244": "MCNEESE - McNeese State University",
    "17245": "APEX - Apex Clearing Solutions, LLC",
    "17246": "VOXITYNET - Voxity Telecom, Inc",
    "17247": "TU - The Times Union",
    "17248": "INTERGLOBECOMMUNICATIONSINC - InterGlobe Communications, Inc.",
    "17249": "BURSATEC, S.A. DE C.V.",
    "17250": "ADETEL, S.A. DE C.V.",
    "17251": "MONST-3 - Monster Worldwide, Inc.",
    "17252": "VDI - Virtual Development INC",
    "17253": "COMMUNIGROUP - TEC of Jackson, Inc.",
    "17254": "TNE-GLOBAL-TELECOM-LLC - TNE Global Telecom, LLC.",
    "17255": "Diveo Uruguay",
    "17256": "CIC-SCCA- - Creative Interconnect Communications LLC",
    "17257": "Collective Mind Chile S.A.",
    "17258": "ATT-MOBILITY-LLC-17258 - AT&T Mobility LLC",
    "17259": "ELYNX-CORP-NET - eLynx Ltd.",
    "17261": "CHEMOILUS - Chemoil Corporation",
    "17262": "CARNEGIEHALL-NY-881 - Carnegie Hall",
    "17263": "CLFH-N-NM - CITYLINK FIBER HOLDINGS, INC.",
    "17264": "CERNER-COM - Cerner Corporation",
    "17265": "GGC-6 - Georgia Gulf Corporation",
    "17266": "HOSTSERVE-NET- - Networx Internet & Networking Solutions Inc.",
    "17268": "COSMOCOM - CosmoCom, Inc.",
    "17269": "NCFB-N - North Carolina Farm Bureau Mutual Insurance Company Inc",
    "17270": "NYSTRS-1 - New York State Teachers' Retirement System",
    "17271": "MSH - Management Sciences for Health, Inc.",
    "17272": "ROTH-NET - ROTH CAPITAL PARTNERS, LLC",
    "17273": "CTX-MORTGAGE - CTX Mortgage Company, LLC",
    "17274": "RWBAIRD - Robert W. Baird",
    "17275": "FMAC-I-BILLING - Federal Home Loan Mortgage Corporation",
    "17276": "SEIC-CORP-1 - SEI Investments",
    "17277": "CHARTER-17277 - Charter Communications",
    "17278": "IONACOLLEGE - Iona College",
    "17279": "KANS-BROADBAND-INTERNET - Propel Wireless Internet, LLC",
    "17280": "N-PRIORITY-HEALTH - Priority Health",
    "17281": "-15 - CONSORTIUM FOR WORKER EDUCATION",
    "17282": "HSNI-LLC - HSN Interactive LLC",
    "17283": "MARKET-FACTS - Synovate, Inc.",
    "17284": "VONAGE-17284 - Vonage Holdings, Inc.",
    "17285": "VIAMEDIA-LEX-KY - Viamedia, Inc.",
    "17286": "PCRMC-ROLLA - Phelps County Regional Medical Center",
    "17287": "Universidad de Carabobo",
    "17288": "KANAKUKMINISTRIES - Kanakuk Ministries",
    "17289": "VERMILLION- - Vermillion Asset Management, LLC",
    "17290": "BLUE-MOUNTAIN - Bluemountain.com a division of Excite At Home Corp.",
    "17291": "MCMILLIN-SANANTONIO - McMillin Texas Homes, LLC",
    "17292": "INFOED-INTERNATIONAL - InfoEd International Inc",
    "17293": "VTXC - VTX Communications",
    "17294": "CARL - Colorado Alliance of Research Libraries",
    "17295": "EHI-CALLCENTER - eHealthInsurance Services Inc.",
    "17297": "ACS-COC-TX - CITY OF CARROLLTON - TEX",
    "17298": "ROEHL- - ROEHL TRANSPORT, INC.",
    "17299": "IPS-4 - iPass Incorporated",
    "17301": "FTENAL - Fastenal Company",
    "17302": "HARTE-HANKS - Harte-Hanks Inc.",
    "17303": "MAILMESSENGER - Mailmessenger Networks, Inc.",
    "17305": "WORLDPOST--01 - WorldPost Technologies, Inc.",
    "17306": "NETCONX - JAB Wireless, INC.",
    "17307": "VIRTELA-NET-VCODEN1 Virtela Communications",
    "17308": "WTI-N - WTI, LLC",
    "17309": "7260 - Roosevelt University",
    "17310": "BVU-2 - BRISTOL VIRGINIA UTILITIES",
    "17311": "ECMC-BGP - Erie County Medical Center",
    "17312": "TERNETCONNEC",
    "17313": "THECBEGROUP - THE CBE GROUP, INC",
    "17314": "REDHAT-HOSTED - Red Hat, Inc.",
    "17315": "RECYCLEBANK - RecycleBank",
    "17316": "AETHERQUEST - AetherQuest Solutions, Inc.",
    "17318": "DOMAINTOOLS - DomainTools, LLC",
    "17319": "MTPCS-N - MTPCS LLC",
    "17320": "CFCU - Coastal Federal Credit Union",
    "17321": "GAZILLION - Gazillion Entertainment",
    "17322": "NAVIGY-HOLDINGS - Navigy Holdings, Inc.",
    "17323": "ARA-SWD - Applied Research Associates",
    "17324": "ALNET - Albert Einstein College of Medicine",
    "17325": "AUTOPARTINTL - AUTOPART INTERNATIONAL INC",
    "17326": "CONCORDIA-COLLEGE - Concordia College",
    "17327": "TSTC- - Texas State Technical College at Waco",
    "17328": "MANULIFE - The Manufacturers Life Insurance Company",
    "17330": "FIREEYE- - FireEye, Inc.",
    "17331": "MINDBYTES-BCP1 - Mindbytes Consultants, Inc.",
    "17332": "SCIENTECH - Scientech,Inc.",
    "17333": "COLLEGE-OF-SAINT-MARY - College of Saint Mary",
    "17334": "AKAM-SOS-17334 - Akamai Technologies, Inc.",
    "17335": "TPLLC-NJ - Third Point LLC",
    "17336": "PMG-NOR - Poli Mortgage Group Inc.",
    "17337": "J-WN - J-W Operating Company",
    "17338": "17338 - AOScloud, LLC.",
    "17339": "SAFELITE - Safelite Glass Corp.",
    "17340": "-ZERIT - ZER IT LLC",
    "17341": "STORAGECRAFT-DRAPER - StorageCraft Technology Corporation",
    "17343": "SFWMD - South Florida Water Management District",
    "17344": "ENGLEWD- - Englewood Hospital",
    "17345": "PHONEFACTOR-02 - PhoneFactor, Inc.",
    "17346": "BITNIK - Bitnik, Inc",
    "17347": "PEPCO - Potomac Electric Power Company",
    "17348": "FULLS-2- - FULL SPECTRUM COMMUNICATIONS, INC.",
    "17349": "SUNGARD-AMS-DOM - Sungard Data Systems",
    "17350": "KMV-LLC - Moody's KMV",
    "17351": "VAMPCOMM - VAMP Communications, Inc.",
    "17352": "APPLICATIONX - Application X",
    "17354": "DAKOTA - DakotaPro.biz",
    "17355": "WSD - Wayzata School District, ISD #284",
    "17356": "VERMONT-TELE - Vermont Telephone Company, Inc.",
    "17357": "-DCI-31 - Development Corporation for Israel",
    "17358": "ETOLL1 - eToll, Inc.",
    "17359": "TELOV-FL-TPA - Telovations, Inc.",
    "17360": "PNCBANK-RIV - PNC BANK NA",
    "17361": "BRS - Sungard Trading System (C)",
    "17362": "NESTEGG - Nestegg, LLC",
    "17363": "FORTRESSITX-LA - FortressITX",
    "17364": "SOKA-UNIVERSITY-OF-AMERICA - Soka University of America",
    "17365": "CITY-OF-FRESNO - City of Fresno",
    "17366": "ARINCN - ARINC, Inc.",
    "17367": "382-COM-NY - 382 Communications Corporation",
    "17368": "TWRS-1V - Towerstream I, Inc.",
    "17369": "CHAPNET - Chapman University",
    "17370": "MCAFEE-COM - McAfee, Inc.",
    "17371": "BMO-TOR1 - Bank of Montreal",
    "17372": "BANK-OF-MONTREAL BANK OF MONTREAL IRELAND PLC",
    "17373": "MCI-COV - MCI WorldCom",
    "17374": "WALMART - WALMART.COM",
    "17375": "EXPERIS-DATA-CENTERS-OF-VA-DR-SOLUTIONS - Virginia DR Solutions, LLC",
    "17376": "Laissez Faire City",
    "17377": "PWI-DFW - Penson Financial Services, Inc.",
    "17378": "DBSINTL1 - DBS INTERNATIONAL",
    "17379": "Intelig Telecomunica\u00e7\u00f5es Ltda.",
    "17380": "PROJ-MUT-TEL - Project Mutual Telephone Cooperative Association, Inc.",
    "17381": "-WSI-ECOM-WEST - Williams-Sonoma",
    "17382": "HEALTHNOW-NY- - HEALTHNOW NEW YORK, INC.",
    "17383": "SBLI-USA - SBLI USA Mutual life Insurnace Company, Inc.",
    "17384": "DIGITEC-INTERACTIVE - Digitec Interactive, LLC",
    "17385": "ORBITEL - Orbitel Communications, LLC",
    "17386": "GRAINGER - W.W.GRAINGER",
    "17387": "ROMAN - Roman & Associates",
    "17388": "HOVERNET- - Hover Networks, Inc.",
    "17389": "IHS-GROUP - Information Handling Services",
    "17390": "AT-AND-T AT&T GLOBAL NETWORK SERVICES",
    "17391": "CPWR-DTW-N01 - Compuware Corporation",
    "17392": "HOLW-GOLD - Holwell Shuster & Goldberg LLP",
    "17393": "SERVERGRID - The Aldridge Company",
    "17394": "NETAPP--1 - NetApp, Inc.",
    "17395": "BSTZ- - Blakely Sokoloff Taylor & Zafman, LLP",
    "17396": "TL5-1 - Tech Level 5, LLC",
    "17397": "OPTIMAL-PAYMENTS - SUREFIRE COMMERCE",
    "17398": "IPS-COM - iPass Incorporated",
    "17399": "BT LATAM Venezuela, S.A.",
    "17400": "EBONET",
    "17401": "ERTACH S.A.",
    "17402": "EMBARQ-CHSK - Embarq Corporation",
    "17403": "HSIS- - HyperSurf Internet Services, Inc.",
    "17404": "CENTERPOINT-SBW - Centerpoint Marketing, Inc.",
    "17406": "EPSCU - PSCU Service Centers Inc.",
    "17407": "CHERRYROAD-TECH - CherryRoad Technologies, Inc.",
    "17408": "ABOVE--AP AboveNet Communications Taiwan",
    "17409": "EFTEL--AP EFTel Pty Ltd",
    "17410": "N-NZDG-AP  # -NZDG-AP CONVERTED TO N-NZDG-AP FOR RPSL COMPLIANCE Anchor House, Hamilton, New Zealand.",
    "17411": "IO-GLOBAL-AP Internet Service Provider",
    "17412": "WOOSHWIRELESSNZ Woosh Wireless",
    "17413": "TWART-TW GRADE Technology CO., Ltd.",
    "17414": "SUIO-TW Suio Inc., ADSL Internet Service Provider,",
    "17415": "TWC-TW Trans World Communication Co., Ltd.",
    "17416": "DWINS-TW DWINS Digital Service Corp.,",
    "17417": "DYXNET-TW Diyixian.COM (TW) Ltd.",
    "17418": "TAT-TW TRANSIA INFORMATION SERVICES INC.",
    "17419": "HINET-IPV6-TW HiNet IPv6 Service Network.,",
    "17420": "ACCSI-TW Acer CyberCenter Services, Inc.",
    "17421": "EMOME-TW Long Distance & Mobile Business Group,",
    "17422": "PCSNET-TW PACIFIC COMPUTER SYSTEMS INC.",
    "17423": "SUREPREP--AP Sureprep",
    "17424": "GEIS-PACHK- GEIO PAC regional office",
    "17425": "EPA--TH Provincial Electricity Authority of Thailand.",
    "17426": "PRIMENET--AP Primesoftex Ltd",
    "17427": "THSUZUKI--AP Thai Suzuki Motor Co.,Ltd.",
    "17428": "CHINA-ABITCOOL 21Vianet.Co.,Ltd",
    "17429": "BGCTVNET BEIJING GEHUA CATV NETWORK CO.LTD",
    "17430": "GWBN-CHENGDU Great Wall Broadband Network Service Co.,Ltd",
    "17431": "TONET Beijing TONEK Information Technology Development Company",
    "17433": "PHILWEB-AP PhilWeb.Com, Inc.",
    "17434": "RBA-AUS-AP RESERVE BANK OF AUSTRALIA",
    "17435": "WXC--NZ WorldxChange Communications LTD",
    "17436": "ICICIBANK- ICICIBANK Ltd, Banking, Mumbai",
    "17437": "ROTHSCHILDAM--AP Rothschild Asset Management",
    "17438": "IPNET-MELB--AP Melbourne POP",
    "17439": "NETMAGIC-AP Netmagic Datacenter Mumbai",
    "17440": "PRONET-AP Putrabu Rajasa Galuh, PT",
    "17441": "SAWDEESHOP--AP INTERNET SERVICE PROVIDER",
    "17442": "CHINANETCENTER-AP Internet Service Provider in China",
    "17443": "KARNET-AP Karuturi Telecom Pvt Ltd",
    "17444": "NWT--AP  number for New World Telephone Ltd.",
    "17446": "POWERLAN--MEL Powerlan Limited",
    "17447": "NET4-IN Net4India Ltd",
    "17448": "WEB-COM--AP Web.com.ph Inc.",
    "17449": "DAH-PRIVATEBANK--AP D.A.H. Private Bank",
    "17450": "ANGKA-KOMUNIKI-ID PT Angkasa Komunikasi Global Utama",
    "17451": "BIZNET--AP BIZNET NETWORKS",
    "17452": "BITSTOP--AP Bitstop Inc",
    "17453": "CYQ- AUTONOMOUS SYTEM FOR MUMBAI-IDC",
    "17454": "HINDONET--ID-AP PT Hasindo Net",
    "17456": "PDSGUAM-USTRANSPORT--GU-AP Pacific Data Systems",
    "17457": "YAHOO-AU-AP internet content provider",
    "17458": "CWNETDG-IO-AP Cable and Wireless",
    "17459": "M2TELECOMMUNICATIONS-AP M2 Telecommunications Group Ltd",
    "17460": "AYD--AP Customer name is Ayudhya Capital Auto Lease Public Company Limited which is one financial in Thailand. His website is http://www.krungsriauto.com. Address of company is 3rd Fl., 87/1 Capital Tower and 30th Fl., 87/2 CRC Tower ,All Seasons Place ,Wireless Road.,Lumpini,Pathumwan,Bangkok 10330",
    "17461": "DPWSAU-AP NSW Department of Commerce",
    "17462": "INDIGO--AP 8.1 Graphix Row",
    "17464": "TMIDC-AP Hosting Services (MYLOCA),",
    "17465": "IANET Cable ISP in India",
    "17466": "GLOBAL-GECIS The  number for GECIS global for their internet peering",
    "17467": "HWC--AP Hostworks Pty Ltd",
    "17468": "TRUE-SERVICE1--AP True Internet Co.,Ltd.",
    "17469": "ACCESSTEL--AP Access Telecom (BD) Ltd.",
    "17470": "ETISALATLK- Etisalat Lanka (Pvt) Ltd.",
    "17471": "CYBERNET-BD- Grameen Cybernet Ltd. Bangladesh.  for local peering and transit. Dhaka",
    "17472": "BNZ-NZ Bank of New Zealand NZ-based networks",
    "17473": "E2-CLOUD--AP emPOWER Data Services",
    "17474": "CONCEPT-NET--NZ-AP ConceptNet Limited. Internet Service Provider. New Zealand",
    "17475": "PENINSULA-CSLOX--TH Siam Chaopraya Holdings Co.,Ltd (The Peninsula Bangkok)",
    "17476": "INFODYNE-TRANSIT- InfoDyne, Inc. Internet and Managed Services",
    "17477": "MCT-SYDNEY Macquarie Telecom",
    "17478": "ICS--AP International Community School which is K-12",
    "17479": "CMU-TH-AP Chiang Mai University",
    "17480": "CANL CANL",
    "17481": "ITBECAMP--AP I.T. Basecamp Pty Ltd",
    "17482": "HOTON--AP HOTON GUANGZHOU",
    "17483": "CITYSERV--AP CityOnline Services Ltd",
    "17484": "WELLINGTONLOOP-NZ-AP The Wellington Schools Loop Network,",
    "17485": "TID-HK-AP Trade and Industry Department, the Government of the Hong Kong Special Administrative Region",
    "17486": "SWIFTEL1-AP People Telecom Pty. Ltd.",
    "17487": "ICBCIA-AP Industrial and Commercial Bank",
    "17488": "HATHWAY-NET-AP Hathway IP Over Cable Internet",
    "17489": "NIIT-CSLOX--TH NIIT Technologies (Thailand) Ltd.",
    "17490": "ETFIBER- Broadhand IP Network based DWDM",
    "17491": "CONSULTTECH-AP CONSULTTECH  Number",
    "17492": "VECTOR-COMMUNICATIONS- Vector Communications LTD.",
    "17493": "AMAZON-AP-RESOURCES--AP-SIN Amazon Asia-Pacific Resources Private Limited",
    "17494": "BTTB--AP Telecom Operator & Internet Service Provider as well",
    "17495": "GATEWAY-AP BROADBAND WIRELESSS INTERNET SERVICE PROVIDER",
    "17496": "VISION-AU Leica Microsystems Biosystems Division Melbourne and Invetech",
    "17497": "ENTERPRISEITPTYLTD--AP Enterprise IT Pty Ltd. ISP and Hosting Centre Albury",
    "17498": "CINENET--AP Cinenet Systems Pty Ltd",
    "17499": "CLUB21-CSLOXINFO--TH Club21",
    "17500": "TELSTRAGLOBAL-IX-HK-AP Reach Networks HK Ltd.",
    "17501": "WLINK-NEPAL--AP WorldLink Communications Pvt Ltd",
    "17502": "IAINFRA-TW-AP AsiaInfra International Ltd.",
    "17503": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17504": "NETCOM NRI Netcom, Ltd.",
    "17505": "SBMOBILE SOFTBANK MOBILE Corp.",
    "17506": "UCOM UCOM Corp.",
    "17507": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17508": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17509": "STARNET STARNET Co.,Ltd.",
    "17510": "ISID INFORMATION SERVICES INTERNATIONAL - DENTSU, LTD.",
    "17511": "K-OPTICOM K-Opticom Corporation",
    "17512": "JAL Japan Airlines International Co., Ltd.",
    "17513": "KIDS-NET Kids-way Corporation",
    "17514": "AICS Otsuka Corp.",
    "17515": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17516": "NTTCOMWARE NTT COMWARE CORPORATION",
    "17517": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17518": "SHIOJIRI Shiojiri City",
    "17519": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17520": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17521": "KUT Kochi University of Technology",
    "17522": "NTT-WEST NIPPON TELEGRAPH AND TELEPHONE WEST CORPORATION",
    "17523": "AOYAMA Aoyama Gakuin University",
    "17524": "DSN DS Networks",
    "17525": "M-NET Japan Cablenet Limited",
    "17526": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17527": "MEDI CHITA MEDI NETWORK INC.",
    "17528": "COSMOS-NET Okinawa Tele Message Corporation",
    "17529": "MEDIACAT COMMUNITY NETWORK CENTER INC.",
    "17530": "NNS Nihon Network Service Co, .Ltd.",
    "17531": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17532": "T-KOUGEI Tokyo Polytechnic University",
    "17533": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17534": "NSK NSK Co.,Ltd.",
    "17535": "GENISYST--AP Genisyst Pty Ltd",
    "17536": "TVP-HOLDING-COMPANY-AP TVP HOLDING COMPANY-AP",
    "17537": "JOSNSCHK-AP Jardine OneSolution",
    "17538": "CIRCLECOM--ID-AP PT. Circlecom Nusantara Indonesia",
    "17539": "N-NCKHI-AP NetSol Connect",
    "17540": "MTL-AP Modern Terminals Limited",
    "17541": "PACCESS- Professional Access,",
    "17542": "HORTRESEARCH--NZ-AP HortResearch Limited",
    "17543": "MELB-IT-US- Melbourne IT US",
    "17544": "INTELSAT-AP N for Intelsat Asia-Pac Network",
    "17545": "DATACOMMALAYSIA--AP Datacom - Malaysia",
    "17546": "JIGSAW-NON-AP Jigsaw Technology, Sydney",
    "17547": "QALA-SG-AP M1 CONNECT PTE. LTD.",
    "17548": "ATOSINFOTECH-SG-AP ATOS Information Technology (Singapore) Pte Ltd",
    "17549": "NCS-SG-AP IDC of NCS in Singapore",
    "17550": "SMC--AP San Miguel Corporation",
    "17551": "DCSINTERNET--AP DCS Internet",
    "17552": "TRUE--AP True Internet Co.,Ltd.",
    "17553": "IPBNET--AP Bogor Agricultural University",
    "17554": "CITIC-HK-AP Citic Telecom International (Data) Limited.",
    "17555": "SPRINGFIELD--AP Springfield NOC",
    "17556": "TRUE-SUB1--AP TRUE INTERNET Co.,Ltd.",
    "17557": "PKTELECOM--PK Pakistan Telecommunication Company Limited",
    "17558": "GLOBALONE-SG-AP Orange Business VPN Gallery",
    "17559": "SPECTUM-NON-AP Spectrums Core Network",
    "17560": "N-PACIFIC-INTERNET-IX Pacific Internet Ltd",
    "17561": "DOFWA-AP Department of Finance - Western Australia",
    "17562": "DATACOM-SYSTEMS Datacom Systems (NSW)",
    "17563": "NEXLINX--AP Autonomous System Number for Nexlinx",
    "17564": "GITN-PCN--AP GITN (M) Sdn. Bhd.",
    "17565": "ADC-BUDDYB- Advance Datanetwork Communications Co.,Ltd. BuddyB service. Bangkok",
    "17566": "POWERLAN-SYD- Powerlan Limited",
    "17567": "IREX--KR Airport Railroad Co ltd",
    "17568": "SCCK--KR Standard Chatered Capital (Korea)",
    "17569": "AJMOTOR--KR AJOU MOTOR COLLEGE",
    "17570": "SKGLOBAL--KR SK Global co., Ltd",
    "17571": "HANACARDEMS HANK card",
    "17572": "HDLNET--KR Hyundai Logistics",
    "17573": "MINS--KR Qrix Daegu, inc",
    "17574": "SMGCC--KR Seoul Metropolitan Government Computer Center",
    "17575": "CAUNET--KR CHUNG-ANG UNIVERSITY",
    "17576": "KOSEF--KR Korea Science and Engineering Foundation",
    "17577": "GIGAPS--KR YOUNGNAM CABLE NETWORK",
    "17578": "HALLA--KR CHEJU HALLA UNIVERSITY",
    "17579": "KREONET2--KR Korea Institute of Science and Technology Information",
    "17580": "KRNIC--BLOCK KRNIC",
    "17581": "HCH--KR SUSUNG BROADCTING CO., LTD.",
    "17582": "KIC--KR Korea Investment Corporation",
    "17583": "KCNNET--KR Keumgang Cable Network",
    "17584": "ICE--KR Inchon Metropolitan  Office Of Education",
    "17585": "PPS--KR Public Procurement Service The Republic of Korea",
    "17586": "NARPEEDNET--KR Nara Cable TV Inc",
    "17587": "EDUHANSOL--KR HANSOL GYOYOOK",
    "17588": "DAEGUBANK--KR The Daegu Bank, Ltd",
    "17589": "GABIA--KR GABIA Inc.",
    "17590": "KGPC--KR Korea Game Promotion Center",
    "17591": "KRFNET--KR korea Research Foundation",
    "17592": "IBK--KR Industrial Bank of Korea",
    "17593": "NONGSHIM--KR NDS Coporation",
    "17594": "INTERTNS--KR INNOSOFT. INC.",
    "17595": "KINSNET--KR Korea Institute of Nuclear Safety",
    "17596": "CST21--KR Computer Solution Technology co.,ltd.",
    "17597": "SAEROMNET--KR TBROAD Saerom Broadcasting",
    "17598": "YBN--KR YBN",
    "17599": "YUHAN--KR Yuhan College",
    "17600": "ENVICO--KR Korea Environment & Resources Corporation",
    "17601": "KCGF--KR KOREA CREDIT GUARANTEE FUND",
    "17602": "GNEDU--KR Kyongnam Education Science Research-center",
    "17603": "KUMOH--KR Kumoh National University Technology",
    "17604": "KIISS--KR NCA",
    "17605": "MJIDC--KR Myongji college",
    "17606": "HJS--KR Hanjing Shipping",
    "17607": "ATT7192--KR ATT GNS korea",
    "17608": "ABN--KR ABN",
    "17609": "SILLAUNIVERSITY--KR Silla Univ.",
    "17610": "ABRAIN--KR ABRAIN",
    "17611": "GWANAKGU--KR Gwanak-Gu OFFICE",
    "17612": "MAPOGU--KR Mapo-gu Office",
    "17613": "CICKOREA--KR CICKOREA",
    "17614": "GEUMGANG--KR Geumgang University",
    "17615": "CJU--KR Cheongju University",
    "17616": "HICARDIRECT--KR Hyundai Hicar Direct Car Insurance Co.,ltd",
    "17617": "NYP--AP Nanyang Polytechnic",
    "17618": "DTF-WA-GOV-AU-AP Department of Treasury & Finance, Western Australia",
    "17619": "POWERNETIX- POWERNETIX",
    "17620": "CNCGROUP-BJ CNCGROUP IP network of Beijing region MAN network",
    "17621": "CNCGROUP-SH China Unicom Shanghai network",
    "17622": "CNCGROUP-GZ China Unicom Guangzhou network",
    "17623": "CNCGROUP-SZ China Unicom Shenzen network",
    "17624": "QUALCOMM-BLR--AP Qualcomm Inc. Bangalore , Developer of CDMA Technology India",
    "17625": "BLAZENET-IN-AP BlazeNet's Network",
    "17627": "MTT--AP Dialog Broadband Networks (Pvt.) Ltd.",
    "17628": "PERTHIX--AP Perth iX",
    "17629": "BACKBONE-WUHAN-AP Backbone of Wuhan Metropolitan Area Network",
    "17630": "HKEDCITY--HK-AP Hong Kong Education City Ltd",
    "17631": "IBS--AP Internet Business Solutions",
    "17632": "BCLNET--AU Barristers Chambers' Limited",
    "17633": "CHINATELECOM-SD--AP N for Shandong Provincial Net of CT",
    "17634": "CENTRALTRADING-CSLOXINFO-TH- Central Trading Co.,Ltd.",
    "17635": "EMERGE--AP Emerge Technologies Pty Ltd",
    "17636": "T-SYSTEMS-SG T-SYSTEMS SINGAPORE for BOSCH",
    "17637": "RDSL--VIC1-AP Autonomous System number for Melbourne POA.",
    "17638": "CHINATELECOM-TJ--AP N for TIANJIN Provincial Net of CT",
    "17639": "COMCLARK- ComClark Network & Technology Corp.",
    "17640": "AMNET-AU-AP Amnet IT Services Pty Ltd",
    "17641": "MGH-INFOTECH--AP MGH INFOTECH LTD. Infotech",
    "17642": "RDSL-NATIONAL- Request Broadband BGP  number",
    "17643": "RDSL--WA1 RequestDSL BGP # for Perth POA",
    "17644": "IQNET--AP Iqnet Pty Ltd",
    "17645": "NTT-SG-AP N - NTT SINGAPORE PTE LTD",
    "17646": "WAVE-NZ--AP Wave Internet Services Network",
    "17647": "CSC-AU-AP CSC Australia",
    "17648": "HECL- HUGHES ESCORTS COMMUNICATIONS LIMITED IS A SATELLITE BED BROADBAND ISP & P",
    "17649": "DMZGLOBAL-AP DMZGlobal Ltd",
    "17650": "GLOBALONE-MY-AP Orange Business",
    "17651": "ABOVENET--AP-2 AboveNet Communications Taiwan",
    "17652": "MauritiusTelecom",
    "17653": "GCHK-HK-AP GlobeCast Hong Kong",
    "17654": "WESTERNPOWER-AU-AP Western Power Corporation",
    "17655": "GDEAGLE Guang Dong Eagle Communications Co., Ltd.",
    "17656": "MOEBIUS-NZ-AP Moebius Systems Ltd",
    "17657": "IBM-HK-AP e-Business Hosting Services",
    "17658": "PRIMANET- PrimaNet - PT. Khasanah Timur Indonesia",
    "17659": "MAINT-AU-NEWSAT NewSat Ltd",
    "17660": "DRUKNET- DrukNet ISP",
    "17661": "EDGE-JP  for DATAHOTEL, which is one of iDC in Japan,",
    "17662": "NETSTAR-AP NetStar Networks Systems Integrator Sydney Head Office",
    "17663": "HNZC-PRIMARY--AP Housing New Zealand Corporation Internet",
    "17664": "CYBER-AP Cyber Solutions Inc.",
    "17665": "IN2CABLE-AP  Number of In2cable.com (India) Ltd.",
    "17666": "FREENET-MY- Free Net Business Solutions Sdn Bhd",
    "17667": "ISEEK-POOL-2 RESERVED FOR VOICE PTY LTD",
    "17668": "SPTEL-AP Soul Pattinson Telecommunications Pty Ltd",
    "17669": "INFOPLEX--AP INFOPLEX Hosting and Managed Service Provider Asia Pacific",
    "17670": "INFOKOM- PT. Infokom Elektrindo",
    "17671": "N-JETCOMS JETCOMS-ID Autonomous system",
    "17672": "CHINATELECOM-HE--AP asn for Hebei Provincial Net of CT",
    "17673": "MKINET MITSUI KNOWLEDGE INDUSTRY CO., LTD.",
    "17674": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17675": "-PNAPTOK Internap Japan Co.,LTD.",
    "17676": "GIGAINFRA Softbank BB Corp.",
    "17677": "MIINET UCOM Corporation",
    "17678": "WIND Gunma Internet Co,.ltd",
    "17679": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17680": "SCS SCSK Corporation",
    "17681": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17682": "CABLENET296 296 BROAD NET Com Inc",
    "17683": "WINTECH-COM Wingtechnology Communications, Inc.",
    "17684": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17685": "PLAYONLINE SQUARE ENIX CO., LTD.",
    "17686": "ACCELIA ACCELIA",
    "17687": "NICE National University Corporation Nagoya University",
    "17688": "SHINENET ShineOn LTD",
    "17689": "H-IX Hokuden Information Technology,Inc.",
    "17690": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17691": "TIKITIKI NDS Co., Ltd.",
    "17692": "KCCS Kyocera Communication Systems Co., Ltd.",
    "17693": "NEKONET YAMATO SYSTEM DEVELOPMENT CO., LTD.",
    "17694": "JPN-DBJP Deutsche Bank Group, Japan BGP connection",
    "17695": "MLJS MLJS",
    "17696": "KDDIOK-NET KDDI Okinawa Srevice CO.",
    "17697": "BBX NTT PC Communications, Inc.",
    "17698": "CCNET-NET COMMUNITY NETWORK CENTER INCORPORATED.",
    "17699": "MEDIA MEDiA K.K.",
    "17700": "JCN-2 Japan Cablenet Limited",
    "17701": "SEINAN Seinan Gakuin University",
    "17702": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17703": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17704": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17705": "INSPIRENET--AP InSPire Net Ltd",
    "17706": "HKAIRPORT- Airport Authority Hong Kong",
    "17707": "EDGE-JP-AP  for DATAHOTEL, which is one of iDC in Japan,",
    "17708": "STELLAR--AU-AP Stellar Systems",
    "17709": "EBT Eastern Broadband Telecom Co.,Ltd",
    "17710": "PIINET-TW President Information Corp.",
    "17711": "NDHU-TW National Dong Hwa University",
    "17712": "CCU-TW National Chung Cheng University",
    "17713": "NSYSU-TW National Sun Yat-sen University",
    "17714": "CHTI-DC Chunghwa Telecom Co. , Ltd.",
    "17715": "CHTTL-TW ChungHwa Telecom. Co. Telecommunication Lab.",
    "17716": "NTU-TW National Taiwan University",
    "17717": "MOECC-IPV6 Ministry of Education Computer Center Taipei, Taiwan",
    "17718": "THIS- Internet Solution Lab., Inc. 14Fl., No. 15-1, Sec. 1, Hangjou S. Rd. Jungjeng Chiu, Taipei, Taiwan 100, R.O.C.",
    "17719": "OPTUSCOM-02-AU-AP SingTel Optus Pty Ltd",
    "17720": "TTECH--AP Treen Technology",
    "17721": "IRRI--AP International Rice Research Institute,",
    "17722": "BUTTERWORTHS-AP Butterworths Australia",
    "17723": "AFFINITY-PH-AP N in Philippines",
    "17724": "DTAC--TH-AP Total Access Communication PLC.",
    "17725": "PHEONWJ--ID Pertamina Hulu Energi ONWJ",
    "17726": "CAMNET- CAMNET is an ISP of Ministry of Posts",
    "17727": "NAPINFO--AP PT. NAP Info Lintas Nusa",
    "17728": "MVI--AP Mindvision Interactive",
    "17729": "LEGION-AU-AP Legion-",
    "17730": "CROWN-AP Crown Limited Autonomous System",
    "17731": "PANEER-AP The Panaseer ISP network.",
    "17732": "BULLETPROOF- Bulletproof, Mission Critical Cloud",
    "17733": "SMU--AP Office of Communications & IT",
    "17734": "IVOISYS--AU iVoisys Pty Ltd, Sydney, Australia",
    "17735": "MST863--AP China Ministry of Science and Technology",
    "17736": "SOLSIS-MY-AP SOLSIS (m) SDN BHD",
    "17738": "AGENBIOMEDICAL Agen Biomedical Ltd",
    "17739": "HAPLINK-CN-AP Shanghai Telecom Haplink Network Co., Ltd",
    "17740": "H3G--HK-AP DOMAIN FIVE ENTERPRISES LIMITED",
    "17741": "MEDOBJ01--AP Service infrastructure of",
    "17742": "FIRSTEL--AP Firstel Telecom",
    "17743": "M1NET-SG-AP M1 NET Ltd",
    "17744": "TELSTRAGLOBAL-CUST-N Telstra Global - Customer  Number",
    "17745": "DATA3ISP-AP Data3 Ltd ISP Services",
    "17746": "ORCONINTERNET-NZ-AP Orcon Internet",
    "17747": "ZIML-AP ZEE INTERACTIVE MUTIMEDIA LTD., BANGALORE",
    "17748": "AFFINITY-IN-AP N in India",
    "17749": "TRENDMICRO Trend Micro Inc.",
    "17750": "N-ENERGEX-AP ENERGEX Ltd",
    "17751": "JPNIC-2BYTE-BLOCK-AP for assignment to JPNIC members",
    "17752": "ECONZ--AP Econz Limited.",
    "17753": "DATAINFOSYS- INTERNET SERVICE PROVIDER",
    "17754": "EXCELL- Excellmedia",
    "17755": "N-DFS-AP  # -DFS-AP CONVERTED TO N-DFS-AP FOR RPSL COMPLIANCE BRIDGEDFS LIMITED",
    "17756": "AUSPOST Australia Post",
    "17757": "HPAUS-AP HP Australia",
    "17758": "MYOBNET--AP MYOB Technology Pty Ltd",
    "17759": "CLPPOWER--AP CLP Power Hong Kong Limited",
    "17760": "FLOW--2 Flow Communications Pty Ltd",
    "17761": "QALA-SG-AP M1 Net Ltd",
    "17762": "HTIL-TTML-IN-AP Tata Teleservices Maharashtra Ltd",
    "17763": "ECOPOST-N-AP  number for Mid Nort Coast Internet,",
    "17764": "OUHK-NON-HK-AP The Open University of Hong Kong",
    "17765": "AAPIS-SYDNEY-AP Australian Associated Press",
    "17766": "DATAFX--AP Data FX Online Pty. Ltd.",
    "17768": "NEXTGENNET--AU NextGen.Net Application Service Provider",
    "17769": "CITYNET-AP PT Indopratama Teleglobal (ISP)Wisma BSG Floor 6",
    "17770": "DIALOG-LK Dialog Telekom Plc",
    "17771": "SOUTHONLINE--AP Southern Online Bio Technologies Ltd",
    "17772": "CHINACOM CHINA COMMUNICATIONS SYSTEM Co.,Ltd.",
    "17773": "UPNET UPNET Technologies Co., Ltd",
    "17775": "STN-CN shanghai science and technology network communication limited company",
    "17776": "CHINAENTERCOM China Enterprise Communications Ltd.",
    "17777": "CSTAR China Telecommunications Broadcast Satellite Corp.",
    "17778": "TYCANET Taiyuan CATV Networks Ltd.",
    "17780": "BJENET BEIJING EDUCATION INFORMATION SERVICE CENTER",
    "17783": "SRILRPG- SRIL RPG Autonomous System",
    "17784": "MAXIS-2-AP MaxisNet International Internet Gateway",
    "17785": "CHINATELECOM-HA--AP asn for Henan Provincial Net of CT",
    "17786": "HSBC-IN- HSBC India",
    "17787": "PSEB--PK Pakistan Software Export Board",
    "17788": "CNCGROUP-BJ-IDC CNCGROUP IP network of BeiJing IDC",
    "17789": "CNCGROUP-SH-IDC CNCGROUP IP network of ShangHai IDC",
    "17790": "CNCGROUP-GZ-IDC CNCGROUP IP network of GuangZhou IDC",
    "17791": "CNCGROUP-SZ-IDC CNCGROUP IP network of ShengZhen IDC",
    "17792": "MET--AP Metservice",
    "17793": "LCSD-NON-HK-AP Leisure and Cultural Services Department, HKSAR Government",
    "17794": "HTCL-ORANGE-HK-AP Hutchison Telephone Company Limited",
    "17795": "NVJ-AP Netvein.co.jp",
    "17796": "PLDT-IP-VPN-AP Philippine Long Distance Telephone Company",
    "17797": "PICKNOWL--AP Picknowl Internet Services",
    "17798": "XINWEI--AP JIHENGXINWEI BEIJING CO.,LTD",
    "17799": "CHINATELECOM-LN--AP asn for Liaoning Provincial Net of CT",
    "17800": "CYBERNET-ID-AP PT. JARINGAN INTECH INDONESIA",
    "17801": "GLEBE-IX Peering exchange at 30 Ross St, Glebe, Sydney",
    "17802": "MACQUARIE-BANK--AP Macquarie Bank",
    "17803": "BSES--AP BSES TeleCom Limited",
    "17804": "AUT-21STCENTURY 21st century Pty Ltd, Internet Service Provider",
    "17805": "CONCEPT-SYD-AU-AP Conceptual Internet Australia, ISP, Sydney",
    "17806": "MANGOTELESERVICE--BD Tire-1 IP Transit Provider of Bangladesh",
    "17807": "STATE-LIBRARY-QUEESLAND--AP State Library of Queensland",
    "17808": "VODAFONE-NZ-AP  number for Vodafone NZ IP Networks",
    "17809": "MONAD-TW-AP Monad Digitnamic Corp.",
    "17810": "CELLNEXT-SOLUTIONS-AP Cellnext Solutions Limited -",
    "17811": "PEOPLESUPPORTMN--PH Peoplesupport Inc.",
    "17812": "SYMCAUTHNET Symantec Inc",
    "17813": "MTNL-AP Mahanagar Telephone Nigam Ltd.",
    "17814": "COMNET-AP-N2 ComNet Telecom International Ltd.  number.",
    "17815": "QUESTDIAGNOSTICS--IN Quest Diagnostics India",
    "17816": "CHINA169-GZ China Unicom  IP network China169 Guangdong province",
    "17817": "DAKSH-IN Daksh.com eServices Pvt.Ltd,",
    "17818": "SABINFOTECH-IN-AP SAB Infotech Ltd.,",
    "17819": "N-EQUINIX-AP Equinix Asia Pacific",
    "17820": "DIL-AP DIRECT INTERNET LTD.",
    "17821": "APNIC-TRAINING-LAB--AP Two-byte  number for APNIC Training Lab",
    "17823": "THNIC-N-AP Thailand Network Information Center",
    "17824": "PACIFICONENET-HK-AP Pacific One Net Limited  number",
    "17825": "MAHINDRABT--AP Tech Mahindra Ltd. Software Development Organisation India",
    "17826": "SATATANET-ID Jl. Raya Pasar Minggu no 99D",
    "17827": "STOU--TH Sukhothai Thammathirat Open University",
    "17828": "TIARE--PG Tiare, a business unit of Pacific Mobile Communications.",
    "17829": "IDL--AP IDL Autonomous system",
    "17830": "KRYPTOS- Kryptos Networks , Remote Infrastructure Management Services",
    "17832": "SIXNGIX--KR Korea Internet Security Agency",
    "17833": "CROWNBAKERY--KR CrownBakery",
    "17834": "KYOBOAUTO--KR Kyobo Auto Insurance CO.,LTD",
    "17835": "HITC--KR Prudential INVESTMENT TRUST &SECURITIES CO.,LTD.",
    "17836": "IBKS--KR IBK Securities",
    "17837": "KCP--KR Korea Cyber Payment Inc",
    "17838": "E-HYUNDAI--KR HYUNDAI HOMESHOPPING",
    "17839": "DREAMPLUS--KR DreamcityMedia",
    "17840": "KOREACERT--KR KECA, Inc.",
    "17841": "NCIA--KR MIC E-GOVERNMENT",
    "17842": "CNE--KR Chungchungnam-Do office of Education",
    "17843": "KISIS--KR KISA",
    "17844": "PBSNET--KR PBS CATV",
    "17845": "GTP--KR Gyeonggi Technopark",
    "17846": "HANANET6--KR Hanaro Telecom Inc.",
    "17847": "FSS--KR Financial Supervisory Service",
    "17848": "INAMES--KR INAMES",
    "17849": "GINAMHANVIT--KR hanvit ginam broadcasting comm.",
    "17850": "OKSUNG--KR OK-NET Co,. Ltd",
    "17851": "EDUS--KR Chungchungnam-Do office of Education",
    "17852": "KOREALIFE--KR KOREALIFE",
    "17853": "LGTELECOM--KR LG Telecom",
    "17854": "CABLELINE--KR Tbroadjeonjubroadcast",
    "17855": "PRUK--KR Prudential",
    "17856": "KONYANG--KR Konyang University",
    "17857": "NAKDONGDIGITALBUSANNET--KR Tbroad Nakdong Broadcasting co.,Ltd",
    "17858": "KRNIC-BLOCK-AP KRNIC",
    "17859": "NICE--KR National Information & Credit Evaluation",
    "17860": "WEBZEN--KR WEBZEN",
    "17861": "KIT--KR KyungNam College of Information & Technology",
    "17862": "KWNU--KR Kangwon National University",
    "17863": "YONHAPNEWS--KR Yonhap News Agency",
    "17864": "HANVITIAB--KR Hanvit I&B",
    "17865": "SCOURT--KR Supreme Court of Korea",
    "17866": "KISTNET--KR Korea Institute of Science and Technology",
    "17867": "KBINET--KR KOREA BANKING INSTITUTE",
    "17868": "HYUPSUNG-NET--KR Hyupsung University",
    "17869": "REGISTRY--KR Ministry of Court Administration",
    "17870": "KHU--KR Kyung Hee University",
    "17871": "DIGITALBUSANDONGNAM--KR Tbroad Dongnam Broadcasting co.,Ltd",
    "17872": "SUNGSHIN--KR SUNGSHIN WOMEN'S UNIVERSITY",
    "17873": "BESTEZ--KR Daewoo Securities Co., Ltd.",
    "17874": "NPC--KR National Pension Corporation",
    "17875": "ECBANK--KR ec-bank",
    "17876": "AHNLAB--KR Ahnlab, Inc.",
    "17877": "NEXG--KR NEXG",
    "17878": "KFISAC--KR K.F.T.C ISAC",
    "17879": "KFCERT--KR K.F.T.C CERT",
    "17880": "SPORTSSEOUL21--KR SPORTSSEOUL21.CO",
    "17881": "INETHOSTING--KR Inet Hosting  Inc.",
    "17882": "N-MCS-AP  # -MCS-AP CONVERTED TO N-MCS-AP FOR RPSL COMPLIANCE The first E-commerce and TriplePlay Service ISP in Mongolia.",
    "17883": "CHINATELECOM-SX--AP asn for Shanxi Provincial Net of CT",
    "17884": "UNINET-AP PT. Uninet Media Sakti (ISP)",
    "17885": "JKTXLNET--AP PT Excelcomindo Pratama",
    "17886": "MATRIXNETWORKS--SG-AP Matrix Networks Pte Ltd",
    "17887": "STT--TH-AP i-STT Nation Ltd.",
    "17888": "SINGTEL-HK SingTel Hong Kong Limited",
    "17889": "INTRACEPTIVES-AU--AP Intraceptives Pty Ltd",
    "17890": "MATILDA--AP Matilda Internet",
    "17891": "WNPL- Worldgate Networks Pvt. Ltd.",
    "17892": "GAZI-OUT1--AP GAZI COMMUNICATIONS, VSAT TELEPORT OPERATOR, DHAKA, BANGLADESH",
    "17893": "PALAU--AP Palau National Communications Corp.",
    "17894": "APMI--AP AyalaPort Makati, Inc. / Data Center Operator",
    "17895": "GLOBALREACH-AP Globalreach eBusiness Networks, Inc.",
    "17896": "CHINATELECOM-JL--AP asn for Jilin Provincial Net of CT",
    "17897": "CHINATELECOM-HLJ--AP asn for Heilongjiang Provincial Net of CT",
    "17898": "IEXEC--AP iExec.com.au",
    "17899": "N-ACN N-ACN",
    "17900": "THINKTECH--AP Think Technology",
    "17901": "SI- SAMART Internet",
    "17902": "IHUG-TRANSIT-AP ihug Wholesale Bandwidth Sales",
    "17903": "COGNIZANT-IN-AP Cognizant Technology Solutions India Pvt Ltd,",
    "17904": "SLTUL-LK Sri Lankan Airlines",
    "17905": "COMMERZBANK-AP-DRT Commerzbank AG",
    "17906": "PWC-AP PricewaterhouseCoopers",
    "17907": "NUSKOPE NuSkope Pty. Ltd.",
    "17908": "TCISL Tata Communications",
    "17909": "ECLECTIC-AP Project Eclectic RandD SA Pty Ltd",
    "17910": "TRIPLEGATE-ID-AP TRIPLEGATE-N",
    "17911": "BRAINPK--AP Brain Telecommunication Ltd.",
    "17912": "ALLIANCEGS--AP Alliance IT Consulting (P) Ltd",
    "17913": "GIPLNET-AP Guj Info Petro Limited",
    "17914": "N-2DAY-NZ-AP 2Day Internet Limited",
    "17915": "GEMONEY1--AP GE Capital Finance Australasia P/L TA GE Money",
    "17916": "CSC-IGN-AUNZ-AP Computer Sciences Corporation",
    "17917": "QTLTELECOM--AP Quadrant Televentures Limited",
    "17918": "INFOPLEX2--AU INFOPLEX Hosting and Managed Service Provider Asia Pacific",
    "17919": "DELL-AP-ONLINE Dell AP-Online",
    "17920": "ULTRERVE-SYD1--AP Ultra Serve Internet Pty Ltd - Transit  - Hosting Provider,",
    "17921": "THOMSON-PH THOMSON SINGPAORE, PTE LTD.",
    "17922": "INDOSAT-INP INDOSAT Internet Network Provider",
    "17923": "CHINATELECOM-NMG--AP asn for Neimenggu Provincial Net of CT",
    "17924": "SMARTONE-MB--AP SmarTone Mobile Communications Ltd",
    "17925": "DEALER-SOLUTIONS-AU Dealer Solutions",
    "17926": "SCS Singapore Computer Systems",
    "17927": "WEBSATMEDIA- WEBSATMEDIA PTE LTD, Satellite Over IP, Singapore",
    "17928": "AWTA--AU-AP Australian Wool Testing Authority Ltd,",
    "17929": "JPMC-AP JPMorgan Chase APTI",
    "17930": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17931": "NETFOREST Netforest,Inc.",
    "17932": "JAIST Japan Advanced Institute of Science and Technology",
    "17933": "NTT-ET Nippon Telegraph and Telephone East Corporation",
    "17934": "JGNV6 National Institute of Information and Communications Technology",
    "17935": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17936": "CTK Cable  Television  Kani Co.,Inc.",
    "17937": "NDMC NIKKEI ADVANCED SYSTEMS INC.",
    "17938": "SOCIO SOFTBANK TELECOM Corp.",
    "17939": "MCN-NET01 miyazaki cabletelevision network Co.,LTD",
    "17940": "CYBERLINKS CYBER LINKS Co.,Ltd.",
    "17941": "BIT-ISLE Bit-isle Co.,Ltd.",
    "17942": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17943": "TDU Tokyo Denki University",
    "17944": "JWA Japan Weather Association",
    "17945": "ITV iTV Co,Ltd",
    "17946": "GUCC Gifu University",
    "17947": "S-UTOPIA SAKURA KCS Corporation.",
    "17948": "EDITNET EditNet, Incorporated",
    "17949": "TEU Tokyo University of Technorogy",
    "17950": "SAINET- SaiNet",
    "17951": "KOCOE Kobe Community Exchange Co.,LTD",
    "17952": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17953": "ICO BroadBand Security, Inc.",
    "17954": "JPNIC-JP-N-BLOCK Japan Network Information Center",
    "17955": "AVISNET Densan Co., Ltd.",
    "17956": "WEDA WEDA University",
    "17957": "CTS SOUTH TOKYO CABLETELEVISION",
    "17958": "KCV Kasaoka Cable Vision Co,LTD.",
    "17959": "ICN K-techsjapan Inc.",
    "17960": "RAINS- University of the Ryukyus",
    "17961": "MITENE mitene internet co., ltd.",
    "17962": "TOPWAY-NET ShenZhen Topway Video Communication Co. Ltd",
    "17963": "NET263 Beijing  Capital-online science development Co.,Ltd. ShangHai Branch\uff09",
    "17964": "DXTNET Beijing Dian-Xin-Tong Network Technologies Co., Ltd.",
    "17965": "CSTNET CHINA SCIENCE AND TECHNOLOGY NETWORK",
    "17966": "CIBN China Information Broadcast Network Ltd.Co.",
    "17967": "CNNIC CNNIC",
    "17968": "DQTNET Daqing zhongji petroleum telecommunication construction limited cpmpany",
    "17969": "CNNIC-KUANCOM-AP Beijing Kuancom Network Technology Co.,Ltd.",
    "17970": "INTERISLAND--AP TRI.ph  Inter-Island Information Systems, Inc.,  Internet Service Provider and Internet Data Center, Manila PH",
    "17971": "TMVADS-AP TM-VADS DC Hosting",
    "17972": "BANKOFAMERICA-ATG-HK Bank of America N.A.",
    "17973": "TBGI--AP TBGI, Transpacific Broadcast Group",
    "17974": "TELKOMNET-2-AP PT Telekomunikasi Indonesia",
    "17975": "APT-AP # for peering purpose with IX and ISP.",
    "17976": "CAMGSM--AP Royal TeleCam Ltd. O.B.O: Telesurf ISP",
    "17977": "SINGTEL-JP NF Park Bldg.3F, 9-15, Futaba 2-Chome",
    "17978": "SERVCORP SERVCORP AUSTRALIAN HOLDINGS LTD",
    "17980": "UNITED-SECURITIES-CSLOXINFO-TH United Securities Public Co.,Ltd.",
    "17981": "CAMBOTECH-KH- ISP Cambodia",
    "17982": "N-IEXEC-AP Level 27, 123 Eagle Street",
    "17983": "COLESMYER--AP Coles Myer",
    "17984": "PCCWHKTNS-AP PCCW-HKT Network Services Limited",
    "17985": "OUTSURANCE--AP Outsurance Australia Insurance",
    "17986": "WEBPROPHETS--AP Web Prophets Pty Ltd",
    "17987": "AUDA-AU- .au Domain Administration",
    "17988": "SINOSAT--AP SINOSAT (HONG KONG) LIMITED",
    "17990": "GLOBALNETHK-AP GLOBALNET COMMUNICATION LTD.",
    "17991": "VIRTUAL-OFFIS--AP Offis Pty Ltd,",
    "17992": "GTC-MY-SIP- Global Transit Communications - Malaysia",
    "17993": "STEL--AP SamoaTel Limited",
    "17994": "L--AP Appserv Limited",
    "17995": "SOLUSINET--ID Solusi Info Struktur Nusantara, PT.",
    "17996": "UIINET-ID-AP PT Global Prima Utama",
    "17997": "CHINAENTERCOM China Enterprise Communications Ltd.",
    "17998": "CHINATELECOM-BEIJING-AP CHINA TELECOM GROUP",
    "17999": "PIPE-ADE--AP PIPE Networks Adelaide Internet Exchange. Used for",
    "18000": "DIMENSIONCSA--AU-AP Dimension Data Cloud Solutions Australia",
    "18001": "DIALOG- Dialog Axiata PLC.",
    "18002": "WORLDPHONE-IN  Number for Interdomain Routing",
    "18003": "FPLN2--AP Faktortel Pty Ltd.",
    "18004": "WIRELESSNET-ID-AP WIRELESSNET",
    "18005": "SURFSHOP-PH-AP Surfshop (ETPI client)",
    "18006": "BSPG--AP Blue Star Print Group",
    "18007": "INHERENT--ID-AP INHERENT",
    "18008": "QUATRRO Quatrro Network Border",
    "18009": "BROADBAND-PH--AP BROADBAND PHILIPPINES",
    "18010": "NFLNET--AP NATIONAL FOODS LTD.",
    "18011": "CERNET-3TN--AP CERNET 863 3TNET Terabit Regional Network (CERNET-3TN)",
    "18012": "ACCESSTEL--AP Access Telecom (BD) Ltd.",
    "18014": "CITYLINK-SR--AP Citylink Co., Ltd, ISP, Siem Reap",
    "18015": "FTCOM--AP Fastcom Limited",
    "18016": "CAPITOL-UNIVERSITY--PH Capitol Univeristy Cagayan de Oro",
    "18017": "TUAROPAKI-AP Tuaropaki Communications Limited",
    "18018": "GAMEBUILDERS--PH Gamebuilders Inc.",
    "18020": "ANCHORSYSTEMS-AP Anchor Systems Pty Ltd",
    "18021": "UNINET--AP Unisys NZ, IT Outsourcer,",
    "18022": "CHENGTONG-AP FoShan SHITONG Information Broadband Networks CO.LTD",
    "18023": "KMU--KR Korea Maritime University",
    "18025": "ACE-1-WIFI--AP Ace-1 Wifi Network",
    "18026": "CHEJU--KR Cheju National University",
    "18027": "NSU--KR namseoul university",
    "18028": "GSNU--KR GyeongSang National University",
    "18029": "HIT--KR Daejeon Helath Sciences College",
    "18030": "PERTHAIRPORT-TRANSIT--AP West Australia Airport Corp. Transit ,",
    "18031": "SANGMYUNG--KR Sangmyung University",
    "18032": "SHINHANSYS--KR SHINHAN DATA SYSTEM",
    "18033": "CMBTGD--KR CMB TAEGU DONGBU BROADCT",
    "18034": "KANGNUNG--KR Kangnung National UNIV.",
    "18035": "HANSEO18035--KR HANSEO UNIVERSITY",
    "18036": "NECA-APPS--AP NECA Applications and Content , Melbourne",
    "18037": "IPERA-AU-AP Ipera Communications Pty Ltd",
    "18038": "KNUE--KR Korea National University of Education",
    "18039": "YB-AU Yellow Billing Services Pty Ltd",
    "18040": "MBTNET Mobitai ISP Network Information Center",
    "18041": "CHICOM Chicom Information Corp.",
    "18042": "KBT Koos Broadband Telecom",
    "18043": "GETOP-TW GETOP Automatic System Inc.",
    "18044": "KINGNET-TW King-Net Info. Tech. Co., Ltd.",
    "18045": "SINOPAC SinoPac Holdings Corporate Network",
    "18046": "DONGFONG-TW DongFong Technology Co. Ltd.",
    "18047": "NTHU-TW National Tsing-Hua University",
    "18048": "CYBERTERRA-TW Cyberterra Corporation,",
    "18049": "TINP-TW Taiwan Infrastructure Network Technologie",
    "18050": "BARTON-CAPITAL-AP Barton Capital Holdings Ltd",
    "18051": "JARDIKN--AP Pustekkom",
    "18052": "IAKOMNET-ID-AP Asiakomnet Multimedia, PT",
    "18053": "ACEQUITY--AP Australian Capital Equity Pty Ltd",
    "18054": "INTERLAB- intERLab/AIT",
    "18055": "CENTRELINK Department of Human Services",
    "18056": "ABADINET--AP Pt Mithaharum Abadi",
    "18057": "AHMG-AP Australian Health Management Group,",
    "18058": "N-IT-SYSTEMS-AP IT System Management Pty Ltd",
    "18059": "DTPNET--AP DTPNET NAP",
    "18060": "VIZCOM-AP Vizcom",
    "18061": "WORLDCOM-INDIA WorldCom Communications India",
    "18062": "GRANGENET--AP GRid And Next GEneration NETwork",
    "18063": "SMARTPATH--AP SmartPath Pty Ltd",
    "18064": "EROADS--AP eRoads Technology Ltd",
    "18065": "CENTRALDATA-WA Central Data Pty Ltd.",
    "18066": "EA-JP-AP Electronic Arts, Japan",
    "18067": "HUMEIA Humeia Corporation",
    "18068": "ACROSS Dream Wave Shizuoka Co. Ltd.",
    "18069": "SOFTBANK SOFTBANK TECHNOLOGY CORP.",
    "18070": "NDAC Global Network Core Co.,Ltd.",
    "18071": "MEI1 Panasonic Corporation Corporate Information Systems Company",
    "18072": "STREAMWING NTT Communications, Corp.",
    "18073": "JPNIC-BLOCK-AP JPNIC",
    "18074": "FRT First Riding Technology Inc.",
    "18075": "HICAT Hiroshima City Cable Television Corp.",
    "18076": "WCE-IAM Institute of Advanced Media Arts and Sciences",
    "18077": "C-ABLE Yamaguchi Cable Vision Co.,Ltd",
    "18078": "JPNIC-BLOCK-AP JPNIC",
    "18079": "JPNIC-BLOCK-AP JPNIC",
    "18080": "SOPIA Sopiafons Co.,Ltd",
    "18081": "KCN Kintetsu Cable Network Co., Ltd.",
    "18082": "LDEC Local Authorities Systems Development Center",
    "18083": "JPNIC-BLOCK-AP JPNIC",
    "18084": "ANC Asia Netcom Japan Corp.",
    "18085": "INFOVALLEY Fujitsu Nagano systems engineering Co.Ltd.",
    "18086": "PFU-IDC PFU LIMITED",
    "18087": "TOYO Toyo University",
    "18088": "QIC Kyuden Infocom Company Inc",
    "18089": "HIKARI-NWC KDDI Corporation",
    "18090": "MAGMA IMS Corporation",
    "18091": "TEIKYO-U Teikyo University",
    "18092": "CSF Kyushu Tele Communications Company",
    "18093": "JPNIC-BLOCK-AP JPNIC",
    "18094": "TCN- Tokyo Cable Network.,INC",
    "18095": "REITAKU Reitaku University",
    "18096": "JPNIC-BLOCK-AP JPNIC",
    "18097": "DCN D.C.N. Corporation",
    "18098": "JPNIC-BLOCK-AP JPNIC",
    "18099": "HIS--AP Hostworks Internet Services Pty Ltd",
    "18100": "NETWORKERS-AU-AP Networkers Pty Ltd",
    "18101": "RELIANCE-COMMUNICATIONS-IN Reliance Communications Ltd.DAKC MUMBAI",
    "18102": "HIC-AP Avantra House",
    "18103": "NEUVIZ--ID-AP Neuviz Net",
    "18104": "WCG--AP Wholesale Communications Group",
    "18105": "KARNET-AP Karuturi Telecom Pvt Ltd",
    "18106": "VIEWQWEST-SG-AP Viewqwest Pte Ltd",
    "18107": "N-IPSYSTEMS-AP IP SYSTEMS",
    "18108": "FUJITSU-AP FujitsuAustraliaLtd",
    "18110": "HANNANPRINTNSW--AP Hannanprint",
    "18111": "NETSPEED--AP Netspeed Internet Communications",
    "18112": "KSNET-ID--AP PT. Sejuta Jaring Global",
    "18113": "PFIZER-SG-AP Pfizer Pte Ltd Singapore dual homed",
    "18114": "SUBICTEL--AP PLDT Subic Telecom, Inc.",
    "18115": "JGS--AP JG Group of Companies",
    "18116": "HGC--AP Hutchison Global Crossing",
    "18117": "HARBOURMSP-AU-AP Harbour MSP Pty. Ltd",
    "18118": "CITICNET-AP CITIC Networks Management Co.,Ltd.",
    "18119": "ACSDATA-NZ ACSData",
    "18120": "GEMINI--IN Gemini Software Solutions (P) Ltd. Hosting Services, India",
    "18121": "INCL Ishikawa Computer Center Co.,LTD.",
    "18122": "KYOTO-IX Advanced Software Technology & Management Research Institute of KYOTO",
    "18123": "SEIRYO INAOKI EDUCATIONAL INSTITUTION",
    "18124": "OUS-NET Okayama University of Science",
    "18125": "MAFFIN Ministry of Agriculture, Forestry and Fisheries Research Network",
    "18126": "CTCX Chubu Telecommunications Company, Inc.",
    "18127": "TSUKUBA-WAN Tsukuba-WAN Network",
    "18128": "RIKEN RIKEN(Physical and Chemical Research Institute)",
    "18129": "ONI OKAYAMA NETWORK INC.",
    "18130": "JPNIC-BLOCK-AP JPNIC",
    "18131": "IR3 NTT Communications Corporation  Innovative IP Architecture Center",
    "18132": "JPNIC-BLOCK-AP JPNIC",
    "18133": "GAMANIAJP Gamania Digital Entertainment co.,ltd",
    "18134": "KITANET JCN Kita Cable Limited",
    "18135": "BTV BTV Cable television",
    "18136": "CTA Cable television Adachi Corp.",
    "18137": "JPNIC-BLOCK-AP JPNIC",
    "18138": "HI-NET HI-NET INC.",
    "18139": "H-SKSS Security&Knowledge Support Services, Inc.",
    "18140": "IDC18140 Yahoo Japan Corporation",
    "18141": "HBA-IDC HBA",
    "18142": "BIWALOBE biwalobe.co.,ltd.",
    "18143": "DCSNET Mitsubishi Research Institute DCS Co.,Ltd.",
    "18144": "-ENECOM Energia Communications,Inc.",
    "18145": "JPNIC-BLOCK-AP JPNIC",
    "18146": "INETCORE Intec NetCore, Inc.",
    "18147": "JPNIC-BLOCK-AP JPNIC",
    "18148": "FUKUOKA-U Fukuoka University",
    "18149": "JPRS Japan Registry Service Co., Ltd.",
    "18150": "SNI-JP Sagashimbun Co., Ltd.",
    "18151": "CEC COMPUTER ENGINEERING & CONSULTING LTD.",
    "18152": "JPNIC-BLOCK-AP JPNIC",
    "18153": "MULTIDATA-ID-AP PT Multidata Rancana Prima",
    "18154": "AUSTRADE--AU-AP Australian Trade Commission",
    "18156": "BITNET-ID-AP BITNET ISP",
    "18157": "CHUNGJU--KR chungju university",
    "18158": "CBNU--KR CHUNGBUK NATIONAL UNIVERSITY",
    "18159": "NETSPEED--AP Netspeed Data Ltd",
    "18160": "MNU--KR Pusan National University",
    "18161": "HYWOMAN--KR HYNYANG WOMENS COLLEGE",
    "18162": "VICTRACK-TRANSIT- VICTORIAN RAIL TRACK",
    "18163": "JINJU18163--KR jinju national university",
    "18164": "MOKPO--KR Mokpo National University",
    "18165": "RESMED--SYD ResMed Dual Internet Gateway",
    "18166": "ELITECORE-CYBER--AP Elitecore Technologies Pvt. Ltd.",
    "18167": "HCLCOMNET--IN HCL Comnet Systems & Services Ltd",
    "18168": "CMBTGS--KR CMB TAEGU SUSEONG BROADCT",
    "18169": "KOCCA--KR KOCCA",
    "18170": "CHANGWON--KR Changwon National University",
    "18171": "KYUNGNAM--KR KYUNGNAM UNIVERSITY",
    "18172": "CWINDIA-ENTER--IN Cable & Wireless Global, Enterprise Network",
    "18173": "AKU--PK Aga Khan University",
    "18174": "DANKOOK--KR Dankook University",
    "18175": "KPS--KR KPS",
    "18176": "KOOKMIN--KR KOOKMIN UNIVERSITY",
    "18177": "NCKU-TW National Cheng Kung University",
    "18178": "ATT-TW RM D&E, 16F Hung-tai Century tower",
    "18179": "E2CENTER-TW MiTAC Inc.",
    "18180": "ACI-NET All Chinese Internet Inc.",
    "18181": "NHRINET National Health Research Institutes",
    "18182": "SONET-TW Sony Network Taiwan Limited",
    "18183": "NCREE National Center for Research on Earthquake Engineering",
    "18184": "TWIXV6-TW TWIX IPv6 Service Network.(TWIXv6),",
    "18185": "NTCU--TW 4F, No.114, Sec.1, Chung-Shiao W. Road",
    "18186": "EYUPNET--TW YAW JENQ TECHNOLOGY CORPORATION",
    "18187": "WIFICITY--AP Wificity, Inc.",
    "18188": "ATENEO--AP Ateneo de Manila University",
    "18189": "BROADNETIA-AP Broadband Network Asia",
    "18190": "WWW-PH-AP ETPI IDS Client",
    "18191": "AIRSERVICESAUS-AP OPTUS CUSTOMER NETWORK",
    "18192": "MIBROADBAND--AP Engin Pty Ltd, Voice over IP",
    "18193": "TALENT--AP Suite 2/109 Alexander St",
    "18194": "PMMSI--AP Philippine Multi-Media",
    "18195": "ZETTANET- ZettaNet Pty Ltd",
    "18196": "SEVENSTAR- Seven Star Internet Service Provider",
    "18197": "TOYOTAIA-TH--AP TOYOTA MOTOR IA PACIFIC Engineering and Manufacturing,",
    "18198": "MATHI-NZ Mathias Technologies",
    "18199": "LINKTELECOM-NZ-AP Link Telecom (NZ) Limited",
    "18200": "OPT-NC--AP Office des Postes et Telecommunications New-Caledonia",
    "18201": "SERVICECORP--AP ServiceCorp Pty Ltd",
    "18202": "VOYAGERNET--AP Voyager Internet Ltd.",
    "18203": "FX-KAREN-AGGR--AP FX Networks to KAREN Network",
    "18204": "MINDSHARE--AP MindShare Asia Pacific CHANGE GroupM Asia Pacific",
    "18205": "IANUST-AP Asian University of Science And Technology Chon buri",
    "18206": "VPIS-AP VADS Managed Business Internet Service Provider",
    "18207": "YOU-INDIA-AP YOU Broadband & Cable India Ltd.",
    "18208": "ABNAMRO-AP CWO Customer Network",
    "18209": "BEAMTELE--AP Beam Telecom Pvt Ltd",
    "18210": "AUSREGISTRY--ANYCT2 AusRegistry Anycast system",
    "18211": "NOMURAINDIA--AP Nomura India Services Pvt Ltd",
    "18212": "NIFT--PK National Institutional Facilitation Technologies",
    "18213": "ZENTO--AP Optus Customer Network",
    "18214": "AMBERGRIS- AMBERGRIS SOLUTIONS, INC.",
    "18215": "PLUSPRO-AP Plus Property",
    "18217": "NET-IPV6-AP CC",
    "18218": "HKSTPC--AP HK Science & Technology Parks Corporation",
    "18219": "SAP--AP SAP IA PTE LTD",
    "18221": "PLANET-OZI Planet Ozi Pty Ltd",
    "18222": "OPTO--AP Opto Network Private Limited, OPTO",
    "18223": "CAPITALIQ Capital IQ Information Systems (India) Pvt, Ltd.,",
    "18224": "N-CRIMSONLOGIC-AP  # -CRIMSONLOGIC-AP CONVERTED TO N-CRIMSONLOGIC-AP FOR RPSL COMPLIANCE Singapore Network Services",
    "18225": "SOFTCELL-AP Softcell  Number",
    "18226": "SMARTBRO-VIS-AP Smart Broadband, Inc.",
    "18227": "CCSBNET--MY-AP Clear-Comm Sdn Bhd",
    "18228": "NCSHUB-SG-AP NCS IDC in Singapore",
    "18229": "CTRLS--IN CtrlS Datacenters Ltd.",
    "18230": "ZIPNETBD-DKB--AP Zipnet Limited DKB  number",
    "18232": "ALI--AP Alias Internet",
    "18233": "PTTNET Philippine Telegraph and Telephone Corporation,",
    "18234": "AIH-DISC-ONLINE--AP Australian Insurance Holdings",
    "18236": "LEI-AU-AP Leading Edge Internet",
    "18237": "VISION-ID Visionnet  Number",
    "18239": "CAPNET--AP Beijing Capital Public Information Platform",
    "18240": "BITNET Beijing Bitone United Networks Technology Service Co.,Ltd.",
    "18241": "SPINET State Power Information Net",
    "18242": "CDIH Chengdu Information Harbor Co., Ltd",
    "18243": "NETEE- Shanghai EaseNet Network Technology Limited",
    "18244": "STIDC Stateline Internet Data Center Co., Ltd. Shanghai",
    "18245": "FOUNDERBN CNNIC",
    "18247": "GWBN Great Wall Broadband Network Service Co.Ltd",
    "18248": "ACXIOM--AU-AP Acxiom Australia Pty Ltd Internet Services",
    "18249": "GLOBEIDC--AP Globe Telecom Internet Data Center",
    "18250": "PACWIRE-AP Pacific Wireless Pty Ltd",
    "18251": "IGF2013-ID Internet Governance Forum 2013",
    "18252": "CAT--AP The Communication Authoity of Thailand, CAT",
    "18253": "EXXONMOBIL-AP-MY EXXON MOBIL CORPORATION",
    "18254": "HOTSPEED HOTSPEED INTERNET PTE LTD",
    "18255": "BRISBANE-AP Brisbane City Council",
    "18256": "BAY-TH Bank of Ayudhya Public Co.,Ltd.",
    "18258": "MORGANSTANLEY--JP Morgan Stanley Japan Limited transit",
    "18259": "HIGE NTT Communications Corporation",
    "18260": "E-CATV EHIME CATV CO.,LTD.",
    "18261": "JPNIC-BLOCK-AP JPNIC",
    "18262": "JPNIC-BLOCK-AP JPNIC",
    "18263": "MEINET MEITETSUCOM Co., Ltd.",
    "18264": "SEN Seikei Eizo Network Inc.",
    "18265": "TWIN ZEXIS CORPORATION",
    "18266": "ATNAP Datacoa Co., Ltd.",
    "18267": "DOSHISHA Doshisha University",
    "18268": "JANIS Naganoken Kyodou Densan Co.Ltd.",
    "18269": "KAI Kai Creates Inc.",
    "18270": "TOIN Toin University of Yokohama",
    "18271": "EVONET Sojitz Systems Corporation",
    "18272": "SYNFORM-NET SYNFORM CO.,LTD",
    "18273": "JPNIC-BLOCK-AP JPNIC",
    "18274": "UCATV Utsunomiya Cable TV Corporation",
    "18275": "JPNIC-BLOCK-AP JPNIC",
    "18276": "KAISER Kansai University",
    "18277": "KUSA Kurashiki University of Science and the Arts",
    "18278": "CC9N Cable TV Corporation",
    "18279": "BUKKYO-U Bukkyo University",
    "18280": "JPNIC-BLOCK-AP JPNIC",
    "18281": "TAC-NET Tokoname New-TV Corporation",
    "18282": "CORALNET TONAMI Internet Service(TONAMI TransportationCo.,Ltd.)",
    "18283": "CCV Fureai Channel Inc.",
    "18284": "ISETANNET Isetan Data Center Co., Ltd.",
    "18285": "JPNIC-BLOCK-AP JPNIC",
    "18286": "OCUNET Osaka City University",
    "18287": "OCV Odakyu Telecommunication Services",
    "18288": "JPNIC-BLOCK-AP JPNIC",
    "18289": "AGNS-JP-IBM AT&T JAPAN KK",
    "18290": "IWAMI Mimedia Corporation",
    "18291": "VFAU-NET- Vodafone Australia Public Autonomous System Number",
    "18292": "CUSCAL- Credit Union Services Corporation Australia Ltd. Sydney",
    "18293": "YAHOO-HK2-AP Internet content provider",
    "18294": "NFFC--KR NFFC",
    "18295": "ALLIANZ--KR Allianz Life Insurance Co.Ltd",
    "18296": "HANSYS--KR Hanbit Microsystems",
    "18297": "KJISTNET--KR K-JIST",
    "18298": "CNUNET--KR Chungnam National University",
    "18299": "SHINGU-NET--KR SHINGU College",
    "18300": "KEPRI--KR KEPCO",
    "18301": "DSNET--KR DAESUNG NETWORK SERVICE CO.,LTD.",
    "18302": "SKG_NW--KR SK Telecom",
    "18303": "SMARTRO--KR SMARTRO",
    "18304": "KKUNET--KR KONKUK UNIVERSTY CHUNGJUCAMPUS COMPUTER CENTER",
    "18305": "POSNET POSDATA Co.,Ltd",
    "18306": "MANHANANET--KR HANANET",
    "18307": "HTS--KR National Tax Service",
    "18308": "BUCHEONSI--KR BUCHEONSI",
    "18309": "KOVAN--KR Korea VAn Service Co.LTD",
    "18310": "VITSSEN--KR TBROAD ABC BROADCTING CO.,LTD.",
    "18311": "BORANET--KR Dongsue Digital BROADCTING CO.,LTD.",
    "18312": "KAMCO--KR Korea Asset Management COrporation",
    "18313": "PCN--KR CJ-CABLENET",
    "18314": "DNUE--KR Daegu National University of Education",
    "18315": "SORABOLNET--KR Sorabol College",
    "18316": "GEN--KR Gyeongsangnamdo Office of Education",
    "18317": "CHODANG--KR Chodang University",
    "18318": "SPEEDON--KR Chonnam Dongbu CATV",
    "18319": "YJNET--KR Yeungnam College of Science & Technology",
    "18320": "GNUE--KR Gwangju National University of Education",
    "18321": "KWU--KR KwangJu Women's University",
    "18322": "DHC--KR Daegu Health College",
    "18323": "DKC--KR Dongkang College",
    "18324": "MANC--KR Masan College",
    "18325": "KORCHRISTUNIV160--KR Korea Christian University",
    "18326": "SPORTSTOTO--KR Sports TOTO",
    "18327": "JINJUIU--KR Jinju International University",
    "18328": "DOTNAME--KR Dotname Korea Corp",
    "18329": "SMUC--KR Sangmyung University",
    "18330": "HONGIK--KR HONGIK UNIVERSITY",
    "18331": "HCC--KR Hyechon college",
    "18332": "POSTOPIA--KR postopia",
    "18333": "CLN--KR Korea Press Foundation",
    "18334": "GCNCATV--KR Gyounggidongbu cable tv co., Ltd.",
    "18335": "SWU-NET--KR Seoul Women University",
    "18336": "KDTC--KR Kyungdong College of Techno-information",
    "18337": "KSUCC--KR KyungSan University",
    "18338": "STARVAN--KR STARVANKOREA",
    "18339": "KHCU--KR Kyung Hee Cyber University",
    "18340": "KORAC-HEALTHSCI1--KR Korea University",
    "18341": "GUMI--KR Gumi College",
    "18342": "KJTJC--KR KunJang College",
    "18343": "TAEGUTECH--KR Daegu Technical College",
    "18344": "CNCGROUP-BACKBONE-NORTH USED IN NORTH CHINANET BACKBONE",
    "18345": "HOSTWAY-AU Hostway Corporation Pty Ltd",
    "18346": "GROUNDHOG--AP Groundhog Software Pty Ltd",
    "18347": "IPNET-ID Indo Pratama CyberNet, PT.",
    "18348": "DPS--AP DIRECT PAYMENT SOLUTIONS",
    "18349": "FUJIXEROXAUSTRALIA Fuji Xerox Australia",
    "18350": "PROMINA--AP Suncorp",
    "18351": "MEDIAAKSES- PT Media Akses Global Indo, Internet Provider Jakarta",
    "18352": "ISERVE-NZ--AP Border",
    "18353": "HDSVDCNZ--AP Revera NZ Limited",
    "18354": "TECHPART-ADELAIDE--AP Technology Partners in Adelaide,",
    "18355": "DONGSUH--ID-AP PT. Dongsuh Securities",
    "18356": "AWARE--AP Aware Corporation Autonomous System",
    "18357": "SUTHERLAND--AP Sutherland Corporation",
    "18358": "UE-AU-AP Alinta",
    "18359": "VODAFONE Vodafone Australia Pty Ltd.",
    "18360": "UST--AP Santo Tomas E-Service Providers",
    "18361": "AUSTOCKEXCHANGE-AU AUSTRALIAN STOCK EXCHANGE LIMITED,",
    "18362": "NETWAY--AP Netway Communication Co.,Ltd.",
    "18363": "HUDSON  HUDSON GLOBAL RESOURCES SYDNEY",
    "18364": "QUAR-ID PT Quasar Jaringan Mandiri",
    "18365": "GRAMEDIA-ID GRAMEDIA, PT.",
    "18366": "APNIC-ANYCT-AP ANYCT",
    "18367": "APNIC-UNI1-AP UNICT  of ANYCT node(Hongkong)",
    "18368": "APNIC-SERVICES APNIC DNS Anycast",
    "18369": "APNIC-UNI3-AP UNICT  of ANYCT node(USA)",
    "18370": "APNIC-UNI4-AP UNICT  of ANYCT node(Other location)",
    "18371": "NCABLE-AP Neighbourhood Cable",
    "18372": "PAGE-NET-EXPR--AP Page Net Express",
    "18373": "KOOKMINBANK--KR KOOKMIN BANK",
    "18374": "DEMAND-TRANSIT--AP Demand  Broadband,",
    "18375": "DEUTSCHE- Deutsche Bank Australia",
    "18376": "AMNET-AU-AP Amnet IT Services Pty Ltd",
    "18377": "CDV-SG-AP Clear Datavoice Service Provider",
    "18378": "NIWA--AP National Institute of Water and Atmosphere",
    "18379": "CSMNAP--AP CSMNAP-N",
    "18380": "SEALCORP-HOLDINGS-LTD-AP Sealcorp Holdings Ltd",
    "18382": "WATSONWYATTHK-NON-HK-AP Watson Wyatt HK Ltd",
    "18383": "CAHI--JP CAHI Corporation,",
    "18384": "E-WIRE--AU-AP e-wire internet service provider",
    "18385": "KDDI--AP KDDI Australia Pty. Ltd.",
    "18386": "SEAGATE-KSC--AP Seagate Technology",
    "18388": "GOWIRELESS-AU GoWireless",
    "18389": "IA-SOLUTIONS--AP Asia Solutions  (ETPI Client)",
    "18390": "SPIN-INTERNET-AP Spin Internet Service",
    "18391": "MRNET--SG-AP Mediaring Network Services Pte Ltd.",
    "18392": "GLOBE-TELECOM-IX Globe Telecom IX Network",
    "18393": "JAVA--AP Java Online, PT.",
    "18394": "UPI--ID Universitas Pendidikan Indonesia",
    "18395": "INFOCOMNP--AP Infocom Pvt. Ltd",
    "18396": "PHILCOMCORP-MND--AP PhilCom Corporation",
    "18397": "POPORTS-SYDNEY- P&O Ports  Sydney link",
    "18398": "PIPE-SYD- PIPE Networks Sydney Internet Exchange. Used for peering services",
    "18399": "YTCL--AP Yatanarpon Teleport Company Limited",
    "18400": "XTREME--AP Xtreme Networks Limited",
    "18401": "18401--KR DAEGU UNIVERSITY",
    "18402": "NLB--SG-AP NATIONAL LIBRARY BOARD",
    "18403": "FPT--AP The Corporation for Financing & Promoting Technology",
    "18404": "NEXG-CARRIER-AU NexG Carrier Pty Ltd",
    "18405": "SNOWREGAL--AP Snowregal Holdings TA Digital Data Solutions Perth Peering",
    "18406": "FX-EDGE- FX Networks Limited",
    "18407": "CLICKINT--AP Click Internet Limited",
    "18408": "RESERVED-CSLOXINFO-TH CSLOXINFO",
    "18409": "BOT-TH- Bank of Thailand, Bangkok, Thailand",
    "18410": "TW-104IT- 104 Information Technology Co., Ltd.",
    "18411": "EDTNS--TW EDT Network Services Limited Co,Ltd.",
    "18412": "FEG-MPLS Far EastTone Telecommunication Co., Ltd.",
    "18413": "GBTC-TW Great Taipei Broadband Company Ltd.",
    "18414": "TWAREN--TW National Center for High-performance Computing",
    "18415": "BWIZ B-WIZ Technology",
    "18416": "NETOWNCHIEF Genmart Tech. Co. lmt.",
    "18417": "TWNIC- Taiwan Network Information Center",
    "18418": "TWNIC- Taiwan Network Information Center",
    "18419": "SIGMATV--TW SIGMA BROAD TV CO.,LTD",
    "18420": "NCU-TW National Central University",
    "18421": "TAISHINBANK--T Taishin International Bank",
    "18422": "ITRINET--TW Industrial Technology Research Institute",
    "18423": "ROAMNET--TW Yuanghong MultiMedia Technology Co. Ltd.",
    "18424": "AIRNET--TW CHWBN",
    "18425": "NTTTW--TW NTT Taiwan Ltd.",
    "18426": "STPI--TW National Applied Research Laboratories",
    "18427": "PCHOME--TW PChome Online",
    "18428": "CUNET--TW China United Telecom Corp",
    "18429": "EXTRALAN-TW Extra-Lan Technologies Co., LTD",
    "18430": "BLUE-TONGUE-ENTERTAINMENT-AP Optus Customer Network",
    "18431": "DFAT-PUBLIC-GW- Department of Foreign Affairs and Trade",
    "18432": "TORONTO-COLO - Vonage Holdings, Inc.",
    "18433": "-PCAL - PAUL CAPITAL ADVISORS, L.L.C.",
    "18434": "FNIS - Fidelity National Information Services, Inc.",
    "18435": "THEJUNCTION - The Junction Internet, LLC",
    "18436": "MSPD-N - Mohegan Sun Pocono Downs",
    "18437": "PITT-OHIO-EXPRESS- - Pitt-Ohio Express, LLC.",
    "18438": "BROWNB - Brown Brothers Harriman & Company",
    "18439": "VISTATSI - VISTA Technology Services Inc.",
    "18440": "NCCI - National Council on Compensation Insurance, Inc.",
    "18441": "IP-NETWORKED-SERVICES - IP Networked Services Inc.",
    "18442": "YOUSENDIT1 - YouSendIt Inc",
    "18443": "APSC - Alyeska Pipeline Service Company",
    "18444": "SMART-CITY-LONG-BEACH - Smart City Networks, L.P.",
    "18445": "POLYONE-CORPORATION - PolyOne Corporation",
    "18446": "KIHEW-TECHNOLOGIES-INC - Kihew Technologies Inc.",
    "18447": "AFFINITY-INTER - Affinity Internet, Inc",
    "18448": "GIANTEAGLE - Giant Eagle",
    "18449": "MVS Net, S.A. de C.V.",
    "18450": "WEBNX - WebNX, Inc.",
    "18451": "N-LES - LES.NET",
    "18452": "ALORICA - ALORICA INC",
    "18453": "Organisation Atticus LLP",
    "18454": "AUGSBURG - Augsburg College",
    "18455": "Netdata S.R.L.",
    "18456": "GDIT-1 - General Dynamics Information Technology, Inc.",
    "18457": "BOURNS - Bourns,Inc",
    "18458": "NYBG - The New York Botanical Garden",
    "18459": "UAIC-INTERNET - UNITED AUTOMOBILE INSURANCE",
    "18460": "FHSU - Fort Hays State University",
    "18461": "BELL-ATL - Verizon Data Services LLC",
    "18462": "TILTED - Tilted Planet Ltd",
    "18463": "RMHP - Rocky Mountaint Health Plans",
    "18464": "CHAM-N - Cotton Hall Asset Management, LP",
    "18465": "WORKDAY-01 - Workday, Inc.",
    "18466": "Geminicommunications Limited",
    "18467": "AXIOM-TECH - Axiom Technologies LLC",
    "18468": "POORMAN-DOUGL - POORMAN-DOUGL Corp.",
    "18469": "PLT - Plantronics",
    "18470": "ZFOPRODN - RE FormsNet, LLC",
    "18471": "SI-N - Senvest International",
    "18472": "CANADIANMUSUEMFORHUMANRIGHTS - Canadian Museum for Human Rights",
    "18473": "NBGISP-ARIN - Intel Corporation - Dupont WA",
    "18474": "AENE-CWUS - Aeneas Internet Services",
    "18475": "ROGERSWIRELESSINC - Rogers Wireless Inc.",
    "18476": "PRISON-FELLOWSHIP-MINISTRIES - Prison Fellowship Ministries",
    "18477": "G2-SATELLITE-SOLUTIONS-CORPORATION - G2 Satellite Solutions Corporation",
    "18478": "NATAL-MED - PEDIATRIX MEDICAL GROUP,INC.",
    "18479": "Universo Online S.A.",
    "18480": "GDT- - General Datatech, LP",
    "18481": "BSWLHRIC - BOCES Southern Westchester Lower Hudson Regional Information Center",
    "18482": "CMSA-NYC-01 - Commercial Real Estate Finance Council, Inc.",
    "18483": "TIMES-WORLD- - TIMES-WORLD, LLC",
    "18484": "VIRTELA-NET-VCALAX1 Virtela Communications",
    "18485": "VIRTELA-NET-VCJC1 Virtela Communications",
    "18486": "VIRTELA-NET-VGAATL1 Virtela Communications",
    "18487": "VIRTELA-NET-VMABOS1 Virtela Communications",
    "18488": "VIRTELA-NET-VJPTKY1 Virtela Communications",
    "18489": "VIRTELA-NET-VWEA1 Virtela Communications",
    "18490": "VIRTELA-NET-VTXDAL1 Virtela Communications",
    "18491": "VIRTELA-NET-VILCHI1 Virtela Communications",
    "18492": "Almacenes Paris Comercial S.A",
    "18494": "EMBARQ-WRBG - Embarq Corporation",
    "18495": "NOVANT-1 - Novant Health Inc.",
    "18496": "GlobalNet SA",
    "18497": "UTSI- - The University of Tennessse Space Institute",
    "18498": "INTEGRATED - Integrated Networks Inc.",
    "18499": "CYBER-GENERATION - Cyber Generation Inc",
    "18500": "PACCAR - PACCAR-ITD",
    "18501": "CODERO-KC - Codero",
    "18502": "WESTCORP - Westcorp",
    "18503": "LOGICSOUTH - LOGICSOUTH, INC.",
    "18504": "FLHSEATS-APOD-N1001 - Veritix",
    "18505": "PALTALK - Paltalk",
    "18506": "IFT-10 - Institute of Food Technologists Inc",
    "18507": "NYMEX-EXTRANET - NEW YORK MERCANTILE EXCHANGE",
    "18508": "FORCE10-NET - Force10 Networks, Inc.",
    "18509": "CORILLIAN - Corillian Corporation",
    "18510": "TRAFELET-AND-COMPANY - Trafelet & Company, LLC",
    "18511": "WWDNY-N - World Wide Dictation of New York",
    "18512": "IKANO-OHIO - IKANO Communications",
    "18513": "AKORN - Akorn Pharmaceuticals",
    "18514": "MDCH-CRP-N - M.D.C. Holdings, Inc.",
    "18515": "UTARLINGTON - University of Texas at Arlington",
    "18516": "MOLALLACOM - Molalla Communications Systems Inc.",
    "18517": "LIMRAI - LL Global Inc",
    "18518": "LCA-N - LaGrange Capital Administration, L.L.C.",
    "18519": "SPRING-HILL-COLLEGE-ARIN - Spring Hill College",
    "18521": "AMERICAN-CAMPUS-COMMUNITIES - American Campus Communities, Inc",
    "18522": "YUMBRANDS - Yum! Brands, Inc.",
    "18523": "CHEP-1 - Chep",
    "18524": "SAM-MEMPHIS - SOUTHETERN SET MANAGEMENT, INC.",
    "18525": "THRU - ThruPoint Inc.",
    "18526": "SMS--01 - Shared Marketing Services, Inc.",
    "18527": "HAGC-N - The Health Alliance of Greater Cincinnati",
    "18528": "DOMINION - DOMINION-TELECOM",
    "18529": "PLEXUSSYSTEMS - Plexus Systems Inc.",
    "18530": "ISOMEDIA-1 - Isomedia, Inc.",
    "18531": "WIFI-MIDWEST-INC - WIFI Midwest Inc",
    "18532": "Secretaria de Hacienda y Credito Publico",
    "18534": "ARBINET-LA-TRADING - ARBINET-THEXCHANGE, INC.",
    "18535": "ROCHE-INDY Hoffmann LaRoche, Inc",
    "18536": "ESERVER-SPACE - ESERVER SPACE INC.",
    "18537": "PPD-AUSTIN - PPDI",
    "18538": "WCPSS-BOE - Wake County Public School System",
    "18539": "DAYTON-SUPERIOR-MIAMISBURG - DAYTON SUPERIOR CORPORATION",
    "18540": "RECOVERYPOINTSYSTEMS - Recovery Point Systems Inc.",
    "18541": "BJN2 - Blue Jeans Network, Inc.",
    "18542": "BRAILLE - Braille Institute of America, Inc.",
    "18543": "NYCION - ION MEDIA NETWORKS",
    "18544": "NKTR-01 - Nektar Therapeutics",
    "18545": "OSMNET - Office of Surface Mining",
    "18546": "CINCINNATI - Accenture LLP",
    "18547": "Picture Inform\u00e1tica Ltda",
    "18548": "18VO - 1 800 Video On, Inc.",
    "18549": "MAVENWIRE-1 - MavenWire, LLC",
    "18550": "FARCAP- - Farallon Capital Management LLC",
    "18551": "ROTHINC - Rothschild, Inc",
    "18552": "SPI-BGP-BDR - Sony Pictures Imageworks, Inc.",
    "18553": "UWF-N - University of West Florida",
    "18554": "AWARD- - Award Solutions, Inc.",
    "18555": "THE-ART-INST - The Art Institute of Chicago",
    "18556": "SCIF - State Compensation Insurance Fund",
    "18557": "HAWKCOMM - Hawk Communications",
    "18558": "NETBLK-RCOEK - Riverside County Office of Education",
    "18559": "BLIP - Blip Networks, Inc.",
    "18560": "LSCO1 - Lamar State College - Orange",
    "18561": "AGSL - Alliance Global Services, LLC",
    "18562": "ALEXA-N - Alexa Internet",
    "18563": "CGINET-01 - CGI Inc",
    "18564": "SJU149068 - St. John's University, New York",
    "18565": "VINS--3 - ViaWest",
    "18566": "MEGAPATH5-US - MegaPath Corporation",
    "18567": "CUTX12-N - Credit Union of Texas",
    "18568": "METACARTA--2 - MetaCarta, Inc.",
    "18569": "COMSPECO-NET-1 - COMMUNICATION SPECIALISTS",
    "18570": "ECHOSTAR-BROADCTING-CORPORATION - EchoStar Broadcasting Corperation",
    "18571": "WESTERNRESERVEGROUP - The Western Reserve Mutual Casualty Company",
    "18572": "BVIU27 - Beaver Valley Intermediate Unit #27",
    "18573": "WCOM-TSENGR- - MCI Communications Services, Inc. d/b/a Verizon Business",
    "18574": "SILVACO - Silvaco Inc.",
    "18575": "IPHOUSE - ipHouse",
    "18576": "Educ.ar",
    "18577": "MIC-64 - ManTech International Corporation",
    "18578": "SCHLUTER-SYSTEMS-LP - Schluter Systems L.P.",
    "18579": "Dalinco",
    "18580": "BGA-HOU - BG North America, LLC",
    "18581": "ALLIANZLIFE - Allianz Life",
    "18582": "CONSUMERINFO - Consumerinfo.com, Inc.",
    "18583": "HATTERCPC - Hatteras CPC",
    "18584": "CORPAK - CORPAK MedSystems, Inc.",
    "18585": "COMMERCEHUB - Commerce Technologies, Inc.",
    "18586": "DIVINEHOST - Divine Hosting Services",
    "18587": "AGUTL - AltaGas Utilities Inc.",
    "18588": "POSTM - Postmedia Network Inc",
    "18589": "OZCAP-NYC - Och Ziff Captial Managment",
    "18590": "CHINETWORKS - Chi Networks",
    "18591": "NYFH - New York Foundling",
    "18592": "Corporacion Universitaria para el Desarrollo de Internet, A.C.",
    "18593": "GSHULLGR - The Goldman Sachs Group, Inc.",
    "18594": "FTPS-LLC - Fifth Third Processing Solutions, LLC",
    "18595": "FPC-N - The Findlay Publishing Company",
    "18596": "MADISONTELCO - Madison Telephone Company",
    "18597": "RVBD - RIVERBED TECHNOLOGY, INC.",
    "18598": "CEQUINT-INC - Cequint, Inc",
    "18599": "ESCAPE-MEDIA-GROUP - Grooveshark",
    "18600": "WPIA-NET - Western PA Internet Access, Inc.",
    "18601": "SMART-CITY-COLUMBUS - Smart City Networks, L.P.",
    "18602": "PWRWG - Paul, Weiss, Rifkind, Wharton & Garrison",
    "18603": "ANS1 - Global Infrastructure Management, LLC",
    "18604": "HPS - Heartland Payment Systems, Inc.",
    "18605": "SOUTHPOLE - SOUTHPOLE",
    "18606": "WHERETOLIVE - WHERETOLIVE.COM",
    "18607": "HIGHWINDS4 - Highwinds Network Group, Inc.",
    "18608": "PALADYNE-SYSTEMS-INC - PALADYNE SYSTEMS, LLC",
    "18609": "NETAPP-ANYCT - Net Applications, Inc.",
    "18610": "SEQUO- - Sequoia Capital",
    "18611": "ATRION - Atrion Networking Corp",
    "18612": "TRI-NET-SOLUTIONS - Tri-Net Solutions LLC.",
    "18613": "LIVEVOX - LiveVox, INC.",
    "18614": "YAKNET - Yakima County",
    "18615": "BG-TELECOM - BG Telecom Holdings, LLC",
    "18616": "NATURALWIRELESS - Natural Wireless, LLC",
    "18617": "CURRENT-COMMUNICATIONS-SERVICES-LLC-NET3 - Current Communications Services LLC",
    "18618": "WCENTRALN - west central wireless",
    "18619": "SOTEL-SYSTEMS - SoTel Systems, LLC.",
    "18620": "DERMALOGICA - Dermalogica, Inc.",
    "18621": "CONESTOGA-COL - Conestoga College",
    "18622": "IVANET-YTO - IBIS INC.",
    "18623": "TWC-MISP-1 - Time Warner Cable Internet LLC",
    "18624": "CITYOFWILSONNC - Greenlight",
    "18625": "DIO-6464 - Data I/O Corporation",
    "18626": "NET-IDEO - IDEO Product Development",
    "18627": "CBE-2 - Calgary Board of Education",
    "18628": "NYMEX - NEW YORK MERCANTILE EXCHANGE",
    "18629": "LTF-001 - LIFE TIME FITNESS, Inc.",
    "18630": "IFCO-US - IFCO SYSTEMS NORTH AMERICA, INC.",
    "18631": "CBT-N1 - Commonwealth Bank & Trust Company",
    "18632": "VOLCANO-NET - Volcano Internet provider",
    "18633": "HPICORP - Health Plans Inc",
    "18634": "FUSIX-1 - Fusix Corporation",
    "18635": "SECUREHOST - Secure Hosting Ltd.",
    "18636": "SHOREN - ShoreTel Inc.",
    "18637": "VDS - babyTEL Inc.",
    "18638": "DHDC-CA - DH DataCentres Inc.",
    "18639": "ABTSOCIATES- - Abt Associates, Inc.",
    "18640": "IDEALAB - Idealab",
    "18641": "DATACONSULTANTSCORP - Data Consultants Corp.",
    "18642": "SPACENET-ENT2 - Spacenet, Inc.",
    "18643": "SMARTCITY-LVCC - Smart City Networks, L.P.",
    "18644": "UOL DIVEO S.A.",
    "18646": "APERO-SOLUTIONS - Sentai Software Consulting",
    "18647": "ACCEL- - Accel Net, Inc.",
    "18648": "SIMPSON - Simpson Paper Company",
    "18649": "M5-NETWORKS - M5 Networks, Inc.",
    "18650": "KORAX - Korax Inc.",
    "18651": "EMANUEL-MEDICAL-CENTER - EMANUEL MEDICAL CENTER, INC",
    "18652": "TOTALITY-2 - MCI Communications Services, Inc. d/b/a Verizon Business",
    "18653": "TOTALITY-2 - MCI Communications Services, Inc. d/b/a Verizon Business",
    "18654": "TOTALITY-2 - MCI Communications Services, Inc. d/b/a Verizon Business",
    "18655": "APRIVA-ISS - Apriva ISS, LLC",
    "18656": "TELESIGN01 - Telesign Corp.",
    "18657": "MEETUP - Meetup, Inc.",
    "18658": "ECHD-1 - ECTOR COUNTY HOSPITAL DISTRICT",
    "18659": "FTPS-LLC - Fifth Third Processing Solutions, LLC",
    "18660": "KSUONLINE-I2 - Kentucky State University",
    "18661": "DCA-BGP - Dunn Carney Allen Higgins & Tongue, LLP",
    "18662": "AFLAC - Aflac",
    "18663": "UOP- - University of the Pacific",
    "18664": "EMPIRE-HEAL - Empire Blue Cross Blue Shield",
    "18665": "CKC-HM-92100-3215-1 - 800 Call KC",
    "18666": "NOKIA-AMERIC NOKIA Corporation",
    "18667": "Web2mil S.A",
    "18668": "MFM - MFM Communication Software, Inc",
    "18669": "BSEC-CA-1 - Bal Seal Engineering Co. Inc.",
    "18670": "ARROWSTREET - Arrowstreet Capital, L.P.",
    "18672": "TOPEK-2 - Topeka Capital Markets, Inc.",
    "18673": "CFP-N - The Casey Family Program",
    "18674": "FROST-NAT-BANK - Frost National Bank",
    "18675": "FNW-WMICH - FreedomNet",
    "18676": "AVAYA AVAYA",
    "18677": "COLUMBUS-NETWORKS - Columbus Networks USA, Inc.",
    "18678": "INTERNEXA S.A. E.S.P",
    "18679": "NIRVANIX-N1 Nirvanix, Inc.",
    "18680": "AKAMAI- - Akamai Technologies, Inc.",
    "18681": "CONSTELLATION-ENERGY - Constellation Energy",
    "18683": "MWFN - Midwest Fiber Networks, LLC",
    "18684": "WCM-N - Westfield Capital Management Company, LLC",
    "18685": "BIR-2-N - Bacharach Institute for Rehabilitation",
    "18686": "INCO--1 - INCOGNITO SOFTWARE INC.",
    "18687": "MPOWER-2 - MPOWER COMMUNICATIONS CORP.",
    "18689": "GWYNN-GROUP-INC - Gwynn Group Inc.",
    "18690": "MEDIDATA Mediadata",
    "18692": "NEUBERGER - Neuberger Berman",
    "18693": "UCH-CENTRAL - University of Colorado Hospital",
    "18694": "SDWARREN - S. D. Warren Services Co.",
    "18695": "ARBINET-NY-TRADING - ARBINET-THEXCHANGE, INC.",
    "18696": "NTM-USHQ - NEW TRIBES MISSION, INC.",
    "18697": "CVPS-N - Central Vermont Public Service (CVPS)",
    "18698": "IAC-NYC-01 - Icahn Associates Corp.",
    "18699": "JAGUAR-2 - Jaguar Communications",
    "18700": "TIWI-CA-NET - The Integration Works, LLC",
    "18701": "PPCO-US - ConocoPhillips Company",
    "18702": "PAYROLLLINK- - Payroll Link, Inc.",
    "18703": "IBMCCH-H - IBM",
    "18704": "T-SYSTEMS-NA - T-Systems North America, Inc.",
    "18705": "RIMBLACKBERRY - Research In Motion Limited",
    "18706": "LISTEN-SF-3 - RealNetworks, Inc.",
    "18707": "PREMIERLINK - Intelemedia Communications, Inc",
    "18708": "HDR-CORP - HDR, Inc.",
    "18709": "BOTW - Bank of the West",
    "18710": "GKG-NET - GKG.NET, INC",
    "18711": "RICHARD-STOCK - The Richard Stockton College of New Jersey",
    "18712": "SUREWEST-KANS - SureWest Kansas Operations, LLC",
    "18713": "IBMCCH-SJO - IBM",
    "18714": "PERRYCAP-NY - Perry Capital",
    "18715": "NYPA - New York Power Authority",
    "18716": "ADESK-EUROPE Autodesk SARL is the EU branch of Autodesk, Inc.",
    "18717": "AKAMAI- - Akamai Technologies, Inc.",
    "18718": "MARVELL - Marvell Semiconductor Inc.",
    "18719": "TSRSOLUTIONS - TSR Solutions, Inc.",
    "18720": "PACSUN - Pacific Sunwear of California",
    "18721": "ACDLABS- - ACD/Labs",
    "18722": "SUPERVALU - SUPERVALU, Inc.",
    "18723": "SEAGATE-TECHNOLOGY- Seagate Technology",
    "18724": "SHSN01 - SUPERIOR HOME SERVICES, INC.",
    "18725": "PVH-INTERNET1 - Phillips-Van Heusen",
    "18726": "SECUREWORKS-18726 - SecureWorks Inc.",
    "18727": "DNPS - Detroit Newspapers",
    "18728": "ISINJ - Instructional Systems Inc.",
    "18729": "SHAWMUT - Shawmut Design & Construction",
    "18730": "CYBERSOURCE-SC4 - Cybersource Corp.",
    "18731": "STREAM-G-ELECTRIC- - SGE IP Holdco, LLC",
    "18732": "QOSNETWORKS QoS Networks, Inc.",
    "18733": "US-CABLE-OF-COTAL-TEX-MO - US Cable of Paramus-Hillsdale, LLC",
    "18734": "Operbes, S.A. de C.V.",
    "18735": "TWM-BGP - Tolleson Management LP",
    "18737": "TRIALPAY - TrialPay, Inc.",
    "18738": "EPICOR - EPICOR",
    "18739": "AGENCIA MODERNA TECNOLOGIA LTDA.",
    "18740": "YELLOWBRIX - YellowBrix, Inc.",
    "18741": "SOUNDHOUND1 - SoundHound, Inc.",
    "18742": "ON24-SAC - ON24, Inc.",
    "18743": "EVERENCE-SERVICES-LLC - MENNONITE MUTUAL AID",
    "18744": "SMISLOVA-KEHNEMUI-AND-SOCIATES-ENGINEERS - Smislova, Kehnemui & Associates, P.A.",
    "18745": "CWPS-WDC - CWPS",
    "18746": "MIG-BGP - Merchants Insurance Group",
    "18748": "AT-WAN - Ann Taylor Stores Corporation",
    "18749": "PREMINC-INTER - Premier, Inc.",
    "18750": "LEXICOM - Lexicom Ltd.",
    "18751": "BPL-B1 - Basketball Properties Ltd",
    "18752": "HUNTBROTHERS-ETCOT - Hunt Brothers",
    "18753": "TEX-STATE-BANK - Texas State Bank",
    "18754": "LOOKSMART - Looksmart, LTD",
    "18755": "VOXEO-SERVICE - Voxeo Corporation",
    "18756": "PATEAM - Level 3 Communications, Inc.",
    "18757": "ADT-SECURADT - ADT Security Services, Inc.",
    "18758": "MGSC-2 - Maas Global Solutions Corporation",
    "18759": "ARMSTRONG- - Armstrong Atlantic State University",
    "18760": "RANCHO-CUCA - City of Rancho Cucamonga",
    "18761": "BLM-WAN - Bureau of Land Management",
    "18762": "DOMDOMINICK - Dominick & Dominick LLC",
    "18763": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18764": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18765": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18766": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18767": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18768": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18769": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18770": "PHJW-LLP - Paul, Hastings, Janofsky & Walker LLP",
    "18771": "AGAVEBB-NM01 - Agavue LLC",
    "18772": "SKY-LAKES-MEDICAL-CENTER - Sky Lakes Medical Center, Inc.",
    "18773": "HENRICO- - County of Henrico",
    "18774": "TIMESPUBLISHING - St. Petersburg Times",
    "18775": "ENGEN-PET",
    "18776": "VALSIS - Valassis Communications, Inc.",
    "18777": "TSU-SM - Texas State University - San Marcos",
    "18778": "LARSONALLEN - LarsonAllen",
    "18779": "EGIHOSTING - EGIHosting",
    "18780": "RESTEL-81 - Reservation Telephone Coop.",
    "18781": "BITSHOP - BitShop, Inc.",
    "18782": "Pegasus Telecom",
    "18784": "MCD-US-N - McDonald's Corporation",
    "18786": "SHELBYBB - Shelby Broadband",
    "18787": "DANAHER - Danaher",
    "18788": "INTEGRYS-ENERGY - Integrys Business Support, LLC",
    "18789": "NETMLH- - Main Line Health, Inc.",
    "18790": "GLOBALCOMPANIESLLC2006 - Global Companies LLC",
    "18791": "TCU - Texas Christian University",
    "18792": "QCBONE - Reseau Inter-Systeme LLC",
    "18793": "COM-PAIR-BROADBAND - Com-Pair Services",
    "18794": "RAMAPO-COLLEGE - Ramapo College of New Jersey",
    "18795": "ULV- - University of La Verne",
    "18796": "QUALCARE - Qualcare inc",
    "18797": "ITO-LLC - ITO, LLC",
    "18798": "ENCORE-N - Encore Productions, Inc.",
    "18799": "TBD - Palmdale Regional Medical Center",
    "18800": "PRING - Associated Spring",
    "18801": "NETBX-1 - NETBX TECHNOLOGIES INC.",
    "18802": "MUT-AMER - Mutual of America Life Insurance Company",
    "18803": "MUNIS-P - Munis, Inc.",
    "18804": "AKCIN - AKCIN INC.",
    "18805": "WCP--1 - Weatherford Canada Partnership",
    "18806": "ONENECK-IT-SERVICES-TDC- - OneNeck IT Services Corporation",
    "18807": "SPEEDHOST-1 - SpeedHosting Inc",
    "18808": "C21- - CENTURY 21 DEPARTMENT STORES, LLC",
    "18809": "Cable Onda",
    "18810": "EHI-PRODUCTION - eHealthInsurance Services Inc.",
    "18811": "ESILICON - eSilicon.com",
    "18812": "NEWWAVECOMM - New Wave Communications",
    "18813": "ENERGYSOLUTIONS - EnergySolutions LLC",
    "18814": "ATC-DC-NET01 - Atlantic Technology Centre Inc",
    "18815": "-CITY-AND-COUNTY-OF-DENVER - CITY AND COUNTY OF DENVER",
    "18816": "ANDREWCORP-AOP - Andrew Corp.",
    "18817": "DWNET - Dataware, LLC",
    "18818": "LSUHSCS-NET2 - LSU Health Sciences Center - Shreveport",
    "18819": "ENTERGY-CORP-US - Entergy Corporation",
    "18821": "AVISTA-2 - Avista Advantage, Inc.",
    "18822": "Manquehuenet",
    "18823": "MEDICALERT - Medicalert Foundation",
    "18824": "WWW-THESEAM - Plains Cotton Cooperative Association",
    "18825": "LOCALTEL-COMMUNICATIONS - LocalTel Communications",
    "18826": "TERRESTAR - Terrestar Networks Inc.",
    "18827": "VGMGR-FORBIN - Forbin",
    "18828": "TRIMBLE-WEST - Trimble",
    "18829": "GALAXY-CONTROL-SYSTEMS - Galaxy Control Systems",
    "18830": "HMH-18830 - Houghton Mifflin Harcourt Publishing Company",
    "18831": "XPRESSWEB - XPRESSWEB INTERNET SERVICES",
    "18832": "INFLOW18832 - Inflow Inc.",
    "18833": "HP-NETWORK - American Specialty Health Plans of CA, Inc.",
    "18834": "NETWORKIP - Network IP",
    "18835": "FIDUCIAL - Fiducial Inc.",
    "18836": "PROCEDA TECNOLOGIA E INFORMATICA S.A.",
    "18837": "ADDTHIS - AddThis, Inc.",
    "18838": "DCSSGA - DeKalb County School System",
    "18839": "2000FISHERISSS - FISHER SCIENTIFIC",
    "18840": "EQUIPOS Y SISTEM S.A.",
    "18841": "TRIMBLE-SNVL - Trimble",
    "18842": "VERTICAL-SCR - Business Information Group, Inc.",
    "18843": "CHI-MANAGEMENT - Crossmark",
    "18844": "SHERWIN- - The Sherwin Williams Company",
    "18846": "Petroleos Mexicanos",
    "18847": "RANDOLPH-ISP - Randolph County Government of NC",
    "18848": "ALTEC-IND-DOM - Altec Industries",
    "18850": "TOOLWIRE - Toolwire, Inc.",
    "18851": "ICORE-N-1 - iCore Networks, Inc.",
    "18852": "HLANDINC- - Ashland, Inc.",
    "18853": "LVWIFI - LVWifi.com",
    "18854": "LIGHTSPEEDTRADING - Lightspeed Trading, LLC",
    "18855": "AWC - AWC Inc.",
    "18856": "SCCA - Seattle Cancer Care Alliance",
    "18857": "USD231- - USD 231 Gardner Edgerton",
    "18858": "ISVS-216169032000-19 - Interconnect Services, Inc.",
    "18859": "GVEC-NET - GVEC.NET, INC.",
    "18860": "-KRAFTKENNEDY-NET - Kraft & Kennedy, Inc.",
    "18861": "IVANET-BUE - IBIS INC.",
    "18862": "NCS-HEALTHCARE - Omnicare, Inc.",
    "18863": "BROADRIVER-18863 - BroadRiver Communication Corp.",
    "18864": "FIRST-UNITED-BANK - First United Bank and Trust Company",
    "18865": "-INTUIX - Intuix LLC",
    "18866": "ATJEU - atjeu publishing, llc",
    "18867": "AMERICAN-MESSAGING - American Messaging Services L.L.C.",
    "18868": "ORMUC-2 - Ormuco",
    "18869": "EPM Telecomunicaciones S.A. E.S.P.",
    "18870": "GWB - Great Western Bank",
    "18871": "YOURINTERNET - Indiana Printing and Publishing Company",
    "18872": "VERIT - Symantec Corporation",
    "18873": "LACKLANDIT - Lackland Acquisition II, LLC.",
    "18874": "EWI-N-1 - Digitalglobe, Inc.",
    "18875": "QZN-N-001 - Questzone.Net, Inc.",
    "18876": "ARRIVAL-COMM - Arrival Communication, Inc",
    "18877": "SAILTHRU-01 - Sailthru, INC",
    "18879": "ALTEGRITY - Altegrity, Inc.",
    "18880": "VIRTELA-NET-CCAFRE5 Virtela Communications",
    "18881": "Global Village Telecom",
    "18882": "FLEX-DUC- Flextronics International - Duesseldorf",
    "18883": "FIBERNET-NETWORK-OPERATIONS-CENTER - FiberNet Communications L.C.",
    "18884": "RCLS - Ramapo Catskill Library System",
    "18885": "WAVE2WAVE - Wave2Wave Communications, Inc",
    "18886": "INLINE-NET - Inline Connections",
    "18887": "VISTO-IT-2 - Visto Corporation",
    "18888": "-ZILLOW - ZILLOW, INC.",
    "18889": "CITY-OF-RUSTON - City of Ruston",
    "18890": "HOGARTH-WORLDWIDE - Hogarth Worldwide Inc",
    "18891": "CONFLUENCE - Confluence Technologies, Inc.",
    "18892": "MEGA-BRANDS-MONTREAL - MEGA Brands, Inc",
    "18893": "SELECT-EQUITY - Select Equity Group, Inc.",
    "18894": "NEXTPAGE - NextPage, Inc.",
    "18895": "NUSTREAM-COMMUNICATIONS - Nustream Communications",
    "18896": "CALLIS-COMMUNICATIONS-18896 - Callis Communications",
    "18897": "MONTANA-SKY-NETWORKS-INC - Montana Sky Networks, Inc.",
    "18898": "VESTA-CORP - Vesta Corporation",
    "18899": "-JDOFTSCT - JDA Software Group Inc.",
    "18900": "CQG-INC - CQG, Inc.",
    "18901": "RANGER-CAPITAL - Ranger Capital",
    "18902": "CONSULATE-IT - CMC II, LLC",
    "18904": "OPO - OPO, INC.",
    "18905": "BROADRIVER-18905 - BroadRiver Communication Corp.",
    "18906": "CONCORD- - Concord Management Ltd",
    "18907": "COLOVORE - Colovore LLC",
    "18908": "BRIGHTCOVE- - Brightcove, Inc.",
    "18909": "GSCBV-N - Gannett Supply Corp. - Burlington, VT",
    "18910": "BIG-SANDY-BROADBAND-INC - Big Sandy Broadband Inc",
    "18911": "MARKETFACTORY - Market Factory, Inc.",
    "18912": "RTC-DESMONIES - Des Moines Register & Tribune Co",
    "18913": "AIR-PIPE- - AIR-PIPE, LLC.",
    "18914": "JOSEP-44 - Joseph Cory Holdings LLC",
    "18915": "PGTEL--2 - PG Telecom Holding Inc.",
    "18916": "PSFT-ECENTER - Oracle Corporation",
    "18917": "RHEEM-WATER-HEATING - Rheem Manufacturing Company",
    "18918": "UNOCOMM - Uno Communications Inc.",
    "18919": "STT-GLOBAL - smartTrade Technologies",
    "18920": "HEI - Hawaiian Electric Industries, Inc.",
    "18921": "NNAVTEQEQUINIXCHICAGO - HERE North America LLC",
    "18922": "AfOL-Zw--2",
    "18923": "TWRS-FTW - Towerstream I, Inc.",
    "18924": "RPTK2 - RPTK",
    "18925": "59010 - TMP Direct",
    "18926": "IIG - The International Investment Group L.L.C.",
    "18927": "PIXELSTREAMS - Pixelstreams LLC",
    "18929": "AAMVA - THE AMERICAN SOCIATION OF MOTOR VEHICLE ADMINISTRATORS",
    "18930": "DOWCORNING151-163 - Dow Corning",
    "18931": "SAINTERNET1",
    "18932": "KBS-160VARICK - Kirshenbaum Bond Senecal & Partners LLC",
    "18934": "SMITH-AND-HAMMAKER - SMITH & HAMMAKER",
    "18935": "SIRNY-3861 - Sotheby's International Realty, Inc.",
    "18936": "GLENCOM - Glencom Systems Inc.",
    "18937": "NMC - National Monitoring Center",
    "18938": "PRESSGANEY - PRESS GANEY SOCIATES INC",
    "18939": "DBC-SALT-LAKE - Data Broadcasting Corporation",
    "18940": "SHPS-INC - SHPS, Inc",
    "18941": "El Mercurio S.A.P.",
    "18942": "WEBHOSTPLUS-INC - WebHostPlus Inc",
    "18943": "YELCOT - YELCOT TELEPHONE COMPANY",
    "18944": "APTEA - Great Atlantic and Pacific Tea Company, inc.",
    "18945": "VINS--5 - ViaWest",
    "18946": "FANNIEMAE-2 - Fannie Mae",
    "18947": "FSN-USTXAUS01 - Freight Security Net, Inc.",
    "18948": "NYMC2000-ARIN - New York Medical College",
    "18949": "GIN-RIDGE-BOYS - Gin Ridge Boys",
    "18950": "EDUCATE - Educate Inc",
    "18952": "IMLLOU1 - INTERACTIVE MEDIA LAB INC",
    "18953": "LOUDOUN-WIRELESS - LOUDOUN WIRELESS LLC",
    "18954": "COWEN-N18954 - Cowen Group, Inc",
    "18955": "TWEA- - Treasury Wine Estates Americas",
    "18956": "NYK - NYK Business Systems Americas, Inc.",
    "18957": "TRIRIGA - TRIRIGA, INC.",
    "18958": "CRRESEARCH - C&R Research",
    "18959": "AWL-29- - The American Way, LLC",
    "18960": "HORNELL-INTERNET-PRIMARY - Hornell Brewing Co., Inc.",
    "18961": "MCLANECO - McLane Company, Inc.",
    "18962": "MEDITECH-1 - Medical Information Technology, Inc.",
    "18963": "OFDA - Office of U.S. Foreign Disaster Assistance",
    "18964": "AHSSSCI - Adventist Health Systems SSCI",
    "18967": "AMAXX - AMAXX, Inc.",
    "18968": "QUADRANT - Quadrant Newmedia Corp.",
    "18969": "KLC--1 - Knowledge Learning Corporation",
    "18970": "XNPD - The NPD Group Inc.",
    "18971": "BCUS - BARCLAYS FINANCIAL CORP.",
    "18972": "PROMENET - PROMENET, INC.",
    "18973": "TAG-ONLINE - TAG Online Inc.",
    "18974": "TRULIANT-1 - Truliant Federal Credit Union",
    "18975": "STANCOEORG95354 - Stanislaus County Office of Education",
    "18976": "FREIGHTQUOTE - Freightquote.com, Inc.",
    "18977": "MAIN - Reliable-ISP",
    "18978": "ENZUINC-US - Enzu Inc",
    "18979": "WHI - Whi Solutions Inc.",
    "18980": "PEACEHEALTH - Peace Health",
    "18981": "SUPREME-TELECOM - Supreme Telecom Systems, Inc.",
    "18982": "ONENECK-IT-SERVICES-CHARLOTTE- - OneNeck IT Services",
    "18983": "FMI-BR - FM Services Company",
    "18984": "SERVERCAVE - ServerCave, Inc.",
    "18985": "GAPINC-NET - GAP, Inc.",
    "18986": "PACIFICONLINE - Pacific Online Inc.",
    "18987": "N-GLOBALMDM - Global MDM Inc.",
    "18988": "CITYWEST-CORP - City West Cable & Telephone Corp.",
    "18989": "LIFELOCK-1 - LIFELOCK",
    "18990": "AIRBAND-DALL - Airband Communications, Inc",
    "18991": "CONIFER-SECURITIES - Conifer Securities, LLC",
    "18993": "AFS147 - Area Financial Services Inc.",
    "18994": "COVANCE-PRINCETON-ATT-MCI - COVANCE INC",
    "18995": "CLACKAM-N - Clackamas County",
    "18996": "JK-GRP - J.K. Group, Inc",
    "18997": "RUNETWORKS - RU",
    "18998": "Credomatic",
    "18999": "POPLAR-BLUFF - Poplar Bluff Internet, Inc.",
    "19000": "CBSI-4 - CBS Interactive Inc.",
    "19001": "AVENTCOMMTECH - Aventure Communications",
    "19002": "FDBS- - Financial Database Services",
    "19003": "IHSENERGY-CALGARY - IHS Energy Group",
    "19004": "SCHWABPLAN - Schwab Plan Retirement Services",
    "19005": "SMTP-HOME-NETWORK - SMTP, Inc.",
    "19006": "CLICK1 - Infostructure Cable and Internet",
    "19007": "USRN--1 - United Stations Radio Networks, Inc.",
    "19008": "PSCI - Perry-Spencer Communications, Inc.",
    "19009": "ONECLEVELAND - OneCleveland",
    "19010": "HODC - Shale-Inland Holdings LLC",
    "19011": "ODETICS - Odetics",
    "19012": "ENDSIGHT-CL-1 - Endsight",
    "19013": "PERF-FOOD - Performance Food Group Company LLC",
    "19015": "GREENPATH - GreenPath Inc",
    "19016": "WCG- - Westman Communications Group",
    "19017": "QUALCOMM-QWBS-LV - Qualcomm, Inc.",
    "19018": "MEGAPATH7-US - MegaPath Corporation",
    "19019": "-COSENTRY-COM-1 - COSENTRY.NET, LLC",
    "19020": "CAPITALONEMCLEAN - Capital One Financial Corporation",
    "19021": "BTC-BROADBAND - BTC Broadband Inc.",
    "19022": "CISP-TOTAL - CISP",
    "19023": "SERVICEMTER - The ServiceMaster Company",
    "19024": "INTERNAP-BLK5 - Internap Network Services Corporation",
    "19025": "XO-N12 - XO Communications",
    "19026": "XO-N14 - XO Communications",
    "19027": "XO-N11 - XO Communications",
    "19028": "XO-N10 - XO Communications",
    "19029": "NEWEDGENETS - New Edge Networks",
    "19030": "HMH-19030 - Houghton Mifflin Harcourt Publishing Company",
    "19031": "WESCO - CU*Answers, Inc.",
    "19032": "WLETC - Wireless Etc Inc.",
    "19033": "World Tel-Fax Electronics C.A.",
    "19034": "-MLS-PIN - MLS Property Information Network",
    "19035": "HIX - Hawaii Internet Exchange",
    "19036": "LORAL-CYBERSTAR - Telesat Network Services Inc",
    "19037": "CTI Compania de Telefonas del Interior S.A.",
    "19038": "SCOTIABANK INVERLAT SA",
    "19039": "DURABLEDNS - DurableDNS, LLC",
    "19040": "FIRSTMERIT - FirstMerit N.A.",
    "19041": "ADOBE-19041 - WebSideStory Search and Content Solutions",
    "19042": "INDS-NY-1 - Interstate National Dealer Services",
    "19043": "ONEBEACONINSURANCEGROUP - OneBeacon Insurance Group LTD",
    "19044": "INNER - The Inner Net",
    "19045": "DIRECTCOM - Direct Communications Cable LLC",
    "19046": "STACKPOP - 43Bytes",
    "19047": "LUNDWALL-1 - Lundwall Creative, Inc.",
    "19048": "CORIO - Corio, Inc.",
    "19049": "PROVIDECOMMERCE-2 - Proflowers Inc",
    "19050": "TIC-DHHS-INTERIOR - U.S. Department of Health & Human Services",
    "19052": "CNI - Cobourg Networks Inc.",
    "19053": "EPIC-IS - Epic Information Solutions",
    "19054": "PENFORD-CORP - Penford Corporation",
    "19055": "CAC-HQ - Credit Acceptance Corporation",
    "19056": "IETF-49 - Qualcomm, Inc.",
    "19057": "IBMCCH-CHI - IBM",
    "19058": "IRTC-NET - Illinois Rural Telecommunication Co.",
    "19059": "CODERO-HBURN - Codero",
    "19060": "BRYANLGH--01 - Bryan Health",
    "19061": "N-CCILINK - CCiLink LLC",
    "19062": "W3MEDIA - W3 International Media Ltd.",
    "19063": "SJHS - St. John Health System",
    "19064": "NET EXPRESS S.A.",
    "19065": "LRS - Levi, Ray & Shoup, Inc.",
    "19066": "WIREDTREE - Cogswell Enterprises Inc.",
    "19067": "VAILSYS - Vail Systems",
    "19068": "N-TOMMYBAHAMA - Tommy Bahama Group, Inc.",
    "19069": "NDAQ-OMX-19069 - THE NDAQ OMX GROUP, INC.",
    "19070": "EIUNET - Eastern Illinois University",
    "19071": "MATCHCOM - Match.com, L.L.C.",
    "19072": "OFFICEMAX - OfficeMax",
    "19073": "BLUE-BOX-GRP - Blue Box Group, Inc.",
    "19074": "N-01-FBCL - Fort Bend County Libraries",
    "19075": "SHAW-COMMUNICATIONS - Shaw Communications Inc.",
    "19076": "WELDCOUNTYGOVERNMENT-N - Weld County Government",
    "19077": "CYBERCENTER S.A.",
    "19078": "RNK-N - RNK Capital LLC.",
    "19079": "LOCL-NET - Locl-Net Inc",
    "19080": "N-WBS-01 - WBS Connect, LLC",
    "19081": "GFSI-INC - GFSI, Inc.",
    "19082": "EVERESTBROADBAND - EVEREST BROADBAND NETWORKS",
    "19083": "WEBTRENDS-INCORPORATED - WebTrends Incorporated",
    "19084": "SINDAD-LLC - Sindad LLC",
    "19085": "KSDK-TV - KSDK-TV",
    "19086": "CGI-HOSTING - CGI Inc",
    "19087": "MAILBOXES-ECT - The UPS Store, Inc.",
    "19088": "ECG - E Commerce Group",
    "19089": "DH&C Outsourccing S/A.",
    "19091": "BOSC - BOENNING & SCATTERGOOD, Inc.",
    "19092": "360NETWORKS-US - 360Networks (USA) Inc.",
    "19093": "IBMUSF-SCH - IBM",
    "19094": "LVLT-19094 - Level 3 Communications, Inc.",
    "19095": "GMS- - Gilsanz Murray Steficek LLP",
    "19096": "DESALES-NETWORK - DeSales University",
    "19098": "BDTCAPITALPARTNERS - BDT Capital Partners, LLC",
    "19099": "RAMBUS - Rambus",
    "19100": "GPSAC - General Pacific, Inc.",
    "19101": "MANCHESTERNH - City Of Manchester, NH",
    "19102": "PCI-CAESY - Patterson Companies, Inc.",
    "19103": "SNC-LAVALIN-CONSTRUCTORS-INC - SNC-Lavalin Constructors",
    "19104": "AXISINTERNET - AxisInternet, Inc.",
    "19105": "FIRST-DATA-CORP - Firstbank Data Corporation",
    "19106": "ANDREWS - Andrews University",
    "19107": "YMAX- - Ymax Communications Corp",
    "19108": "SUDDENLINK-COMMUNICATIONS - Suddenlink Communications",
    "19109": "CETELEM",
    "19110": "GCC - Global Cash Card",
    "19111": "NATURES-BOUN - NBTY, Inc.",
    "19112": "NORTH-BAY---N - North Bay Capital Management, LP",
    "19113": "DUKE-ENERGY - Duke Energy Corporation",
    "19114": "Otecel S.A.",
    "19115": "CHARTER-LEBANON - Charter Communications",
    "19116": "LANDMARK-HEALTHCARE - Landmark Healthcare, Inc.",
    "19117": "HEAVYCOMPUTING - Heavy Computing",
    "19118": "-SIT - IDT Corporation",
    "19119": "ROLLINSCOLLEGE - Rollins College",
    "19120": "ARGIA - ARGIA",
    "19121": "KAVI - Kavi Corporation",
    "19122": "19THFLOORNET-HOSTING-SERVICES - 19thfloor.net",
    "19123": "OHIOTRANSMISSIONCORP - Ohio Transmission Corporation",
    "19124": "WHEATON-FRANCISCAN-SERVICES-INC - Covenant Healthcare Systems, Inc.",
    "19125": "ROCK-NET - Rockford Corporation",
    "19126": "RAIL-EUROPE-INC - Rail Europe Group",
    "19127": "SEI-MER - SEI INFORMATION TECHNOLOGY",
    "19128": "TTN - Trade The News",
    "19129": "PLAINS-NET - Premier Systems Unlimited, Inc.",
    "19130": "DOCKNET - Aerioconnect",
    "19131": "EOHIONET - Eohio Net",
    "19133": "BIRD-HOSTING - Bird Hosting Inc.",
    "19134": "FTBONLINE - First Horizon National Corporation",
    "19136": "NNET",
    "19137": "EPSILON-INTERACTIVE - Epsilon Interactive LLC",
    "19138": "SWEET-BRIAR-COLLEGE - Sweet Briar College",
    "19139": "MARINERSYSTEMS - Mariner Systems Inc.",
    "19140": "META-PHARMACEUTICAL-SERVICES - Meta Pharmaceutical Services, LLC",
    "19141": "CSC-ENYU - Computer Sciences Corporation",
    "19142": "AAFES - Army & Air Force Exchange Service",
    "19143": "FWS-NET - U.S. Fish and Wildlife Service",
    "19144": "SUSQ-HEALTH - Susquehanna Health",
    "19145": "NETSONIC - Netsonic",
    "19146": "ILGYUW19L - Delgado Industries, LLC",
    "19147": "ALPHA-SYS - Alpha Systems",
    "19148": "LIVEWORLDCA - LiveWorld, inc.",
    "19149": "TEAMTECH-DSM - TEAM Technologies LLC.",
    "19150": "SPARKNET - SparkNET Corporation",
    "19151": "WVFIBER-1 - WV FIBER",
    "19152": "IBMCCH-TOR - IBM",
    "19153": "UTMARTIN - The University of Tennessee at Martin",
    "19154": "SOLUTIONARY - Solutionary, Inc.",
    "19155": "VYSTARCU - Vystar Credit Union",
    "19157": "CHARTER-TN - Charter Communications",
    "19158": "USCARRIER - USCARRIER TELECOM, LLC.",
    "19159": "STING - Sting Communications",
    "19160": "ATGL- - Apex Tool Group LLC",
    "19162": "BELLCOHEALTH1 - Bellco Health",
    "19163": "WHM - FIT Technologies",
    "19164": "COGENT-19164 - Cogent Communications",
    "19165": "WEBPS - Webpass Inc.",
    "19166": "ACRONOC - ACRONOC INC",
    "19167": "MUSKOKA-COM - Muskoka.com",
    "19168": "HUDSON-POTOMAC - Hudson Potomac Services Corp",
    "19169": "Telconet S.A",
    "19170": "MISN - Meramec Interactive Services Network",
    "19171": "STARGATE-VAN - Stargate Connections Inc.",
    "19172": "XROADS-NET - Crossroads InternationalCommunications Inc. USA",
    "19173": "HYKO - HY-KO Products Company",
    "19174": "19174 - China Unicom (Americas) Operations Ltd",
    "19175": "LCSN - Levin Capital Strategies, L.P.",
    "19176": "PAISP - PaISP Inc.",
    "19177": "GO-NET-NETWORK - GO International, Inc.",
    "19178": "ESPEED-LONDON Cantor Fitzgerald International Ltd",
    "19179": "COEP - City of El Paso",
    "19180": "AMERICATEL PERU S.A.",
    "19181": "CWIE - CWIE LLC",
    "19182": "TELEF\u00d4NICA BRIL S.A",
    "19183": "CDI-CORPORATION - CDI Corporation",
    "19184": "UWECNET - University of Wisconsin - Eau Claire",
    "19186": "CSNY350MAD - COLLINS STEWART INC.",
    "19187": "IFOXNETLE - INFOCROSSING, INC.",
    "19188": "EMSINC - Exchange Market Systems E.M.S. Inc.",
    "19189": "PULSEPOINT - Pulsepoint Inc",
    "19190": "FTWIRE-COM - Fastwire.com Inc",
    "19191": "SPRINGNET1-EOS - EOS, Inc.",
    "19192": "Universidad Central de Venezuela",
    "19193": "SPIDERROCK-GW - SPIDERROCK HOLDINGS, LLC",
    "19194": "JOVITA - Sentris Network LLC",
    "19195": "DURALEE-FABRICS - DURALEE FABRICS LTD",
    "19196": "BellSouth Chile",
    "19197": "TECHTEAM-EUROPE TECHTEAM EUROPE",
    "19198": "DRW-HOLDINGS - DRW Holdings, LLC",
    "19199": "PANAMSAT-ATL - PanAmSat Corporation",
    "19200": "Universidade Federal do Rio Grande do Sul",
    "19201": "ETC - Eastex Telephone Cooperative, Inc.",
    "19202": "BB-DVI - Backbone Data Vault Inc",
    "19203": "IMPRI-1 - Imprivata Inc",
    "19204": "NO - Toktumi, Inc.",
    "19205": "PHIBRO-148111 - Phibro, LLC",
    "19206": "FCS-001 - First Class Solutions, Inc",
    "19207": "OPENMARKET-INC - OpenMarket",
    "19208": "LC-N - Liquid Compass LLC",
    "19209": "GMO-BOSTON - Grantham, Mayo, VanOtterloo & Co. LLC",
    "19210": "SYNCHRONOSS - SYNCHRONOSS TECHNOLOGIES",
    "19211": "ACROPOLIS-TECHNOLOGY-GROUP - Acropolis Technology Group",
    "19212": "PRTC-LAURENS - Piedmont Rural Telephone Cooperative, Incorporated",
    "19213": "SABRE-DFW - Sabre Inc.",
    "19214": "CENTAURI-COMMUNICATIONS-COM - Centauri Communications",
    "19215": "ENERGIZE - Pulaski Electric System",
    "19216": "REVLON- - Revlon Consumer Products Corp.",
    "19217": "IVYTECHSC - IVY Tech Community College of Indiana",
    "19218": "MTE-N - Midvale Telephone Exchange",
    "19219": "WPS-ETS-DATACENTER - Wisconsin Physcians Service Insurance Corp.",
    "19220": "CBE - Calgary Board of Education",
    "19221": "NORTHSTAR-TRAVEL-MEDIA - NORTHSTAR Travel Media, LLC.",
    "19222": "LIGHTCREST - Lightcrest LLC",
    "19223": "NTEGRATED-SOLUTIONS - Ntegrated Solutions",
    "19224": "SUNAMERICA - SunAmerica Financial",
    "19225": "IMVU- - IMVU, Inc",
    "19226": "AURA-SOUTH - A.U.R.A",
    "19227": "VALNET - Terra World, Inc.",
    "19228": "ENTEL CHILE S.A.",
    "19229": "IFOXNETODPD - INFOCROSSING, INC.",
    "19230": "NANOG - NANOG",
    "19231": "NBCUNI - NBC UNIVERSAL",
    "19232": "MONH-ZA",
    "19233": "DIALOGIX - Dialogix Telecom",
    "19234": "CANADAWEBHOSTING- - Canada Web Hosting",
    "19235": "HOSTING-COM - WCP/32POINTS INTERMEDIATE HOLDING COMPANY, INC.",
    "19236": "STEELCE- STEELCE SA",
    "19237": "OMNIS - Omnis Network, LLC",
    "19238": "ADOBE2-- - Adobe Systems Inc.",
    "19239": "ICOS-VISION ICOS VISION SYSTEMS NV",
    "19240": "CRIF-US - CRIF Lending solutions",
    "19241": "LOCAL-ISP-NJ-2000 - Local-ISP, Inc.",
    "19242": "STRATA8 - Strata8 Networks, Inc.",
    "19243": "ACMLLC - Atlantic Coast Mortgage LLC",
    "19244": "Telmex USA",
    "19245": "LEADING-EDGE-N - Leading Edge Communications, LLC",
    "19246": "ACT2000 - Antigua Computer Technology Co. Ltd.",
    "19247": "N1 - Central DuPage Health",
    "19248": "ACSC1000 - Automobile Club of Southern California",
    "19249": "COREEXPRESS-STLCORP - CoreExpress",
    "19250": "WILEYNET - John Wiley & Sons, Inc.",
    "19251": "ALICO - American Life Insurance Company",
    "19252": "MEADJ-N - Mead Johnson Nutrition",
    "19253": "SBAINC- - SBA, Inc",
    "19254": "KOCH-INDUSTRIES - Koch Industries, Inc.",
    "19255": "YOUR-ORG-INC-NA - YOUR.ORG, INC.",
    "19256": "COMMNET-WIRELESS-LLC - COMMNET WIRELESS LLC",
    "19257": "SUBRIGO - SUBRIGO CORPORATION",
    "19258": "DEVRY-DATACENTER-2 - Devry Inc",
    "19259": "Todito.com S.A. de C.V.",
    "19260": "GKTL-1-1 - Global Knowledge Training, LLC",
    "19261": "PSTATION - aspStation, Inc.",
    "19262": "VZGNI-TRANSIT - Verizon Online LLC",
    "19263": "CBAD-NET - Cincinnati Bell Any Distance, Inc.",
    "19265": "SUCCESS-WARE - Success Apparel, LLC",
    "19266": "TOTES-ISOTONER - Totes Isotoner Corporation",
    "19267": "FUSIONSTORM-COM - Fusion Storm",
    "19268": "PREFERRED-OFFICES - PBC-Greensboro, LLC",
    "19269": "ACCO-WEB- - ACCO Brands Inc.",
    "19270": "CHE-PAYMENTECH-SOLUTIONS-DALL-TX - Chase Paymentech Solutions, LLC",
    "19271": "PEAK10 - Peak 10",
    "19272": "CENTERBEAM - CenterBeam, Inc.",
    "19273": "LGEENERGY - Louisville Gas & Electric",
    "19274": "SYSTEM-66 - System Techniques",
    "19275": "INTERVAL - Interval International, Inc.",
    "19276": "BLG - Scott & Aylen",
    "19277": "CRAM-N - Claren Road Asset Management, LLC",
    "19278": "Resource Recovery",
    "19279": "VISTAAR - VISTAAR",
    "19280": "WYOMING-MEDICAL-CENTER - Wyoming Medical Center, Inc.",
    "19281": "DMCWL - DISTRIBUTION MANAGEMENT CONSOLIDATORS (WORLDWIDE), LLC",
    "19282": "SMFRA - South Metro Fire Rescue Authority",
    "19283": "CDGI-N - Cyber Development Group International, LLC",
    "19284": "AGSTAR- - AgStar Financial Services, FLCA",
    "19285": "WRH64 - WR Hambrecht + Co",
    "19286": "MORADNET - Morad Communications Ltd.",
    "19287": "INFLOW19287 - Inflow Inc.",
    "19288": "INFLOW19288 - Inflow Inc.",
    "19289": "INFLOW19289 - Inflow Inc.",
    "19290": "INFLOW19290 - Inflow Inc.",
    "19291": "INFLOW19291 - Inflow Inc.",
    "19292": "INFLOW19292 - Inflow Inc.",
    "19293": "INFLOW19293 - Inflow Inc.",
    "19294": "INFLOW19294 - Inflow Inc.",
    "19295": "INFLOW19295 - Inflow Inc.",
    "19296": "INFLOW19296 - Inflow Inc.",
    "19297": "WEATHERCITY - WeatherCity Services",
    "19298": "DEDICATED-LOGISTICS - Dedicated Logistics, Inc.",
    "19299": "SILENTCIRCLE - Silent Circle LLC",
    "19300": "KUBRA-USA - Kubra",
    "19301": "CERIDIAN-TAX - CERIDIAN TAX SERVICE, INC",
    "19302": "USCC-DC - US Chamber of Commerce",
    "19303": "PPOWER - Phone Power, LLC",
    "19304": "GEORGETOWN-COLLEGE - Georgetown College",
    "19305": "TNSI--19305 TNS  Mirror from ARIN",
    "19306": "CNI-HMB-001 - COTSIDE NET, INC",
    "19307": "MONTG-47- - Water Works & Sanitary Sewer Board of the City of Montgomery",
    "19310": "CAIR - CRYSTAL AUTOMATION SYSTEMS INC",
    "19311": "STEWART-1 - Stewart Title",
    "19312": "JOHN-MUIR-HEALTH - John Muir Health",
    "19313": "DATACOR - Datacor, Inc.",
    "19314": "THERAWLINGSCO-LAGRANGE-KY - The Rawlings Company, LLC",
    "19315": "Banelco S.A.",
    "19316": "BLUEMONTNETWORKS - Bluemont Networks, LLC",
    "19317": "MERIDIAN-ENVIRONMENTAL - Meridian Environmental Technology, Inc.",
    "19318": "NJIIX--1 - NEW JERSEY INTERNATIONAL INTERNET EXCHANGE LLC",
    "19319": "CCN-DMZ - Bonneville Power Administration",
    "19320": "PEAKPEAK - Peak to Peak Internet",
    "19321": "UMC-HEALTH-SYSTEM - University Medical Center",
    "19322": "THIRDROCKVENTURES - Third Rock Ventures LLC",
    "19323": "HGE-NET - Holyoke Gas & Electric Department",
    "19324": "DOSARREST - Dosarrest Internet Security LTD",
    "19325": "DVI-MISHAWAKA - Data-Vision, Inc.",
    "19326": "TELNET-DR- - Telnet Worldwide, Inc.",
    "19327": "WVFIBER-3 - WV FIBER",
    "19328": "SOFTREKWEB2 - Softrek Corporation",
    "19329": "MCNET - Martin County Board of County Commissioners",
    "19330": "JONES1-WEB - Jones & Associates, Inc.",
    "19331": "TWIN-LAKES - Twin Lakes Telephone Cooperative Corporation",
    "19332": "Marcatel Com, S.A. de C.V.",
    "19333": "ACML-2 - AllianceBernstein L.P.",
    "19334": "SPORTLINE-DBC - Sportsline.com",
    "19335": "APRIA-HEALTHCARE - Apria Healthcare Inc.",
    "19336": "BLAIN-SUPPLY-PRIMARY - BLAIN SUPPLY, INC",
    "19337": "NEGMABS-01 - Negma Internet",
    "19338": "Telmex Chile Internet S.A.",
    "19339": "DIDATA-NE - Dimension Data",
    "19340": "EPRIZE-PR-01 - ePrize",
    "19341": "CYENCE-02 - Cyence International",
    "19342": "TRINITY-UNIVERSITY - Trinity University",
    "19343": "WNYCS - Synergy Global Solutions, Inc.",
    "19344": "VCT-11 - Virtual Connect Technologies, Inc",
    "19345": "SIMONS-ROCK-EDU-N01 - Bard College at Simon's Rock",
    "19346": "I3-DENVER - I-CUBED",
    "19347": "INDYMACBANK - Onewest Bank FSB",
    "19348": "CITY-OF-BRENTWOOD---TENNESSEE - City of Brentwood",
    "19349": "KCL-N - Katz Capital, LLC",
    "19350": "CENTENNIALCOLLEGE - CENTENNIAL COLLEGE OF APPLIED ARTS AND TECHNOLOGY",
    "19351": "MODELN - MODEL N, INC.",
    "19352": "CALLFINITY - Callfinity, Inc.",
    "19353": "TUN7 - Trans Union, LLC",
    "19354": "WJCC-PUBLIC-SCHOOLS - Williamsburg James City County Public Schools",
    "19355": "SMRN-NET - San Mateo Regional Network, Inc.",
    "19356": "TOUA-NOC - Tohono O'Odham Utility Authority",
    "19357": "NESL - New Enterprise Stone & Lime Company",
    "19358": "NVT - NetVision Technologies, Inc.",
    "19359": "GENERAL-INVESTMENT-ADVISERS-LLC - GID Investment Advisers LLC",
    "19360": "SIRIUS-COMPUTER-SOLUTIONS- - Sirius Computer Solutions, Inc.",
    "19361": "A.Telecom S.A.",
    "19362": "VALUEACT-CAPITAL-MANAGEMENT-LP-N - ValueAct Capital Management, L.P.",
    "19363": "IMOV - Patrick Michael Kane",
    "19364": "ECHOPS-UT1 - ECHOPS",
    "19365": "NETWURX-01 - Netwurx LLC",
    "19366": "MNS - Managed Network Solutions, Inc.",
    "19367": "CAROUSEL-INDUSTRIES - Carousel Industries of North America Inc",
    "19368": "SNS-COLO - Secured Network Services, Inc.",
    "19369": "BESTHF - Best Chairs Inc.",
    "19370": "LAGNIAPPE- - Lagniappe Health Acquisition Company, Inc.",
    "19371": "ENOVATEL-1 - ENOVATEL LLC",
    "19372": "NCOGROUP-FTW - NCO Group, Inc.",
    "19373": "Triara.com, S.A. de C.V.",
    "19374": "CMRL-NCT - Access Northeast Inc.",
    "19375": "NUMERICINVESTORS - Numeric Investor's L.P.",
    "19376": "JUSTNET Ministerie van Justitie",
    "19377": "GSDM - GSDM",
    "19378": "ADEA- - AMERICAN DENTAL EDUCATION SOCIATION",
    "19379": "IFOXNETND - INFOCROSSING, INC.",
    "19380": "CHROBINSON - C. H. Robinson Company",
    "19381": "SIMPLY-BITS-LLC - Simply Bits, LLC",
    "19382": "USCRIDC - U.S. COMMITTEE FOR REFUGEES AND IMMIGRANTS",
    "19383": "WEBEL-1 - Web Elite LLC",
    "19384": "GRAMTEL001 - CyrusOne LLC",
    "19385": "CBP - CONTINENTAL BROADBAND PENNSYLVANIA, INC.",
    "19386": "ALLECH-GDC - Alltech, Inc.",
    "19387": "NAME-HANYS - Healthcare Association of New York State, Inc.",
    "19388": "IPS-COMM - iPass Incorporated",
    "19389": "GOLUB - GOLUB CORPORATION",
    "19390": "COMPUNET-JACKSON - Compunet",
    "19391": "BAJAU-CO-NM-TX - Baja Broadband",
    "19392": "JCOM - J2 Global Inc.",
    "19393": "ONECOM-REON - One Communications Corporation",
    "19394": "FORZANIGROUPLIMITED - Forzani Group Limited",
    "19395": "BCCC-COLLEGE-I2 - Bucks County Community College",
    "19396": "HFI - Haynes Furniture Company Inc.",
    "19397": "ACN-DIGITAL-PHONE - ACN",
    "19398": "INDENET - Concord Technology Services, LLC",
    "19399": "SLLNET Stockholms Lans Landsting",
    "19400": "SPX-CORP- - SPX Corporation",
    "19401": "NLR - National LambdaRail",
    "19402": "CACTUS - Cactus Commerce Inc.",
    "19403": "SPIRIT-AEROSYSTEMS - Spirit AeroSystems, Inc",
    "19404": "QUEST - Quest",
    "19405": "HRSD-INTERNET-IP-BLOCK - Hampton Roads Sanitation District",
    "19406": "TWRS-MA - Towerstream I, Inc.",
    "19407": "THE-REVERE-GROUP - The Revere Group",
    "19408": "WDS-DENTAL - Western Dental",
    "19409": "VWCREDIT-COM - VW CREDIT, INC",
    "19410": "BENTONREA2 - BENTON REA POWERNET",
    "19411": "Nap Chile",
    "19412": "MARBLEGATE - Marblegate Asset Management , LLC",
    "19413": "TRUCKERSB2B - TruckersB2B LLC",
    "19414": "MMCWEB - Modern Marketing Concepts",
    "19415": "VALLEYCARE-LIVERMORE-DC-1 - ValleyCare Health System",
    "19416": "RBC-NY - RBC CAPITAL MARKETS CORPORATION",
    "19417": "CENTR-65-N - Centra-Larm Monitoring, Inc.",
    "19418": "WPPUSA - WPP Group USA, Inc.",
    "19419": "SONY-PICTURES-ENTERTAINMENT - Sony Pictures Entertainment Inc",
    "19420": "CSVI - Clinica Sierra Vista",
    "19421": "LANDSEND - Lands' End, Inc.",
    "19422": "Telefonica Moviles del Uruguay SA",
    "19423": "LCC-AB-CA - Lethbridge Community College",
    "19424": "CV-NET-1 - Classified Ventures",
    "19425": "ITA-SOFTWARE - ITA Software LLC",
    "19426": "NRT-NEW-YORK---CORCORAN - NRT NEW YORK, INC.",
    "19427": "JBFCS - JBFCS",
    "19428": "CONOCOPHILLIPS FTIP003256947",
    "19429": "ETB - Colombia",
    "19430": "ACXIOM-CORP - Acxiom Corporation",
    "19431": "INTELLICLAIM - IntelliClaim, LLC",
    "19432": "SWI - Sierra Wireless, Inc.",
    "19433": "MISO- - Midwest Independent Transmission Systems Operator, Inc.",
    "19434": "SPRICHARDS - S. P. RICHARDS COMPANY",
    "19435": "DNET-ISP - Dnet Internet Services",
    "19436": "ZOYTO-INTERNET - Zoyto Inc.",
    "19437": "SS-H - SECURED SERVERS LLC",
    "19438": "PRIME-BROKERAGE - Bank of America",
    "19439": "NEBOSBOY - AES CORP",
    "19440": "AICENT - Aicent Inc.",
    "19441": "ARRIS2 - Arris Group, Inc",
    "19442": "NELSONJOBS - Gary D Nelson Associates Inc.",
    "19443": "STAPLES - Staples, Inc",
    "19444": "CHARTER-STL - Charter Communications",
    "19445": "HELLER- HELLER EHRMAN",
    "19446": "E3C-INTERBUILD - Interbuild Networks",
    "19447": "ALFANUMERIC",
    "19448": "GOOGLE-FIBER - Google Fiber Inc.",
    "19449": "CONCURRENT - Concurrent Technologies Corp.",
    "19450": "SMARTBOX - Smartbox Equipment Inc",
    "19451": "JMM-N - Joyce Meyer Ministries",
    "19452": "OAKTREECAP-COM - Oaktree Capital Management, LLC",
    "19453": "TWRS-RI - Towerstream I, Inc.",
    "19454": "OET--01 - Outer Edge Technology, LLC",
    "19455": "SYNERTECH-SYSTEMS - Synertech Systems",
    "19456": "WATERS-CORPORATION - Waters Corporation",
    "19457": "RUDIN - Rudin Management Company, Inc.",
    "19458": "GLOBALSTAR-1 - Globalstar, Inc.",
    "19459": "DADE-BEHRING-01 - Dade Behring",
    "19460": "SUTHERLAND Sutherland Global Services, Inc. Autonomous system Number",
    "19461": "OPSOURCE-INC-2 - Dimension Data Cloud Solutions, Inc.",
    "19462": "USSCO-19462 - United Stationers Supply Co.",
    "19463": "SOPS-JABWI - JAB Wireless, INC.",
    "19464": "WHINGTON-AND-LEE - Washington & Lee University",
    "19465": "-GOSFIELD - Gosfield North Communications Co-operative Limited",
    "19466": "T-LINK-BROADBAND-SERVICES - T LINK BROADBAND SERVICES, LLC",
    "19467": "TWGINC - THE WORKING GROUP INC.",
    "19468": "YIELDBUILD- - YieldBuild Inc",
    "19469": "-SMSAC - SMS.ac, Inc.",
    "19470": "LCPS - L CRUCES PUBLIC SCHOOLS",
    "19471": "CENARKTEL - Central Arkansas Telephone Cooperative, Inc.",
    "19472": "CAROLLO-ENGINEERS - Carollo Engineers",
    "19473": "PATCOMM - Patrick Communications LLC",
    "19474": "MFTI - MFT International",
    "19475": "VIGILANT-FUTURES - Vigilant Futures",
    "19476": "ITOL - Infinity Technology, Inc.",
    "19477": "FLYINGJ - F J Management Inc.",
    "19478": "ICMARC - ICMA RETIREMENT CORP",
    "19479": "CERVALIS - CERVALIS LLC",
    "19480": "CPL - CHICAGO PUBLIC LIBRARY",
    "19481": "CRUMP--19481 - Crump Life Insurance Services, Inc",
    "19482": "GTLLP - Greenberg Traurig P.A",
    "19483": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19484": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19485": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19486": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19487": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19488": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19489": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19490": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19491": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19492": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19493": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19494": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19495": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19496": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19497": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19498": "SBCI-AKRON-OH-COVLIL - AT&T Internet Services",
    "19499": "ESRTA-1 - Eastern Slope Rural Telephone Association",
    "19501": "TTURWN - Texas Tech University",
    "19502": "CRANEWAREINSIGHT- - Craneware Insight, Inc.",
    "19503": "NYMAGDIA-SPR-YIP - Magnetar Capital LLC",
    "19504": "WTCC - WTC Communications, Inc.",
    "19506": "CLOUDMARK-PRD - Cloudmark, Inc.",
    "19507": "NYC-TRANSIT - New York City Transit Authority",
    "19508": "DEL-VAL-FINANCIAL-SRV - Delaware Valley Financial Services",
    "19509": "OLLUSA - Our Lady of the Lake University",
    "19511": "ELECTROLUX-NA - Electrolux Home Products, Inc.",
    "19512": "LYONDELL - Lyondell Chemical Company",
    "19513": "IBTCO - Investors Bank & Trust Company",
    "19515": "ORICOM-QUEBEC1 - Oricom Internet",
    "19516": "SMITH - Smith International, Inc.",
    "19517": "VISUAL-LINK-INOC - VISUAL LINK",
    "19518": "ROCKISLAND - Rock Island Technology Solutions, Inc.",
    "19519": "ACRON S.A.",
    "19520": "WISHVPS - wishVPS Inc.",
    "19521": "AKIBIA - Akibia, Inc.",
    "19522": "ADVANCED-ONLINE - Advanced Graphic Products Inc.",
    "19523": "AZTECSYSTEMS - Aztec Systems, Inc.",
    "19524": "COMERICA-INC - Comerica Incorporated",
    "19525": "3E-COMPANY - 3E Company",
    "19526": "SUMNER - Sumner Communications",
    "19527": "MEEBO1 - Meebo, Inc.",
    "19528": "NRIV - NetRiver INT LLC",
    "19529": "RAZOR-PHL - Razor Inc.",
    "19530": "NDIN-STATE - State of North Dakota, ITD",
    "19531": "NODESDIRECT - Nodes Direct",
    "19532": "BTMG - BROWN TOLAND MEDICAL GROUP",
    "19534": "LCTC-1 - Lee County Tax Collector",
    "19536": "DIRECTV-DENVER - DirecTV",
    "19537": "TRITONN - TRITON COMMUNICATIONS",
    "19538": "ADVANTAGECOM - Advantagecom Networks, Inc.",
    "19539": "IPONLY-US- - IP-Only Inc",
    "19540": "ATT-MOBILITY-LLC-19540 - AT&T Mobility LLC",
    "19541": "BIOWAREONLINEVA1 - BioWare Austin, LLC",
    "19542": "PLICO - Protective Life Corporation",
    "19543": "MINTZ-BOS - Mintz, Levin, Cohn, Ferris, Glovsky and Popeo, P.C.",
    "19544": "WINTERSBROADBAND - Winters Broadband LLC",
    "19545": "SITA-NGDC-ATL - SITA Information Networking Computing USA, Inc.",
    "19546": "RCWILLEY - R.C. WILLEY HOME FURNISHINGS",
    "19547": "ICOMMERCE - iCommerce, Inc.",
    "19548": "ADELPHIA-2 - Time Warner Cable Internet LLC",
    "19549": "SERVERSILO - ServerSilo",
    "19550": "SIHOPE- - Sihope Communications",
    "19551": "INCAPSULA Incapsula.com",
    "19552": "CHRISBANKS - Christopher & Banks",
    "19553": "PSINET-AR (PSINet Argentina)",
    "19554": "ANX-INTERNET - ANXeBusiness Corp.",
    "19555": "KMI-NETWORK - Knight, Inc.",
    "19556": "ISOTECH-INC - Isotech, Inc",
    "19557": "CHANGEIP-01 - CHANGEIP COM",
    "19558": "KMCN-N - Kettering Medical Center",
    "19559": "VANGENT-INC - Vangent Inc.",
    "19560": "GWHA - GW Hannaway & Associates",
    "19561": "BIGPIPE - Shaw Telecom G.P.",
    "19562": "USA--EXPEREOINTERNATIONAL - EXPEREO USA, INC.",
    "19563": "IDX-SYSTEMS-CORP - IDX Systems Corporation",
    "19564": "LATECH - Lousiana Tech University",
    "19565": "WATKINSIT - Intelice Solutions, L.L.C.",
    "19566": "PON-SYSTEMS - Pason Systems Corp",
    "19568": "GSC-PORTHURON - Gannett Supply Corp. - Port Huron, MI",
    "19569": "UBAVTS - Upper Bucks County AVTS",
    "19570": "MAPLETRONICSCOMP - Maple Tronics Computers, Inc.",
    "19571": "WTD - World Tech Design, LLC",
    "19572": "OMEGYS-HQ - Omega Systems Consultants Inc",
    "19573": "PACIFIC-NATIONAL - PACIFIC NATIONAL BANK",
    "19574": "CSC - Corporation Service Company",
    "19575": "REPEC - REPE Capital Partners (USA) LLC",
    "19576": "VLINGO - Vlingo Corporation",
    "19578": "TRUENET-INC - Truenet, Inc.",
    "19579": "MANAGEDSTORAGE - Presilient, LLC",
    "19580": "ZONETEL - ZONE TELECOM, INC.",
    "19581": "DALL-COUNTY - DALL COUNTY SCHOOLS",
    "19582": "GRUPO BRAVCO",
    "19583": "IMPSAT FIBER NETWORKS INC",
    "19584": "ADVANCED-NET - Advanced Computers, LLC",
    "19585": "ICONG-3 - iCongo, Inc.",
    "19586": "CREATIVE-DATA-PNS - Creative Data Concepts Limited, Inc.",
    "19587": "H2-CREDIT-MANAGEMENT - H/2 Credit Manager GP LLC",
    "19588": "GC-1 - GOR CORPORATION",
    "19589": "COL - City Of Leesburg",
    "19590": "PI-CHATSWORTH - Property Insight, LLC.",
    "19591": "LVLT-19591 - Level 3 Communications, Inc.",
    "19592": "3CI-BOS - 3Cinteractive",
    "19593": "DIVOX-INTERNATIONAL-INC - Divox International Inc.",
    "19594": "SALEMHOSPITALN - Salem Hospital",
    "19595": "SDHU - Sudbury & District Health Unit",
    "19596": "Clifford Chance",
    "19597": "DAILY-MANAGEMENT - Daily Management, Inc.",
    "19599": "COPYRIGHT - COPYRIGHT CLEARANCE CENTER",
    "19600": "NCH- - Nationwide Children's Hospital",
    "19601": "CADIA - Cadian Capital Management, LLC",
    "19602": "19602 - Cantor Fitzgerald & Co.",
    "19603": "IBMCCH-STV - IBM",
    "19604": "IBMCCH-ATL-BS - IBM",
    "19605": "3RC - 3 Rivers Telephone Cooperative, Inc.",
    "19606": "NIELSEN-MEDIA-RESEARCH - Nielsen Media Research Inc.",
    "19607": "SB-US Sharedband London Network",
    "19608": "CANADIAN-BLOOD-SERVICES - Canadian Blood Services",
    "19609": "MANDA-VEEDIX-NET - M&A Technology, Inc",
    "19611": "Associa\u00e7\u00e3o Ant\u00f4nio Vieira - Unisinos",
    "19612": "JPMC-VTERA - JPMorgan Chase & Co.",
    "19613": "MICRO-GENERAL - Fidelity National Financial Inc.",
    "19615": "REDBELLRE - 406 Partners",
    "19616": "ACCESS-OHIO - ACCESS",
    "19617": "SAA - SOUTHERN AUTO AUCTION",
    "19618": "GLOBEOP-2000 - GlobeOp Financial Services",
    "19619": "8498500 - Graham Packaging Company",
    "19620": "STATCAN - Statistics Canada",
    "19621": "MID-NO - MODESTO IRRIGATION DISTRICT",
    "19622": "GHI301PENOBSCOT - Genomic Health, Inc.",
    "19623": "PRICEWATERHOUSECOOPERS-MSO - PriceWaterhouseCoopers, LLP",
    "19624": "SERVERROOM - Data Room, Inc",
    "19625": "CONXXUS - Conxxus, LLC",
    "19626": "EVC- - QuoVadis Services Limited",
    "19627": "SOCANTEL-001 - South Canaan Telephone Company of PA",
    "19628": "WOODARDCURRAN - Woodard & Curran Inc.",
    "19629": "CONSULT-RAD--QWEST - CONSULTING RADIOLOGIST, LTD",
    "19630": "WANLINK-DARIEN - Guggenheim Services LLC",
    "19631": "TRAVELPORT - Travelport Operations, Inc.",
    "19632": "VTR BANDA ANCHA S.A.",
    "19633": "CSI-3634 - The Cableshoppe Inc",
    "19634": "AVITUSGROUP - AVITUS GROUP",
    "19635": "MARK-SET - Mark Asset Management",
    "19636": "FORMFACTOR - FORMFACTOR, INC",
    "19637": "LSI-CORP-19637 - LSI Corporation",
    "19638": "CARRINGTON-CAPITAL - Carrington Capital Management, LLC",
    "19639": "LOGICAL2 - Logical Net Corporation",
    "19640": "OUT-TI - Outsource Technologies, Inc.",
    "19641": "BED-BATH-AND-BEYOND - Bed Bath and Beyond",
    "19642": "CONNEL-FOLEY - Connell Foley LLP",
    "19643": "NETSYN - Network Synergy Corporation",
    "19644": "WANLINK-PHILADELPHIA - Liberty Hampshire Corporation",
    "19645": "HERMES-US-1 MNT-HPL-40 Hermes Phone, LLC The own  number 19645 of 195.137.252.0/24. Date 20070829",
    "19647": "HPOD20001 - Hewlett-Packard Operation Division",
    "19648": "LDSCHURCH1 - THE CHURCH OF JESUS CHRIST OF LATTER DAY SAINTS",
    "19649": "NEW-WORLD-APPS - New World Apps, Inc.",
    "19650": "BUNZLUSA - Bunzl Distribution, Inc.",
    "19651": "WEBTRENDS-INC-SANBRUNO - WebTrends Incorporated",
    "19652": "VACATION-EXPRESS - VACATION EXPRESS",
    "19653": "CTSTELECOM - CTS Communications Corp",
    "19654": "WVFIBER-1 - WV FIBER",
    "19656": "PROCURIAN - ICG Commerce",
    "19659": "TCRL-1 - Trinity Capital Research LLC",
    "19660": "NSAU-LIB - Nassau Library System",
    "19661": "SUSQ-BALA - Susquehanna Partners",
    "19662": "UNISERVE-ONLINE - Uniserve On Line",
    "19663": "CS-STL - CS INFORMATION SYSTEMS",
    "19664": "VITALCHEK - Vitalchek Network, Inc.",
    "19665": "RAMPANT - Rampant Inc!",
    "19666": "HENDERSONBROTHERS-MAIN - Henderson Brothers, Inc.",
    "19667": "LEETECH-ATLANTA - Lee Technologies Group",
    "19668": "PRICEWATERHOUSECOOPERS-MSO - PriceWaterhouseCoopers, LLP",
    "19669": "SEEGRID-N01 - Seegrid Corporation",
    "19670": "CUSTOMCOMPUTERSPECIALISTS - Custom Computer Specialists, Inc.",
    "19671": "EVERESTBROADBAND1 - EVEREST BROADBAND NETWORKS",
    "19672": "EVERESTBROADBAND1 - EVEREST BROADBAND NETWORKS",
    "19673": "LIT - LAKE FOREST COLLEGE",
    "19674": "NAVPOINT - Navpoint Internet",
    "19675": "VCS- - Virtacore Systems Inc",
    "19676": "SWIFT-GLOBAL",
    "19677": "NJTRANSIT - NJTRANSIT",
    "19678": "UOP - UOP LLC",
    "19679": "DROPBOX - Dropbox, Inc.",
    "19680": "PORTLAND-CEMENT-SOCIATION - Portland Cement Association",
    "19682": "TORC-FINANCIAL-LLC - TORC Financial LLC",
    "19685": "HCIS-1 - CSI Telecom Group, Inc",
    "19686": "ITST- - Intelsat GlobalConnex Solutions (GXS)",
    "19687": "PPPS-ILG - Planet Payment Processing Services",
    "19688": "Banco Santander (Mexico) S.A., Institucion de Banca Multiple, Grupo Financiero Santander",
    "19689": "MST- - MST Acquisition Group, LLC.",
    "19690": "HYATT-INTERNET1 - Hyatt Technical Center",
    "19691": "888-US - 888 US Inc.",
    "19692": "-PICIS-1-WFD - PICIS, INC.",
    "19693": "CENTRILOGIC-N Centrilogic UK",
    "19695": "BEAVER-VISITEC-INTERNATIONAL-WALTHAM - Beaver Visitec International Inc",
    "19696": "VODALINK - Vodalink Telecom Inc.",
    "19698": "XO-19698-19699 - XO Communications",
    "19699": "XO-19698-19699 - XO Communications",
    "19700": "IAVM-1 - Industrielle Alliance Valeurs Mobilieres inc.",
    "19701": "YODLEE - Yodlee Inc.",
    "19702": "FITCH-COLO--01 - FITCH INC.",
    "19703": "VALUELINE - Value Line Publishing Inc.",
    "19704": "CURRENT-COMMUNICATIONS-SERVICES-LLC-NET2 - Current Communications Services LLC",
    "19705": "ERX-NEXTED-USA NextEd Limited",
    "19706": "SOS116W23 - Select Office Suites",
    "19707": "SETL-1--00 - Summit Energy Tech LLC",
    "19708": "SLEHS - St. Luke's Episcopal Hospital",
    "19709": "HX-ISP-CHO - Helix Computer Systems, Inc.",
    "19710": "DINO-SOL - Dino Solutions, Inc.",
    "19711": "SWAZINET",
    "19712": "365MAIN-SANFRANCISCO - Granicus Inc.",
    "19713": "STATE-OF-NH-USA - State of New Hampshire",
    "19715": "YOUBET - YOUBET.COM, Inc.",
    "19716": "JACOE- - Jaco Electronics, Inc.",
    "19717": "MAINSTREAMDATA-375 - Mainstream Data, Inc.",
    "19718": "NCNI - MCNC",
    "19719": "STI - Southland Technology, Inc.",
    "19720": "CABLEVISION-CORP - Cablevision Systems Corp.",
    "19721": "MHN - Magellan Health Services",
    "19722": "MSR-ECUSTOMS - MSR CUSTOMS CORPORATION",
    "19723": "CIA. DE TECNOL. DA INFOR. E COMUNICA\u00c7\u00c3O DO PARAN\u00c1",
    "19724": "CAPITOL1-AUTO-FINANCE - Capitol One Auto Finance Inc.",
    "19725": "COHPWE - City Of Houston - Public Works",
    "19726": "MSIVE-IO - MSIVE.IO, LLC.",
    "19727": "CARNIVAL-CRUISE-LINES-DISTER-RECOVERY-SITE - CARNIVAL CRUISE LINES",
    "19728": "CORADIANT - Coradiant Inc",
    "19729": "VCOMSERVICES- - Virtual Communication Services Inc.",
    "19730": "BME-A00001 - BENCHMARK INTERNET GROUP",
    "19731": "Codensa S.A. ESP",
    "19732": "WTSP-TV - WTSP-TV",
    "19733": "SEVEN - Seven Networks, Inc.",
    "19734": "HALO - HALO Branded Solutions",
    "19735": "BADGERLANDFINANCIAL-ACA - Badgerland Financial, ACA",
    "19736": "HARDCTLE-EXT - Hardcastle Trading USA, LLC",
    "19737": "RMC - Royal Military College of Canada",
    "19738": "SURANT-ATL01INET - Assurant, Inc.",
    "19739": "COUNTY-SANBERNARDINO - County of San Bernardino",
    "19740": "SUDJAM - Sudjam, LLC",
    "19741": "NII - NII Holdings, Inc.",
    "19742": "ALTERCAPE - Alterascape, LLC",
    "19743": "WAJAM - Wajam",
    "19744": "EDUCATION-DEVELOPMENT-CENTER - Education Development Center",
    "19745": "RUWEB-USA - RuWeb Corp.",
    "19747": "DATAVAIL-N - Datavail",
    "19748": "SECTORLINK - Sector Link LLC.",
    "19749": "GNC-LIVE-WELL - GNC",
    "19750": "-CRITEO - Criteo Corp.",
    "19751": "CCRTC - Endeavor Communications",
    "19752": "HYDROONETELECOM - Hydro One Telecom Inc.",
    "19753": "IWN - InnerWorkings, Inc.",
    "19754": "LIVEAIR1 - LiveAir Networks",
    "19755": "KIMBANET - KIMBANET",
    "19756": "ACCS-AB - Alberta Communication Cable Services Inc",
    "19758": "STERLINGFINANCIALNET - STERLING NATIONAL BANK",
    "19759": "REALD-ARIN-N - Real D",
    "19760": "CALPINECORP-1 - CALPINE CORP",
    "19761": "SLEDGE - Sledge Telephone Company, Inc.",
    "19762": "BBDODETROIT - BBDO Detroit",
    "19763": "Fundacao Universidade do Vale do Itajai",
    "19764": "GEORGIAN-COLLEGE-N - Georgian College of Applied Arts & Technology",
    "19766": "QUIK-HOUSTON - Quik Internet of Houston",
    "19767": "Global One Guatemala",
    "19768": "SCAN - SCAN Health Plan",
    "19769": "CAPITALONE-KDC - Capital One Financial Corporation",
    "19770": "KS-MSO - KS-MSO, Inc.",
    "19772": "CORPORATE-WEB - Corporate Web Services, Inc.",
    "19773": "MOTOROLA - Motorola, Inc.",
    "19774": "AVA1 - Avista Corporation",
    "19775": "INTRYSTEMS - Intrasystems Inc",
    "19776": "MIDPAC-N - Mid-Pacific Institute",
    "19777": "TAMARAC-SEATTLE - Envestnet Asset Management, Inc.",
    "19778": "CTSBGP - Custom Technology Solutions, LLC",
    "19780": "-INTERMEDIA2 - Intermedia.net, Inc.",
    "19781": "AAA-ALLIED-GROUP - AAA Allied Group, Inc.",
    "19782": "INDIANAGIGAPOP - Indiana University",
    "19783": "APPRISS - APPRISS INC",
    "19784": "TBA - FIRSTLIGHT FEDERAL CREDIT UNION",
    "19785": "SOLUTIONPRO-NET - SOLUTION PRO",
    "19786": "FTI-FGN-A001 - Fusion Telecommunications International (FTI), Inc.",
    "19787": "BLEICHROEDER1 - First Eagle Investment Management LLC",
    "19788": "ADGMN-1 - Airadigm Communications, INC.",
    "19789": "HAZELTONHOTEL - Hazelton Hotels International Inc",
    "19790": "BANGWEBWORKS - Bang Web Works, Inc.",
    "19791": "CLOUGH-CAPITAL---N - Clough Capital Partners",
    "19792": "YOURL- - Yourlink Inc.",
    "19793": "R-HPC - R Systems",
    "19794": "HARRIET - The Cementworks LLC",
    "19795": "SILVERPOP-ATL - Silverpop Systems Inc.",
    "19796": "SHUBERT - Shubert Organization, Inc.",
    "19797": "DEXAGON-NET - DEXAGON Inc.",
    "19798": "TBOL - TrustBenefits Online",
    "19799": "HCS - Highland Communication Services",
    "19800": "GCPUD-ORG - Grant County Public Utility District",
    "19802": "LANEPRESS - The Lane Press, Inc.",
    "19803": "VIRTELA-NET-VNYNYC1 Virtela Communications",
    "19804": "VIRTELA-NET-VVAVIE1 Virtela Communications",
    "19805": "VIRTELA-NET-19805 Virtela Communications",
    "19806": "VIRTELA-NET-VGBLON2 Virtela Communications",
    "19807": "VIRTELA-NET-VSGSNG1 Virtela Communications",
    "19808": "VIRTELA-NET-VFLMIA1 Virtela Communications",
    "19809": "VIRTELA-NET-VCNHON2 Virtela Communications",
    "19810": "VIRTELA-NET-VCPTOR1 Virtela Communications",
    "19812": "BT-RADIANZ- BT Radianz",
    "19813": "EXCALIBUR - Excalibur Entertainment Inc.",
    "19814": "FQLP-SAVOC2 - First Quadrant L.P.",
    "19815": "DIGITECH-N1 - Digitech Systems, Inc.",
    "19816": "NCSDATACOM - NCS DataCom, Inc.",
    "19817": "DSLEXTREME - DSL Extreme",
    "19818": "IVERIFY5320 - iVerify.US, INC",
    "19820": "REXAM-N01 - Rexam Inc.",
    "19821": "ACS-CORP - ALCOHOL COUNTERMEURE SYSTEMS CORP",
    "19822": "TPAC-SD-01 - TelePacific Communications",
    "19823": "TPAC-SJ-01 - TelePacific Communications",
    "19824": "TPAC-LV-01 - TelePacific Communications",
    "19825": "LABONE - LabOne, Inc.",
    "19826": "WDMP- - WD Web Company",
    "19827": "GOLFSMITH - Golfsmith International, Inc.",
    "19828": "MARICOPA - Orbitel Communications, LLC",
    "19829": "VISIUM950 - Visium Asset Management",
    "19830": "RTC-RINGGOLD-GA - RTC Internet",
    "19831": "STAMPIN - StampinUp",
    "19833": "ABAATLN1 - Abacus Solutions, LLC",
    "19834": "FYI-NETWORKS - NetForce, Inc.",
    "19835": "FUTWAY - Futureway Communications Inc.",
    "19836": "VERISIGNGRS - VeriSign Infrastructure & Operations",
    "19837": "STOCK-BUILDING-SUPPLY - Stock Building Supply",
    "19838": "PARCOM - Parcom",
    "19839": "SANDSBETHLEHEM - Sands Casino Resort Bethlehem",
    "19840": "OAKTREECAP - Oaktree Capital Management, LLC",
    "19841": "THESEAM-COM - The Seam, L.L.C.",
    "19842": "COLOSSEUM-ONL - Colosseum Online, Inc.",
    "19843": "PROMOTIONS-COM - Corsis Technology Group II, LLC",
    "19844": "GORACK - GoRack LLC",
    "19845": "PEABODY-COAL-N - PEABODY INVESTMENTS CORP",
    "19846": "CTC-WIRELESS - Computers & Tele-Comm, Inc.",
    "19847": "NHA",
    "19848": "EMERGIS--2 - Emergis Inc.",
    "19849": "ARBITRON - Arbitron Inc.",
    "19850": "RYLAND-GROUP - THE RYLAND GROUP",
    "19851": "BRE-PROPERTIES - BRE Properties, Inc.",
    "19852": "INTERTEL-INC-N - Intertel, Inc.",
    "19853": "USONL-2 - US Online Sales, Inc.",
    "19854": "LOS-ANGELES-NETWORK - CAAL Enterprise",
    "19855": "N-MERGY-US Masergy US Autonomous System",
    "19856": "BRAZOSPORT-COLLEGE - Brazosport College",
    "19857": "BEFCORP - Bob Evans Farms, Inc.",
    "19858": "GENSLER - Gensler and Associates Architects",
    "19859": "FLAIR-DATA-SYSTEMS - Flair Data Systems",
    "19860": "OPTIV-US-1 - OPTIVER US LLC",
    "19861": "WCBE - Washington County Board of Education",
    "19862": "BNB-22- - Bridgehampton National Bank",
    "19863": "Guyana Telephone & Telegraph Co.",
    "19864": "O1COMM - O1.com",
    "19865": "ICARZ - Icarz, Inc",
    "19866": "DECARTA - deCarta, Inc.",
    "19867": "VOODOO1 - Voodoo.com, Inc",
    "19868": "-UL-LV - UnitedLayer, LLC",
    "19869": "AECNET - EnCana Corporation",
    "19870": "CCSD - Cherry Creek School District #5",
    "19871": "NETWORK-SOLUTIONS-HOSTING - Network Solutions, LLC",
    "19872": "CUSTOM-76 - CUSTOM SOFTWARE INC",
    "19873": "INFOLINK TELEINFORMATICA LTDA",
    "19874": "CDI-01 - CUSTOM DIRECT",
    "19875": "IPWORLDNET - IPWorld Networks",
    "19876": "HYPERSURF - HyperSurf Internet Services, Inc.",
    "19877": "LORE-NET - Lore Systems, Inc.",
    "19878": "MEDIMPACT - MedImpact Healthcare Systems, Inc.",
    "19879": "PCT-HOME - Pacific Crest Technology, Inc.",
    "19880": "REALCOMPII - REALCOMP II LTD.",
    "19881": "VTCNET - Valley Telecom Internet",
    "19882": "-LL - Acuity Brands, Inc.",
    "19883": "BUEHNER-FRY - Navis",
    "19884": "DENIR-1-N - DENIRO MARKETING, LLC.",
    "19885": "ISOCENTRIC - Isocentric Networks, Incorporated",
    "19886": "BOFABROKERDEALERSVCS - Bank of America",
    "19887": "KIN - KI",
    "19888": "ISTA-US01 - ISTA Pharmaceuticals, Inc.",
    "19889": "Cooperativa Telefonica Del Viso",
    "19893": "RWT - RagingWire Telecommunications",
    "19894": "NOVEL-YYZ-N - Novel, Inc",
    "19895": "WVFIBER-4 - WV FIBER",
    "19896": "CS-NJ-N-01 - Cole, Schotz, Meisel, Forman & Leonard, P.A.",
    "19897": "BROADVOX - BroadVox LTD",
    "19898": "FIBERLINK - Fiberlink Communications Corporation",
    "19899": "MDC-EDU - Miami Dade College",
    "19900": "JD-BARNES - J.D. Barnes Limited",
    "19901": "BBS - Brookfield Asset Management",
    "19902": "NET-STATE-OHIO - Department of Administrative Services",
    "19904": "COL - City of Longview",
    "19905": "NEUSTAR-6 - NeuStar, Inc.",
    "19906": "CHARLES-RIVER - Charles River Associates Inc.",
    "19907": "NEUSTAR-6 - NeuStar, Inc.",
    "19908": "RAINTEL - Rainforest Telecom, Inc.",
    "19909": "DAYLIGHT - Daylight Transport, LLC",
    "19910": "NEUSTAR-6 - NeuStar, Inc.",
    "19911": "NEUSTAR-6 - NeuStar, Inc.",
    "19912": "ESP-GROUP - The ESP Group LLC",
    "19913": "19913 - Cynergy Data, LLC",
    "19914": "AEG-SPRINTCTR - AEG Kansas City Arena, LLC",
    "19915": "END-TO-END-NETWORKS - End to End Networks",
    "19916": "TRUM-0001 - OLM, LLC",
    "19917": "MOHEGANSUN - Mohegan Sun",
    "19918": "LUCFILM - Lucasfilm Ltd.",
    "19919": "VSW - VA SkyWire, LLC",
    "19920": "AKINBGP - Akin, Gump, Strauss, Hauer, & Feld",
    "19921": "ACCESSPENNSYLVANIA - Health Sciences Libraries Consortium",
    "19922": "ARDSLEY-PARTNERS - Ardsley Partners",
    "19923": "SHENANDOAH-UNIV - Shenandoah University",
    "19924": "PROVIDENET - Provide.Net",
    "19925": "SWCHSC - Sunnybrook Health Sciences Centre",
    "19926": "IMC-N - Interfaith Medical Center",
    "19927": "NHMCCD - Lone Star College System District",
    "19928": "ITRACKS - Interactive Tracking Systems",
    "19929": "HHSC - Hawaii Health Systems Corporation",
    "19930": "EQUINIX-MA-CH - Equinix, Inc.",
    "19931": "VIRTELA-CUST-VILCHI1-SPSS Virtela Communications",
    "19932": "WEBSTER-BANK - Webster Bank",
    "19933": "BUFFALOSTATE - Buffalo State College",
    "19934": "TRANSPLACE - Transplace Texas, LP",
    "19935": "CRRS - CRRS-TV",
    "19936": "GORDONFOODS - Gordon Food Service",
    "19937": "MENLO-EDU - Menlo College",
    "19938": "SLHSUPPORT-INC - CSS Corporation",
    "19939": "BCTELCO - Beaver Creek Telephone Company",
    "19940": "ACECAPE-INC - Ace Innovative Networks, Inc.",
    "19941": "CONCORDIA-UNIVERSITY-CHICAGO - Concordia University Chicago",
    "19942": "FLOCHI - Flochi Networks",
    "19943": "CRCS-4-N - Chestnut Ridge Counseling Services, Inc.",
    "19944": "TA-INSTRUMENTS - TA Instruments",
    "19945": "GRANBURYISD - Granbury Independent School District",
    "19946": "HMI-QPT001 - Hexagon Metrology, Inc.",
    "19947": "VINS--2 - ViaWest",
    "19948": "RES19948 - RES",
    "19949": "IIS-WP - Informa Investment Solutions, Inc.",
    "19950": "COUPONS-COM - Coupons, Inc",
    "19951": "MEUREMENT-INCORPORATED-DURHAM-DATACENTER- - Measurement Incorporated",
    "19952": "NSPAN-BOSTON - Nortel Networks, Inc",
    "19953": "NSPAN-BOSTON - Nortel Networks, Inc",
    "19954": "ATDESK - Automated Trading Desk",
    "19955": "PINELAND-TELEPHONE - Pineland Telephone Cooperative, Inc.",
    "19956": "TENNESSEE-NET - BellSouth.net Inc.",
    "19957": "TENNESSEE-NET - BellSouth.net Inc.",
    "19958": "USICA-NET - USinternetworking Inc",
    "19959": "KINET - Kansas Data Inc.",
    "19960": "NET SITE S.A",
    "19961": "STARG-NET-1 - Star Gas Partners, LP",
    "19962": "LVLT-19962 - Level 3 Communications, Inc.",
    "19963": "DOSUB-1 - Dutchess County BOCES",
    "19964": "INVACARE - Invacare Corporation",
    "19965": "FCS - First Class Solutions, LLC",
    "19966": "LAURION---N - Laurion Capital Management, LP",
    "19967": "JSJ-CORP - JSJ Corporation",
    "19968": "MAG- - Mark Anthony Group Inc.",
    "19969": "JOESDATACENTER - Joe's Datacenter, LLC",
    "19970": "CARRIERDOMAIN-NYC - R&R Managed Telecom Services",
    "19971": "MMC-GNS-BEDFORD-N - Marsh USA, Inc.",
    "19973": "WBS-JAN-1 - WorldCom BroadBand Solutions",
    "19974": "NETCONEX - Netconex, Inc.",
    "19975": "CCADELINK - CCADELINK INC",
    "19976": "REALPAGE-STARFIRE - Real Page, Inc.",
    "19977": "MBPCHICAGO - Mayer, Brown & Platt",
    "19978": "IMPSAT FIBER NETWORKS INC",
    "19979": "CIBER-NET - CIBER INC.",
    "19980": "CAREERED - Career Education Corporation",
    "19981": "-WFC-LHC-AZ-01 - WireFree Communications Inc.",
    "19982": "TWRS-FL - Towerstream I, Inc.",
    "19983": "ONVIA-SEA - Onvia.COM",
    "19984": "VSECU-N - Vermont State Employees Credit Union",
    "19985": "MD-BEAUTY - Bare Escentuals",
    "19986": "BUC-INTL - BUC INTERNATIONAL",
    "19987": "CECOMM - California Energy Commission",
    "19988": "PORTALSYSTEMS - Portal Systems, Inc.",
    "19991": "FIRSTENERGYCORP - FirstEnergy",
    "19992": "CALOP-63-66-184-224 - Caloptima",
    "19993": "RJOBRIEN - R.J. O'Brien and Associates, Inc.",
    "19994": "RACKSPACE - Rackspace Hosting",
    "19995": "VSECORP - VSE Corporation",
    "19996": "ANY2-RS-WEST - CoreSite",
    "19997": "PENNNATIONALINSURANCE - Penn National Insurance",
    "19998": "TA-CHEN-INTERNATIONAL-INC - TA CHEN INTERNATIONAL, INC.",
    "19999": "UNIONN - Union College",
    "20001": "ROADRUNNER-WEST - Time Warner Cable Internet LLC",
    "20002": "Telstar S.A.",
    "20004": "MISO - Midwest Independent Transmission Systems Operator, Inc.",
    "20005": "SANDHILLS-SA - SANDHILLS PUBLISHING",
    "20006": "CORTEL-JH - Cortel Business Systems",
    "20007": "-ALOGI - ALOGIENT INC.",
    "20008": "NAUTILUS - Nautilus, Inc.",
    "20009": "WADSNET - The City of Wadsworth",
    "20010": "IDRC-1 - INTERNATIONAL DEVELOPMENT RESEARCH CENTRE",
    "20011": "INTERNET-SOLUTIONS",
    "20012": "INTERNET-HOLDINGS- - Internet Holdings LLC",
    "20013": "CYRUSONE - CyrusOne LLC",
    "20014": "WRCTC-NET-1 - West River Cooperative Telephone Company",
    "20015": "FullCom S.A.",
    "20016": "B3CORP - B3 Corp",
    "20017": "TRANSCORE-FBS - Transcore Commercial Services LLC",
    "20018": "MVT- - Moapa Valley Telephone Company",
    "20019": "PEC-TEL - Parwan Electronics Corporation",
    "20020": "NESHAMINYSCHOOLDISTRICT - Neshaminy School District",
    "20021": "LNH-INC - HostMySite",
    "20022": "EVERESTBROADBAND-NET - EVEREST BROADBAND NETWORKS",
    "20023": "EVERESTBROADBAND-NET - EVEREST BROADBAND NETWORKS",
    "20024": "EVERESTBROADBAND-NET - EVEREST BROADBAND NETWORKS",
    "20025": "EVERESTBROADBAND-NET - EVEREST BROADBAND NETWORKS",
    "20026": "EVERESTBROADBAND-NET - EVEREST BROADBAND NETWORKS",
    "20028": "CLINE- - Cline Communications",
    "20029": "TRAVELPORT - Travelport Operations, Inc.",
    "20030": "MCCLI-ARTELCO - Artelco",
    "20031": "SDP-N - The School District of Pittsburgh",
    "20032": "Grupo VITRO, S.A. de C.V.",
    "20033": "NOAA-NCDC - National Climatic Data Center",
    "20034": "FIRST-NATIONAL-TECHNOLOGY-SOLUTONS - First National Technology Solutions, Inc.",
    "20035": "-BBI - Broadway National Bank",
    "20036": "DSS-INC - DSS Inc.",
    "20037": "SEBL - Siebel Systems, Inc.",
    "20038": "ALLENTOWNSD - Allentown School District",
    "20039": "BAKERJK - Baker College",
    "20040": "WESTERNAND-SOUTHERN-FINANCIAL-GROUP - Western & Southern Financial Group Inc.",
    "20041": "PROSCAN - Proscan Imaging, LLC",
    "20042": "GCEC-TECHNOLOGIES - GCEC Technologies",
    "20043": "DKA SA.",
    "20044": "S/A ESTADO DE MIN",
    "20045": "TORHYDRO-CORP - Toronto Hydro Electric System Limited",
    "20046": "MICROSOFT-BOS - Microsoft Corporation",
    "20047": "CITYOFVABEACH - City of Virginia Beach, Virginia",
    "20048": "AMA--0001 - American Medical Association",
    "20049": "LINKEDIN - LinkedIn Corporation",
    "20050": "SPPINTERNET01 - Southwest Power Pool",
    "20051": "RENTRAK - Rentrak",
    "20052": "ARBOR - Arbor Networks, Inc.",
    "20053": "AIRCLIC - AirClic Inc",
    "20054": "ATG-COM2 - Art Technology Group, Inc",
    "20055": "C-HOLDINGS-INC - C Holdings, Inc.",
    "20056": "TVFR-COMPUTER-OPERATIONS-CENTER - Tualatin Valley Fire & Rescue",
    "20057": "AT&T Wireless Service",
    "20058": "CCTC-LINK1 - Totelcom Communications, LLC",
    "20059": "CAR-PART - PHONEWARE, INC.",
    "20060": "CSC-FS - CSC - FS",
    "20061": "TRUCKXL - TruckXL",
    "20062": "WTE-MAN - WTE MANAGEMENT INC.",
    "20063": "COFFEECREEKNET - Coffee Creek Technologies",
    "20064": "H-COLO - Resonate Networks, Inc.",
    "20065": "HOWARD-LEADMON - PBW Communications, LLC",
    "20066": "MORRISTECH - Morris Technologies, Inc.",
    "20067": "FORSYTHE01 - Forsythe Technology",
    "20069": "20069 - Royal Bank of Canada",
    "20070": "TELNES - Telnes Broadband",
    "20071": "ALH - SYSTEMS SOLUTIONS INC",
    "20072": "WEBSTER-BANK - Webster Bank",
    "20073": "ENERCOM - Comverge Inc.",
    "20074": "PLNU-N - Point Loma Nazarene University",
    "20075": "RFERL-ORG - Radio Free Europe",
    "20076": "ADVANIS - ADVANIS Inc.",
    "20077": "IPNETZONE-N - IPNetZone",
    "20078": "PIM-N - Pzena Investment Management, L.L.C.",
    "20079": "VCP-N - VESTAR CAPITAL PARTNERS",
    "20081": "NET2ATLANTA - NET2ATLANTA.COM LLC",
    "20082": "ABSNOC1 - TAG International",
    "20083": "ROANOKE-CITY-PUBLIC-SCHOOLS - RCPS",
    "20084": "TSIHEALTHCARE - TSI Healthcare",
    "20085": "UAKRON - The University of Akron",
    "20086": "SIEMENS-2",
    "20087": "TCW-SC - 2 CoolWeb, Inc.",
    "20088": "2GEEKSANDAPIPE - 2 Geeks and a Pipe, LLC",
    "20089": "ACS-DIABLO-INTERNET - Affiliated Computer Services, Inc.",
    "20090": "FREMONT-INS - Fremont Insurance Company",
    "20091": "MARTINSVILLE-VA - City of Martinsville, VA",
    "20092": "OWENS-MINOR - Owens and Minor",
    "20093": "ZEROLAG - Zerolag Communications, Inc.",
    "20094": "MIDWEST-TEL - Midwest Telnet, LLP",
    "20095": "SIEMENS-1",
    "20096": "ESS00-N00 - MCKINSTRY ESSENTION, INC.",
    "20097": "CITY-OF-TULSA - City of Tulsa",
    "20098": "BCBS-AL - Blue Cross Blue Shield of Alabama",
    "20099": "HMNS - Houston Museum of Natural Science",
    "20100": "INFRADAPT - Infradapt",
    "20101": "MICHWAVE - Michwave Technologies, Inc.",
    "20102": "A-LA-MODE - a la mode, inc.",
    "20103": "VALMONT-INDUSTRIES - Valmont Industries",
    "20104": "CITRIX-ONLINE-OPS- - Citrix Online, LLC",
    "20105": "URICHMOND - University of Richmond",
    "20106": "Interbanking S.A.",
    "20107": "THEDOW-N - The Dow Chemical Company",
    "20108": "PI-N - Premier Innovisions, Inc",
    "20109": "DC09 - DC09, LLC.",
    "20110": "NTT - NTT America, Inc.",
    "20112": "CAVIAIR-N - Caviair Corp",
    "20113": "COOKT-1N - COOK TELECOM, INC.",
    "20114": "KEATING - KEATING,MUETHING  KLEKAMP,P.L.L.",
    "20115": "CHARTER-NET-HKY-NC - Charter Communications",
    "20116": "CAIXA ECONOMICA FEDERAL",
    "20117": "HSBC BANK Argentina S.A.",
    "20119": "KTBNET - KTB Internet, LLC",
    "20120": "VAWEBPROP-DC-FBURG - VIRGINIA WEB PROPERTIES, LLC",
    "20121": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "20122": "NOS-NOG2 - NOS Network Operations Group",
    "20123": "NOS-NOG2 - NOS Network Operations Group",
    "20124": "DE-TELECOMM - Windstream Communications Inc",
    "20125": "CAMPUS - Luther Seminary",
    "20126": "UC-DOM - University of Cincinnati",
    "20127": "KLEINSCHMIDT - Kleinschmidt Inc.",
    "20128": "IN2 - IN2 LLC",
    "20129": "MIZUHO-SECURITIES-USA-NEW-YORK - MIZUHO SECURITIES USA INC",
    "20130": "DEPAUL - Depaul University",
    "20131": "LENMAR - Lenmar Enterprises, Inc.",
    "20132": "DSC- - Dundee Securities Corporation",
    "20133": "CS-COL - CS INFORMATION SYSTEMS",
    "20134": "CML- - CapRio Management LLC",
    "20135": "MTL-19 - Millennium Telcom LLC",
    "20136": "MCGN1 - Mainstream Consulting Group, Inc",
    "20138": "CARSONTAHOERMC - Carson Tahoe Regional Medical Center",
    "20139": "SSNC-MS - SS&C Technologies, Inc.",
    "20140": "EHI-CORP-MV- - eHealthInsurance Services Inc.",
    "20141": "QUALITYTECH-SUW-300 - Quality Technology Services, LLC.",
    "20142": "SimpleWeb Informatica Ltda.",
    "20143": "SUNET-1 - Suffolk University",
    "20144": "L-ROOT DNS Root Name Server L.ROOT-SERVERS.NET",
    "20145": "FCS - FLORIDA CANCER SPECIALISTS, P.L.",
    "20146": "N1GUARD23ATTWINSTAR - Guardian Industries Corp",
    "20147": "KO-DC3-N - Kroll Ontrack Inc.",
    "20148": "TECHNICOLOR-TPN-UK Technicolor Production Network UK",
    "20149": "NHLICE - NHL Enterprises",
    "20150": "VITRUE-SJ-N - ViTrue, Inc.",
    "20151": "MCW-12-01 - Mountain Computer Wizards, Inc.",
    "20152": "TEX-RANGERS - Rangers Baseball LLC",
    "20153": "ARGUSHEALTH - ARGUS HEALTH SYSTEMS",
    "20154": "AIRBITS - Airbits LLC",
    "20155": "OCO-1 - ORANGE COUNTY ONLINE",
    "20156": "PGCPS - Board of Education of Prince George's County",
    "20157": "AHL - American Heritage Life Insurance Company",
    "20158": "BOKU-00 - boku, inc.",
    "20159": "IMPERIAL-CAPITAL-GROUP-LLC - Imperial Capital Group LLC",
    "20160": "LSCPA - Lamar State College - Port Arthur",
    "20161": "TRGO - TeraGo Networks Inc.",
    "20162": "UTDALL - University of Texas at Dallas",
    "20163": "SUNMED Sunrise Medical",
    "20164": "JOANN-INET - JO-ANN STORES INC.",
    "20165": "EXPEDIA-PHX2 - Expedia, Inc.",
    "20166": "1FBUSA-1 - 1st Financial Bank USA",
    "20167": "BLT-IU17 - BLaST Intermediate Unit #17",
    "20169": "EMPI- - EMPI, Inc.",
    "20170": "MARITZFENTONMO - Maritz Inc.",
    "20171": "N-VMC-01 - VMC Consulting",
    "20172": "SUREWEST-20172 - SureWest Broadband",
    "20173": "Televisa, S.A de C.V.",
    "20174": "WU - WESTERN UNION COMPANY",
    "20175": "LXTNKYSETEL - SOUTHET TELEPHONE INCORPORATED",
    "20176": "FNNI-20176 - First National Bank of Omaha",
    "20177": "EMPORIA-STATE-UNIVERSITY - Emporia State University",
    "20178": "INTERNETEMC - EMC Connections",
    "20179": "BONDS- - Tullett & Tokyo Forex, Inc.",
    "20181": "WEBTER-BANK - Webster Bank",
    "20182": "ESSENTGTY001 - ESSENT GUARANTY",
    "20183": "VERICENTER - SunGard VeriCenter Inc",
    "20185": "GEUS-CABLE-INTERNET - GEUS",
    "20186": "BELINE-PH - Thomson Reuters U.S. LLC",
    "20187": "PSPORTHEALTH - Passport Health Communications, Inc.",
    "20188": "GMU1325 - Gwynedd Mercy College",
    "20189": "AKAMAI- - Akamai Technologies, Inc.",
    "20191": "Pontificia Universidad Catolica de Chile",
    "20192": "EFRAME-CORE - eFrame, LLC",
    "20193": "SINEWAVE - SineWave Technologies, Inc.",
    "20194": "BEARTECH - Bear Technologies Corporation",
    "20195": "SPARKLV-1 - Sparkplug Las Vegas, Inc.",
    "20196": "OGDEN-N - Ogden Newspapers Inc",
    "20197": "NCRC-KANNAPOLIS - NCRC Net, LLC",
    "20198": "CBSITE-IIR - CareerBuilder, LLC",
    "20199": "CRITICAL-IMPACT - Critical Impact",
    "20200": "AMBAC-FINANCIAL-GROUP - Ambac Financial Group",
    "20201": "CARYCO-TECH - Caryco Tech",
    "20202": "CRUCIAL - Crucial Paradigm",
    "20203": "RCGINET - RENAL CARE GROUP",
    "20204": "NOVOLINK-HOUSTON - NovoLink Communications, Inc. - Houston",
    "20205": "AMPLEX - Amplex Electric, Inc.",
    "20206": "I-BUSINESS - I Business Solutions, Inc.",
    "20207": "Gigared S.A.",
    "20208": "WEBJOGGER - Webjogger Internet Services",
    "20209": "LOGICWORKS- - Logicworks Corporation",
    "20210": "PRA-INTERNATIONAL-KC - Pharmaceutical Research Associates, Inc.",
    "20211": "HWI-N00 - Henry Wurst, Inc.",
    "20212": "HISNET - Hanson Information Systems, Inc. / Family Net",
    "20213": "-HBM-GRV - Hearst Business Communications Inc.",
    "20214": "COMCT-20214 - Comcast Cable Communications Holdings, Inc",
    "20215": "STEWART - ALLONHILL, LLC",
    "20216": "CBSITE-H - CareerBuilder, LLC",
    "20217": "PERCEPTA-GW1- - Percepta",
    "20218": "BLACKSUN - BlackSun Inc.",
    "20220": "INDIAN-WELLS - Indian Wells Valley ISP",
    "20221": "IATA - International Air Transport Association",
    "20222": "PLTE - Plant Telephone Company",
    "20223": "CBSITE-QTW - CareerBuilder, LLC",
    "20224": "WHIPP1-1 - WhippleHill Communications, Inc.",
    "20225": "TELJET - TelJet",
    "20226": "ROADWAY-EXPRESS - Roadway Express, Inc.",
    "20227": "ACCIDENTFUND-NET - Accident Fund Insurance Company of America",
    "20228": "NTUA - Navajo Tribal Utility Authority",
    "20229": "MERRICK- - Merrick Bank",
    "20230": "CARRINGTON-MS-LLC-2007 - Carrington Mortgage Holdings, LLC",
    "20231": "ROADRUNNER-CENTRAL - Time Warner Cable Internet LLC",
    "20233": "TBWA-WORLDWIDE-NA - AGENCY.COM",
    "20234": "HNTB - HNTB CORPORATION",
    "20235": "MYLANP- - Mylan Pharmaceuticals Inc.",
    "20236": "BEAL-SERVICE-CORPORATION - Beal Service Corporation",
    "20237": "KUBRA - Kubra",
    "20238": "ITC-LGCA-ORG - Lake Geauga Computer Association",
    "20239": "MNPOWER-N - Minnesota Power",
    "20240": "VENTURAFOODS - VENTURA FOODS, LLC",
    "20241": "TAEC - Toshiba America Electronic Components, Inc",
    "20242": "GCO-HQ - GENESCO INC",
    "20243": "UVI - University of the Virgin Islands",
    "20244": "Division de Impuestos y Aduanas de Colombia",
    "20245": "VONAGE-20245 - Vonage Holdings, Inc.",
    "20246": "IMSI- Investment Management Services",
    "20247": "IC531954 - Mercy College",
    "20248": "TAKE2 - Take 2 Hosting, Inc.",
    "20249": "JEFFERIES-INTERNATIONAL-LIMITED- Jefferies International Limited",
    "20250": "RMWC-NET - Randolph College",
    "20251": "SOLARWINDSAUSTIN - SolarWinds, Inc.",
    "20252": "JSIWMC - Joan and Sanford I. Weill Medical College and Graduate School of Medical Sciences of Cornell University",
    "20253": "VISA-DPS - VISA Debit Processing Services",
    "20254": "FRML-N - Fore Research & Management, LP",
    "20255": "Tecnowind S.A.",
    "20256": "Ultramar Agencia Maratima",
    "20257": "FTC-INET - Farmers Telephone Cooperative, Inc.",
    "20258": "ANALOG-DEVICES - Analog Devices, Inc.",
    "20259": "CVW-1 - Copper Valley Telephone Cooperative Incorporated",
    "20261": "MSA-CORP - Medical Services of America",
    "20262": "DON-JARVIS - Data Innovations LLC",
    "20263": "ZYEDGE - ZyEdge LLC",
    "20264": "WEBAIR-INTERNET-2 - Webair Internet Development Company Inc.",
    "20265": "UMR - United Medical Resources",
    "20266": "Vesper Sao Paulo S.A.",
    "20267": "INTERNETSERVER - INTERNET SERVER CONNECTIONS INC",
    "20268": "BAKERPH - Baker College",
    "20269": "INI-DEL - Independent Newspapers, Inc.",
    "20270": "K2-ADVISORS - K2 Advisors L.L.C.",
    "20271": "WINDWIRELESS - Dogear/Packet Partners",
    "20272": "-BTVC - Bluewater TV Cable, Limited",
    "20273": "PMCNET - PRAIRIE COMMUNICATIONS LTD",
    "20274": "FVCC- - Flathead Valley Community College",
    "20276": "GDVL - Global Data Vault, L.L.C",
    "20277": "TECHSPACE-OC2 - TECHSPACE INC.",
    "20278": "INNOPATH-SOFTWARE - InnoPath Software, Inc.",
    "20279": "ESC-REGION12 - Education Service Center Region 12",
    "20280": "CORPUS-CHRISTI-ISD-1 - Corpus Christi ISD",
    "20281": "NEXTLEVEL-LV - NEXT LEVEL INTERNET, INC.",
    "20283": "CTC-INTERNET-MN - CONSOLIDATED TELEPHONE CO",
    "20284": "INETUN1 - INETu, Inc.",
    "20285": "INFINITECAMPUS - Infinite Campus, Incorporated",
    "20286": "AMERICAN-COLLEGE-OF-CARDIOLOGY-DC - American College of Cardiology",
    "20287": "OFINY - OppenheimerFunds, Inc.",
    "20288": "UBARRY-NET - Urner Barry Publications, Inc.",
    "20289": "-ISGNOC - Integrated Solutions Group - Columbia",
    "20290": "RCML-9 - Rocwood Capital Management LP",
    "20291": "INFYNET - Infosys Technologies Limited",
    "20292": "WEST-B2B-DEN06 - West Corporation",
    "20293": "WU - WESTERN UNION COMPANY",
    "20294": "MTN-UG",
    "20295": "FILERTELEPHONE - Filer Mutual Telephone Company",
    "20296": "EXPEDIA-ARIN - Expedia, Inc.",
    "20297": "Convergence Communications de Venezuela",
    "20298": "TIBBANK - TIB -Bank of the Keys",
    "20299": "Newcom Limited",
    "20300": "WT-1 - Woodstock Telephone Company",
    "20301": "NA-PROTO-NET - National Aeronautics and Space Administration",
    "20302": "CITY-OF-PALM-COT - City of Palm Coast",
    "20303": "DINET-01 - Desert iNET",
    "20304": "GSC-TALLAHSEE - Gannett Supply Corp. - Tallahassee, FL",
    "20305": "Banco Rio de la Plata S.A.",
    "20306": "ADELPHI - Adelphi University",
    "20308": "STARTEKUSA - StarTek USA, INC.",
    "20309": "NDAQ-OMX-20309 - THE NDAQ OMX GROUP, INC.",
    "20310": "ITW-CORPORATE - ITW Corporate Headquarters",
    "20311": "VALERO - Valero Corporate Services",
    "20312": "Fundaci\u00f3n Centro Nacional de Innovaci\u00f3n Tecnol\u00f3gica (CENIT)",
    "20313": "SMSI - Smith Micro Software, Inc.",
    "20314": "CONAGRAFOODS - ConAgra Foods",
    "20315": "MCHENRY-COUNTY-1 - McHenry County",
    "20316": "SECTOR-NET1 - Sector, Inc.",
    "20317": "TDECU - TEX DOW EMPLOYEES CREDIT UNION",
    "20318": "MOONGLOBAL - Moon Global Network",
    "20319": "DALTON-U - Dalton Utilities",
    "20320": "EVENLINK - Evenlink",
    "20321": "Alternativa Gratis",
    "20322": "CIFG- - CIFG Services, Inc.",
    "20323": "KC-DATA-CENTER-1 - Jack Cooper Transport Co., Inc.",
    "20324": "ORMUC - Ormuco",
    "20325": "PATELCOCU - Patelco Credit Union",
    "20326": "TERWITCH - TeraSwitch Networks Inc.",
    "20327": "FORBES-COM - Forbes.com",
    "20328": "COMSPAN-BANDON - Comspan Bandon Network, LLC",
    "20329": "DIAMONDNET - Sallisaw Municipal Authority",
    "20330": "NYS-UNIFIED-COURTS - New York State Unified Court System",
    "20331": "GMACMR - GMAC Mortgage, LLC",
    "20332": "SFSLTD - SouthWest Financial Services, Ltd.",
    "20333": "OPSUS-NET - PARK PLACE INTERNATIONAL, LLC",
    "20334": "EPICTOUCH--1 - Epic Touch Co.",
    "20335": "CAMAC-TX - CAMAC ENERGY INC",
    "20336": "NYSDOT - New York State Department of Transportation",
    "20337": "SUNYIT-N - SUNY Institute of Technology",
    "20338": "MYTELN - My Telepath, Inc",
    "20339": "RR-CENTRAL - Rosenthal & Rosenthal Inc.",
    "20340": "APPIA-COMMUNICATIONS - ISPHONE, INC.",
    "20341": "HURRICANE-LABS-207-166-205-0 - Hurricane Labs, LLC",
    "20342": "GATEH-4-N - Gatehouse Management Inc.",
    "20343": "PEPPERDINE - Pepperdine University",
    "20344": "SMTUSA- - Sales and Marketing Technologies",
    "20345": "Elnath S.A.C",
    "20346": "SOC-OF-ACTUARIES1 - Society of Actuaries",
    "20347": "ILINK - LifeScript",
    "20349": "CFRDC-MFICORE - Crystal Farms Refrigerated Distribution Company",
    "20350": "TDS-INTERNET- - TDS TELECOM",
    "20351": "PARTS123 - Connect Marketing, Inc.",
    "20352": "LHS - Legacy Health System",
    "20353": "ADAGE-CAPITAL---N - Adage Capital Partners, LLC",
    "20354": "ATOMSPLH - Atomsplash LLC",
    "20355": "NTG- - Venyu Solutions Inc.",
    "20356": "BACAVALLEY-COM - SIERRA COMMUNICATIONS, INC.",
    "20357": "BAJA-UT-NM-CO - Baja Broadband",
    "20358": "MBPSANTAFE - Mayer, Brown & Platt",
    "20359": "PREFERREDMUTUALINSURANCECOMPANY - Preferred Mutual Insurance Company",
    "20361": "Globalnet S.A.",
    "20362": "THOMSON-THOMSON - THOMSON & THOMSON",
    "20363": "IMPSAT FIBER NETWORKS INC",
    "20364": "LMS-NA - Leica Microsystems, Inc.",
    "20365": "GWMC-2 - Globalive Wireless Management Corp.",
    "20366": "LINKEDIN-1 - LinkedIn Corporation",
    "20367": "ONNETSECURE - Realware LLC",
    "20368": "SMART-CITY-INDIANAPOLIS - Smart City Networks, L.P.",
    "20369": "GDC-CBG1 - GLOBAL DATA CONSULTANTS LLC",
    "20370": "MARCHO-2 - March of Dimes",
    "20371": "LIBGO - Lib/Go Travel, Inc.",
    "20372": "GOBIERNOPR- - Office of Management and Budget",
    "20373": "KITD- - Kit Digital, Inc",
    "20374": "FOX-INC - Fox Entertainment Group, Inc.",
    "20375": "TEKSAVVY-VAN TekSavvy Solutions Inc. Vancouver",
    "20376": "HUBRIS - Hubris Communications",
    "20377": "MLODE-COM - Mother Lode Internet, LLC",
    "20379": "NET-BAKER - Baker College",
    "20380": "APEX-SYSTEMS-INC - APEX Systems Inc.",
    "20381": "CABLELABS - Cable Television Laboratories, Inc.",
    "20382": "XOTECH - XOTECH L.L.C.",
    "20383": "EXCHANGEBANK- - Exchange Bank",
    "20384": "NWLRBD - NewellRubbermaid Inc.",
    "20385": "ACCESSLINE-COM-1000 - AccessLine Communications Corp.",
    "20386": "MOVE-VAN - Move Sales, Inc.",
    "20387": "CBR-TS-AND-CBR-SF - CBR SYSTEMS, INC.",
    "20388": "GLORIAD - GLORIAD",
    "20389": "-SAVINGS - Arizona State SAvings and Credit Union",
    "20390": "FSS - Feith Systems and Software, Inc.",
    "20391": "PRGPARKING-DOMAIN - The Parking Spot",
    "20392": "WESTPANET - WestPAnet, Inc.",
    "20393": "BEANSTALK - Beanstalk Networks",
    "20394": "MHELL-TELECOM - Rainier Connect",
    "20395": "MEDFUSION-LEWISVILLE - Med Fusion, LLC",
    "20396": "FIDMXV15 - The Fashion Institute of Design and Merchandising",
    "20397": "BOXLAKE - Box Lake Networks, Inc.",
    "20398": "CNCS- - Controlled Networks and Communications Solutions, Inc.",
    "20399": "N-NET - Advanced Systems Network",
    "20400": "CUDIRECTCORPORATION - CU Direct Corporation",
    "20401": "HOSTWAY-1 - Hostway Corporation",
    "20402": "OSRAM-SYLVANIA - OSRAM SYLVANIA INC.",
    "20403": "DSL-ONLY-PDX - DSL-Only, Inc",
    "20404": "20404 - NRG Energy, Inc.",
    "20405": "EPLICA- - Eplica, Inc.",
    "20406": "BRLINK - Braslink Network Inc",
    "20407": "N-FBMC-WDM-IA - Farm Bureau Management Corporation",
    "20408": "NTTA - North Texas Tollway Authority (NTTA)",
    "20409": "AUTONATION-P2 - Autonation, Inc",
    "20410": "DACD-MARINADELREY - Sony Corporation of America",
    "20411": "GSSLK - The Goldman Sachs Group, Inc.",
    "20412": "WOW-INTERNET - WideOpenWest Finance LLC",
    "20413": "CCIU-1 - Chester County Intermediate Unit",
    "20414": "HWN - Hunton & Williams LLP",
    "20415": "COUNCILROCKSD-PA - Council Rock School District",
    "20416": "GCC-01 - General Cable Corporation",
    "20417": "FPSSI - FrontPoint Security",
    "20418": "DAC S.A.",
    "20419": "NETBLK-DMRCOM - DMR Communications Inc.",
    "20420": "BBCC- - Buckingham Branch Railroad Company",
    "20421": "1STTECHCU - First Tech Credit Union",
    "20422": "PARMA-COMMUNITY-GENERAL-HOSPITAL - Parma Hospital",
    "20423": "SUQUAMISH-TRIBE - Suquamish Tribe",
    "20424": "AMERICAN-STOCK-EXCHANGE-LLC - American Stock Exchange LLC",
    "20425": "-INTEGRAL - Integral Group Inc.",
    "20426": "PWC- - PriceWaterhouseCoopers, LLP",
    "20427": "AAAE - American Association of Airport Executives",
    "20428": "GLOWPOINT- - Glowpoint Inc.",
    "20429": "GUITAR-CENTER-2 - Guitar Center",
    "20430": "AXCESS-FINANCIAL - Axcess Financial Services, Inc.",
    "20431": "SUREWEST-20431 - SureWest Broadband",
    "20432": "N-SCBC-1 - SUGAR CREEK BAPTIST CHURCH",
    "20433": "TL-MABOS - Cengage Learning Inc",
    "20434": "-SELLERSAIDE-NET - Seller's Aide, LLC",
    "20435": "ROSE-GROVE-CAPITAL-MANAGEMENT-LLC-N - Rose Grove Capital Management, LLC",
    "20436": "PGTC-COM - Prairie Grove Telephone Co.",
    "20437": "20437 - Nationwide Mutual Insurance Company",
    "20438": "LAQUINTA - La Quinta Inns, Inc.",
    "20439": "PLANO-DATACENTER- - Intuit Inc.",
    "20440": "BITTO-1 - BitTorrent, Inc.",
    "20441": "AFFINA--1 - AFFINA, LLC",
    "20442": "YNHHSC - Yale-New Haven Health Services Corporation",
    "20443": "ONE-BUCKHEAD - ONE BUCKHEAD LOOP CONDO SOCIATION",
    "20444": "INSTILL-CORP-1 - Instill Corporation",
    "20445": "HDT - HDT Engineered Technologies",
    "20446": "HIGHWINDS3 - Highwinds Network Group, Inc.",
    "20447": "CADMUSCOMMNET - Cadmus Communications, Inc.",
    "20448": "VPNTRANET-LLC - VPNtranet, LLC.",
    "20449": "RANDOLPHHOSPITAL - Randolph Hospital, Inc.",
    "20450": "THL16-N - Trojan Hosting, LLC.",
    "20451": "KEYSTONE-PEER-REVIEW - Keystone Peer Review Organization, Inc.",
    "20452": "BSU - BALL STATE UNIVERSITY",
    "20453": "ROGERS-WIRELESS - Rogers AT&T Wireless Inc",
    "20454": "SSN2 - SECURED SERVERS LLC",
    "20455": "NRTC-ORG - NRTC",
    "20456": "T6-BROADBAND - JAB Wireless, INC.",
    "20457": "INACOM-MADISON-WI-USA - Inacom Information Systems - Madison",
    "20458": "N1 - C Severn",
    "20459": "TELECOM-NAMIBIA-",
    "20460": "MYTHOSTECH - TFB NET",
    "20461": "MYPT-SCH - United Airlines",
    "20462": "ESI-NETA - ESI",
    "20463": "EZYIELD - EZ Yield.com, Inc.",
    "20464": "POLYCOM - Polycom, Inc.",
    "20466": "WGBH-EDUCATIONAL-FOUNDATION - WGBH Educational Foundation",
    "20467": "SW-ORG- - Scott & White",
    "20468": "WINDSTREAM-COMMUNICATIONS - Windstream Communications Inc",
    "20469": "TRIMETNET - Tri-County Metropolitan Transit District",
    "20470": "DIRECTV-LOSANGELES - DirecTV Operations",
    "20471": "QCV-N-1 - Quick Connect VOIP, Inc",
    "20472": "SYNN - Synergy Networks",
    "20473": "-CHOOPA - Choopa, LLC",
    "20474": "NCIDATACOM - NCI Data.com, Inc.",
    "20475": "20475 - Global Capacity, LLC",
    "20476": "LVLT-20476 - Level 3 Communications, Inc.",
    "20477": "RANDOLPHTELEPHONE - Randolph Telephone Company",
    "20478": "GENMILLS - General Mills",
    "20479": "TCF-N-TCF - TCF Financial Corporation",
    "20480": "Excite Italia B.V.",
    "20482": "ABP Informatique S",
    "20483": "EUROCOM EUROCOM Ltd.,",
    "20484": "YallaOnline",
    "20485": "TRANSTELECOM TransTelecom",
    "20486": "eCard S.A.",
    "20487": "N-CEDECRA Cedecra Informatica Bancaria SRL",
    "20488": "KIEZ- Clemens Schrimpe",
    "20489": "KOSMOTEL- ISP Kosmotel",
    "20490": "CJSC ARQA Technologies",
    "20491": "WKO WKO S.A.",
    "20492": "USi Europe B.V.",
    "20494": "IPY- Kaisanet Oy",
    "20495": "WEDARE We Dare BV Autonomous System",
    "20496": "DK_MEDNET MedNet",
    "20497": "INTERNIO- INTERNIO SYSTEMS SRL",
    "20499": "IPC- IP Communications Ltd.",
    "20500": "GRIFFIN MDNX Enterprise Services Ltd",
    "20501": "Banque de Luxembourg SA",
    "20502": "Slovenska sprava ciest (SSC)",
    "20503": "number for Logica UK",
    "20504": "RTL- RTL Nederland Interactief B.V.",
    "20505": "LEGAL-AND-GENERAL-INVESTMENT-MANAGEMENT-LIMITED Legal & General Investment Management Holdings Ltd",
    "20506": "SINGULAR-SOFTWARE SINGULARLOGIC INTEGRATOR SA",
    "20507": "INTERNLNET InterNLnet Autonomous System",
    "20508": "Isnet srl",
    "20509": "ELKO Grupa",
    "20510": "NEXUM- Nexum Hungary Internet Service Provider Ltd.",
    "20511": "CyberTwiga Limited, Internet Services Provider,",
    "20512": "TEDICON TeDiCon GmbH",
    "20513": "CREPUNDIA A.M.S. Carlzon",
    "20514": "QBRANCH Qbranch Stockholm AB",
    "20515": "INTERDON- Inter-don Ltd.",
    "20516": "SVUA SkyVision Ukraine Ltd",
    "20517": "Yorkshire Electricity Autonomous System",
    "20519": "BALTNET OJSC Rostelecom",
    "20520": "CENTRIC-ACC Centric Telecom Limited",
    "20521": "N-BELLNET Bellnet Ltd.",
    "20522": "SEVEN-AUTONOMOUS-SYSTEM SEVENLAB Spa",
    "20523": "Novotron Informatikai Rt.",
    "20524": "MVHNET MVH Bit Conection Soft Computers S.R.L.",
    "20525": "NOVLINE- OOO NovLine",
    "20526": "INTEREUROPA- Intereuropa IT doo",
    "20527": "Autonomous System for Third Rail an ISP in Ghana",
    "20528": "GENNET str.Siderurgistilor nr.1",
    "20529": "1_SAFETY-HOST Alfa-safety",
    "20530": "ANISP-ROMANIA OCIATIA NATIONALA A INTERNET SERVICE PROVIDERILOR DIN ROMANIA",
    "20532": "BANH- BANANA HOSTING SRL",
    "20533": "SAKHTEL- Sakhalin Telecom Ltd.",
    "20534": "SEMACA-COMEXIM-SRL Semaca-S.I.-Comexim SRL",
    "20535": "DE-INSAT InSat GmbH",
    "20536": "Start Communications, Hungary",
    "20537": "Amt d. NOe Landesregierung",
    "20539": "Technical Centre Radio Systems Ltd.",
    "20540": "WEBINN Web Inn SA",
    "20541": "Generali Vie S.A",
    "20542": "HTV DNA Oy",
    "20543": "Miori Joint Stock Company",
    "20544": "EXTEL CJSC Express TeleCom",
    "20545": "GRENA- GRENA Autonomous System",
    "20546": "SOPRADO-ANY SOPRADO GmbH",
    "20547": "SIXDG- Six Degrees Managed Data Limited",
    "20548": "LATVIJ_REPUBLIK_SAEIMA Latvijas Republikas Saeima",
    "20549": "FREE-MPEI State Educational Enterprise of Higher Professional Education Moscow Power Engineering Institute (Technical University)",
    "20550": "TCC-ONLINE- SPE TCC Ltd",
    "20551": "TEIPAT Autonomous System",
    "20552": "HORYZONT Horyzont Technologie Internetowe sp.z.o.o.",
    "20553": "HPPOLAND- Hewlett Packard Polska",
    "20554": "IMIWEB- UBI Sistemi e Servizi S.c.p.a.",
    "20555": "WSISIZ- Wyzsza Szkola Informatyki Stosowanej i Zarzadzania",
    "20556": "Global One Communications",
    "20559": "Skandia Finanz AG, Autonomous System",
    "20560": "N-PC-DIREKT PC Direkt Systems AG",
    "20561": "20561-INA Schaeffler Technologies AG & Co. KG",
    "20562": "OPEN-PEERING- Open Peering Initiative, Amsterdam, The Netherlands",
    "20563": "20563 ATOS Worldline S",
    "20568": "AH-CDN- Antenna Hungaria Broadcast and Telecommunication Corporation",
    "20569": "AINAIP- AinaCom - IP Services and Transit Network",
    "20570": "N-TSI-IPLS T-Systems International GmbH",
    "20571": "EXOMI Ztango Finland",
    "20572": "GIESECKE Giesecke & Devrient GmbH  Autonomous System",
    "20574": "CSSHOSTING- Cybercom Sweden AB",
    "20576": "GAZSVYAZ Gazsvyaz Ltd",
    "20577": "Tradeweb Europe Ltd",
    "20578": "KATELCO- JSC KAZAKHSTAN TELECOMMUNICATIONS (KATELCO)",
    "20579": "NETLABPLUS SWAN a.s.",
    "20580": "Telecom Italia S.p.A.",
    "20581": "MAXIMALNET_1 Ing. Jan Mindzak - Maximal Net",
    "20582": "Vizional Technologies, Inc.",
    "20583": "ABNAMROKZ- JSC Subsidiary Bank RBS (Kazakhstan)",
    "20585": "VIEL- E-viel SA",
    "20588": "FVB Forschungsverbund Berlin e.V.",
    "20590": "DEC- Donbass Electronic Communications Ltd.",
    "20591": "-FOTR Ford Otosan Otomotiv Sanayii A.S. Turkey",
    "20592": "Liberate Technologies Autonomous System",
    "20593": "Realise Ltd",
    "20594": "MOSAICDE-ATOS Atos IT Solutions and Services GmbH",
    "20595": "HELABA Autonmous System of Landesbank Hessen-Thueringen Girozentrale",
    "20596": "STSnet Autonomous System",
    "20597": "ELTEL- OJSC \"Vimpelcom\"",
    "20598": "CYBERSPACE- Autonomous System number for Cyber Space,",
    "20600": "SKYTEC-AG SKYTEC AG",
    "20601": "HERCULES HIX GROUP S.R.L",
    "20602": "RINOTEL LLC",
    "20603": "Orange S.A.",
    "20604": "ETRINF Etruria Informatica",
    "20606": "GTS-RO GTS Romania",
    "20607": "GU74- CJSC Global-Utis",
    "20608": "T-SYSTEMS-ITALIA- T-Systems Italia Autonomous System",
    "20609": "Kesco-M corporate network,",
    "20610": "AN-MEDIA Northcliffe Media Limited",
    "20611": "UK-PS-GROUP UK PS Group Ltd",
    "20612": "SWISSIX SwissIX Internet Exchange",
    "20615": "Germanos SA",
    "20616": "NETBRIDGE- NetBridge Services SRL",
    "20617": "BNP-PARIB BNP PARIB SA",
    "20618": "DK-INFO-CONNECT Info-Connect A/S",
    "20619": "ALANIT- Alanit, Ltd.",
    "20621": "OPENIT OpenIT GmbH",
    "20622": "PERFETTI- Perfetti Van Melle Gida San. ve Tic A.S.",
    "20623": "SAFELINES The network of ISP Safelines,includes POPs in various cities",
    "20624": "Euronet Services Kft",
    "20625": "HELSINGENET Bollnas energi AB",
    "20626": "se.sandnet Autonomous System",
    "20627": "CONCORD-AG Concord Autonomous System",
    "20629": "BIS BIS Ltd",
    "20631": "ARTECOM Artecom Ltd",
    "20632": "PETERSTAR- OJSC MegaFon",
    "20633": "UNIFFM-NET Johann Wolfgang Goethe-Universitat Frankfurt am Main",
    "20634": "TELECOM-LI Telecom Liechtenstein AG",
    "20635": "HDI-GERLING HDI-Gerling Zycie Towarzystwo Ubezpieczen SA",
    "20636": "TSI-RIGA-LV- Transport & Telecommunication Institute",
    "20637": "EMAZE Emaze Networks S.p.A.",
    "20638": "MEGABITEX-IT A commercial Internet exchange point in Milano, Italy",
    "20640": "TITAN-NETWORKS Titan Networks Internet & Telecommunications",
    "20641": "LHCONE-RS CERN- European Organization for Nuclear Research",
    "20642": "Bassilichi S.P.A.",
    "20643": "MCIT SC Marketing Consulting & IT SRL",
    "20644": "NETSTREAM-TEMP Netstream AG Temporary",
    "20645": "PUREPEAK-N PurePeak Limited",
    "20646": "CELOX QSC AG",
    "20647": "IPB IPB Internet Provider in Berlin GmbH",
    "20648": "RAN-NETWORKS RAN Networks S.L.",
    "20649": "FIBERSUNUCU Fibersunucu internet Hizmetleri",
    "20650": "TOLEDO- IP NEXIA N.V.",
    "20652": "UNITRON- Unitron Systems & Development LTD Autonomous System",
    "20653": "BYTEACTION- ByteAction GmbH",
    "20654": "N-UNIONESARDA L'Unione Editoriale Spa",
    "20655": "E-STYLEISP- e-Style ISP LLC",
    "20656": "ELEKTRIM- Laris Investments Sp. z o.o.",
    "20657": "ATLANTIS Atlantis BG, Ltd.",
    "20658": "COMPUTERDESIGN- Web Farm of Computer Design in a multi-homed infrastructure",
    "20660": "LE-UA- LinkExpress Ltd.",
    "20661": "TURKMENTELECOM- TurkmenTelecom ISP Network",
    "20662": "MP-ELEKTRONIKA- SIA \"MP ELEKTRONIKA\"",
    "20663": "INAR-VOLOGDA- OJSC MegaFon",
    "20664": "UNI-NAIROBI- Automous system for University of Nairobi",
    "20665": "VARNANET- Varna Net Ltd.",
    "20666": "TRANSWORLD-PAYMENT-SOLUTIONS HOSTING PAYMENT SOLUTIONS",
    "20668": "DATA-NET Data Net SRL",
    "20670": "INFANET- InfaNET Sylwester Kus",
    "20671": "NETMTERS NETMTERS - ROMANIA/Craiova",
    "20672": "GROUPE-SERVEUR-NUMBER Groupe Serveur S",
    "20674": "SWAN GlobalTel",
    "20675": "FIMATEX-NUMBER BOURSORAMA S.A.",
    "20676": "QSC-1 QSC AG",
    "20677": "IMOS- imos GmbH",
    "20679": "HSO hSo: broadband internet, data and",
    "20680": "ATCOM- ATCOM S.A. Commercial Network",
    "20681": "SAXOBANK Saxo Bank A/S",
    "20682": "BGONE- BG ONE Ltd",
    "20683": "Pre-Tel Wireless, Aalborg, Denmark",
    "20684": "TUEV- TUEV AUSTRIA HOLDING AG",
    "20685": "EVROCOM-NET Evrocom.Net Autonomous System",
    "20686": "BISPING Bisping & Bisping GmbH & Co. KG",
    "20688": "NEOCLES- NEOCLES",
    "20689": "HCCNET XS4ALL Internet BV",
    "20690": "APATIT JSC Apatit",
    "20691": "GLS-SLO- General Logistics Systems logisticne storitve d.o.o.",
    "20692": "NETGATE- NetGate Datacenter N",
    "20693": "INTERNET-XPRESS- INTERNET XPRESS Autonomus System",
    "20694": "NMMN- NMMN New Media Markets & Networks IT-Services GmbH",
    "20695": "CAP1- Capital One Bank (Europe) plc",
    "20696": "ABSNET Absnet on Aker Brygge, Oslo,Norway",
    "20697": "AGS- A.G.S. Associazione Giovanile Salesiana",
    "20698": "CSPB Credit Suisse Private Banking",
    "20699": "SLW \"Internet Service Ltd.\"",
    "20700": "Rothschild Bank AG",
    "20701": "MARICZ MARI s.r.o.",
    "20702": "CSSMPS- Central Switching Station of Ministry Railway Transport",
    "20703": "CARBOCHIM- S.C. Carbochim S.A.",
    "20704": "FUNKNETZ- www.funknetz.at GmbH",
    "20705": "HSBC-UK HSBC Bank plc",
    "20707": "20707 IHnet Srl",
    "20708": "SKODA-AUTO SKODA AUTO a.s.",
    "20709": "TICOM- Techinform Ltd",
    "20710": "XINTER- Xinter Network Services Espana",
    "20712": "20712 Andrews and Arnold Ltd",
    "20713": "NSNBS Siemens Switzerland Ltd.",
    "20714": "MERLIN-TELECOM \"Merlin-Telekom\" LLC",
    "20715": "THREE-C- 3 C Systems",
    "20716": "TOTALTELECOM- TOTAL TELECOM SRL",
    "20718": "_ARSYS-EURO-1 arsys.es",
    "20719": "PS-BZU- Birzeit University",
    "20720": "CTEL- CJSC \"Tatarstan-On-Line\"",
    "20721": "KAOSES KAOS REDES IP",
    "20722": "ALLNET- ALLNET TELECOM SRL",
    "20723": "MGI CZ.MGI autonomous system, Czech Republic",
    "20724": "TELEPARK- Telepark LTD",
    "20725": "DATAGROUP-_NCC2013033607 PRIVATE JOINT STOCK COMPANY \"DATAGROUP\"",
    "20726": "REIS- ReIS Autonomous System",
    "20727": "DE-WRONLINE WRonline GbR",
    "20728": "GUNESSIG Gunes Sigorta",
    "20729": "Sun Alliance Management Services",
    "20730": "BAYKAL-INCANET- BIKS+ Ltd",
    "20731": "MEGATON- Limited Company Megaton, Moscow, Russia",
    "20732": "WORLDTRAVEL-HOLDINGS World Travel Holdings",
    "20733": "UKRTEL Ukrtel Ltd",
    "20734": "EON-BREDBAND E.ON Bredband Sverige Autonomous System",
    "20736": "Edifica Online Autonomous System",
    "20738": "20738 Webfusion Internet Solutions",
    "20739": "PIOCOMMERCE Pio Commerce Ltd.",
    "20740": "MESSEFFM Messe Frankfurt GmbH",
    "20741": "PFIZER- Pfizer Inc.",
    "20742": "AHOL Internet4U Kereskedelmi es Szolgaltato Kft.",
    "20743": "SWX SIX Swiss Exchange AG",
    "20744": "DIONYS-NET- Dionys Net AG",
    "20745": "CNIT Autonomous System",
    "20746": "N-IDC Telecomitalia s.p.a.",
    "20748": "CAJAMADRID Bankia S.A.",
    "20750": "NETLAN NetLan Ltd.",
    "20751": "N-AZISTA AZISTA GmbH",
    "20753": "PCTCONSULTING Pohl Consulting Team GmbH",
    "20754": "RCT- Rivne Communication Technologies Ltd",
    "20755": "NET-LAB net-lab's famous autonomous system",
    "20756": "NAMESHIELD ECHO MARQUES",
    "20759": "ISU-JED King Abdul Aziz City for Science and Technology",
    "20760": "EUROCIBER- Produban Servicios Informaticos Generales, S.L.",
    "20762": "SYNETRIX Synetrix (Holdings) Limited",
    "20763": "BPH Bank BPH S.A.",
    "20764": "RCOM- CJSC Rascom, St.Petersburg, Russia",
    "20765": "Henkel AG & Co.KGaA",
    "20766": "GITOYEN-MAIN- Association \"Gitoyen\"",
    "20767": "UNITEL- Unitel Autonomous System",
    "20768": "KEYNETSYSTEMS ZDIS GmbH",
    "20769": "QUANZA Quanza Engineering BV",
    "20771": "CAUCUS-CABLE-SYSTEM CCS Autonomous System",
    "20772": "SWSU- KurskSSU",
    "20773": "HOSTEUROPE- Host Europe GmbH",
    "20774": "JYVKYLA- University of Jyvaskyla, Commercial Internet Services",
    "20775": "GETIT GETIT Internet GmbH",
    "20776": "OUTREMER- Outremer Telecom",
    "20777": "Infoserv-Riga Ltd",
    "20778": "PKOBP Powszechna Kasa Oszczednosci Bank Polski SA",
    "20779": "RGA Seguros RGA",
    "20781": "TELETON- TeleNet Zachod Sp. z o.o.",
    "20782": "ZEBRAELEC Zebra Electronics LTD",
    "20783": "POP pop-interactive GmbH",
    "20784": "CECA- Cecabank,S.A.",
    "20785": "UCT- TOV UCT",
    "20787": "PRO-CONNECTION- SC Pro Connection SRL",
    "20790": "UA-INT- International Information Technology Centre INT Ltd",
    "20791": "BITPOINT- BitPoint AG",
    "20792": "VISTEC- Vistec Internet Service Autonomes System",
    "20793": "CONCORD Concord Ltd",
    "20794": "EURNETCITY \"EUR TEL - SOCIETA' A RESPONSABILITA' LIMITATA\"",
    "20795": "ITM- ITM Research GmbH",
    "20796": "ORIONMEDIA OOO TRO Orion Media",
    "20798": "EPTE-FI EPTE Oy",
    "20799": "DATANET- Datanet.co.uk Ltd",
    "20800": "Globes",
    "20802": "BELLATRIX- Internet Provider BELLATRIX Poland",
    "20803": "RISS- LLC \"Ris-Tel\"",
    "20804": "N-TELENERGO Exatel S.A.",
    "20805": "HFONETZ Aut.-System HFO Telecom AG",
    "20806": "JSCITT JSC InfoTeCS Taganrog Telecom",
    "20807": "CREDOLINK-N Credolink ISP Autonomous System",
    "20808": "-BGZ Bank Gospodarki Zywnosciowej SA",
    "20809": "GAUSS-INTERPRISE-AG-N Gauss Interprise AG",
    "20810": "NETCOM-KSEL Netcom Kassel",
    "20811": "BRENNERCOM- Brennercom S.p.A.",
    "20813": "HOU- Hellenic Open University",
    "20815": "GRN- GRN Network",
    "20816": "IIP-NET-20816 Science and Society Telecomm Center",
    "20817": "DELTANET- OOO DeltaCOMM",
    "20818": "SITESCOPE Sitescope's data centre for the supply of mapping data for enviromental surveys",
    "20819": "ALITALIA Alitalia - Compagnia Aerea Italiana S.p.A.",
    "20820": "N-CJD-NET JUDETUL DAMBOVITA",
    "20821": "ELEKTROCENTROMONTAZH- OJSC Elektrocentromontazh",
    "20822": "BGBSYSTEMS BGB Systems Ltd",
    "20823": "KBMEDIA- 5587.NET - Broadband solutions provider based in Bedford, UK",
    "20824": "FR-CORNUT Cienum S.A.S",
    "20825": "UNITYMEDIA Unitymedia NRW GmbH",
    "20826": "S-LOGISTIC-LTD- S-Logistic Ltd",
    "20827": "Art Technology Group",
    "20828": "NDIX- Nederlands-Duitse Internet Exchange B.V.",
    "20829": "SURFLAND- Surfland Systemy Komputerowe SA",
    "20830": "GLOBALAIRNETWORK- The Cloud Networks Germany GmbH",
    "20831": "FUNDATIA- Fundatia Lambda",
    "20832": "MSN- MULTICT SATELLITE NETWORKS SRL",
    "20833": "ATL- Atlantis Telecom",
    "20835": "ATS69- ZAO ATS-69",
    "20836": "CDLAN- CDLAN Autonomous System",
    "20837": "ITELEKOM ISP iTelekom Autonomous System",
    "20838": "YIF- France Telecom Espana S.A",
    "20839": "SED-UA-NET Private Firm \"NT-Zv'yazok\"",
    "20840": "XS-NETWORKS- XS Networks BV",
    "20841": "COOP-BLUE-SQUARE Mega Retail Ltd",
    "20842": "FORMULAPLUS- Formula+",
    "20843": "EARNE- EARNE-AT Autonomous System Number",
    "20844": "COLTEX- Coltex B.V.",
    "20845": "DIGICABLE DIGI Ltd.",
    "20846": "PARABOLE- UAB \"Parabole\"",
    "20847": "PREVIDER- Previder B.V.",
    "20848": "ROSBUSINESSCONSULTING- RosBusinessConsulting, CJSC.",
    "20849": "CONTINUM Continum AG",
    "20850": "VALORKIEV- LLC \"TC Valor\"",
    "20852": "ATLANT-TELECOM- FE \"ALTERNATIVNAYA ZIFROVAYA SET\"",
    "20853": "ETOP- eTOP sp.  z o.o.",
    "20855": "AIRDATA- AIRDATA AG",
    "20856": "TODAYSONLINE Autonomous System for Todays-Online which is an ISP in Kenya",
    "20857": "TRANSIP- TransIP B.V.",
    "20858": "EGYNET-",
    "20859": "NOMURA- NOMURA-INTERNATIONAL",
    "20860": "IOMART- Iomart",
    "20861": "FUJITSU-SE- Fujitsu Sweden AB",
    "20863": "THREEUNITED- mobile messaging solutions (mms) GmbH",
    "20864": "SISECAM- SISECAM",
    "20865": "-YOURVOICE Yourvoice  number",
    "20866": "INTELECOM- LLC Promsvyaz-Invest",
    "20867": "ORDINA- Ordina Application Outsourcing & Projecten B.V.",
    "20868": "ABB ABB Schweiz AG",
    "20869": "CLARANET-SPAIN Claranet S.A.U.",
    "20870": "KAVKAZ-TRANSTELECOM- CJSC \"Caucasus - Transtelekom\"",
    "20872": "URALSIB- OJSC \"UralSib\"",
    "20873": "P5 P-Five Ltd",
    "20874": "ICC-INFORMATION-LTD ICC Information Ltd",
    "20875": "HPTNET- HT d.o.o. Mostar",
    "20876": "EVRO- \"GEO KOMERS 97\" EOOD",
    "20877": "DATEK DATEK Telecom SRL",
    "20878": "ATIA- Atia Solutions Ltd",
    "20879": "MICRONET SC Servicii Micronet SRL",
    "20880": "TELECOLUMBUS Tele Columbus GmbH",
    "20881": "ENRON-EUROPE-LTD Enron Europe Ltd",
    "20882": "INFORM- Inform Media Kft.",
    "20883": "WMDATA-CCB WM-Data CCB",
    "20884": "CZ-CTNET- Telefonica Czech Republic, a.s.",
    "20886": "DE-IORG--1 bn:t Blatzheim Networks Telecom GmbH",
    "20887": "CITYNETZ- Citynetz Enterprises Inc.",
    "20888": "SCANDINAVIA-ONLINE-N Scandinavia Online AB",
    "20889": "BCC- Business Consulting Center sp. z o.o.",
    "20890": "SULZER_MANAGEMENT- Sulzer Management AG",
    "20892": "ACTIVA-SI- Intesa Sanpaolo Card d.o.o.",
    "20893": "SYSTEM-CLINCH- SYSTEM-CLINCH",
    "20895": "UGTEL Yuzhniy TELECOM ltd.",
    "20896": "Office Depot Europe B.V.",
    "20897": "ISD- Limited company with foreign investments ISD",
    "20898": "PENET Trigon Dom Maklerski SA",
    "20899": "TRADEHAVEN- Tick Trading Software AG",
    "20900": "MAN-CTRES- SAEM Intermediasud",
    "20901": "CSC-MANN- CSC-Mann GmbH",
    "20902": "DEGNET DegNet GmbH",
    "20903": "VMB-SERVICE- Smart Telecom Limited",
    "20904": "NETPLAZA- Netplaza Oy",
    "20905": "BANCOESPANA Banco de Espana",
    "20906": "ALLIANZ- ALLIANZ Compania De Seguros y Reaseguros SA",
    "20907": "SHOW-TV-AUTONOMOUS_SYSTEM AKS TELEVIZYON REKLAMCILIK VE FILMCILIK SAN VE TIC A.S.",
    "20908": "CR-MEDIA- Grupa Pino Sp. z o.o. w upadlosci likwidacyjnej",
    "20909": "CONTIUM- UNITY S.A.",
    "20910": "BALTKOM- SIA \"Baltcom TV\"",
    "20911": "NETSURF--BG Net-Surf.net Ltd.",
    "20912": "N-PANSERVICE Panservice",
    "20913": "BETAM_TELECOMUNICAZIONI_ Betam.it SNC di Leoni marco e Zibelli Maurizio",
    "20914": "OPENOFFICE- Openoffice",
    "20915": "HUNDRED-PERCENT-IT 100 Percent IT",
    "20916": "ADMINEXPERT- PE Arzanova Nadezhda Borisovna",
    "20917": "KHEOPS-AUTONOMOUS-SYSTEM KHEOPS Organisation",
    "20918": "PI- PI-Informatik GmbH",
    "20919": "IBS IBS Systems Integration Limited",
    "20921": "AMENA- France Telecom Espana SA",
    "20922": "DW- Invitel Tavkozlesi Zrt.",
    "20924": "ICTEAM ICTeam Autonomous System",
    "20926": "PULSATION- Oceanet Technology S",
    "20927": "ADDISON-LEE Addison Lee",
    "20928": "NOOR-",
    "20929": "MF-CTIF Agentia Nationala de Administrare Fiscala",
    "20930": "SOFTWIN SOFTWIN SRL",
    "20931": "PPOINTS- Elisa Oyj",
    "20932": "SIG-ST Services Industriels de Geneve",
    "20933": "VECTONE- Vectone Group Holding Limited",
    "20934": "ABCINTERNET JSC Maket",
    "20935": "OEBV- Oesterreichische Beamtenversicherung",
    "20936": "GRXPROVIDER- Deutsche Telekom AG",
    "20937": "LEVANTINA- LEVANTINA Y OCIADOS DE MINERALES S.A.",
    "20938": "RETSAT STK Retsat1",
    "20939": "IPTELECOMBALTIA IP Telecom Baltia",
    "20940": "AKAMAI-N1 Akamai International B.V.",
    "20941": "ZEN- Zen Internet Ltd",
    "20942": "ISGS-N2 Intesa Sanpaolo Group Services S.c.p.A.",
    "20943": "NETNOD-LUL NETNOD Internet Exchange i Sverige AB",
    "20945": "IT-SERVICES- IT-Services s.a r.l. Luxembourg",
    "20946": "CCE- Moscomsvyaz Ltd",
    "20947": "UPC-PL-NET UPC Polska Sp. z o.o.",
    "20948": "CPINET- Conseil et Partenariat Informatique",
    "20949": "INCOSOFT Incosoft Telecommunications, Ltd.",
    "20950": "RICC- Regional Informational Computer Center, Rovnen regional council",
    "20952": "VENUS-INTERNET- VENUS BUSINESS COMMUNICATIONS LIMITED",
    "20953": "INFONL- info.nl/hf Amsterdam, The Netherlands",
    "20954": "EKINCILER_HOLDING_ EKINCILER YATIRIM MENKUL DEGERLER A.S",
    "20955": "PROQUEST-UK ProQuest Information and Learning Limited",
    "20956": "STYLECOM- Stylecom Ltd",
    "20958": "SIGMA-IT- Travelport Italia SRL",
    "20959": "TELECOM-ITALIA-DATA-COM Telecom Italia S.p.A.",
    "20960": "TKTELEKOM- TK Telekom sp. z o.o.",
    "20961": "PTCNET- PT CENTRALA Sp. z o.o.",
    "20962": "OTE- Ote SA (Hellenic Telecommunications Organisation)",
    "20963": "VODAFONEFAROE- Vodafone",
    "20964": "SEAEXPRESS- SeaExpress Co. Ltd.",
    "20965": "GEANT The GEANT IP Service",
    "20967": "HALKBANK- TURKIYE HALKBANKI A.S.",
    "20968": "HEADLIGHT- Headlight Housing Factory GmbH",
    "20969": "NOB- Autonomous System of Technicolor NL (formerly NOB)",
    "20970": "INKAROBANK-JSCB- INKAROBANK JSCB",
    "20971": "INFOTECH- INFOTECH Ltd",
    "20972": "OFFICINE- Officine Informatiche Srl",
    "20973": "LIAM- Liam Telecommunications Autonomous System Number",
    "20974": "EGGENET EWE TEL GmbH",
    "20975": "CAJANFERNANDO- CAJA SAN FERNANDO",
    "20976": "HOTLINKS- Domainmaster Ltd.",
    "20977": "SGI- MTS OJSC",
    "20978": "AVEA-TELEKOMUNIKYON AVEA Iletisim Hizmetleri A.S.",
    "20979": "OLVI- TOV Olvi",
    "20980": "GEMA- GEMA Gesellschaft fuer musikalische Auffuehrungs- und Mechanische Vervielfaeltigungsrechte",
    "20981": "INNOVAPUGLIA InnovaPuglia SpA Autonomous System",
    "20983": "PZU-CL- PZU-CL Agent Transferowy S.A.",
    "20984": "PANALPINA- Panalpina Welttransport (Holding) AG",
    "20985": "ARTX- ArtX CJSC",
    "20986": "AOL- Atlantic Online  for use in interconnecting to other ISPs in the",
    "20988": "SHLINK-CH- my-ch.net  Autonomous System",
    "20989": "ISE- ISE Netsolutions- Carphone Warehouse",
    "20990": "DKB-LONDON- Commerzbank Aktiengesellschaft",
    "20991": "DKB-FRANKFURT- Commerzbank Aktiengesellschaft",
    "20992": "IDP- IDP s.n.c. di Repetto Davide e Magnone Paolo",
    "20993": "VIVELAVIE- Publicom S.r.l.",
    "20994": "ACTIMAGE Actimage Consulting S",
    "20995": "WESTLB-AUTONOMOUS-SYSTEM WESTLB- Autonomous System",
    "20997": "PEACOCK- Peacock Autonomous System",
    "20998": "SDL- SDL International PLC",
    "20999": "MAGNITUDE- MAGNITUDE Autonomous System",
    "21000": "ATOS- ATOS Origin Infogerance",
    "21002": "BILGISAYAR- Servus Bilgisayar",
    "21003": "GPTC-",
    "21004": "EXTEL-II- CJSC Express TeleCom",
    "21005": "COMDIRECT- Comdirect  for announcing own routes",
    "21006": "PDR- Services Network Presidenza Repubblica Italiana",
    "21007": "DIGICOM DigiCom Systems S.R.L.",
    "21008": "COMLINK- Comlink Ltd",
    "21009": "IUF- Internet Users Foundation",
    "21010": "KGHM- KGHM Autonomous System",
    "21011": "TOPNET \"TOP NET\" PJSC",
    "21013": "ITANDTEL-  ITandTel",
    "21014": "GRTN- Terna S.p.A.",
    "21015": "N-AIAF AIAF Sistemas y Servicios SA Autonomous System",
    "21016": "TCLV- Telecentrs Internet Service Autonomous System",
    "21017": "VSI- OJSC Rostelecom",
    "21018": "SOGETEL- Autonomous System for Sogetel",
    "21019": "SRO-SK- S.A. s.r.o",
    "21020": "DIAP Dagestan Ministry of Economics Department of Information-Analytical Providing",
    "21021": "MULTIMEDIA- Multimedia Polska S.A.",
    "21022": "COMMUNAUTE-URBAINE-DE-NANTES Collectivites territoriales de",
    "21023": "UPB- Joint Stock Company Ural Industrial Bank",
    "21024": "NEWTRON-NETWORK Newtron AG",
    "21025": "RGA- RGA SEGUROS",
    "21026": "ATOS-ESSEN- Atos Information Technology GmbH",
    "21027": "N-PARADORES PARADORES DE TURISMO DE ESPANA SA",
    "21029": "KHRSA Kharkiv Regional State Administration",
    "21031": "ELNETA- UAB Elneta",
    "21032": "TELTA- TELTA Citynetz GmbH",
    "21033": "ESSILOR ESSILOR International SA",
    "21034": "MICSO-SRL- Micso S.r.l.",
    "21035": "OIC SIA Ogres Interneta Centrs",
    "21038": "LINEPRO Line Informatica Profesional S.L.",
    "21039": "STEWEAG Steweag-Steg GmbH",
    "21040": "DATAPARK Datapark AG",
    "21042": "GULFSAT- Gulfsat Autonomous System",
    "21044": "VIZZAVI-DE- Vodafone Content Services Germany Autonomous System",
    "21045": "QNETCZ QNET CZ s.r.o.",
    "21046": "LIVINGSYSTEM- Living Systems autonomous system",
    "21047": "DEUTSCHE-BANK-SUISSE- Deutsche Bank (Suisse) SA",
    "21048": "COUNTRYCOM-SPB JSC CountryCom",
    "21049": "TELEBORSA- Teleborsa S.p.A.",
    "21050": "FT-TELCO Fast Telecommunications Company W.L.L.",
    "21051": "NIVAL- Limited liability company Mail.Ru",
    "21053": "BOSCH-REXROTH- Bosch Rexroth AG",
    "21054": "RBSG-UK- RBSG Internet operations",
    "21055": "WEBTAPESTRY- Axamba Limited T/As Web Tapestry",
    "21056": "N-WELCOMEITALIA Welcome Italia S.p.A.",
    "21057": "OVERON-SPAIN- Servicios Audiovisuales Overon S.L.",
    "21058": "N-MEDIAONLINE MEDIA.IT s.r.l",
    "21059": "BKG- RFT kabel Nord GmbH",
    "21060": "N-ATEA-DK Atea A/S",
    "21061": "TELEKOMUNIKACIJU-GRUPA Telegrupa Baltija SIA",
    "21062": "ANITEX- Anitex Ltd",
    "21063": "RANTZAU-GRUPPE- Rantzau Gruppe",
    "21064": "OLMAN-COM- OLMAN, Metropolitan Area Network (commercial )",
    "21065": "BGTELECOM BG Telecom Autonomus system",
    "21067": "GLOBECT GlobeCast Asia",
    "21068": "IE-NET- Image Electronics Autonomous System",
    "21069": "N-METANET METANET AG, Switzerland",
    "21070": "TOTAL Total S.A.",
    "21071": "GLOBALACCESS- N for Global Access in Cote d'Ivoire",
    "21072": "MAGNET- Magnet Enterprises",
    "21073": "ZORANET- Zoranet Autonomous System",
    "21074": "N-BANCAROMA Banca di Roma",
    "21075": "FOTAKOM- PRIVATE JOINT STOCK COMPANY \"DATAGROUP\"",
    "21076": "BTA-LTD-UK BTA Limited",
    "21077": "ISP4B ISP4Business",
    "21078": "OOEFERNG-AT OOE Ferngas AG",
    "21079": "OEKB- Oesterreichische Kontrollbank Aktiengesellschaft",
    "21080": "PRONEXON-SA pronexon GmbH",
    "21081": "HAVELSAN- Havelsan",
    "21082": "NEWS-MEDIA- Demos-Internet CJSC",
    "21083": "_NIX N-IX - Nuernberger Internet eXchange",
    "21084": "GELIRLER- Gelir Idaresi Baskanligi (GIB)",
    "21086": "MYCOM-IT TeleMedia.net srl",
    "21087": "ELCITY- Electronniy gorod, Ltd.",
    "21088": "FARAH- Farah Trading & Contracting Co.",
    "21089": "TELEWIFI TELEWIFI S.L.",
    "21090": "TELEFONIJA-RS- Telefonija Banjaluka",
    "21091": "DRAKKEN- Part of Mistral Internet",
    "21092": "ATLANTEL_MULTIMEDIA Alienor.Net",
    "21093": "FR-BOUYGUES Bouygues Telecom S.A.",
    "21094": "FR-EUROSPORT EUROSPORT SA",
    "21095": "AULAVIA- Directivosnet S.L.",
    "21096": "DSTSIP- Department of Support of State Service of Special Communication and Information Protection of Ukraine",
    "21099": "GAMEGROUP-UK- Game Stores Group Ltd",
    "21100": "ITLVOIP ITL Company",
    "21101": "SISTEMIUNO- Sistemi Hardware&Software S.P.A.",
    "21102": "N-MERKURAG Valora AG",
    "21103": "PRIMTEL- MTS OJSC",
    "21104": "AM-NETSYS- Netsys JV LLC",
    "21105": "RTK-PRIMORYE RTK-Primorye",
    "21106": "SOLNET- JSC \"AKADO-Stolitsa\"",
    "21107": "BLICNET- Blicnet d.o.o.",
    "21108": "SIEMENS-BELGIUM- SIEMENS AG",
    "21109": "CONTACT- Contact Company Autonomous System",
    "21110": "LADBROKES-UK LADBROKES IT & SHARED SERVICES LIMITED",
    "21111": "CISG Ministerstwo Gospodarki",
    "21112": "URB Ukrainian Reserve Bank, Kiev, Ukraine",
    "21113": "HILTI- HILTI AG",
    "21114": "ACCECO-NET- ACCECO.NET Autonomous System",
    "21115": "-NESTLE Nestle' Italiana s.p.a",
    "21117": "XROM-2000-IMPEX XROM 2000 IMPEX S.R.L.",
    "21118": "TFEGPOWER Total S.A.",
    "21119": "WAN-NO Braathe Gruppen",
    "21120": "BUSYINTERNET- Autonomous System Number for BusyInternet, Ghana",
    "21121": "ALTEC- Autonomous System Number for ALTEC, Ghana",
    "21122": "N-APPLICABLE Applicable Ltd",
    "21123": "INCENTI SECO Poland S.A.",
    "21124": "ATRILA-ANYCT AtrilA GmbH",
    "21125": "EMPERION- Emperion Autonomous System",
    "21127": "ZSTTK JSC \"Zap-Sib TransTeleCom\", Novosibirsk",
    "21129": "DEUROMEDIA Deuromedia S.R.L.",
    "21130": "EQSN Iomart",
    "21131": "SACURA- TOV \"Unitrade Pro\" aka Sacura",
    "21132": "KORBANK- Korbank sp. z o.o.",
    "21133": "NETONCOURSE- Invoke Solutions IL Ltd",
    "21134": "N-DATAMNG-RA Software products, P services",
    "21135": "MTT- MTT  (Russia)",
    "21136": "CSUCS- Csucs-Hu Informatika Kereskedelmi es Szolgaltato Ltd",
    "21137": "FR-CAI Credit Agricole Corporate and Investment Bank",
    "21138": "IMPOSSIBLE- Impossible Software GmbH",
    "21139": "SONYITE  will be used for SONY INFORMATION TECHNOLOGY",
    "21140": "N-SULZERTEXT Sulzer Textil",
    "21142": "PRAGONET-TRANSIT- T-Systems Czech Republic a.s.",
    "21143": "TULSUISP an Autonomous System for Tula State University located",
    "21144": "TELECONTRACT- Autonomous System Number for Telco Zimbabwe, Zimbabwe",
    "21145": "COMSOLVINGS-MNT COMSOLVINGS",
    "21146": "EYSSEN- Sunbooks Ltd.",
    "21147": "IF-NOC- If P&C Insurance",
    "21150": "INACDE-ATOS Atos IT Solutions and Services GmbH",
    "21151": "UKRCOM-KHERSON Ukrcom Ltd",
    "21152": "SOFICOM-  for the uplinks of Soficom",
    "21153": "INGNL ING",
    "21155": "N-PROSERVE ProServe B.V.",
    "21156": "DATAGRUPA SIA \"Datagrupa.lv\"",
    "21157": "SYSCO SYSCO SRL",
    "21158": "AN-MSD msd.net",
    "21159": "IAF- Internet Access Facilities BV",
    "21160": "N-MARKEL Markel International Services Ltd",
    "21161": "N-BECHTLE Bechtle AG",
    "21162": "ISM-HOSTING Innovative Solutions in Media (ISM) B.V.",
    "21166": "21166 SatGate LLC",
    "21168": "HELEX-RP-2 HELEX-RP-2",
    "21169": "POLCARD- First Data Polska S.A.",
    "21170": "N-SIMCOM Simbirsk Communcations LLC , Ulyanovsk",
    "21171": "SCHIBSTED Schibsted A Autonomous system, Oslo, Norway",
    "21173": "N-LANTANA Network of LANtana GmbH, Germany, Ahrensburg",
    "21174": "RWANDATEL- Autonomous System Number for RWANDATEL, Rwanda",
    "21175": "WIS WIS Telecom SA",
    "21176": "N-SEMA Engineering IT S.p.A.",
    "21177": "UKLINUX Uklinux Ltd",
    "21178": "LFDATI LF Dati SIA",
    "21179": "LOGWIN- Logwin AG",
    "21180": "AVENTIS-CROP-SCIENCE Aventis CropScience",
    "21181": "SOCIEDAD-DE-TACION- Sociedad Tasacion",
    "21182": "OPOLMAN--EDU Opole University",
    "21183": "ABCOM- ABCOM Shpk",
    "21184": "FARPOST Farpost Int.",
    "21185": "MEGABET- MEGABET LTD",
    "21186": "MTI-1- MTI-1",
    "21187": "ABCDATA-POLAND- ABC Data SA",
    "21188": "UNILEVER-ES-UK Unilever PLC",
    "21189": "MAKEEVKA Makeevka Online Ltd",
    "21190": "ALPIQ-AG-SWITZERLAND Alpiq AG",
    "21191": "N-SEVERTTK Closed Joint Stock Company \"SeverTransTeleCom\"",
    "21192": "DPA- dpa Deutsche Presse-Agentur GmbH",
    "21193": "XARXA- Centre de Telecomuncaciones i Tecnologies de la Informacias de la Generalitat de Catalunya",
    "21194": "UNI-NET Universal Network LTD",
    "21195": "DGCSYSTEMS DGC Access AB",
    "21196": "EPN-BA- europroNET Bosnia Autonomus System",
    "21197": "ROHDE-SCHWARZ-N Rohde & Schwarz GmbH & Co. KG",
    "21198": "JESSENLENZ- JessenLenz GmbH",
    "21199": "SEAT- Seat Pagine Gialle SPA - Autonomous System",
    "21200": "SKANDIABANKEN Skandia Informationsteknologi AB",
    "21201": "NETFONDS- Netfonds Bank A, Oslo, Norway",
    "21202": "DCSNET- Bredband2 AB",
    "21203": "FR-CMA-CGM FR-CMA-CGM",
    "21205": "INGBANK ING WholeSale Bank",
    "21206": "UK-POLARCOMPUTERCOMM Polar Computer Communications Limited",
    "21207": "RWE RWE IT GmbH",
    "21208": "YOUNG-AND-RUBICAM YOUNG AND RUBICAM SL",
    "21209": "MKB MKB Uzemeltetesi Kft.",
    "21210": "INFOMONITOR Biuro Informacji Gospodarczej InfoMonitor S.A.",
    "21211": "SKY-NET- Penkiu kontinentu komunikaciju centras, Ltd.",
    "21213": "CYBERSERVICE-AT CYBERSERVICE Internetdienstleistungs GmbH",
    "21214": "GEONET- Geonet Ltd.",
    "21215": "ABSOLUTOK AbsolutOK NET, Belgrade, SRB",
    "21216": "IT-PORTALS-JELGAVA SIA \"IT PORTALS\"",
    "21217": "SAFEHOSTNET Safe Host SA",
    "21218": "SMARTWAYS Smartways Autonomous System",
    "21219": "DATAGROUP PRIVATE JOINT STOCK COMPANY \"DATAGROUP\"",
    "21220": "TELEMOBIL Telemobil S.A.",
    "21221": "INFOPACT- InfoPact Netwerkdiensten B.V.",
    "21222": "N-ROLEX Rolex Autonomous System",
    "21223": "CARREFOUR- Carrefour",
    "21224": "ROMSAT Romsat Cable TV & Radio S.A.",
    "21225": "AMTKOM- Autonomus System",
    "21226": "RU-4NET Krasnoyarsk PTUS",
    "21227": "OLIKA OLiKA Networks",
    "21228": "VINTERISK- PP \"Vinasterisk\"",
    "21229": "DRAVANET- Dravanet Co Ltd.",
    "21230": "MNET-BG M SAT Cable SA",
    "21231": "AEROFLOT AEROFLOT's Autonomous System",
    "21232": "GGAMAUR GGA Maur",
    "21233": "N-C2INTERNET C2 Direct Transit",
    "21234": "GRENKE-SERVICE-AG GRENKE Service AG",
    "21235": "ADVANCED-SYSTEMHAUS Advanced Systemhaus GmbH",
    "21236": "AICHYNA- Additional Liability Company Aichyna Plus",
    "21237": "-WDC-EUROPE Western Digital Netherlands B.V",
    "21239": "DNS-BELGIUM DNS-Belgium",
    "21240": "HELIOSNET- JSC Web Media Services",
    "21241": "MUZO- Global Payments Europe, s.r.o.",
    "21242": "AFRITEL-",
    "21243": "PLUSNET Polkomtel Sp. z o.o.",
    "21244": "WARSAW-DATA-CENTER- Warsaw Data Center Sp. z o.o.",
    "21245": "NETSA- NETSA INTERNET HIZMETLERI IC VE DIS TICARET LIMITED SIRKETI",
    "21246": "IPKO- Ipko Telecommunications LLC",
    "21247": "IPSYN- IP SYNERGIES",
    "21248": "TDM- N for Telecommunication of Mozambique in Mozambique",
    "21249": "RUTIL-BG- Rutil Ltd.",
    "21250": "TYFON Tyfon Svenska AB - Sweden",
    "21251": "KINETIC-CENTRE Kinetic Business Autonomous System",
    "21252": "NIKOIL- NIKOil Autonomous System",
    "21253": "SWISSWEB- SwissWeb AG",
    "21254": "CTM-N Citco's N for European Peering",
    "21255": "N-VGTK JSC Volgotelcom, ISP, Volgograd",
    "21256": "VIZOR- Enterprise Vizor",
    "21257": "IT-PARK- TOV IT-PARK",
    "21258": "PSEINFO PSE-Info Autonomus System",
    "21259": "BBP Bonnier Business (Polska) Sp. z o.o.",
    "21260": "POSITIVE-INTERNET-UK- The Positive Internet Company Ltd",
    "21261": "STELS Stels ISP Ltd",
    "21262": "DLIGHT- D-Light GmbH",
    "21263": "TELEDATA- TeleData GmbH",
    "21266": "EESNET- MTCES Autonomous System",
    "21267": "IZR- Wavenet Limited",
    "21268": "IPF IP Fjarskipti ehf",
    "21269": "PROGON Progon Network Engineering - C. Wittenhorst",
    "21270": "RTELEKOM- RATMIR-TeleKom Ltd",
    "21271": "SOTELMABGP",
    "21272": "DANONE-GROUP DANONE SA",
    "21273": "TEST--CUST Swisscom (Switzerland) Ltd",
    "21274": "B-NET- State Scientific Enterprise 'United Institute of Informatics Problems of National Academy of Sciences of Belarus' (UIIP NB)",
    "21275": "KOMPANIYA-METALLINVEST- Kompaniya Metallinvest Ltd.",
    "21276": "STORTEXT-UK- Stortext Ltd",
    "21277": "NWRZ Newroz Telecom Ltd.  Number",
    "21278": "GECOS- General Computing Systems",
    "21280": "SWIFTGLOBAL-",
    "21282": "KAZNIC-  of KazNIC Organization",
    "21283": "SIMOBIL- SI.MOBIL D.D.",
    "21284": "VIVODI- ON S.A.",
    "21285": "TELEKOM2-AT A1 Telekom Austria AG",
    "21286": "GETRONICS- KPN Corporate Market B.V.",
    "21287": "ITN- Closed Joint-Stock Company \"Integration of Communication\"",
    "21288": "SPRINTNET \"SPRINT\" S.A.",
    "21289": "ROSTOVTELECOM- JSC RostovTelecom Autonomous System JSC RostovTelecom Rostov-on-Don, Russia",
    "21291": "OMEGABANK Proton Bank SA",
    "21292": "-ALKARIA Alkaria - Italy",
    "21293": "N-NRK NRK Autonomous System",
    "21294": "IDILIS Idilis SRL",
    "21296": "N-PWC-UK Pricewaterhouse Coopers Services Ltd",
    "21297": "OSE- Oslo Bors A",
    "21298": "IHOUSE- Republican Fund 'Mordovia-Internet'",
    "21299": "ORBITA-PLUS- ORBITA-PLUS Autonomous System",
    "21300": "ACCESSNET SC AccessNet International SRL",
    "21301": "RBS-FM- Royal Bank of Scotland plc",
    "21302": "FT-PATH-E Fast Path Backbone E",
    "21303": "LEMON42 Lemon42 IT, Web und Software AG",
    "21304": "CARREFOUR Carrefour Organisation et Systemes Groupe",
    "21305": "IPTEL- IP TelCom Ltd.",
    "21307": "EPICLINK Ex-Epiclink S.p.A.",
    "21309": "CAWEB- ACANTHO SPA",
    "21310": "N-SATELLITE ISP Satellite",
    "21311": "N-KRAFTSVIAZ Kraftsviaz-Novosibirsk Autonomous System",
    "21312": "CHEREDA-SM- GRYGORIY CHEREDA",
    "21313": "N-GNR VeriSign Inc.",
    "21314": "MULTIKABEL Ziggo B.V.",
    "21315": "ENNE-SOLUTIONS ENNE Solutions B.V.",
    "21316": "NEXT-COMPUTER Next-Computer SRl",
    "21318": "VAGSOYKOMMUNE Norwegian Open Peering Initiative",
    "21320": "EUMEDCONNECT DANTE Ltd",
    "21321": "ARETI- Areti Internet Ltd.",
    "21322": "ICGNET- ICGNET",
    "21323": "ERSTEBANK Erste & Steiermarkische Bank d.d., Rijeka, Croatia",
    "21324": "OSW Osrodek Studiow Wschodnich im Marka Karpia",
    "21325": "TNA Tiesu Namu Agentura, V",
    "21326": "OPENNET-SA OpenNet-Service-",
    "21327": "H3GUKNIE Hutchison 3G UK and Ireland Core",
    "21328": "NBP- National Bank of Poland",
    "21330": "AVE- TOV GORILLA",
    "21331": "OKDN- Oslo kommune, Utviklings- og kompetanseetaten",
    "21332": "NTC- OJSC \"Vimpelcom\"",
    "21333": "INVA- IN.VA.'s Autonomous System",
    "21334": "N-VODAFONE-HU VODAFONE-HU Vodafone Hungary Ltd.",
    "21335": "DIGITONESPB- CJSC \"WEST CALL LTD\"",
    "21336": "INFORENT- INFORENT Autonomous System Area",
    "21337": "UBBNET United Bulgarian Bank AD",
    "21338": "NORD-VOSTOK- PrivateJSC DataGroup",
    "21339": "CONTINGENCYNETWORKS Contingency Networks Limited",
    "21340": "GPS-BIROTIC GPS Birotic SRL",
    "21341": "SINET- Soroush Rasanheh Company Ltd",
    "21342": "AKAMAI-N2 Akamai International B.V.",
    "21343": "ALLIED \"Allied Standart Limited\" LLC",
    "21344": "INTELIGO Inteligo Financial Services S.A.",
    "21345": "MESSAGELABS-EU MessageLabs",
    "21346": "VISTORM- Vistorm Limited",
    "21348": "KOPTERIFI KOPTERIFI is autonomous system. Located in Vammala Finland",
    "21350": "INTERSPACE- INTERSPACE LTD. Autonomous System",
    "21351": "MEDIERV Mediaserv",
    "21352": "NETMOBILE Net Mobile AG",
    "21353": "ARTCOMS- PRESTIGE-INTERNET LTD",
    "21354": "S-NET- TELECOMCITY Ltd.",
    "21355": "DBH- dbh Logistics IT AG",
    "21356": "XCHANGEPOINTMLP GTT - EMEA Ltd.",
    "21357": "AKAMAI-MAPPING Akamai International B.V.",
    "21358": "ATOS-ORIGIN-DE- Atos Information Technology GmbH",
    "21359": "PAGIN-AMAREL- Paginas Amarelas",
    "21360": "EMPIRION Empirion Telekommunikations Services GmbH",
    "21361": "WPP- WPP 2005 Limited",
    "21362": "KBC-EDS Kapsch BusinessCom AG",
    "21363": "ORBOGRAPH- Orbograph Ltd.",
    "21364": "LANTIK- Lantik S.A.",
    "21365": "INTELECA- MTS OJSC",
    "21366": "KYMP KYMP OY",
    "21367": "ZVEZDATEL- Zvezda Telecom ltd.",
    "21368": "BSCH- Operaciones Internet BSCH",
    "21369": "SEMA-UK- Atos IT Services UK Ltd",
    "21370": "ETEL-N Elis Telecom Ltd",
    "21371": "EQUINIX-UK-N Equinix Limited",
    "21372": "TELEHOUSE- Open Joint Stock Company TeleHouse",
    "21373": "NBB- National Bank of Belgium Autonomous System",
    "21374": "ALICE-UA- Private company Alice",
    "21375": "BNPP- Balakovo NPP",
    "21376": "VEKTOR TRK Vektor Ltd.",
    "21378": "CTCTVER OJSC Rostelecom",
    "21379": "ISV- LLC TC \"Interzvyazok\"",
    "21381": "NETLOCK- NETLOCK Internet Security Ltd.",
    "21382": "GEZ- Gebuhreneinzudszentrale der offentlich-rechtlichen Rundfunkanstalten in der Bundesrepublik Deutschland",
    "21383": "LSIBNET-RU PE Alexander Yakimov",
    "21385": "TNIB Trusted Network GmbH",
    "21387": "IAP IAP Ingenieurbuero fuer Anwendungs-Programmierung GmbH",
    "21388": "INSP- ClubMessage B.V.",
    "21389": "TRIMM-NET Trimm Multimedia BV",
    "21390": "BESTNETWORK- Bestnet Ltd.",
    "21391": "TDA-",
    "21392": "MUNTINET- MuntInternet Networks B.V.",
    "21393": "APSS- Six Card Solutions Austria GmbH",
    "21395": "TPNET Telekomunikacja Polska S.A. (TPI)",
    "21396": "NETCONNEX NetConnex Broadband Ltd.",
    "21399": "AKAMAI3 Akamai International B.V.",
    "21400": "SATLIGHT FE \"ALTERNATIVNAYA ZIFROVAYA SET\"",
    "21401": "BORZEN- Borzen d.o.o.",
    "21403": "INTERTRANSACT- Intertransact member-of:",
    "21404": "ZETOSA- ZETO S.A. Tarnow",
    "21405": "TSS1 T-Systems (Schweiz) AG",
    "21406": "SWAROVSKI- D Swarovski KG",
    "21407": "INGRAM- Ingram Micro SL",
    "21408": "N-MAE Ministry for foreign Affairs",
    "21409": "IKOULA Ikoula Net S",
    "21410": "LINKPARDAZ Pardaz Gostar Ertebatat Berelian Limited Liability Company",
    "21411": "ITERA-NET-UA ITERA.NET.UA Ltd",
    "21412": "CGATES- UAB \"Cgates\"",
    "21413": "ENVIA-TEL- envia Tel GmbH",
    "21414": "RUSCOMNET- RusComNet Ltd.",
    "21415": "INTERNETGROUP--BG Internet Group Ltd.",
    "21416": "TCINET- CJSC Technical Center Internet",
    "21418": "HARVESTR- Harvestr Ltd.",
    "21419": "PISHTAZEJADIDINFOMRATION PISHTAZE E JADID INFOMRATION COMPANY (Ltd.)",
    "21420": "SWEDBANK Swedbank, AB",
    "21421": "ECLINSO ECLINSO AG",
    "21422": "CONNECT-LIVERPOOL Connect internet Solutions Limited",
    "21423": "KOMAX-HOLDING- Komax AG",
    "21424": "ING-BELGIUM ING Belgique SA",
    "21426": "ACER-EUROPE Acer Computer GmbH",
    "21427": "RADIANZ-ES- RADIANZ NETWORK IN SPAIN",
    "21429": "SICOB Sicob S.r.l.",
    "21430": "WIA- WIA spol. s.r.o.",
    "21432": "AVAL PAT \"Raiffeisen Bank Aval\"",
    "21433": "ACCENTUREFSSC Accenture UK Limited",
    "21434": "CLARIANT CLARIANT-B2B",
    "21435": "BROADNET-CZ Broadnet Czech, Prague",
    "21436": "ALMANID almanid group GmbH",
    "21437": "AVITI- Aviti ltd.",
    "21438": "ECOM-KALUGA- ZAO ELECTRO-COM KALUGA",
    "21439": "MORGAN-STANLEY Morgan Stanley & Co. International PLC",
    "21441": "LJSE- Ljubljanska borza d.d.",
    "21442": "MEGATELECOM- JSC Megapolis-Telecom",
    "21443": "AGNS-CH AGNS-CH Autonomous System",
    "21444": "INFRACOM- INFRACOM  for announcing own prefixes",
    "21446": "21446 VPK-Telecom",
    "21448": "MWIL Netserve Consultants Ltd",
    "21449": "ETATGE ETAT DE GENEVE",
    "21450": "MIRS- Mirs Communications Ltd.",
    "21451": "SELLA- Banca Sella S.p.A.",
    "21452": "SKANNET-IBADAN SKANNET IP Network",
    "21453": "FLEX- Flex Ltd",
    "21454": "ENET- EYNET SrL",
    "21456": "KVADRAT-DK Kvadrat Denmark A/S located at Lundbergsvej 10 DK-8400 Ebeltoft",
    "21457": "NLINE- NETLINE Srl",
    "21458": "KFW- KfW Kreditanstalt fur Wiederaufbau",
    "21459": "GNSEUROPEUK- Advanced 365 LTD",
    "21460": "MOVYS- Movys a.s.",
    "21461": "TRANSFAIRNET Transfair-net GmbH",
    "21462": "TERRALINK- TERRALINK SRL",
    "21464": "EDF- EDF Trading",
    "21465": "EUROPAEISKE- Europaeiske IT",
    "21466": "QUICKNET This  belongs to the Cablenetwork Quicknet of",
    "21467": "MECOM- Medien Communications Gesellschaft mbH",
    "21468": "ES-PROTEL Promocion y Planificacion Hotelera S.A",
    "21469": "CREDEM- Credito Emiliano S.p.A.",
    "21470": "SWISP- South West Communications Group Ltd",
    "21471": "N-FERRANIA Ferrania Technologies S.P.A",
    "21472": "SERVERHOUSE- ServerHouse Ltd",
    "21473": "MANET- MAnet Autonomous System Number",
    "21474": "SD-WORX SD WORX vzw",
    "21475": "GLOBALLVIV-NET ISP TiMax",
    "21476": "N-ACDC all-connect Data Communications GmbH",
    "21477": "PRESIDENCY Administratia Prezidentiala",
    "21478": "PLEX Plex N",
    "21479": "ROSTOV-TELEGRAF- The branch \"Rostovelectrosviaz\" of Public Joint Stock Company \"Southern Telecommunications Company\"",
    "21480": "WBT- JSC WestBalt Telecom",
    "21483": "TEL- OJSC \"Vimpelcom\"",
    "21484": "BT Global Services Luxembourg S.a.r.l",
    "21485": "APDL- Administracao dos Portos do Douro e Leixoes",
    "21486": "NDS- NDS Israel Technologies Ltd",
    "21487": "SAKHATELECOM- OJSC Rostelecom",
    "21488": "EMPLOT- Emplot Ltd.",
    "21489": "SHAPE- NATO Consultation, Command and Control Agency (NC3A)",
    "21490": "EVLI-BANK- Evli Pankki Oyj",
    "21491": "UGANDA-TELECOM Uganda Telecom",
    "21492": "MNX- O. Paulzen",
    "21493": "PKXGEU GTT - EMEA Ltd.",
    "21494": "GREEN green.ch AG",
    "21495": "PZUCI- Centrum Informatyki Grupy PZU S.A.",
    "21496": "KRTELECOM- Company Krastelekom Ltd.",
    "21497": "UMC- PrJSC \"MTS UKRAINE\"",
    "21498": "SEPEPNV SEPEPNV Autonomous System",
    "21499": "IMS- internet24 GmbH",
    "21500": "TNS- Scientific Production Enterprise \"Technaukservice\" Ltd",
    "21501": "MAINLAB- Autonomous System Mainlab GmbH, Germany",
    "21502": "N-NUMERICABLE NUMERICABLE is a cable network operator in France, offering TV,VOICE and Internet services",
    "21503": "ARETE- Phonera Networks AB",
    "21505": "EXENET- - Exenet Technologies, Inc.",
    "21506": "Funda\u00e7\u00e3o Universidade de Bras\u00edlia",
    "21507": "HTINGS - Hastings Entertainment Inc.",
    "21508": "COMCT-21508 - Comcast Cable Communications Holdings, Inc",
    "21509": "APOLLONYC - Apollo Management, L.P.",
    "21510": "TRISTAR - Tristar Communications",
    "21511": "NCSBN - NCSBN, Inc.",
    "21512": "UNITYHS- - Unity Health System",
    "21513": "EPIKNETWORKS - Epik Networks, Inc.",
    "21514": "LEGACY - LEGACY MARKETING PARTNERS, L.L.C.",
    "21515": "NET-SISQTEL-NET1 - SISKIYOU TELEPHONE COMPANY",
    "21516": "ECH-2 - Ephrata Community Hospital",
    "21517": "TECHSPACE-95-MORTON - TECHSPACE INC.",
    "21518": "INTEGRIS-HEALTH - INTEGRIS Health",
    "21519": "FISHERCOMM - Fisher Communications",
    "21520": "Instituto Tecnologico Autonomo de Mexico(ITAM)",
    "21521": "BANCTEC - BancTec, Inc.",
    "21522": "ROADRUNNER-MNPLS - Time Warner Cable Internet LLC",
    "21523": "LEENET - LeaseNet, Inc.",
    "21524": "PB - Parsons Brinckerhoff Inc.",
    "21525": "-SPL - Seattle Public Library",
    "21526": "NETGATEWAY-1 - Netgateway, Inc.",
    "21527": "DAYSTARR-NET - Daystarr Communications",
    "21528": "ALCONNECTINC - AlasConnect Inc.",
    "21529": "CDC-AMN - CDC.NET",
    "21530": "EPSIIA-HEPSIIAN - EPSIIA Corporation",
    "21531": "CTUSA-NET - Multiband",
    "21532": "WC-MN-MPLS-POP - Warner Connect",
    "21535": "MCGSE - Management Compensation Group/Southeast, LLC",
    "21536": "MILLENNIUM-PHARMACY-SYSTEMS - Millennium Pharmacy Systems, Inc.",
    "21537": "MBPPALOALTO - Mayer, Brown & Platt",
    "21538": "IGWAN-BL- - IGWAN.NET",
    "21539": "VONAGE - Vonage Holdings, Inc.",
    "21540": "LEWIS-ROCALLP - Lewis and Roca LLP",
    "21541": "101NETLINK - 101Netlink",
    "21542": "ENERGYSERVICESGROUP - Energy Services Group",
    "21543": "RITEAID - Rite Aid Corporation",
    "21544": "THESYS-1 - Thesys Technologies, LLC",
    "21545": "KCOENET - Kings County Office of Education",
    "21546": "TROUTMANSANDERSRICHMOND - TROUTMAN SANDERS",
    "21547": "OXNET - Oxford Networks",
    "21548": "MTO - MTO Telecom Inc.",
    "21549": "IRON-MOUNTAIN - Iron Mountain Inc",
    "21550": "THEWORLD-1 - Software Tool & Die, The World",
    "21551": "HIGHBRIDGENY - Highbridge Capital Management, LLC.",
    "21552": "2141471-ONTARIO-ABOUT-COMMUNICATIONS - About Communications",
    "21553": "HENEGAN - Henegan Construction Co., Inc.",
    "21554": "CYBERLYNK - Wisconsin CyberLynk Network, Inc.",
    "21555": "LHTC - LAUREL HIGHLAND TELEPHONE COMPANY",
    "21556": "NARC-EROOT - NA Ames Research Center",
    "21557": "CYB-BLK-1 - Cybernet Communications, Inc.",
    "21558": "SC-JOHNSON - S.C. Johnson & Son, Inc.",
    "21559": "OSNET - OSNET Wireless",
    "21560": "NETSTREAM-COMMUNICATIONS - Netstream Communications, LLC",
    "21561": "LESSCHWABMO - Les Schwab Tire Centers",
    "21562": "IQUEST-LB - IQuest Internet",
    "21564": "NS-PROVINCIAL - Nova Scotia Provincial Government",
    "21565": "21565 - Horry Telephone Cooperative, Inc.",
    "21566": "OSIRISCOMM - Osiris Communications, Inc.",
    "21567": "MARKETRON - Maketron Broadcast Solutions, LLC",
    "21568": "NYTD - The New York Times Company",
    "21570": "ACI-1 - Accelerated Connections Inc.",
    "21571": "MLS Wireless S/A",
    "21572": "CPP-AMERIC - CPP, Inc.",
    "21573": "HEALTHPARTNERS - HealthPartners",
    "21574": "Century Telecom Ltda",
    "21575": "NEXTEL DEL PERU S.A.",
    "21576": "DCCA-WALLINGFORD-DATA-CENTER - Dell Marketing L.P.",
    "21577": "TOLEDOTELNET - TOLEDO TELEPHONE CO INC",
    "21578": "Universidad autonoma de Bucaramanga",
    "21579": "ACCESS2-OHIO - ACCESS",
    "21580": "CAL-NET-INC - Cal.net, Inc.",
    "21581": "M5HOSTING - M5 Computer Security",
    "21582": "NAU- - Northern Arizona University",
    "21583": "HOUSTON-COLO - Vonage Holdings, Inc.",
    "21584": "X2CLOUD-MAIN - X2Cloud, LLC",
    "21585": "DIGIS-21585 - JAB Wireless, INC.",
    "21586": "SWKO - SWKO - SouthWest Kansas Online",
    "21587": "SAI- - Salomon Analytics Inc",
    "21588": "SPOKEO - Spokeo, Inc",
    "21589": "CSJ-INTERNET - City of San Jose",
    "21590": "Telecom Argentina S.A.",
    "21591": "NSINOC-KC1 - NETSTANDARD INC",
    "21592": "MULTIVIEW - Multi-View Inc.",
    "21593": "ZANTAZ-US - Zantaz",
    "21594": "IBSA - Interstate Battery System of America Inc.",
    "21595": "BAXTER BAXTER SERVICES EUROPE SA",
    "21596": "AHCA - AHCA",
    "21597": "PEOPLESUPPORTCOM - PeopleSupport, Inc.",
    "21598": "DUKE-ENERGY-ENERGY - Duke Energy Corporation",
    "21599": "NETDIRECT S.A.",
    "21600": "LMR - Logistics Management Resources, Inc.",
    "21601": "WEBSOFT-NET - Websoft Publishing Company",
    "21602": "GIGLINX - Giglinx Inc.",
    "21603": "Universidad La Salle, AC",
    "21604": "CHEMONICS-USA - CHEMONICS INTERNATIONAL, INC.",
    "21606": "SUMMER-ROAD - Summer Road, LLC",
    "21607": "LRIP-US - WebHostingBuzz USA LLC",
    "21608": "HCSCNET10 - Blue Cross Blue Shield of Illinois or Blue Cross Blue Shield of Texas",
    "21611": "NET-WSGWIN - Wilson Sporting Goods Co.",
    "21612": "FUNDACAO INSTITUTO OSWALDO CRUZ",
    "21613": "CITYOFSANTAROSA - CITY OF SANTA ROSA",
    "21614": "LatLink.net S.A",
    "21615": "CEBRIDGE - Cebridge Connections",
    "21616": "NECA - National Exchange Carrier Association, Inc.",
    "21617": "NARA - National Archives and Records Administration",
    "21618": "DDI-DL - DISCUS DENTAL, INC",
    "21619": "GREYWOLF-CAPITAL - Greywolf Capital Management LP",
    "21620": "-AIRCLIC - AirClic Inc",
    "21621": "RESPONSYS-2 - Responsys Inc.",
    "21622": "PR-NEWSWIRE-USA-1 - PR Newswire",
    "21623": "SPACELINK - Spacelink Systems",
    "21625": "VODAFONEGROUP-GLOBAL - Vodafone",
    "21626": "DMPAYROLL - DM Payroll Services",
    "21627": "CSTC--2010 - CORNERSTONE TELEPHONE COMPANY, LLC",
    "21628": "TWRS-SEA - Towerstream I, Inc.",
    "21630": "PDS-NEWROADS - Promotions Distributor Services",
    "21631": "CHFA-COLORADO - Colorado Housing and Finance Authority",
    "21632": "CYBERNET1 - Cybernet1, Inc.",
    "21633": "DOI-NBC-NET - National Business Center Department of theInterior",
    "21634": "UNTAN-N1 - Untangle, Inc.",
    "21635": "WWCUSA - World Wide Communications USA Inc.",
    "21636": "PROMETRIC - Prometric, Inc.",
    "21637": "BROADBANDIP - Broadband IP, Inc.",
    "21638": "PRINCESS-COM - PRINCESS CRUISES",
    "21639": "BCBSLA-N - Blue Cross Blue Shield Of Louisiana",
    "21640": "GIGAFED- - National Research Council of Canada",
    "21641": "MBPHOUSTON - Mayer, Brown & Platt",
    "21642": "MBPWHDC - Mayer, Brown & Platt",
    "21643": "MBPNY - Mayer, Brown & Platt",
    "21644": "MBPLA - Mayer, Brown & Platt",
    "21645": "MBPCHARLOTTE - Mayer, Brown & Platt",
    "21646": "FISHER - Fisher Investments Inc.",
    "21647": "TARO-INTERNET-USA-1 - Taro Pharmaceuticals U.S.A., Inc.",
    "21648": "SNINET-1 - SageNet",
    "21649": "DC - DC Software Solutions",
    "21650": "WEST-INTERNET - West Corporation",
    "21651": "THRIVENTFINANCIAL - Thrivent Financial for Lutherans",
    "21652": "PWC - Pratt & Whitney Canada Corp.",
    "21653": "CIMCO3 - CIMCO Communications, Inc.",
    "21654": "WTSGR- - Wireless Technology Solutions of Grand Rapids, Inc.",
    "21655": "BTR - Blogtalkradio, Inc.",
    "21657": "LYCOM - Lycom Communications, Inc.",
    "21658": "TENN1 - TENSILICA, INC.",
    "21659": "BOLLINGER-SH-MTN-BGP - Bollinger, Inc.",
    "21660": "UBG-BUILDER-INC - UBG Builders Inc",
    "21661": "NEEBA - Neeba, Inc.",
    "21662": "VOICERUNNER-COM - Voice Runner, Inc.",
    "21663": "GETWELL-NETWORK - Get Well Network, Inc.",
    "21664": "TTSL-2 - Tora Trading Services, LLC",
    "21666": "OSFHEALTHCARE- - OSF Healthcare System",
    "21668": "ENET - ElbertonNet",
    "21669": "NJ-STATEWIDE-LIBRARY-NETWORK - New Jersey State Library",
    "21670": "AUDIBLE - Audible, Inc.",
    "21671": "MBHYDRO - Manitoba Hydro",
    "21672": "CES-HQPA-01 - Customized Energy Solutions, Ltd.",
    "21673": "NGMC-N - Northeast Georgia Medical Center",
    "21674": "WORLDCONNECTION INTERNET & TELECOMUNICA\u00c7\u00d5ES LTDA.",
    "21675": "METACARTA-MA - MetaCarta, Inc.",
    "21676": "GSIC-2 - GSI Commerce Solutions, Inc.",
    "21677": "DISTRIBUTEL - DISTRIBUTEL COMMUNICATIONS LTD.",
    "21678": "NEW-BREED - New Breed, Inc.",
    "21679": "SERVERSIDE-01 - Server Side, Inc.",
    "21680": "GWLNET - Great-West Life Assurance Company",
    "21681": "ANDOVER-TRADING - ANDOVER TRADING",
    "21682": "THELADDERS - TheLadders.com, Inc",
    "21683": "GREENLIGHT - Greenlight Business Solutions, LLC",
    "21684": "CYBERINETBGP - Cyberonics, Inc.",
    "21685": "OFFICESCAPE - Officescape, Inc.",
    "21686": "SYSTEMMETRICS-1 - SystemMetrics Corporation",
    "21687": "HVDN-ROUTING - HUDSON VALLEY DATANET, LLC",
    "21688": "GMP-METROCT - GMP Cable TV",
    "21689": "CVHP- - Citrus Valley Health Partners, Inc.",
    "21690": "MILESTECHINC - Miles Technologies Inc",
    "21691": "TMCC-2 - Toyota Motor Credit Corporation",
    "21692": "Secretar\u00eda de la Funci\u00f3n P\u00fablica",
    "21693": "XCEL-ENERGY - Xcel Energy Inc.",
    "21694": "FRESNOCOE - Fresno County Office of Education",
    "21696": "PER-SE - Per-Se Technologies",
    "21698": "GCG - Giovine Capital Group, LLC",
    "21699": "NHDS - New Hope-Solebury School District",
    "21700": "FRSL-3 - Flint River Services LLC.",
    "21701": "TRUVEN-HEALTH-ANALYTICS- - Solucient, LLC",
    "21702": "HADDAD - The Haddad Organization Ltd.",
    "21703": "NETWORKS-AND-MORE - Networks & More! Inc.",
    "21704": "NYCBOE-BGPNET - New York City Board of Education",
    "21705": "HOUDINI-WCGB - Houdini Inc.",
    "21706": "KHHTE - Kellogg, Huber, Hansen, Todd & Evans, PLLC",
    "21707": "EMHS - Endless Mountains Health Systems",
    "21708": "SDCOE - San Diego County Office of Education",
    "21709": "IMPLEX-NET - Implex.net, Inc.",
    "21710": "SLCHA - St. Lucie County - Automated Services",
    "21711": "PERRYJOHNSON-INCORP - Perry Johnson, Inc",
    "21712": "N-SJHC - CATHOLIC HEALTH INITIATIVES",
    "21713": "BULLOCH - Bulloch Telephone",
    "21714": "LFBGP01 - Lebhar-Friedman, Inc.",
    "21715": "NSPNET - Nature's Sunshine Products",
    "21716": "TRADOS-N01 - SDL International America, Inc.",
    "21717": "MCCANN-ERICKSON - McCann-Erickson Worldwide, Inc.",
    "21718": "NW-NATURAL-G - Northwest Natural Gas",
    "21719": "CHL - CHL",
    "21720": "VOCALOCITY - Vocalocity, Inc.",
    "21722": "QSS-NOTL- - Quick Service Software Inc.",
    "21723": "RADIANT-VAN2 - Radiant Communications Ltd.",
    "21724": "RADIANT-TORONTO - Radiant Communications Canada Ltd.",
    "21725": "BIGRIVER - Millington Telephone Company, Inc.",
    "21726": "RGTS-JFK - Rockefeller Group Technology Solutions, Inc.",
    "21727": "HAMLINE-EDU - Hamline University",
    "21728": "OCSNY - Optimized Computer Solutions, Inc",
    "21729": "CROWN-EQUIPMENT - Crown Equipment Corporation",
    "21730": "RRV-NET - Halstad Telephone Company",
    "21731": "HOMEDICS-COMMERCE - HoMedics USA Inc",
    "21732": "FLAVORUS-N - Flavorus Inc",
    "21733": "CHANNELLCOMMERCIALCORP - Channell Commercial Corp.",
    "21734": "TRADINGTECH-TTNET - Trading Technologies Intl, Inc.",
    "21735": "GANNETT5-NET - Gannett Co. Inc.",
    "21736": "GANNETT4-NET - Gannett Co. Inc.",
    "21737": "SPRINGNET2-NET - SpringNet",
    "21738": "WORLDSITES - Madison Internet Corp.",
    "21740": "ENOM1 - eNom, Incorporated",
    "21741": "Visualcorp Holding",
    "21742": "ELANY-NY-NET01 - ELANY",
    "21743": "ANL-36 - Atlas Networks LLC",
    "21744": "WESTSTAR - WestStar TV Ltd",
    "21745": "FSAFOOD - Food Services of America",
    "21746": "MANCON-COX-CAVALIER-FAILOVER - Mancon",
    "21747": "WINDSTREAM - Windstream Communications Inc",
    "21748": "SKYCOM1 - Pecquet, Adair, Freeland, Ober LLC",
    "21749": "MOLAM - Mitsui OSK Lines (America) Inc.",
    "21750": "CPOINT-NET-1 - Counterpoint Networking Inc.",
    "21751": "OWL-CREEK - Owl Creek Asset Management, L.P.",
    "21752": "SAINT-ROSE - The College of St. Rose",
    "21753": "Consorcio seguros Vida",
    "21754": "MARKEL-CORPORATION - Markel Corporation",
    "21755": "RBS-BOSTON - Sidera Networks LLC",
    "21756": "SIDERCA S.A.I.C.",
    "21757": "HTC-COMM - HTC Communications",
    "21758": "MODINE-MANUFACTURING - Modine Manufacturing Company",
    "21759": "NRUCFC - NRUCFC",
    "21760": "XEROX-OPB - Xerox, Inc., Office Printing Business",
    "21761": "BERTS-MEGA-MALL - BERT'S MEGA MALL",
    "21762": "QUALITY-DISTRIBUTION - Quality Distribution",
    "21763": "ROSSSTORES - Ross Stores Inc.",
    "21764": "ESOFTINC-NET - eSoft, Inc.",
    "21765": "VOISSNET S.A.",
    "21766": "BEN-LOMAND-TEL - BEN LOMAND RURAL TELEPHONE COOPERATIVE, INC.",
    "21767": "WHINGTON-COLLEGE - Washington College",
    "21768": "Promocion y Operacion SA de CV",
    "21769": "-COLOAM - Colocation America Corporation",
    "21770": "SIMPLE2CALL - Simple2Call",
    "21771": "NUCOR - Nucor",
    "21772": "SKY-WEB - SKYWEB, INC.",
    "21773": "-PUH - Power Up Hosting, Inc.",
    "21774": "GSCNET - The Exchange Global Server Center",
    "21775": "-AFILI-REGISTRY-SERVICES - Afilias Canada, Corp.",
    "21776": "BLOSSOMTEL- - CHICKAW TELEPHONE",
    "21777": "MSIVE-NETWORKS - Massive Networks",
    "21778": "NET-DIDATA-NY - Dimension Data",
    "21779": "HCTV - Harlan Community Television, Inc.",
    "21780": "GRIFFITH-LABORATORIES - GRIFFITH LABORATORIES",
    "21781": "DALTONSCHOOL - The Dalton School",
    "21782": "PLATEAU - Plateau Telecommunications Incorporated",
    "21783": "SILVERNET - State of Nevada",
    "21784": "AUCRWWL - Atlanta University Center, Inc.",
    "21785": "DWHOMES - David Weekley Homes",
    "21786": "SAN-MATEO - San Mateo County Office of Education",
    "21787": "CERIDIAN - CERIDIAN",
    "21788": "NOC - Network Operations Center Inc.",
    "21789": "168-244 - Lowe's Companies, Inc.",
    "21790": "EXTOLIA-MANAGEMENT - Extolia Management, LP",
    "21791": "HUNTSVILLE-MEMORIAL-HOSPITAL - HUNTSVILLE MEMORIAL HOSPITAL",
    "21792": "WORKGROUPVIDEO Workgroupvideo N (ARIN)",
    "21793": "GOGAX - InterWeb Media",
    "21794": "AMEREN-2 - Ameren Corp.",
    "21795": "MSMC-N - Mount Saint Mary College",
    "21796": "SPE - Society of Petroleum Engineers",
    "21797": "TX-SKYBEAM-PB - JAB Wireless, INC.",
    "21798": "INTERNATIONALDELIVERS - International Truck and Engine Corp",
    "21799": "MWDSC - Metropolitan Water District of Southern California",
    "21800": "SPS - Suffolk Public Schools",
    "21801": "JEWELERS - Jewelers Mutual Insurance Company",
    "21802": "STADION - Stadion Money Management, Inc.",
    "21803": "CEDAR-NETWORKS - Cedar Networks",
    "21804": "ACCESS-SK - Access Communications  Co-operative Limited",
    "21805": "RICOH-SILICON-VALLEY - Ricoh Silicon Valley",
    "21806": "NATIONAL-FUEL - National Fuel Gas Distribution Corp.",
    "21807": "DOLE-PACKAGED-FOODS - Dole Packaged Foods",
    "21808": "PRLSS - Peerless Network LLC",
    "21809": "LNRP - LNR Property Corp",
    "21810": "TEMPESCHOOLS - Tempe School District #3",
    "21811": "REYNWOOD-H - Reynwood Communications, Inc.",
    "21812": "VOIP1-GPC-COM - GLOBAL PHONE CORPORATION",
    "21813": "THP-14 - Trillium Health Partners",
    "21814": "PARSONS - Parsons Corp.",
    "21815": "OFML-1 - Optima Fund Management LLC",
    "21816": "MEDDIUS - Meddius, LLC",
    "21817": "NORCT- - Norcast Communications",
    "21818": "BWTELCOM - BWTelcom",
    "21820": "AXISPOINT-60HUDSON - Axispoint Inc",
    "21822": "JDBS - JD Byrider Systems Inc",
    "21823": "ARVIG-2 - Arvig Enterprises Inc.",
    "21824": "EYMAIL S.A.",
    "21825": "BTS-XNET - Archon Group",
    "21826": "Corporaci\u00f3n Telemic C.A.",
    "21827": "CALIX-21827 - CALIX NETWORKS",
    "21828": "TCOE - Tulare County Office of Education",
    "21829": "JADETECH-NET - JADE International, Inc.",
    "21830": "CSTEL-NET - COMSOUTH TELEDATA, Inc.",
    "21831": "ZITO-MIDWEST - Zito Media",
    "21832": "KELLINCOM-1 - Kellin Communications",
    "21833": "TRINITY-IS - Trinity Information Services",
    "21834": "DESIRE2LEARN - Desire2Learn Incorporated",
    "21835": "SCARSDALE-SECURITY-SYSTEMS - Scarsdale Security Systems, Inc.",
    "21836": "SUMMITRADIOLOGICAL-N - Summit Radiological Associates, P.A. dba Westfield Imaging Center",
    "21837": "OPEROFTWARE - Opera Software Americas LLC",
    "21838": "IMPSAT FIBER NETWORKS INC",
    "21839": "CLSMATES-2 - Classmates Online Inc.",
    "21840": "SAGONET-TPA - Sago Networks",
    "21841": "AIS-NY-IPARK - First American Real Estate Solutions",
    "21842": "PJM - PJM Interconnection LLC.",
    "21843": "CITY-OF-BUFFALO - City of Buffalo",
    "21844": "THEPLANET- - ThePlanet.com Internet Services, Inc.",
    "21845": "INFLOW21845 - Inflow Inc.",
    "21846": "ESC1 - Region One Education Service Center",
    "21847": "INFLOW21847 - Inflow Inc.",
    "21848": "INFLOW21848 - Inflow Inc.",
    "21849": "CARECENTRIX - CareCentrix, Inc.",
    "21850": "OPAY-SR - Officialpayments.com",
    "21851": "POSITIONTECH - Position Technologies, Inc.",
    "21852": "DISNW1 - State Of Arkansas, Department of InformationSystems",
    "21853": "NBPHC- - New Brunswick Power Holding Corporation",
    "21854": "DP-IS - Digital Passage, Inc.",
    "21855": "GOODTECH-PROD - Good Technology",
    "21856": "NOKIA-FINLAND NOKIA Corporation",
    "21857": "PROHEALTH - ProHealth Care Inc.",
    "21858": "CENT-DATA-LLC - Ascent Data, LLC",
    "21859": "C3 - C3 Networks Inc",
    "21860": "FL-GRIP - FOLEY & LARDNER LLP",
    "21862": "SODIMAC SA",
    "21863": "DMVNOC - Internet Connection",
    "21864": "BEND-BROADBAND - Bend Cable Communications, LLC",
    "21865": "ARA--1 - Allison Royce & Associates, Inc.",
    "21866": "CITRIX-ONLINE-OFFICES - Citrix Online, LLC",
    "21867": "DEALERTRACKCANADA - DealerTrack Canada Inc.",
    "21868": "NESL - New England School of Law",
    "21869": "SUN-CHEMICAL - Sun Chemical Corporation",
    "21870": "JUNIPER-HERNDON - Juniper Networks, Inc.",
    "21871": "IPGMO - THE INTERPUBLIC GROUP OF COMPANIES, INC.",
    "21872": "TOWERS-PERRIN - Towers Watson Pennsylvania Inc.",
    "21873": "NEWMN - Northeast Service Cooperative (N-NEWMN)",
    "21874": "MERCER-RIPE- Mercer Human Resource Consulting",
    "21875": "PICK-INTERNET - Sands River Wireless",
    "21876": "HEDINC - HED Insurance and Risk Services",
    "21877": "CSC-USA - Computer Sciences Corporation",
    "21878": "SAGE-PUBLIC- - Sage Publications, Inc.",
    "21879": "TWRS-SF - Towerstream I, Inc.",
    "21880": "ZENDESK-NETWORK-N - Zendesk, Inc.",
    "21881": "INSIGHT-HEALTH - InSight Health Services Corporation",
    "21882": "SMARTCITY-PHOENIX - Smart City Networks, L.P.",
    "21883": "CHARTER COMMUNICATIONS INTERNATIONAL PANAMA",
    "21885": "1 - McLane Advanced Technologies, LLC",
    "21886": "MINDSHIFT - MINDSHIFT TECHNOLOGIES",
    "21887": "FICFIG - FOREMOST INSURANCE",
    "21888": "Resource Recovery",
    "21889": "RAPIDSYSTEMS - Rapid Systems Corporation",
    "21890": "RHINO-DURACOM - JAB Wireless, INC.",
    "21891": "BUGGS-NET - Buggs Island Telephone Cooperative",
    "21892": "MACROVISION - Rovi Corporation",
    "21893": "XOOM - Xoom Corporation",
    "21894": "HOMESTEAD - Intuit Inc.",
    "21895": "NYLS- - New York Law School",
    "21896": "ALLIANT-ENERGY - Alliant Energy",
    "21897": "VIRTUA-HEALTH - Virtua Health",
    "21898": "PTN-1 - Plant TiftNet, Inc",
    "21899": "ABBOTT Abbot Labs",
    "21900": "LBPC - LAW BULLETIN PUBLISHING COMPANY",
    "21901": "GLOBALSERVE-1 - GLOBAL-SERVE, INC.",
    "21902": "WCTA - West Central Telephone Assn",
    "21903": "AESREDFISH - AES Power Direct LLC",
    "21904": "POWER1COM - PowerOne Internet LLC",
    "21905": "OREGON-HEALTH-NETWORK - Oregon Health Network, Inc.",
    "21906": "VODEX - Vodex Communications Corp",
    "21907": "GRID-LLC-N - GRID TELEKOM LLC",
    "21908": "FAMILY-VIDEO-INTERNET - Family Video",
    "21909": "LONGFIBRE - Longview Fibre Company",
    "21910": "DRTN-SFA - Data Return",
    "21911": "DUALTEC INFORMATICA LTDA",
    "21912": "LMCOMPANIES - L&M Companies, Inc.",
    "21913": "MAINFREIGHTUS- - Mainfreight, Inc.",
    "21914": "EXPRESS-1-EXPEDITED-SERVICES - Express-1, Inc.",
    "21915": "MCOEORG95340 - Merced County Office of Education",
    "21916": "SKYRIVER - Skyriver Communications, Inc.",
    "21918": "ELECTRONET - ElectroNet Intermedia Consulting",
    "21919": "LINX-USA - LINX USA Inc",
    "21920": "EMERGIS--1 - Emergis Inc.",
    "21922": "WEBNET - WorldSpice Technologies",
    "21923": "CS--NAME - CapitalSource Finance LLC",
    "21924": "KERN-HIGH-SCHOOL-DISTRICT - Kern High School District",
    "21925": "ABAQUS - Dassault Systemes Simulia Corporation",
    "21926": "TREUREISLAND-N1 - Treasure Island Colocation, LLC",
    "21927": "MARKETLINX - MARKETLINX SOLUTIONS",
    "21928": "T-MOBILE-21928 - T-Mobile USA, Inc.",
    "21929": "FEMA - Federal Emergency Management Agency",
    "21930": "INFORMATICA - Informatica Corporation",
    "21931": "THOMSON-FINANCIAL-VANCOUVER - Thomson Reuters U.S. LLC",
    "21932": "AVISTAINC - AVISTA, INCORPORATED",
    "21933": "21933 - MSC.SOFTWARE CORPORATION",
    "21934": "VITAC - VITAC Corporation",
    "21935": "EPSILONDATA50 - Epsilon Data Management",
    "21936": "DISTRIBUTEL-21936 - DISTRIBUTEL COMMUNICATIONS LTD.",
    "21937": "EEL-LTL - Estes Express Lines",
    "21938": "YAMAHA-DEALERS - YAMAHA MOTOR CORPORATION, U.S.A",
    "21939": "E3GROUP - e3-Group, Inc.",
    "21940": "FALCON-GSO - Falcon Internet",
    "21941": "SYNCSORT-INC - Syncsort Inc.",
    "21942": "ON-SEMICONDUCTOR-INC - ON SEMICONDUCTOR",
    "21944": "BSA - BSA Integration Systems, LLC",
    "21945": "HARLANDCLARKE- - Harland Clarke Corp.",
    "21946": "VIBES- - Vibes Media, LLC",
    "21947": "BCI - Blackfoot Telephone Cooperative, Inc.",
    "21948": "BROCADE Brocade Communications Systems, Inc.",
    "21949": "BEANFIELD - Beanfield Technologies Inc.",
    "21950": "AUTOTEC - AutoTec LLC",
    "21951": "STOLAF - St. Olaf College",
    "21952": "NEILL-CORPORATION - Neill Corporation",
    "21953": "INTEGRATEDSETSERVICES - Integrated Asset Services, LLC",
    "21954": "TELES-27 - Telestream, Inc.",
    "21955": "TALECRIS - Grifols Inc.",
    "21956": "TENKAMARKETING - Tenaska Marketing Ventures",
    "21957": "1STADVANTAGE - 1ST ADVANTAGE MORTGAGE, L.L.C.",
    "21958": "NOBEL-CANADA - Nobel, Inc.",
    "21959": "RMI-NETWORK-ATLANTA - Railcar Management Inc",
    "21960": "SSS-LLC - SafeSoft Solutions, Inc.",
    "21961": "JBSHOLDINGUSA - JBS USA Holdings",
    "21962": "REDCONDOR2 - Red Condor",
    "21963": "-AGENCYINSURANCEMD-0001 - Agency Insurance Company",
    "21964": "THE-SCOTTS-COMPANY - The Scotts Company",
    "21965": "BLUECROSS-BLUESHIELD - BlueCross BlueShield of Delaware",
    "21966": "SUNBELTRENTALS - Sunbelt Rentals",
    "21967": "HINES-2800-POST-OAK - HINES INTERESTS",
    "21968": "SUPPORT-SERVICES-GROUP - Support Services Group",
    "21970": "PCESYSTEMS - PCE SYSTEMS",
    "21971": "TRIMBLEMS TRIMBLE MOBILE SOLUTIONS",
    "21972": "PPI - Petroleum Place Incorporated",
    "21973": "XPONET - Xponet",
    "21974": "FMIC - Frankenmuth Mutual Insurance Company",
    "21975": "LOOMISSAYLES - LOOMIS SAYLES & CO., LP",
    "21976": "NJEDGE-NET - NJEDge.Net, Inc.",
    "21977": "RHINO-XANADOO1 - JAB Wireless, INC.",
    "21978": "NCWYOGOV - Natrona County Government",
    "21979": "N1 - Royce & Associates, LLC",
    "21980": "Dayco Telecom, C.A.",
    "21981": "GOETON - Easton Utilities Commission",
    "21982": "PRDCA-N - Panasonic Technologies, Inc.",
    "21983": "AURORNET - Aurora Networking",
    "21984": "FCPS - Fairfax County Public Schools",
    "21985": "ARCHSTONE - Archstone Communities Technical Center",
    "21987": "4151EXECFDCISP - First Data Corporation - TPS",
    "21988": "HENDRICK-AUTO-GROUP - Hendrick Automotive Group",
    "21989": "SPECTRUM-BRANDS - Spectrum Brands, Inc.",
    "21990": "CMSI - Credit Management Solutions, Inc.",
    "21991": "ARTSTOR - ARTStor, Inc.",
    "21992": "SSHA-ONE-N - eHealth Ontario",
    "21993": "SML-N - SIR MANAGEMENT, L.P.",
    "21994": "UBSPRIMEBROKERAGE - UBS AG",
    "21995": "POTAMUS-TRADING - Potamus Trading, LLC",
    "21996": "GUAMCELL - GUAMCELL Communications",
    "21997": "PROLIANCE-ENERGY - ProLiance Energy, LLC",
    "21998": "SETA - SETA",
    "21999": "NBN - Northeast Texas Broadband, LLC",
    "22000": "AAIMED - ALLIANCE FOR ACADEMIC INTERNAL MEDICINE",
    "22001": "INVITROGEN - Life Technologies Corp.",
    "22002": "SYSTEMS-SOLUTIONS-OF-PADUCAH-INC - Systems Solutions of Paducah, Inc.",
    "22003": "PT-N - PALANTIR TECHNOLOGIES INC.",
    "22004": "ABOUT-COM - ABOUT, INC.",
    "22005": "VWR - VWR International, LLC",
    "22006": "PRONSS-PULKCO- - PRONSS",
    "22008": "LIBRARYVIDEO - Library Video Company",
    "22009": "IDM - INTERNET DATA MANAGEMENT, INC.",
    "22010": "Primer Banco del Istmo",
    "22011": "Metro Net, S.A.P.I. de C.V.",
    "22012": "REALOGY-MADISON - NRT Inc.",
    "22013": "GUARD-DC1 - Guardian Analytics, Inc.",
    "22014": "GREENBLUM-BERNSTEIN - Greenblum-Bernstein",
    "22015": "CLCH-NYC-NET - Michael Callen-Audre Lorde Community Health Center",
    "22016": "PHS-OR  for PHS-OR",
    "22017": "ADP-EDC - ADP Dealer Services",
    "22018": "TAUNTON-MUNICIPAL - Taunton Municipal Lighting Plant",
    "22020": "PLANETMAGPIE - Magpie Internet Communications, Corp.",
    "22021": "ONTV-PITTSBURGH - OnTV Pittsburgh",
    "22022": "HUB-GROUP - Hub Group, Inc.",
    "22023": "BCBSMO - Blue Cross Blue Shield of Missouri",
    "22024": "SPLUNK-WEST - Splunk",
    "22025": "DEMOCRACYDATA - DDC Advocacy",
    "22026": "TWTC-HI - tw telecom holdings, inc.",
    "22027": "WORKNET-1 - WORKNET INC.",
    "22028": "TEX-LIFE-HOME-OFFICE - Texas Life Insurance Company",
    "22029": "FCS-PUBLIC-BGP-1 - First Corporate Sedans, Inc",
    "22030": "ZIPCON--1 - Zipcon",
    "22031": "HARSCH-INVESTMENT-PROPERTIES - Harsch Investment Properties",
    "22032": "FLIGHTLINE - Flightline",
    "22033": "CYBERSHIFT-INC - CyberShift, Inc.",
    "22034": "MCMNET - MCMTER CARR SUPPLY COMPANY",
    "22035": "STCN - SAVE THE CHILDREN",
    "22036": "TRIVIN-0001 - triVIN Inc / General Systems Solutions",
    "22038": "PRIME-SGF1 - New Prime, Inc.",
    "22039": "SAM-N - SAM",
    "22041": "CED-15-N - Comtech EF Data",
    "22042": "FLOWUSLLC - Flow Traders US LLC",
    "22043": "STERIS - STERIS Corporation",
    "22044": "LADDERCAPITALFINANCELLC - Ladder Capital Finance LLC",
    "22045": "GUINNESSUDV-NA - Guinness United Distillers & Vintners NorthAmerica, Inc.",
    "22046": "-PCNET-INC - PCnet, Inc.",
    "22047": "VTR BANDA ANCHA S.A.",
    "22048": "WHOLE-FOODS - Whole Foods Market, Inc.",
    "22049": "INTERNETNAMES - InternetNamesForBusiness.com",
    "22050": "SDLANCPA - School District of Lancaster",
    "22051": "BTES- - Bristol Tennessee Essential Services",
    "22052": "MARINAR - Marinar Technology Co., LLC",
    "22053": "ARENAONE - Arena One, LLC",
    "22054": "HOOD-CANAL - Hood Canal Communications",
    "22055": "Banco Central do Brasil",
    "22057": "SSGNET-1 - KRM INFORMATION SERVICES INC",
    "22059": "APVIO-1 - Apvio, Inc.",
    "22060": "NETSPECTRUM - Netspectrum Wireless Internet Solutions",
    "22061": "ACCOR-NORTH-AMERICA - Motel 6",
    "22062": "GEOSTAR - GeoStar, LLC.",
    "22063": "JPGETTYTRUST - J. Paul Getty Trust",
    "22064": "FXALL-FXALLIANCE - FXAlliance",
    "22065": "LPL-FINANCIAL - LPL Financial Services",
    "22066": "CITY-OF-EAU-CLAIRE - City of Eau Claire",
    "22067": "AFS-3 - AMERIPRISE FINANCIAL SERVICES, INC.",
    "22068": "TJC-62001 - Tyler Junior College",
    "22069": "CARIB-23 - CCT Global Communications",
    "22070": "CVILLEHOSTING - Blue Ridge Websoft, LLC",
    "22071": "TRADINGSCREEN-INC - TradingScreen INC",
    "22072": "DEFINITYHEALTH - Definity Health",
    "22074": "BCL-N - Black Capital LLC",
    "22075": "-OUTBRAIN - Outbrain, Inc.",
    "22076": "NEWSBANK - NewsBank Inc.",
    "22077": "RENAISSANCE-TECH - Renaissance Technologies Corp.",
    "22078": "ANALYSTS-INT - Analysts International",
    "22079": "APTNET--01 - Alaska Power & Telephone Co",
    "22080": "Broadbandtech S. A.",
    "22081": "CITILAB - Citigroup",
    "22082": "DSS-QUADRELISERVICE - Digital Site Systems, Inc.",
    "22083": "MEMORIAL-HEALTH-CARE - Memorial Health Care System",
    "22084": "PSI-NETWORKS - Progressive Solutions USA",
    "22085": "Claro S/A",
    "22086": "AMERICAN-CENTRAL-G - American Central Gas Technologies, Inc",
    "22087": "SEARS-ECOMM - Sears Holdings Management Corporation",
    "22088": "CITY-OF-EDMONDS-WA - City of Edmonds",
    "22090": "VENYU-2 - Venyu Solutions Inc.",
    "22091": "RSINVSF001 - RS Investments",
    "22092": "Convexx Communications do Brasil S/A",
    "22093": "CCF-NETWORK - Cleveland Clinic Foundation",
    "22094": "RBI2 - Reed Business Information",
    "22095": "NCR-2 - NCR Corporation",
    "22097": "KLGATES - K&L Gates, LLP",
    "22098": "CAPGROUP-NA - The Capital Group Companies, Inc.",
    "22099": "COGENT-22099 - Cogent Communications",
    "22100": "CRITICAL-PATH - Critical Path Inc.",
    "22101": "CPIL-N - Cyber Point International, LLC",
    "22102": "TEX-BB-N - Texas Broadband Inc.",
    "22103": "VOXEE - Voxee, Inc.",
    "22104": "GELB - Gelber Group, LLC",
    "22105": "PRIMESIGNALN - Prime Signal Ltd",
    "22106": "STA-DRT - Samsung SDS America, Inc.",
    "22107": "COLLABNET - CollabNet",
    "22108": "RESEARCH-INT Research International Network",
    "22109": "UNIVERSAL-INSURANCE - Universal Insurance Group",
    "22110": "LIGTEL-COMMUNICATIONS - Ligtel Communications",
    "22111": "ELOYALTY - Mattersight Corporation",
    "22112": "STAND-REG- - Standard Register Co.",
    "22114": "BMWCHI - BAKER & MCKENZIE CHICAGO LLC",
    "22115": "E4X - Fiftyone, Inc.",
    "22116": "XCTLABS191310 - Xcast Labs Inc",
    "22117": "COMNEXIA - COMNEXIA Corporation",
    "22118": "PERRYJOHNSON-REGISTRAR - PERRY JOHNSON REGISTRARS, Inc.",
    "22121": "TOPSHAM-COMMUNICATIONS - Topsham Communications LLC",
    "22122": "Universidad Autonoma de Yucatan",
    "22123": "YVMC - Yampa Valley Medical Center",
    "22124": "FINNEGANBGP - Finnegan, Henderson, Farabow, Garrett &Dunner, LLP",
    "22125": "PFPC - PNC Bank",
    "22126": "DISTRIBION-DALL - Distribion Inc",
    "22127": "HONDAAIRCRAFT - Honda Aircraft Company LLC",
    "22128": "Grupo Editorial Sinos S/A",
    "22129": "Task Software Ltda",
    "22130": "D-BGP-29 - Doctor's Associates Inc.",
    "22131": "JER-NBLOCK1 - J.E. Robert Company, Inc.",
    "22132": "INTERNAP-BLK - Internap Network Services Corporation",
    "22133": "Octet Brasil Ltda",
    "22134": "PETSMART - PetSmart, Inc.",
    "22135": "SKECHERS-USA - Skechers USA",
    "22136": "NYCT - New York Connect",
    "22137": "BCW - Blood Center of  Wisconsin, Inc.",
    "22138": "FARM-MARKET - Farm to Market Broadband, LP",
    "22139": "FAODE- - Friess Associates of DE, LLC",
    "22140": "T-MOBILE-22140 - T-Mobile USA, Inc.",
    "22141": "JMARK-BUSINESS-SOLUTIONS - JMARK Business Solutions, Inc",
    "22142": "I-TECH - Fiserv Solutions Inc.",
    "22143": "NETMAR - NETMAR, INC.",
    "22144": "CHAPMAN - Chapman and Cutler",
    "22145": "RDSI - Rurbanc Data Services, Inc.",
    "22146": "LANDAM - LandAmerica Financial Group, Inc.",
    "22147": "PSURGE OCCAID/Packetsurge Networks",
    "22148": "MPS Informatica",
    "22149": "PSC- - PSC, Inc.",
    "22150": "CARRIERHOUSE - Carrierhouse Corp.",
    "22151": "BREAN-MURRAY - Brean Murray & Co., Inc.",
    "22152": "OCHS- - OC Hosting, Inc.",
    "22153": "CCI-NET01-HAWAII - CENTURY COMPUTERS, INC",
    "22154": "NUTECH - Nu Tech Software Solutions, Inc.",
    "22155": "MSAPP - Mine Safety Appliances",
    "22156": "MUSICNET - MediaNet Digital, Inc.",
    "22157": "1-A2W - Air2web",
    "22158": "22158 - Telecom Colocation, LLC",
    "22159": "SUNY-SYSTEM-ADMIN - State University of New York, Central",
    "22161": "PROJECT-ROVER-N - Project Rover",
    "22162": "AYUSTAR-CORP - Ayustar Corp.",
    "22163": "TAMHSC - Texas A&M University System Health Science Center",
    "22165": "BGP-DUCKS-CA - Ducks Unlimited Canada",
    "22166": "BERTRAM-COM2 - Bertram Corporation",
    "22167": "FINTECH-INTERNET - Fintech",
    "22168": "INSORS - inSORS Integrated Communications",
    "22169": "SLH-DATACENTER1 - slash20, llc",
    "22170": "NEFMLS-JAX - Northeast Florida MLS, Inc.",
    "22171": "IPSV-N1 - IP Services",
    "22172": "MITCHELL-INTERNATIONAL-DC2 - Mitchell International",
    "22173": "PDP-SUPERIOR - PLAIN DEALER PUBLISHING CO.",
    "22174": "NET-SUC-TECH-ALF - State University of New York College ofTechnology at Alfred",
    "22175": "TWO-SIGMA-INTERNATIONAL- Two Sigma International",
    "22176": "PCI-N - PCI",
    "22177": "Transit do Brasil Ltda.",
    "22178": "PA-SENATE - Senate of Pennsylvania",
    "22179": "PROGRESSING- - ADRevolution LLC",
    "22180": "CONPOINT - POWER POINT COMPUTER CENTERS,",
    "22181": "IVNET - IV NET",
    "22182": "LSGSKYCHEFS - LSG Sky Chefs North America Solutions, Inc.",
    "22183": "CISCO-ROS - CISCO SYSTEMS, INC.",
    "22184": "IRIDIUM-SATELLITE - IRIDIUM SATELLITE,LLC",
    "22185": "TELEFONICA-UNIDAD LARGA DISTANCIA",
    "22186": "EMBARQ-GRNR - Embarq Corporation",
    "22187": "RAULAND-BORG - Rauland-Borg Corporation",
    "22188": "QUANTECHSERV-INC-1 - Quantech Services, Inc.",
    "22189": "AMRID - Amridge University",
    "22190": "KNIGHT - Knight Capital Group, Inc",
    "22191": "WILKES-COMM - Wilkes Communications, Inc.",
    "22192": "SSHENET - Pennsylvania State System of Higher Education",
    "22193": "THOMSONCORP - Thomson Corporation",
    "22194": "SWITCH-COMMUNICATIONS - SWITCH Communications Group LLC",
    "22195": "JANGO - DKCM Inc.",
    "22196": "NEULION - NeuLion, Inc.",
    "22197": "APPS - Apps Communications",
    "22198": "LAFAYE - Lafayette College",
    "22199": "MEGAPATH8-US - MegaPath Corporation",
    "22200": "BLOOMINGDALE-COMMUNICATIONS - Bloomingdale Communications Inc.",
    "22201": "ETM-DEN01 - Entercom Communications Corporation",
    "22203": "NAVITAIRE - Navitaire, Inc.",
    "22204": "ACETO - Aceto Corporation",
    "22205": "DATAPIPE-SEA - DataPipe, Inc.",
    "22206": "GOOD-SAM - Evangelical Lutheran Good Samaritan Society",
    "22207": "AKAMAI- - Akamai Technologies, Inc.",
    "22208": "CTC- - Chicago Trading Company",
    "22209": "RUDYS- - RUDYS INFLIGHT CATERING",
    "22210": "MOJO-N - Morgan Joseph & CO. INC.",
    "22211": "INTERNAP-FCP - Internap Network Services Corporation",
    "22212": "INTERNAP-PEERING-NETWORK - Internap Network Services Corporation",
    "22213": "SALK- - Salk Institute",
    "22215": "BHSU - Black Hills State University",
    "22216": "SIEMENS-PLM - Siemens Corporation",
    "22217": "HAVER-A - Haverstick Consulting, Inc.",
    "22218": "PETROCOM - Broadpoint",
    "22219": "AO-MSP-1 - Applied Operations, LLC",
    "22220": "EACOMARTS - Electronic Arts, Inc.",
    "22221": "GMACI-COMM - Integon Services Corporation",
    "22222": "OMAHTEAKS - Omaha Steaks",
    "22223": "MVTV-1 - MVTV Wireless",
    "22224": "CIBERSITES-PHOENIX - CIBER INC.",
    "22225": "PRESTIGE-BRANDS-INC - Prestige Brands, Inc.",
    "22226": "SFUSD - San Francisco Unified School District",
    "22227": "BAC International Bank",
    "22228": "FSI-INTERNATIONAL-1 - FSI International, Inc.",
    "22229": "WORLDPAC - WORLDPAC INC.",
    "22230": "WESCOM-1777-N - Western Communications, Inc.",
    "22231": "ETM-BALA01 - Entercom Communications Corporation",
    "22232": "CRDS - CAPCO REFERENCE DATA SERVICES",
    "22234": "RELATED-COMPANIES-BGP-1 - The Related Companies, Inc.",
    "22235": "BUSINESS-DECISION-NA - Business & Decision North America (PA), Inc.",
    "22236": "UNITEDBANCORP - The Citizens Savings Bank",
    "22237": "ICN - Innovative Communications, Inc.",
    "22238": "DARPA - Defense Advanced Research Projects Agency(DARPA)",
    "22239": "TRADINGTECH-CORP - Trading Technologies Intl, Inc.",
    "22240": "POWELLHOST - Powell Hosting, Inc.",
    "22241": "IC2NET - IC2NET",
    "22242": "NOVTAR - Novastar Mortgage Inc.",
    "22243": "CENTRACOMM - CentraComm Communications",
    "22244": "MOTOROLA-PHX - Motorola, Inc.",
    "22245": "WICHITA-STATE-U - Wichita State University",
    "22246": "NDAQ-OMX-22246 - THE NDAQ OMX GROUP, INC.",
    "22247": "LETOURNEAUUNIVERSITY - LeTourneau University",
    "22248": "WY-JUDICIAL - Wyoming Supreme Court",
    "22249": "MAXEL-4 - MAXELL CORPORATION OF AMERICA",
    "22250": "ABRANET- Associa\u00e7\u00e3o Brasileira de Internet",
    "22251": "REMC - Regional Educational Media Center",
    "22252": "22252 - The City of New York",
    "22253": "IHIRELLC - IHIRE LLC",
    "22254": "ADOBE-22254 - Adobe Systems Inc.",
    "22256": "FIRST-SOUTHWEST - First Southwest Company",
    "22257": "1025CONNECT - 1025Connect",
    "22258": "COMCT-22258 - Comcast Cable Communications Holdings, Inc",
    "22259": "VITAMIX-001 - Vita-Mix Corporation",
    "22260": "PERSHING - The Bank of New York Mellon Corporation",
    "22261": "SDCWA-ORG - San Diego County Water Authority",
    "22262": "IDENTRUST-DR-N - IdenTrust",
    "22264": "BLACKMESH - BlackMesh Inc.",
    "22265": "GENESIS-OMAHA-NE - GENESIS SYSTEMS",
    "22267": "HSL-N - HighVista Strategies LLC",
    "22268": "LEVEL365 - LEVEL365 HOLDINGS LLC",
    "22269": "CHTR-WV-MID-ATLANTIC - Charter Communications",
    "22270": "BANGOR-SAVINGS-BANK - Bangor Savings Bank",
    "22273": "GWCCNET-N - Great West Casualty Company",
    "22274": "FORD-MODELS-INC - Ford Models, Inc.",
    "22275": "SECURENET-SYSTEMS - Securenet Systems, Inc.",
    "22276": "BANKUNITED - BANKUNITED",
    "22277": "TIL-N - Torchlight Investors, LLC",
    "22278": "NC-2 - Nettica Corporation",
    "22279": "AGGREGATEKNOWLEDGE - Aggregate Knowledge Inc.",
    "22280": "FIRSTHEALTHBGP - First Health Corp",
    "22281": "VIRTUALCOMPLETE - VirtualComplete, LLC",
    "22282": "COSMO-MAIN - The Cosmopolitan of Las Vegas",
    "22283": "SIDLEY - Sidley Austin Brown & Wood",
    "22284": "DIOS - Department of the Interior, Office of theSecretary",
    "22285": "PAROFT - ParaSoft Corporation",
    "22286": "INTERSPOTS - INTERSPOTS INC",
    "22287": "THUMB-CELLULAR - THUMB CELLULAR, LLC",
    "22288": "RFBKCORP - Republic First Bancorp, Inc.",
    "22289": "BARRISTER-GLOBAL - Barrister Global Services Network, Inc.",
    "22290": "VENTREIT - Ventas, Inc.",
    "22291": "CHARTER-LA - Charter Communications",
    "22293": "INSP-1 - Blucora, Inc.",
    "22294": "CORE-82-INC - Core 82 Inc.",
    "22295": "NO - ACS, Inc (Government Solutions Group)",
    "22296": "CONN-NET - Cashman Computer Associates",
    "22298": "SPNW - Secured Private Network",
    "22299": "GCRONLINE - GCR Company/GCR Online",
    "22300": "WIKIA - Wikia, Inc.",
    "22301": "MDAFEDERAL - MDA Information Systems, Inc.",
    "22302": "INOC - INOC, LLC",
    "22303": "NEWPALTZEDU - SUNY College at New Paltz",
    "22304": "CITY-OF-MARIETTA-GEORGIA - City of Marietta",
    "22305": "Gamacom S.A.C.",
    "22306": "FISCAL N-FISCAL",
    "22307": "VINS--7 - ViaWest",
    "22308": "VIDYO - Vidyo, Inc.",
    "22309": "N1 - Kitsap Credit Union",
    "22310": "LOI - LIFE Outreach International",
    "22311": "FAIRNET-LLC - FAIRNET LLC",
    "22312": "TECO-ENERGY - TECO Energy, Inc.",
    "22313": "Supercable",
    "22314": "COMMUNICATIONS-CORPORATION-OF-AMERICA - Communications Corporation of America",
    "22315": "SBCSS - San Bernardino County Superintendent of Schools",
    "22316": "OCI - O'CURRANCE TELESERVICES",
    "22317": "F5-NETWORKS - F5 Networks, Inc.",
    "22318": "N-CXA-CF-22318-CBS - Cox Communications Inc.",
    "22319": "FOGODC - Fogo Data Centers",
    "22320": "MVECA- - Miami Valley Educational Computer Association",
    "22321": "PLUMCHOICE-DC1 - PlumChoice",
    "22322": "OBERLIN-NET - CABLE CO-OP",
    "22323": "UNIVERSITY-OF-CALIFORNIA-MERCED - University of California, Merced",
    "22324": "XTEL - XTEL Communications",
    "22325": "COLOCENTRAL - Colo Central Corporation",
    "22326": "DRHORTON - D.R.Horton, Inc",
    "22327": "CIMATELECOM2 - Cima Telecom, Inc.",
    "22328": "CSHS - Cedars-Sinai Health Systems",
    "22329": "BAYMOUNTAIN - Peak 10",
    "22330": "CATALINAMKT - Catalina Marketing Corporation",
    "22331": "NEWBROOK-CAPITAL-ADVISORS-LP - Newbrook Capital Advisors LP",
    "22332": "WDC-US - Western Digital Corporation",
    "22333": "DATACONSTRUCTS - DATACONSTRUCTS",
    "22334": "FERGUSON - Ferguson Enterprises, Inc.",
    "22335": "MREN - Metropolitan Research and Education Network",
    "22336": "PELLA - Pella Corporation",
    "22338": "MBTRADING1 - MB Trading Futures, Inc.",
    "22339": "FIRSTCAL - Inunision",
    "22340": "ACTIONTEC - ACTIONTEC ELECTRONICS, INC.",
    "22341": "RTM - Rede de Telecomunica\u00e7\u00f5es para o Mercado Ltda",
    "22342": "TCMC - The Commonwealth Medical College",
    "22343": "TELESPHERE-NETWORKS - Telesphere Networks Ltd.",
    "22344": "ABC-SUPPLY-CO - ABC Supply Co.",
    "22345": "SOLIX-INC - Solix, Inc.",
    "22346": "NRZ-NETWORK - Newroads Telecom",
    "22347": "DORSEY-WHITNEY - Dorsey & Whitney LLP",
    "22348": "GSB-COM - Glenview State Bank",
    "22349": "N-DCSCORP - DCS Corporation",
    "22350": "ECMD - ECMD INC.",
    "22351": "INTELSAT Intelsat Global BGP Routing Policy",
    "22352": "APPLIED-TECHNOLOGY - Applied Technology Group Inc.",
    "22353": "TAYLOR-LINK1 - Taylor Telephone Cooperative, Inc.",
    "22354": "UNIV-DAR",
    "22355": "FROGFOOT",
    "22356": "Durand do Brasil Ltda",
    "22357": "HDL - Health Diagnostic Laboratory, Inc.",
    "22358": "KRAMER-WILSON - Kramer Wilson",
    "22359": "TTP - Teletouch Paging, LP",
    "22360": "N-GCAL-2 - Greylock Capital Associates, LLC",
    "22361": "BWL - Believe Wireless, LLC.",
    "22362": "GLOBALTELLINK-HNSS - Global Tel*link Corporation",
    "22363": "PHMGMT-1 - Powerhouse Management, Inc.",
    "22364": "-22364 - Telefonica USA, Inc.",
    "22365": "MINDVISION - MindVision Software",
    "22367": "JCOM-4 - J2 Global Inc.",
    "22368": "TELEBUCARAMANGA S.A. E.S.P.",
    "22369": "ACE-CH - Ace Cash Express",
    "22370": "FG1 - Fieldglass, Inc.",
    "22371": "ITS Tecnologia em Sistemas Ltda.",
    "22372": "HIAA-NS - Halifax International Airport Authority",
    "22373": "PEGS - Pegasus Solutions, Inc.",
    "22374": "RCSACCESS-DUSON - Gonthier Inc.",
    "22375": "CREDCO - First Advantage Membership Services INC.",
    "22376": "GOODTECH-CORP - Good Technology",
    "22377": "TRANSATLANTIC - Transatlantic Reinsurance Company",
    "22378": "MATRIXCONSULTINGCOLA - Matrix Consulting, LLC",
    "22379": "TRADETREK - tradetrek.com",
    "22380": "PULLMAN-COMLEY-LLC - Pullman & Comley, LLC",
    "22381": "Megatelecom Telecomunicacoes Ltda",
    "22382": "Mossack & Fonseca",
    "22383": "L-VEG-SUN - Las Vegas Sun",
    "22384": "NATIONALNET-1 - NationalNet, Inc.",
    "22385": "JMS-N - Janney Montgomery Scott, LLC",
    "22386": "SARB",
    "22387": "SONOPRESS-H - Sonopress, LLC",
    "22388": "TRANSPAC - Indiana University",
    "22389": "ONTONOGANTELEPHONECO - Ontonogan Telephone Company",
    "22390": "XEROX-WB - XEROX CORPORATION",
    "22391": "BCIS-BEXAR-COUNTY-INFORMATION-SERVICES - Bexar County -  Information Services",
    "22392": "ACS-GRM-DALL - Government Records Services, Inc.",
    "22393": "HRM-N - Halifax Regional Municipality",
    "22394": "CELLCO - Cellco Partnership DBA Verizon Wireless",
    "22395": "GHCO-INTERNAP - Goldenberg Hehmeyer",
    "22396": "LANVERA - Lanvera Ltd",
    "22397": "COTALSIERRA - Skyline Broadband Service",
    "22398": "NT-T - NT&T",
    "22399": "COBA-1 - Commerzbank AG",
    "22400": "COPLANAR - Coplanar Networks",
    "22401": "PFM - Public Financial Management, Inc.",
    "22402": "NEXTCO- - Nextera Communications LLC",
    "22403": "TRINICOM - TRINICOM COMMUNICATIONS",
    "22404": "NUCLEUS-INC-2 - Nucleus Information Service, Inc.",
    "22405": "WJCS845 - Westchester Jewish Community Services",
    "22406": "HARTEHANKSDIRECT - Harte-Hanks/Direct",
    "22407": "Acesso a Internet R\u00e1pido Ltda.",
    "22408": "WKNET - West Ky Networks",
    "22409": "LACKAWAXEN-TELECOMMUNICATIONS-SERVICES-INC - Lackawaxen Telecommunications Services, Inc.",
    "22410": "22410 - Fidelity Integrated Financial Solutions",
    "22411": "Digital Way S.A",
    "22412": "APL-69-ARIN - Archon Partners LLC",
    "22414": "CRAIGS-NET-1 - Craigslist, Inc.",
    "22415": "KNET N-KNET",
    "22417": "NYCM-FIRE-CO - New York Central Mutual Fire Insurance Company",
    "22418": "COLOG - Cologuard",
    "22419": "ACNINC-01 - ACN, INC",
    "22421": "TCC01 - TCC Networks LLC",
    "22422": "BOARD-OF-ELECTIONS-IN-THE-CITY-OF-NEW-YORK - Board of Elections in the City of New York",
    "22423": "ALTIMA-TELECOM - Altima Telecom Inc",
    "22424": "DNV355A - Corporation of The District of North Vancouver",
    "22425": "KIESLING - Kiesling Associates, LLP",
    "22426": "ILINKADV - Interlink Advantage",
    "22427": "UCG- - United Colocation Group, Inc.",
    "22428": "XCITENET - XciteNet, Inc",
    "22429": "-WFC-LHC-AZ-01 - WireFree Communications Inc.",
    "22430": "LSV-ADVISORS-LLC - LSV Advisors, L.L.C",
    "22431": "ABE - SERVICOS TELECOM DES E COM SOFT LTDA",
    "22432": "INSURANCE-DATA-PROCESSING - INSURANCE DATA PROCESSING, INC.",
    "22433": "HRMC - Human Resource Management Center, Inc.",
    "22434": "INTRIEVE - Intrieve",
    "22435": "PSFT-INC - Oracle Corporation",
    "22436": "ACCIP - Accipiter Capital Management, LLC",
    "22437": "CORESITE-ANY2-RS-ET - CoreSite",
    "22438": "CLEAR-RATE-COMMUNICATIONS - Clear Rate Communications, Inc.",
    "22439": "PERFECT-INTERNATIONAL - Perfect International, Inc",
    "22440": "EVANSCAPITAL - Evanston Capital Management",
    "22441": "WHITWORTH-NET - Whitworth University",
    "22442": "HOU-PHONOSCOPE - PHONOSCOPE",
    "22443": "MINDSET-SOFTWARE - MINDSET SOFTWARE INC",
    "22444": "TTS-SOUTHFIELD-MI-USA - Teledata Technology Solutions, Inc",
    "22445": "MHK - Mohawk Industries, Inc.",
    "22446": "MEDLINE - Medline Industries",
    "22447": "SLEEPYS - Sleepy's LLC.",
    "22448": "MICRO-SPEC - Microcomputer Specialists, Inc.",
    "22449": "AWSHQ - Earth Networks, Inc.",
    "22450": "SUNSTREAM - SunStream Networks, Ltd.",
    "22451": "HRH - Halifax Regional Hospital",
    "22452": "NOMINUM Tautological self-reference:  is duplicated in RADB",
    "22453": "Informacion y Tecnologia S.A",
    "22454": "DAISHO - Daisho Networks",
    "22455": "ESL-FCU - ESL Federal Credit Union",
    "22456": "GOLDF- - Goldfarb & Fleece",
    "22457": "CCI - Corridor Communications, INC.",
    "22458": "NETSOURCE - NetSource Communications, Inc.",
    "22459": "MCKESSON-HEALTH-SVCS - McKesson Corporation",
    "22462": "PARAGON- - Physician's Medical Center L.L.P.",
    "22463": "ADPDS-RESEARCH-DEVELOPMENT - Automatic Data Processing, Dealer Services",
    "22464": "NELTC-ISP - Northeast Louisiana Telephone Company, Inc.",
    "22465": "SMS-MV - Smith Micro Software, Inc.",
    "22466": "WALLOWA-VALLEY-NETWORKS-LLC - Wallowa Valley Networks, LLC",
    "22467": "MIRRORPLUS - Mirror Plus Technologies Inc.",
    "22468": "GAMMA-ROUTERS - Gamma Group, Inc.",
    "22469": "CONSUMER-SOURCE-HOLDINGS-INC - PRIMEDIA, INC.",
    "22470": "NBME - National Board of Medical Examiners",
    "22471": "MOTEMARINELAB - Mote Marine Laboratory",
    "22472": "FLCOURTS - Florida Supreme Court",
    "22473": "SALT-LAKE-CITY - Salt Lake City Corporation",
    "22474": "SAINT-LUKES-HEALTH-SYSTEM- - Saint Luke's Health System",
    "22475": "MVP - MVP Health Plan Inc.",
    "22476": "NUNETWORX - Communication Nunetworx Inc.",
    "22477": "OBERM - Obermayer Rebmann Maxwell & Hippel, LLP",
    "22478": "LS-POWER-N-01 - LS Power Development, LLC",
    "22479": "HGC-N - Hayground Cove Fund Management, LLC",
    "22480": "SOCOLO- - Beulahland Communications, Inc",
    "22481": "AVSGIA- - Audio Visual Services Group, Inc. (AVSG)",
    "22482": "FPH-PUBLIC - Palms Casino Resort",
    "22483": "FOCUS24 - FOCUS24, Inc.",
    "22484": "GKNET - Goldberg, Kohn, Bell, Black, Rosenbloom &Moritz, Ltd.",
    "22485": "MONTANA-OPTICOM-22485 - Montana Opticom, LLC",
    "22486": "TUMI - TUMI",
    "22487": "VALENCIA - Valencia Community College",
    "22488": "TL-NYALB - Cengage Learning Inc",
    "22489": "CTLE-ACCESS - Castle Access Inc",
    "22490": "SIERRABRAVOCORP - Sierra Bravo Corporation",
    "22491": "TTC-CA - The Travel Corporation (Canada) Ltd.",
    "22493": "RVAPC - Rafael Vinoly Architects PC",
    "22494": "E-MICRO-N - Eagle Micro Systems, LLC",
    "22495": "SIMON-208-0 - Simon Property Group LP",
    "22496": "LIMEBROKERAGE-US - Lime Brokerage, LLC",
    "22497": "SEAINTERNET - Sea Consultants, Inc.",
    "22498": "PINELL-COUNTY - Pinellas County Government",
    "22499": "AIG-AMG-WILTON - AIG FINANCIAL PRODUCTS CORP.",
    "22500": "SKYCOMM-N - InterCache LLC",
    "22501": "Cooperativa Telefonica Carlos Tejedor Ltda.",
    "22502": "COVANCE-IP - Covance Central Laboratory Services Inc.",
    "22503": "WORLDAVENUEUSA - World Avenue U.S.A., LLC",
    "22504": "LORETTOCOMM - LORETTO COMMUNICATION SERVICES, INC.",
    "22505": "IWK-AND-NS-HEALTH-NETWORK - Izaak Walton Killam Health Centre",
    "22506": "EMI-N - EnteroMedics Inc.",
    "22507": "MSPOT - mSpot Inc.",
    "22508": "Multimedios Estrellas de Oro, S.A. de C.V.",
    "22509": "BANFIELD - Banfield",
    "22510": "BRAINTREEPAYMENTSOLUTIONS - Braintree Payment Solutions, LLC",
    "22512": "OPENBSD - OpenBSD",
    "22513": "MERCER-DC - MERCER PARK LP",
    "22514": "JITC-AK - The Chenega Corporation",
    "22515": "DEPARTAMENTO DE POLICIA FEDERAL",
    "22516": "INTER-RESPONSE - Interactive Response Technologies",
    "22517": "PINGER--1 - Pinger, Inc",
    "22518": "PANDORA-CORP - Pandora Media, Inc",
    "22519": "HCLTMS - HCL AMERICA INC",
    "22520": "MICHAUD-TECHNOLOGIES-NET - Michaud Technologies Inc",
    "22521": "VGN - Verizon Online LLC",
    "22522": "ULALAUNCH - United Launch Alliance, LLC",
    "22523": "NMCOURTS-N - State of NM Administrative Office of the Courts",
    "22524": "SAGETELECOM - Sage Telecom",
    "22525": "ATALANTA-SOSNOFF - Atalanta Sosnoff Capital, LLC",
    "22526": "PACKETDESIGN - Packet Design",
    "22527": "SAFEWAY-INC - Safeway, Inc.",
    "22528": "CDS-PHX-ATL - M/A/R/C INC",
    "22529": "SEIT",
    "22530": "DLKCORE - Dialink Corporation",
    "22531": "LHBACK - Lashback, LLC",
    "22532": "SHORCAN - SHORCAN BROKERS LIMITED",
    "22533": "IMS - Inquiry Management Systems",
    "22534": "INS-CENTR-1 - Central Scott Telephone Company",
    "22535": "EPLINC - EPL INC",
    "22536": "VNU-LOSANGELES - VNU, Inc.",
    "22537": "ALBEMARLE-CORP - Albemarle Corp",
    "22538": "IBM-GBS - IBM Business Consulting Services",
    "22539": "BORSCHOW - Borschow Medical & Hospital Supplies, Inc",
    "22540": "TUCSONVAISALA - Vaisala, Inc.",
    "22541": "MegaLink",
    "22542": "TCT - TCT Communications, Inc.",
    "22543": "PIXELWEB - Pixelweb",
    "22544": "HOPLITE-CAPITAL - Hoplite Capital Management, LLC",
    "22545": "ELAVON - ELAVON",
    "22546": "BLACKPHOENIX - Black Phoenix Research LLC",
    "22547": "SUREWEST-22547 - SureWest Broadband",
    "22548": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "22549": "TBDSL-01 - PBX-Change",
    "22550": "EXP-TOR2007A - Experian",
    "22551": "QLG - Winkflash",
    "22552": "ESITED - eSited Solutions",
    "22553": "ECONOMIST-GROUP-NY - The Economist Group",
    "22554": "PEWNETWORK - The Pew Charitable Trusts",
    "22555": "INTECOACCESS - Iniciativa Tecnologica Centro Oriental, Inc",
    "22556": "BLACKBOARD - Blackboard Inc.",
    "22557": "UTHL - UNITED TLD HOLDCO LTD",
    "22558": "VPSDATACENTER - VPS Datacenter, LLC",
    "22559": "GNF-ORG - Genomics Institute of the Novartis Research Foundation",
    "22560": "22560 - MasterCard Technologies LLC",
    "22561": "22561 - CenturyTel Internet Holdings, Inc.",
    "22562": "CSC-IGN-EMEA - Computer Sciences Corporation",
    "22563": "COZEN-PHL - Cozen & O'Connor",
    "22564": "TRABON-SOLUTIONS - Trabon Solutions",
    "22565": "YAHOO-NUQ - Yahoo",
    "22566": "Maxcom Telecomunicaciones, S.A.B. de C.V.",
    "22567": "CWGS - CWGS ENTERPRISES, LLC",
    "22568": "WORLDCARE-CLINICAL-LLC - Worldcare Clinical, LLC",
    "22569": "ADPALLIANCE-BHAM - ADP, Inc.",
    "22570": "AUTODESK-1 Autodesk, Inc.",
    "22571": "ARSALON - Arsalon Technologies",
    "22572": "INFOSAT-IP",
    "22573": "NWTEL - Northwestel Inc.",
    "22574": "COCONET - CocoNet Corporation",
    "22575": "MSMUTUAL2 - MassMutual Financial Services",
    "22576": "LAYER3-N - Layered Technologies, Inc.",
    "22577": "ADMOB-US - Google Inc.",
    "22578": "EMERGING-MEDIA-GROUP - Emerging Media Group",
    "22579": "JRCINC - Jonathan Rose Companies, Inc.",
    "22580": "GUARD - GUARD INSURANCE GROUP",
    "22581": "ACE-STX - Broadband VI, LLC",
    "22582": "LUMINEX - Luminex Corporation",
    "22583": "N1 - BATS Trading Limited",
    "22584": "NTELOS-PCS - Ntelos Inc.",
    "22585": "VIPCO - VIP COMMUNICATIONS INC",
    "22587": "DOTSCONNECT-1 - DotsConnect",
    "22588": "DOMIN- - DOMINION ENTERPRISES",
    "22589": "QCHOL-KC - QC Holdings, Inc.",
    "22590": "ARIAD-US - ARIAD Pharmaceuticals",
    "22591": "DECHO - Decho Corporation",
    "22592": "HBP - HBP, Inc.",
    "22593": "BCBSNC- - Blue Cross and Blue Shield of North Carolina",
    "22594": "UNI-NET-N - University of Northern Iowa",
    "22595": "N1 - Technology Service Corp",
    "22596": "MARKETING-SOFTWARE - Marketing Software Company",
    "22597": "SYNYGYN - Synygy, Inc",
    "22598": "ALENCO - ALENCO COMMUNICATIONS, INC",
    "22599": "UC-TELECOMMUNICATIONS-COMPANY - UC Telecommunications Company",
    "22600": "-IOCENTER - Internet Operations Center",
    "22601": "BONNPOWERNET - Bonneville Power Administration",
    "22602": "EXPERIENT-INC - Experient Inc.",
    "22603": "PSD401 - Peninsula School District 401",
    "22604": "JAT-N - JAT CAPITAL MANAGEMENT (NEW YORK), L.P.",
    "22605": "HHCAP-NYC - Hutchin Hill Capital, LP",
    "22606": "EXACT-7 - ExactTarget, Inc.",
    "22607": "DES-MOINES-EDU - Des Moines University",
    "22608": "OKPUD-WA - Public Utility District No. 1 of Okanogan County",
    "22609": "ITAPE - Intertape Polymer Corp",
    "22610": "CVH-NETBLK-1 - Coventry Health Care, Inc.",
    "22611": "IMH-WEST - InMotion Hosting, Inc.",
    "22612": "NAMECHEAP-NET - Namecheap, Inc.",
    "22613": "NDCHEALTH-PHX - Source Healthcare Analytics, Inc.",
    "22614": "CRPUD - Columbia River PUD",
    "22616": "VERTISINC-IRVING - Vertis Inc.",
    "22617": "SACCOURT - Superior Court of California, County of Sacramento",
    "22618": "GWK-LLC - Gannett Welsh & Kotler LLC",
    "22619": "STANDARDIX-01 - Cologix Canada, Inc.",
    "22620": "BOARDPENSIONS-PRESBYTERIAN - The Board of Pensions of the Presbyterian Church (USA)",
    "22621": "UNIGROUP - UniGroup, INC",
    "22622": "MIPPS-INC - MIPPS INC.",
    "22623": "FORTISAB-1 - FortisAlberta Inc.",
    "22624": "FREMONTBANK - Fremont Bank",
    "22625": "FORTRUST-SOLUTIONS - FORTRUST",
    "22626": "EXCELLA-COMMUNICATIONS - EXCELLA COMMUNICATIONS",
    "22627": "UBQTMEDIA UBQT Media Plc",
    "22628": "Alta Tecnologia (ALTEC), S.A.",
    "22629": "NORWORLD - NORTHWESTERN CORPORATION",
    "22630": "ACUMENTECH - Acumen Tech, LLC",
    "22631": "SURFAIRWIRELESS - AIRbaud, Inc",
    "22632": "DAKPRO - DakotaPro.biz",
    "22633": "FISHERBROTHERS - Fisher Brothers",
    "22634": "UBISOFT-COM - Ubisoft Entertainment",
    "22635": "US-MA-DEDHAM - AliMed, Inc.",
    "22636": "NOVA-SCOTIA-POWER - Nova Scotia Power, Inc.",
    "22637": "C-R-T - Arialink",
    "22638": "PHILORCH-N - The Philadelphia Orchestra Association",
    "22639": "COOPTEL--01 - Cooptel Coop de Telecommunication",
    "22640": "IBS-INTERNET1 - IBS INTERPRIT",
    "22641": "NNPI - Novo Nordisk Pharmaceutical, Inc.",
    "22642": "GXCLARKE-BCP - G.X. Clarke & Co.",
    "22643": "WESTEDORG - WestEd",
    "22644": "TJUH - Thomas Jefferson University Hospitals",
    "22645": "NTG - North Texas GigaPOP",
    "22646": "HARCOM1 - Hargray Communications Group, Inc.",
    "22647": "ELLTEL - Fairpoint Communications",
    "22648": "SWG - Southwest Gas Corporation",
    "22649": "ATCIS - Aftermarket Technologies Corp",
    "22650": "CITIGROUP-KNIGHT-FINANCIAL-22650 - Citigroup",
    "22651": "A44K04R32F - AKRF, Inc.",
    "22652": "FIBRENOIRE-INTERNET - Fibrenoire Internet Inc.",
    "22653": "GLOBALCOMPS - Cyber Wurx LLC",
    "22654": "NOV-NET-01 - Novani, LLC",
    "22655": "AGDATACOMPANIES - AGDATA, LP",
    "22656": "VWAINC-6317575100 - Vengroff Williams & Associates, Inc",
    "22657": "PROXIOS - Proxios",
    "22658": "EARTHNET - Earthnet, Inc.",
    "22660": "CL-IND-2401 - Cleveland Indians Baseball Company Limited Partnership",
    "22661": "Telex Chile S.A.",
    "22662": "SIA-CORP - SIA, INC.",
    "22663": "PROMINIC-NET-INC - Prominic.NET, Inc.",
    "22664": "CUSTOM-NETWORK - Custom Network Solutions",
    "22665": "IPS iPass Incorporated",
    "22666": "GBHSD - Glenbrook High School District",
    "22667": "VISTA - Vista Broadband Networks, Inc.",
    "22668": "22668-INT Placeholder",
    "22671": "AA - American Association for the Advancement of Science",
    "22672": "PRISMA-NETWORKS - Prisma Networks LLC",
    "22673": "TURBINE - Turbine Inc.",
    "22674": "SOUTHERNWINE - Southern Wine & Spirits of America, Inc.",
    "22675": "MTERBRAND-CABINETS - MTERBRAND CABINETS, INC.",
    "22677": "SENSIENT - Sensient Technologies",
    "22678": "OSDE",
    "22679": "INTEGRATED-TEL - Integrated Telecom Solutions Inc.",
    "22680": "ALIGNTECH - Align Technology, Inc.",
    "22681": "BLUENILE-NETBLK-1 - Blue Nile, Inc",
    "22682": "OCREGISTER - ORANGE COUNTY REGISTER",
    "22683": "PHILIPS-INTERNET Koninklijke Philips N.V. (internet presence)",
    "22684": "SSIMICRO - SSI Micro Internet Services",
    "22685": "FNDRY-NY - Foundry Media LLC",
    "22686": "AMGHQ - All Media Guide",
    "22687": "L3NET - L3 NETWORKS INC",
    "22688": "DOLGENCORP - Dollar General Corporation",
    "22689": "Internet by Sercomtel S.A.",
    "22690": "AxiomNET-",
    "22691": "ISPNET-1 - ISPnet, Inc.",
    "22692": "N-YAMMER - Yammer, Inc.",
    "22693": "NERIC - Albany Schoharie Schenectady BOCES",
    "22695": "ADE-HOSTING - Abacus Marketing Resources, LLC",
    "22696": "CBI- - CB&I",
    "22697": "FOXGAL - Foxworth-Galbraith Lumber Company",
    "22698": "Avantel S.A",
    "22699": "First Data Conosur S.A.",
    "22700": "USFCA - University of San Francisco",
    "22701": "ULTRADNS-1 - UltraDNS Corporation",
    "22702": "X5SOLUTIONS - X5 Solutions, Inc.",
    "22703": "ANTHEM - Anthem Blue Cross Blue Shield",
    "22704": "VPUSA - vente-privee USA, LLC",
    "22705": "MBI - Placements Montrusco Bolton Investments",
    "22706": "Matsunaka & Matsunaka Ltda - ME",
    "22707": "TECTU1-N - TECTURA CORPORATION",
    "22708": "QLA-DIA - CAVALIERS OPERATING CO LLC.",
    "22709": "NSTELCO - North State Telephone Co.",
    "22710": "BRENCOURT - Brencourt Advisors, LLC",
    "22711": "GNA-CORP-GENWORTH-FINANCIAL - Genworth North America Corporation",
    "22712": "LIBCOM-1 - Libcom",
    "22713": "CAC-HQ2 - Credit Acceptance Corporation",
    "22714": "LIBCOM-4AVE - Libcom",
    "22715": "CCDCSPRINGFIELD45502 - Champion City Data Center",
    "22716": "NETARX - Netarx Inc.",
    "22717": "HALLIBURTON - Halliburton Company",
    "22718": "INTERIM-HEALTHCARE - Interim Healthcare, Inc.",
    "22719": "ATLANTICBB-JOHNSTOWN-2 - Atlantic Broadband Finance, LLC",
    "22720": "RACKSPACE-AUS - Rackspace Hosting",
    "22721": "SPC-12 - Saint Peter's University",
    "22722": "SEVONE - SevOne, Inc.",
    "22723": "UN - United Nations",
    "22724": "PUNTONET S.A.",
    "22725": "HOME-COMMUNICATIONS-INC - Home Communications Inc",
    "22726": "C.A. Vencemos",
    "22727": "USADATANET - US Data Net",
    "22728": "THINKSIS - Software Information Systems, LLC",
    "22729": "FRII - Front Range Internet Inc.",
    "22730": "LYONLABS - LyonLabs, LLC",
    "22731": "MTB - Manufacturers and Traders Trust Company",
    "22732": "LINKNET - Kitsap Regional Library",
    "22733": "WGHS-2ISP - West Georgia Medical Center",
    "22734": "DEVRY-DATACENTER-1 - Devry Inc",
    "22735": "Govt-Namibia",
    "22736": "CPS-BGP - Cincinnati Public Schools",
    "22737": "SCHENKERUSA - Schenker Inc.",
    "22738": "LANLOGIC - LanLogic,Inc.",
    "22739": "BYU-H - Brigham Young University Hawaii",
    "22742": "CT-ED-NET - State of Connecticut",
    "22743": "FIRST-AMERICAN-REIS - IS",
    "22744": "WRIGHT-EXPRESS - WRIGHT EXPRESS CORPORATION",
    "22745": "BrT Servi\u00e7os de Internet S.A",
    "22746": "LCTS - Lincoln County Telephone System, Inc.",
    "22747": "TCIS - TulsaConnect, LLC",
    "22748": "SKYNET-CANADA-QC-BLOCK - SkyNet Canada Wireless Fiber",
    "22749": "MARKDALE- - Markdale Cable TV Ltd.",
    "22750": "BCSNET",
    "22752": "MCJUN-1 - MCJUNKIN CORPORATION",
    "22753": "REDHAT-STUTTGART REDHAT Stuttgart",
    "22754": "GAPARTNERS-CT - General Atlantic Service Corp.",
    "22756": "ISLC-BLUFFTON - ISLC, Inc.",
    "22757": "CITY-OF-AKRON-OHIO - City of Akron",
    "22758": "SAPIENT-DCO - Sapient Corporation",
    "22759": "TOUND-CABLE - Wave Broadband",
    "22760": "ECNMEDIA - Entertainment Communications Network, Inc.",
    "22761": "CORSAIR-COMPONENTS - Corsair Components, Inc.",
    "22762": "OFIDEN - OppenheimerFunds, Inc.",
    "22763": "BGP-DUCKS-INC - DUCKS UNLIMITED, INC.",
    "22764": "FD-MFG - FLUOR CORP",
    "22765": "NELSONVILLE-TVCABLE - Nelsonville TV Cable Inc",
    "22766": "TVON - The Ontario Educational Communications Authority",
    "22767": "NA-ESDIS-NET - National Aeronautics and Space Administration",
    "22768": "SYNERGYBROADBAND-MI-02 - SYNERGY BROADBAND",
    "22769": "FONES-WEST-ISP - FONES WEST DIGITAL SYSTEMS, INC",
    "22770": "WHEELS-COM - Wheels Inc.",
    "22771": "THE-COMMON-FUND - The Common Fund",
    "22772": "LOGIN - Login, Inc.",
    "22773": "N-CXA-ALL-CCI-22773-RDC - Cox Communications Inc.",
    "22775": "MOORECAP  for Moore Europe Capital Management Ltd.",
    "22776": "CONRES01730 - Continental Resources",
    "22777": "GIBNEY-ANTHONY-FLAHERTY - Gibney, Anthony & Flaherty, LLP.",
    "22778": "AMARRDOORS - Amarr Garage Doors",
    "22779": "GAARD - Asgaard Holdings, LLC",
    "22780": "ABOUT-COM - ABOUT, INC.",
    "22781": "RBLHST - Reliablehosting.com",
    "22782": "1 - Texas A&M University",
    "22783": "WEBPOWER - WebPower, Inc.",
    "22785": "GLACIER-BANCORP-INC - GLACIER BANCORP INC",
    "22786": "ADOBES-2 - Adobe Systems Inc.",
    "22787": "ARRIS - Arris Group, Inc",
    "22788": "KATYISD - Katy Independent School District",
    "22789": "VMSI - VENTANA MEDICAL SYSTEMS INC",
    "22790": "ACTWORLDNET - Advanced Computer Technologies, LLC",
    "22791": "MSDCAPITAL - MSD Capital, L.P.",
    "22792": "MNET - MOUNTAINET",
    "22793": "PTSDCS - PTS Data Center Solutions, Inc",
    "22794": "AQR - AQR CAPITAL MANAGEMENT LLC",
    "22795": "ABOUT-COM - ABOUT, INC.",
    "22796": "CCC-HART - Campus Crusade for Christ, Inc.",
    "22797": "TEEA - THE ENERGY AUTHORITY",
    "22798": "RED LINK S.A.",
    "22799": "DCC - Delta Cable Communications Ltd.",
    "22800": "IRVINE-ICT - IRVINE COMMUNITY TELEVISION",
    "22801": "INTAP-1 - Intap, LLC",
    "22802": "NIVIS - Nivis",
    "22803": "NOV- - National Oilwell Varco, Inc.",
    "22804": "IDEAL - Ideal Integrations, Inc.",
    "22805": "CNL-FINANCIAL-GROUP - CNL Financial Group Inc.",
    "22806": "TENCO-INC - TENCO, INC.",
    "22807": "CINEMARK-US - CINEMARK USA, INC",
    "22808": "RESOURCES-22808 - LION RESOURCES, INC.",
    "22809": "AMFAM-INS - American Family Insurance",
    "22810": "BROOKS-AUTOMATION - Brooks Automation Inc.",
    "22811": "WSGR - Wilson, Sonsini, Goodrich & Rosati, Professional Corporation",
    "22812": "ADP-CA - Automatic Data Processing, Inc.",
    "22813": "RCAB - ROMAN CATHOLIC ARCHDIOCESE BOSTON",
    "22814": "FRANSERV - Franchise Services, Inc.",
    "22815": "KELLY-INSURANCE-GROUP - Kelly and Associates Insurance Group",
    "22816": "VIT - Virginia International Terminals",
    "22817": "BBVACOMPS - Compass Bank",
    "22819": "Funda\u00e7\u00e3o Universidade de Caxias do Sul",
    "22820": "CYBERA - Cybera, Inc.",
    "22821": "AIPSO-COM - AIPSO",
    "22822": "LLNW- Limelight Networks, INC. proxy  object",
    "22823": "HEARTLANDAMERICA - Heartland America",
    "22824": "BBVACOMPS - Compass Bank",
    "22825": "OMTOOL-BLOCK1 - OMTOOL, LTD",
    "22826": "CALIPER - Caliper Corporation",
    "22827": "SMARTCITY-ORLANDO - Smart City Networks, L.P.",
    "22828": "N-FDA - Parklawn Computer Center / DIMES HQ",
    "22831": "SCG-ARIN - The Scientific Consulting Group, Inc.",
    "22832": "CCHCANADA - CCH Canadian Ltd.",
    "22833": "CTE S.A. de C.V.",
    "22834": "BOSTONCOLLEGE - Boston College",
    "22835": "BDLAWBGP - Beveridge & Diamond, P.C.",
    "22836": "WHINGTON-PENN-PLTIC - WHINGTON PENN PLTIC CO., INC.",
    "22837": "SWIFTCOMM-NET - Swiftcomm, Inc",
    "22838": "GIONA-US - Unilever GIO NA",
    "22839": "STANDARDAERO - Standard Aero Ltd",
    "22840": "ATC-IP-LLC - ATC IP LLC",
    "22841": "NCCNORTHAMPTON - Northampton Community College",
    "22842": "SCCI - Suffolk Construction Company, Inc.",
    "22843": "PROOFPOINT-N-US-ET - Proofpoint, Inc.",
    "22844": "RETRIEVER - RETRIEVER PAYMENT SYSTEMS",
    "22845": "VIRGINIA-COMMUNITY-COLLEGE-SYSTEM - Virginia Community College System",
    "22846": "DTVLA - DIRECTV Latin America, LLC",
    "22847": "BOWDOIN - Bowdoin College",
    "22848": "XL-CAPITAL - XL Capital Ltd.",
    "22849": "CINGULAR-AW - AT&T Services, Inc.",
    "22850": "EPANA - Epana Networks, Inc.",
    "22851": "NSU-SD - Northern State University",
    "22852": "PLESKLOGIN - PleskLogin Net",
    "22853": "EMULEX-1 - EMULEX CORP",
    "22854": "CATAWBA-COLLEGE - Catawba College",
    "22855": "CARDINALHEALTH1 - Cardinal Health, Inc.",
    "22856": "365WIRELESS - 365 Wireless, LLC",
    "22857": "COVINGTONTRAVEL - Covington International Travel",
    "22858": "GDC4S-GROUP - General Dynamics C4 Systems, Inc.",
    "22859": "GOOGLE - Google Inc.",
    "22860": "SERVICIOS INTERNET LTDA",
    "22861": "CAMP-COMM-SERVICES - Camp Communication Services, INC",
    "22862": "EXTROVERSIVE - EXTROVERSIVE NETWORKS, LLC",
    "22863": "MIST - MIST Inc.",
    "22864": "UTPA - The University of Texas - Pan American",
    "22865": "PROJECT-PERFORMANCE - Project Performance Corporation",
    "22866": "AECOM-USPHX3 - AECOM/CCSI",
    "22867": "PALADINARNNO - Paladin Data Systems Corporation",
    "22868": "BDPINTERNATIONAL - BDP International",
    "22869": "SULANET SA / INSETEC GROUP",
    "22870": "SVR-GRX - Syniverse Technologies, LLC",
    "22871": "CHALLC - CHA",
    "22872": "HAPPEWARE-AZ-1 - Happ eWare, LLC.",
    "22873": "FNI - Fiber Networx Inc.",
    "22874": "WESTERN-ILLINOIS-NET - Western Illinois Network",
    "22875": "LIFEU - Life University, INC.",
    "22876": "JOHNSON & JOHNSON BR IND.COM.PR.SAUDE LT",
    "22877": "UMUC - University of MarylandUniversity College",
    "22878": "ACENET1 - ACENET, INC.",
    "22879": "SIRUS-2 - Sirus, Inc",
    "22880": "PRIMED-HPMG - PRIMED MANAGEMENT CONSULTING INC",
    "22881": "USBANCORP-2 - US Bancorp (formerly Firstar Bank)",
    "22882": "CEMEX Central, S.A. de C.V.",
    "22883": "CONDENT - CondeNast Publications",
    "22884": "Iusacell PCS de Mexico, S.A. de C.V.",
    "22885": "I - Advertising Specialty Institute",
    "22886": "ICI-ATL - Incomm",
    "22887": "WIU- - Western Illinois University",
    "22888": "SUAGM - Sistema Universitario Ana G. Mendez",
    "22889": "IP Matrix, S.A. de C.V.",
    "22890": "OPSMILE - OPERATION SMILE, INC",
    "22891": "STANDARDINSURANCE - Standard Insurance Company",
    "22892": "AIRSPEED - Air Speed Internet",
    "22893": "CYBERWORLD-INT - Cyber World Internet Services, Inc.",
    "22894": "NIC M\u00e9xico, S.C.",
    "22895": "CMR1122 - CMR LLC",
    "22897": "84LUMB-CORP - 84 LUMBER COMPANY",
    "22898": "ATLINK - ATLINK SERVICES, LLC",
    "22899": "UMICO - Utica Mutual Insurance Company",
    "22900": "ITRON - ITRON",
    "22901": "ATL-OFFICE - Noble Systems Corporation",
    "22902": "DNIC--22902 - DoD Network Information Center",
    "22903": "EDGEWEBHOSTING - Edgewebhosting.net",
    "22904": "WSITS - Winning Strategies ITS",
    "22905": "SOFTCOMUS - SoftCom America Inc.",
    "22906": "TWAI - FRIT",
    "22907": "ACSSLS - ACS State and Local Solutions",
    "22908": "Sixsigma Networks Mexico, S.A. de C.V.",
    "22909": "COMCT-22909 - Comcast Cable Communications, Inc.",
    "22910": "LOBLAW-COMPANIES - Loblaw Companies Limited",
    "22911": "SINAP-TIX - SINAP-TIX, LLC",
    "22912": "CITGO-PETROLEUM - CITGO PETROLEUM",
    "22913": "CSSTRIPARISH - Computer Sales & Services, Inc.",
    "22914": "BIGRIVER2 - Big River Telephone",
    "22915": "FUTUREQUEST-INC - FutureQuest, Inc.",
    "22916": "PHS-CA - Providence Health & Services",
    "22917": "INFOCHANNEL N-INFOCHAN",
    "22918": "BOOYAH1 - Booyah Inc",
    "22919": "PCCNET - Portland Community College",
    "22920": "BIAEDNET-INTERNET - Bureau of Indian Affairs Office of IndianEducation",
    "22921": "CURIOUSPICTURES - Curious Pictures",
    "22922": "SHGREENPOINTS - ProLogic Consumer Marketing Services, Inc",
    "22923": "YESUP-389 - Yesup Ecommerce Solutions Inc.",
    "22924": "SCOTIABANK CHILE (Banco del Desarrollo)",
    "22925": "ALLIED-TELECOM - Allied Telecom Group, LLC",
    "22926": "11EZEEWEB-24WIRELESS - Ezeeweb.com Inc",
    "22927": "Telefonica de Argentina",
    "22928": "CMR1385 - CMR LLC",
    "22929": "VC3 - VC3, Inc.",
    "22930": "MARY-BALDWIN-COLLEGE - Mary Baldwin College",
    "22931": "HURONCG Huron Consulting",
    "22932": "CCL-224- - Cobridge Communications LLC",
    "22933": "TURKS N-TKI",
    "22934": "SLIC-NETWORK- - Starmount Insurance Agency, Inc.",
    "22935": "WAYNE-BOCES - Wayne Finger-Lakes BOCES",
    "22936": "ESCHELON-180 - Integra Telecom, Inc.",
    "22937": "SHELDON--1 - ACT USA",
    "22938": "BIGCITY-NET - Big City Networks, Inc.",
    "22940": "SILVERLAKE - Silver Lake Technology Management, L.L.C.",
    "22941": "MARYVILLE-DATA-SYS - Marvyille Data Systems, Inc",
    "22942": "Commerzbank London",
    "22943": "INSURAMCE-SERVICES-OFFICE - Insurance Services Office",
    "22944": "KCTCS-INTERNET2 - Kentucky Community and Technical College System",
    "22945": "-PHHS - Parkland Health & Hospital System",
    "22946": "BRIGHTMAIL - Symantec Corporation",
    "22947": "UC4WA - UC4 Software, Inc",
    "22948": "WVUSD - Walnut Valley Unified School District",
    "22949": "GRINNE- - Grinnell College",
    "22950": "USK - University of Saskatchewan",
    "22951": "JCPL-N - Jamison Capital Partners, LP",
    "22952": "ALKINET-1 - Allegany.com Internet Services Inc.",
    "22953": "CALCULQUEBEC - Calcul Quebec",
    "22954": "WQN - WQN, Inc.",
    "22955": "CHHS-1 - Children's Hospital & Health System, Inc.",
    "22956": "T - American Stock Transfer & Trust Co.",
    "22957": "BIGWELLS-01 - Bigwells Technology LLC",
    "22958": "FIDELITY-001 - Fidelity Access Networks, LLC",
    "22959": "NOROC - NOROC BROADBAND, LLC",
    "22960": "RIGAKU-MSC - Rigaku/MSC Inc",
    "22961": "EURO-RSCG-WORLDWIDE- - Euro RSCG Worldwide, LLC",
    "22962": "KENNEDY-NW-DC-US - The Kennedy Center",
    "22963": "BP - Blommer Peterman, S.C.",
    "22964": "ISPT - ISP Telecom",
    "22965": "ALLDATA-NETWORKS - SiteGenie, LLC",
    "22966": "GOSHEN-COLLEGE - Goshen College",
    "22967": "CIMATELECOM1 - Cima Telecom, Inc.",
    "22968": "MIAMI-UNIVERSITY - Miami University",
    "22969": "MARIETTA-FIBERNET Marietta Fibernet",
    "22970": "MAINETECHCOLLEGESYS - Maine Technical College System",
    "22971": "SVHHSTOSF-NET - ST. VINCENT HOSPITAL OF THE HOSPITAL SISTERS OF THE THIRD ORDER OF ST. FRANCIS",
    "22972": "NWHSEA - Northwest Hospital",
    "22973": "NORWEST-VENTURE - Norwest Venture Partners",
    "22974": "INTEAR - Information Technology Architects, Inc.",
    "22975": "Banco de Chile",
    "22976": "FIRST-CITIZENS-01 - First Citizens Bank",
    "22977": "LIT-BMT - Lamar Institute of Technology",
    "22978": "GSU - Governors State University",
    "22979": "DUPACO-COM-BGP - DUPACO COMMUNITY CREDIT UNION",
    "22980": "APOGEE-TELECOM - Apogee Telecom Inc.",
    "22981": "HYGRADEBUSINESS - Hygrade",
    "22982": "LIVE365 - LIVE365, Inc.",
    "22983": "FISERV-INC - Fiserv, Inc.",
    "22984": "ECC-65 - Econotek Communications",
    "22985": "UL-LAFAYETTE-1 - University of Louisiana at Lafayette",
    "22986": "SONICFOUNDRY - SONIC FOUNDRY",
    "22987": "USCABLE-PARAMUS - US Cable of Paramus-Hillsdale, LLC",
    "22988": "SONEPARN1 - Sonepar Management US, Inc.",
    "22989": "FREEINFREEDOM - Free Software Foundation, Inc.",
    "22990": "ALBANYEDU - The University at Albany",
    "22991": "TRENDMLS - Delaware Valley Real Estate InformationNetwork;  Trading as Trend",
    "22992": "SECUREWORKS - SecureWorks Inc.",
    "22993": "DAYMONWORLDWIDE - Daymon Worldwide Inc",
    "22994": "WILLIAMS-GROUP-HOLDINGS-LLC-1 - Williams Group Holdings LLC",
    "22995": "BARR-XPLR-N - Xplornet Communications Inc.",
    "22996": "BIDS - BIDS Trading L.P.",
    "22997": "PREM - Premier America Credit Union",
    "22998": "SWNINET - Southwestern Energy Company",
    "22999": "RAMALLO-BROTHERS - Ramallo Brothers",
    "23000": "WESCOM - Wescom Credit Union",
    "23001": "WEBWIZARDS - Ultimate Internet Corp.",
    "23002": "Primesys Solu\u00e7\u00f5es Empresariais S.A",
    "23003": "MWAA - Metropolitan Washington Airport Authority",
    "23004": "VIEWTRADE - VIEWTRADE SECURITIES",
    "23005": "SWITCH-COMMUNICATIONS - SWITCH Communications Group LLC",
    "23006": "THE-I-GRACE-COMPANY - The I-Grace Company",
    "23007": "Universidad de Los Andes",
    "23008": "NORC-1 - NORC",
    "23009": "NORC-2 - NORC",
    "23010": "FFHSJ - Fried, Frank, Harris, Shriver & Jacobson",
    "23011": "WIDEVOICE-SD - WideVoice Communications, Inc.",
    "23012": "HEATSEEKER-TECHNOLOGY-PARTNERS - HeatSeeker Technology Partners, Inc.",
    "23013": "NET-COM - Network Equipment Technologies, Inc.",
    "23014": "COCENTRAL-DSL - Computer Central of Wilson Inc",
    "23015": "CMC180-TOR- - Cambridge Mercantile Corp.",
    "23016": "23016 - 23016 LLC",
    "23017": "CADURX - CaduRx, Inc",
    "23018": "CSMGUSA - CareSource Management Group, Co.",
    "23019": "BGP1-BOH - BANK OF HAWAII",
    "23020": "Resource Recovery",
    "23021": "BTC-SD - The Bermuda Telephone Company, Limited.",
    "23022": "DSU-CMNST - DELAWARE STATE UNIVERSITY",
    "23023": "INTUITIVE - Intuitive Surgical, Inc.",
    "23024": "OCDE - Orange County Department of Education",
    "23025": "BONDDESK - BondDesk.com",
    "23026": "MSADM-ERISA - ERISA Systems",
    "23027": "BOINGO - Boingo Wireless, Inc.",
    "23028": "TEAM-CYMRU - Team Cymru Inc.",
    "23029": "ESTREET - E Street",
    "23030": "UNIVERSITY-OF-HOUSTON---DOWNTOWN - University of Houston - Downtown",
    "23031": "Unilink Master",
    "23032": "FCS-INDUSTRIES-01 - FCS Industries",
    "23033": "WOWRACK Routing from Hyper to Wowrack",
    "23034": "DESCARTES-SVC1 - Descartes Systems Group",
    "23035": "VOLOGIC-NET - Vologic, Inc.",
    "23036": "NORTHWEST-MINNESOTA-SPECIAL-ACCESS-LLC - Northwest Minnesota Special Access, LLC",
    "23037": "N-MKTGINC - Mktg, Inc.",
    "23038": "BRDBND-USER-GRP - City of Hillsboro",
    "23039": "BELLAMB - Bell Ambulance, Inc.",
    "23040": "CORBIS-LA - Corbis Corporation",
    "23041": "PENNHIGHLANDSCC - Pennsylvania Highlands Community College",
    "23042": "SJRMC-N - San Juan Regional Medical Center Inc.",
    "23043": "ROVER-WIRELESS - Rover Wireless, Inc.",
    "23044": "VMOBILE-CORP - Sprint Nextel Corporation",
    "23045": "WEBCLIENTS - Web Clients Inc.",
    "23046": "STANDARD - Standard Life",
    "23047": "MCKINSEY-US - Mckinsey & Company",
    "23048": "IPSWITCH-INC - Ipswitch Inc",
    "23050": "-EATONV - Eaton Vance Management",
    "23051": "23051 - FHI 360",
    "23052": "IHOST-SOLUTIONS-1 - ihost Solutions, Inc.",
    "23053": "SELECTIVE- - Selective Insurance Company of America",
    "23054": "PRAIRIEINET1 - JAB Wireless, INC.",
    "23055": "JDRCABLES - JDR Cable Systems Inc",
    "23056": "NRT-SAROTA - NRT, Incorportated",
    "23057": "DART-IP-N - DART TRANSIT COMPANY",
    "23058": "DHN-BGP-2002",
    "23059": "LLNW-LAX - Limelight Networks, Inc.",
    "23060": "CGGV-HOU - CGGVeritas Services (US) Inc.",
    "23061": "HSH - Holy Spirit Hospital",
    "23062": "JWPEPPER - J W Pepper and Son, Inc.",
    "23063": "SENTINEL- - Sentinel Properties-Needham, LLC",
    "23064": "HDSMITH-N - H.D. Smith, Inc.",
    "23065": "SBCEO - Santa Barbara County Education Office",
    "23066": "COKEM - COKeM International, LTD.",
    "23067": "OCBCC - Orange County Network Operations",
    "23068": "MEIJERNET - MEIJER",
    "23069": "N1 - Berenson & Company, LLC",
    "23070": "VCHS-ORDNE - Valley County Health System",
    "23071": "HUNTING-INTL - HUNTING ENERGY SERVICES, INC.",
    "23072": "SEM - SEM",
    "23073": "PGI--1 - PGI Solutions LLC",
    "23074": "Petr\u00f3leo Brasileiro S/A - Petrobras",
    "23075": "SKOTOS- - Skotos Tech, Inc",
    "23076": "LT-MILE-COMMUNICATIONS-INC - Last Mile Communications, Inc",
    "23077": "WIRELESSMETRO- - Wireless Metro",
    "23078": "LOUDOUN-CNTY-VA-GOVT - County of Loudoun Virginia",
    "23079": "ARVEST-1 - Arvest Bank Operations",
    "23080": "OUTCOMESCIENCES - Outcome",
    "23081": "VENTURE-NOC - Venture Technologies",
    "23082": "MPHI - Michigan Public Health Institute",
    "23083": "IRONCORE-LAX - Ironcore, Inc.",
    "23084": "CNA-INSURANCE - Continental Casualty Co. (CNA)",
    "23085": "WATSONPHARM - Watson Pharmaceuticals, Inc.",
    "23086": "POUNDBANG-HOSTING - Pound Bang Incorporated",
    "23087": "CDG - Communications Data Group",
    "23088": "TBG The Blackstone Group",
    "23089": "HOTWIRE-COMMUNICATIONS - Hotwire Communications",
    "23090": "PETCO - Petco Animal Supplies, Inc.",
    "23091": "Universidad Autonoma Chapingo",
    "23092": "ISUNET - Internet Services United Networks",
    "23093": "HEALTH-MARKETS - HEALTH MARKETS",
    "23094": "YELLOWBOOK - hibu inc.",
    "23095": "SHARP - SHARP HealthCare",
    "23096": "TRANZACT - Tranzact",
    "23097": "COHEN-STEERS - COHEN & STEERS CAPITAL MGMT., INC.",
    "23098": "PHOENIX-PLANO-EDS - American Airlines Inc.",
    "23099": "SPR - DM Petroleum Operations Company",
    "23100": "CT-METROCT-NET - MetroCast Communications of Connecticut, LLC",
    "23101": "PERCEPTA-GW2- - Percepta",
    "23102": "RMU-EDU - Robert Morris University",
    "23103": "WD-1 - Western Digitech, Inc.",
    "23104": "AMERICAN-TIRE-DISTRIBUTORS-INC - AMERICAN TIRE DISTRIBUTORS, INC.",
    "23105": "BCMG INTERNET LTDA",
    "23106": "Cemig Telecomunica\u00e7\u00f5es SA",
    "23107": "PETRO-CANADA-GLOBAL- - Petro-Canada",
    "23108": "QUANTACT - Quantact Hosting Solutions, Inc.",
    "23109": "23109 - Thomson Reuters U.S. LLC",
    "23110": "GENESIS-N - GENESIS COMPUTER SYSTEMS",
    "23111": "GSC-ATLANTAVPC - Gannett Supply Corp. - Atlanta, GA (VPC)",
    "23112": "EHARMONY - eHarmony.com",
    "23114": "CRITICALHUBNET - Critical Hub Networks",
    "23115": "HEALTHBRIDGE - Healthbridge",
    "23116": "MPA-N1 - Marvin & Palmer Associates, Inc.",
    "23117": "ICOE-NETWORK - Imperial County Office of Education",
    "23118": "SKYBEST - Skyline Telephone",
    "23119": "WSO-LLC - Weiss Special Operations LLC",
    "23120": "LEGACY-OKC-N - Legacy",
    "23121": "SOLD - Housevalues, Inc.",
    "23122": "DSU - Dakota State University",
    "23123": "ATHOC-BGP - AtHoc Inc",
    "23124": "MILLER-TABAK - MILLER TABAK + CO., LLC",
    "23125": "N-MERU - Meru Networks, Inc.",
    "23126": "CENTURYTEL-SOLUTIONS-LLC - CenturyTel Solutions, LLC",
    "23127": "SOFNETINC - Sofnet, Inc.",
    "23128": "HSBC BANK BRIL S.A. - BANCO MULTIPLO",
    "23129": "SUTTERHEALTH - Sutter Health",
    "23130": "BCBGNET1-LA- - BCBG MAXAZRIA GROUP,Inc.",
    "23131": "STARLAN - STARLAN TELECOM CORP.",
    "23132": "RINCHEM-COMPANY - RINCHEM COMPANY",
    "23133": "ARETI-US- - Areti Internet LLC",
    "23134": "NEWPAGE-DMVPN - NewPage Corporation",
    "23135": "LLNW-SJC - Limelight Networks, Inc.",
    "23136": "ONX - OnX Enterprise Solutions Inc.",
    "23137": "RTI-N - Round Table Investments, Inc.",
    "23138": "FIRST-STEP - FIRST STEP INTERNET, LLC",
    "23139": "IHI - Intelligent Holdings, Inc.",
    "23140": "Universidad de Chile",
    "23141": "DTCNET - Doylestown Communications Inc",
    "23142": "GENOPTIX-N - Genoptix Inc.",
    "23143": "ADMC-ONLINE - ATT Broadband",
    "23144": "VCE-COMPANY-LLC - VCE Company, LLC",
    "23145": "BLUE-BOX-GRP - Blue Box Group, Inc.",
    "23146": "BOD - TotalCom America, Corp",
    "23147": "MBG-2425 - Metropolitan Bank Group",
    "23148": "TERREMARK Terremark",
    "23149": "TTG-FL-US - Think Technologies Group LLC",
    "23150": "ARAMARKUNIFORM - ARAMARK Uniform & Career Apparel, LLC",
    "23151": "TERC-1 - Technical Education Research Centers, Inc.",
    "23152": "NDC-INTERNET1- - Nissan North America, Inc.",
    "23153": "KENNAMETAL - Kennametal Inc.",
    "23154": "SANMINA-SCI Sanmina-SCI Corporation",
    "23155": "HTC-NET - HARRISONVILLE TELEPHONE",
    "23156": "UNOVA-1 - Unovation Inc.",
    "23157": "ANRPI- - ANR Pipeline Company",
    "23158": "ETEX-COMMUNICATIONS - ETEX COMMUNICATIONS, LP",
    "23159": "HAREWAVES - Harewaves Wireless Inc",
    "23160": "HEILIND - Heilind Electronics",
    "23161": "VIRTELA-CUST-VNYNYC1-GABROBINS Virtela Communications",
    "23162": "CONTA-27 - Contac Services Inc",
    "23163": "N9E7X5E3N1I2N4C - Nexen Inc.",
    "23164": "LLNW-SFO - Limelight Networks, Inc.",
    "23165": "BP-01 - Brierley & Partners, Inc.",
    "23166": "NORVAX - Norvax, LLC",
    "23167": "PHILIPPICOMMUNICATIONSSYSTEM - City of Philippi",
    "23168": "MCDEAN-N - M.C. Dean,Inc.",
    "23169": "ROBERT-ALLEN - Robert Allen/Decor Holding Inc",
    "23170": "US-ICAP-001 - GARBAN INTERCAPITAL",
    "23171": "MANHATTAN-EDU - Manhattan College",
    "23172": "PENTAGONFEDERALCU - Pentagon Federal Credit Union",
    "23173": "CITISTREET-ENT - CITISTREET",
    "23174": "ARKEMAINC - Arkema Inc.",
    "23175": "POGOZONE - PogoZone",
    "23176": "BICRESEARCHLLC - Basic Research, LLC",
    "23177": "TNB-NET - Thomas & Betts Corporation",
    "23178": "MMI-NET - MONEY MANAGEMENT INTERNATIONAL",
    "23179": "DRIHQ - Directions Research, Inc.",
    "23180": "JISS-JICOMPANIES - JI Specialty Services, Inc.",
    "23181": "QUICKSILVER1 - Quicksilver Wireless",
    "23182": "GREENBRIER- - THE GREENBRIER COMPANIES, INC.",
    "23183": "SWIFTSYSTEMS - SWIFT SYSTEMS, INC.",
    "23184": "PERSONA - PERSONA COMMUNICATIONS INC.",
    "23185": "GHXUS - GHX",
    "23186": "AZCCU-1 - Arizona Central Credit Union",
    "23187": "ICEPTS - iCepts Technology Group",
    "23188": "WIN - Wabash Independent Networks",
    "23189": "OSAM - O'Shaughnessy Asset Management, LLC",
    "23190": "AES - AES Pacific Inc.",
    "23191": "LEMOYNE - Le Moyne College",
    "23193": "CCAC - Community College of Allegheny County",
    "23194": "PENNANTPARK-INVESTMENT - PennantPark Investment Corporation",
    "23195": "NETRIUMNETWORKS - Netrium Networks inc.",
    "23196": "SYSTEMS-APPL-ENG - Systems Application Engineering, Inc.",
    "23197": "GENESYS-SA UK",
    "23199": "COMDATA-NETWORK - Comdata,INC",
    "23200": "ELVAT - Elvate.com, LLC",
    "23201": "Telecel S.A.",
    "23202": "SupportComm S/A",
    "23203": "UNWIRED-EUGENE - UnwiredWest, LLC",
    "23204": "HMSA-NID - Hawaii Medical Service Association",
    "23205": "DIGIS-23205 - JAB Wireless, INC.",
    "23206": "23206 - MTM Technologies, LLC",
    "23207": "NORTHWESTERN-STATE - Northwestern State University",
    "23208": "USD308- - Hutchinson Public Schools",
    "23209": "VHDA20011260123220 - Virginia Housing Development Authority",
    "23210": "DISD-7-ARIN - Denton Independent School District",
    "23211": "JCOM-2 - J2 Global Inc.",
    "23212": "LININ1950-1 - LIN Media",
    "23213": "AMXP - American Express Publishing Corporation",
    "23214": "CESD-1 - Chinook's Edge School Division No. 73",
    "23215": "MEGAPATH-US - MegaPath Networks Inc.",
    "23216": "MEGADATOS S.A.",
    "23217": "EY-CANADA - Ernst & Young",
    "23218": "TMC - Texas Medical Center",
    "23219": "MICROCERV - MicroCerv",
    "23220": "NHFINCH - Nash-Finch Company",
    "23221": "JLBJH - JACK LINK'S BEEF JERKY",
    "23222": "CBS-INC - Computerized Business Solutions, Inc.",
    "23223": "TOTAL-QUALITY-LOGISTICS-INC - Total Quality Logistics",
    "23224": "PARDUS - Pardus Capital Management L.P.",
    "23225": "NORTH-CAROLINA-WIRELESS - North Carolina Wireless, LLC",
    "23226": "TFA - Teach For America, Inc.",
    "23227": "NIKON - Nikon, Inc.",
    "23228": "1-CO-EL-PO-TX - The County of El Paso",
    "23229": "TRANSCANADA - TransCanada Pipelines Ltd.",
    "23230": "BROADNET-DENVER - Broadnet Teleservices LLC",
    "23231": "CMG-01 - Chicago Media Group, LLC",
    "23232": "DORMAN - Dorman Trading, LLC.",
    "23233": "FENWICK - Fenwick & West, LLP.",
    "23234": "MSUSA-FUTURES-1 - MIZUHO SECURITIES USA INC",
    "23235": "BOSMED-88-ENEWTON - Boston Medical Center",
    "23236": "BLACKPOINTPARTNERS - BLACKPOINT PARTNERS NYC LLC",
    "23237": "MCMTER - McMaster University",
    "23238": "ICON-ENTERPRISES - Icon Enterprises, Inc.",
    "23239": "EVO-N - EVO Merchant Services, LLC",
    "23240": "LCA-EXTRANET - LifeCare Assurance Company",
    "23241": "USA-ICS - big planet, inc.",
    "23242": "RUCITYT- LLC \"City-Telekom\"",
    "23243": "COMCEL GUATEMALA S.A.",
    "23244": "CALPOP2 - AirlineReservations.Com, Inc.",
    "23245": "EADS-NORTH-AMERICA--01 - EADS North America, Inc.",
    "23246": "gigaipnet.com Inc",
    "23247": "SAMTECNA - Samtec, inc.",
    "23248": "PPS - Paducah Power System",
    "23249": "AVECTRA - Avectra",
    "23250": "BPS-STAGING - Braintree Payment Solutions, LLC",
    "23251": "BFRC - Bridgestone Firestone Retail & Comercial LLC.",
    "23252": "IK - WTC Communications",
    "23253": "COMCT-23253 - Comcast Cable Communications, Inc.",
    "23254": "CARR-INTERNET - CARR COMMUNICATIONS",
    "23255": "PACIFICORP - Pacificorp",
    "23256": "STARCITE - Starcite, Inc.",
    "23257": "IBMCCH-DAL-EQU - IBM",
    "23259": "PLANES-INCORPORATED - Planes Incorporated",
    "23260": "SCI- - Savage Communications Inc.",
    "23261": "JOHN-MORRELL-1 - John Morrell & Co.",
    "23263": "EL-INTERNET-NORTHWEST - E.L. Internet Northwest",
    "23264": "CONSOLIDATED-SCHOOL-DISTRICT-158 - HUNTLEY SCHOOL DISTRICT NO 158",
    "23265": "POCKETINET - Pocketinet Communications, Inc",
    "23266": "COMCT-23266 - Comcast Cable Communications",
    "23267": "BLEKKO-N - Blekko, Inc.",
    "23268": "NEULION - NeuLion, Inc.",
    "23269": "SVSN-RKE-VA-01 - Sitevision, Inc.",
    "23271": "CITY-OF-WATSONVILLE - City of Watsonville",
    "23272": "EC1-PROD - Marketplace Rewards LLC",
    "23273": "SBWH - Santa Barbara Web Hosting, Inc.",
    "23274": "PRICELINE-COM--01 - Priceline.com",
    "23275": "LM-USA - Lycamobile USA Inc",
    "23276": "WINTSEC - Wintsec Technologies, LLC",
    "23277": "SMARTCITY-SAN-DIEGO - Smart City Networks, L.P.",
    "23278": "SMARTCITY-ANAHEIM - Smart City Networks, L.P.",
    "23279": "SMARTCITY-LOS-ANGELES - Smart City Networks, L.P.",
    "23280": "OS33 - OS33, Inc",
    "23281": "CITY-OF-SACRAMENTO - City of Sacramento",
    "23282": "COUNTYOFSB - Santa Barbara County",
    "23283": "AMEREN - Ameren Corp.",
    "23284": "COMPL- - Complete Genomics Inc.",
    "23285": "GES-NATIONAL-LV - GES Exposition Services",
    "23286": "HULU - Hulu, LLC",
    "23287": "SCRIPPS - Scripps Networks Interactive, Inc.",
    "23288": "TNA-INTERNET - THALES NORTH AMERICA INC",
    "23289": "Connection Network Systems",
    "23290": "SSARIS-ADVISORS-LLC - SSARIS Advisors LLC",
    "23291": "FLAGSTAR-BANK-US - Flagstar Bank",
    "23292": "MILLENIUM-DIGITAL - Broadstripe",
    "23293": "PARKER-DATA-CENTER - Medical Hosting Systems",
    "23294": "ULM-1 - The University of Louisiana at Monroe",
    "23295": "EA-01 - Extend America",
    "23296": "LINCARE-HOLDINGS-INC - LINCARE INC",
    "23297": "IPROS-1 - iProspect.com Inc.",
    "23298": "TELENATIONAL--1 - Telenational Communications, Inc.",
    "23299": "SYS-TECH-NOC1 - STI-Net Inc.",
    "23300": "MDCONNECT - MDConnect Internet Services, USA",
    "23301": "WISC-INVESTMENT-BOARD - State of Wisconsin Investment Board",
    "23302": "STC - South Texas College",
    "23303": "NEXTEL-IT - Nextel Communications, Inc.",
    "23304": "DATOTEL-STL- - Datotel LLC, a NetLabs LLC Company",
    "23305": "WORTHINGTONINDUSTRIES - Worthington Industries Inc.",
    "23306": "PLTIPAK-PACKAGING - Plastipak Packaging",
    "23307": "CDE-NS - Nova Scotia Department of Education",
    "23308": "UTILITY- - UTILITY TELEPHONE, INC.",
    "23309": "CCCOE-NET - Contra Costa County Office of Education",
    "23310": "TTYLIME - TTY LIME",
    "23311": "HINDANET-01 - Hinda Incentives",
    "23312": "NAQUEIT - Naque IT",
    "23313": "GCS-USA - Gonzales Consulting Services",
    "23314": "ORLANDOTELCO - Summit Broadband",
    "23315": "USUT-SLC - Firstsource Solutions USA, Inc",
    "23316": "BAI-IP-SERVICES - Bel Air Internet, LLC",
    "23317": "WHITMANCOLLEGE - Whitman College",
    "23318": "ABBVIE-1 - AbbVie, Inc.",
    "23319": "ENOTCH-NET - Enotch Networks",
    "23320": "PROPPSTC- - Propper International Sales, Inc",
    "23321": "PH-N - Pleasant Holidays LLC",
    "23322": "PSI-N-23322 - Print Mail Systems, Inc.",
    "23323": "NET-DVC - Diablo Valley College",
    "23324": "MFEDS01 - mFormation Technologies Inc.",
    "23325": "MCL-N - Magnitude Capital, LLC",
    "23326": "BROADCOM-CORP - Broadcom Corporation",
    "23327": "ACDNET-N3 - ACD.net",
    "23328": "DFW-BROADBAND-LLC - DFW Broadband, LLC",
    "23329": "-OPENACCESS - Open Access Inc.",
    "23330": "OMEGA-ADVISORS - Omega Advisors, Inc",
    "23331": "EQT - Equitable Resources",
    "23332": "-JDOFTRCKVLLE - JDA Software Group Inc.",
    "23333": "NSPARC - NSPARC",
    "23334": "COMM-OF-BEBALL - Major League Baseball",
    "23335": "GRAVIT-TECHNOLOGY-SERVICES-LLC - Gravitas Technology Services, LLC",
    "23336": "SOLIDSPACE-N - SolidSpace LLC",
    "23337": "ATCE-N - Alfa Tech Cambridge Group",
    "23338": "N-DCS-01 - DCS Pacific Star, LLC",
    "23339": "TACHYON-INC - Tachyon Networks, Inc.",
    "23340": "AFFMANAGERSGRP - Affiliated Managers Group, Inc.",
    "23341": "FIT - Fashion Institute of Technology",
    "23342": "UNITEDLAYER - Unitedlayer, Inc.",
    "23343": "TRNS - Transbeam Inc.",
    "23344": "DWS-DATG - Disney Worldwide Services, Inc.",
    "23345": "WEBCORE - Webcore Technologies, Inc.",
    "23346": "JLTSERVICES - JLT Services Corporation",
    "23347": "HANOVER-HOSPITAL - Hanover Hospital",
    "23348": "EQT - Equatorial Research & Marketing Corp.",
    "23349": "FARMERS-NETWORK-WEST - Farmers Group, Inc.",
    "23350": "SHELL3-SER - Shell Information Technology International, Inc.",
    "23351": "ANSYSNH - Ansys, Inc. - Lebanon NH",
    "23352": "SERVERCENTRAL - Server Central Network",
    "23353": "Metro Net Hosting, S. de R.L. de C.V.",
    "23354": "MEDIARING - Mediaring.com Inc.",
    "23355": "DICTAPHONE-ICHART - Dictaphone Healthcare Solutions",
    "23356": "WANETICS-LLC - WANetics, LLC.",
    "23357": "CXP - CyberXpress, Inc.",
    "23358": "OUTLOOKAMUSEMENTS - Outlook Amusements, Inc.",
    "23359": "WLNYN - WLNY-TV Inc",
    "23360": "Morgan & Morgan",
    "23361": "WVUF - West Virginia University Foundation, Inc.",
    "23362": "DATATXT - Data.txt Corporation",
    "23363": "CITYOFLEWISVILLE - City of Lewisville",
    "23364": "SECOTOOLS-US - Seco Tools Inc.",
    "23365": "IFBYPHONE - Ifbyphone, Inc.",
    "23366": "LSUHEALTHSCIENCESCTR - LSU Health Sciences Center",
    "23367": "GENADAP - Genesis Adaptive, INC.",
    "23368": "DATAONE - DATA ONE LOGISTICS, INC.",
    "23369": "SCOE - Sonoma County Office of Education",
    "23370": "NET-TY - TY INC",
    "23371": "CAEUS- - CAE USA, Inc",
    "23372": "IDCGLOBAL - IDC Global Networks Inc.",
    "23373": "CYENCE-01 - Cyence International",
    "23374": "FPUA - FPUAnet Communications",
    "23375": "GTA-COM - Global Technology Associates, Inc.",
    "23376": "APPSERVE - AppServe Technologies, LLC",
    "23377": "CARLSON - Carlson Companies Inc.",
    "23378": "MPLUSN - Maloney + Novotny LLC",
    "23379": "CHECKAGAIN - CheckAgain",
    "23381": "TRAVELERS - Travelers Property Casualty Corp.",
    "23382": "uServers Comunicaciones SC",
    "23383": "METRORED S.A. DE C.V.",
    "23384": "REEDTECH - Reed Technology and Information Services, Inc.",
    "23385": "PCPL-N - P2 Capital Parnters LLC",
    "23386": "CRYE-LEIKE-REALTORS - Crye Leike Realtors",
    "23387": "NONE---THIS-IS-A-NEW-N-REQUEST - Omsoft Technologies",
    "23388": "DUANE-MORRIS-CHICAGO - Duane Morris",
    "23389": "CAMPBELL-SCIENTIFIC - Campbell Scientific, Inc.",
    "23390": "SUNKIST-GROWERS - Sunkist Growers, Inc.",
    "23391": "OIS-SALUDA - GMP CABLE TV",
    "23392": "VWFS - VW CREDIT, INC",
    "23393": "ISPRIME - ISPrime, Inc.",
    "23394": "PSPINC-BDC - Pacific Software Publishing, Inc.",
    "23395": "ELISPORTSBUREAU - Elias Sports Bureau",
    "23396": "NUTRISYSTEM - Nutrisystem, Inc",
    "23397": "CBOT - Chicago Board of Trade",
    "23398": "ZHONE - Zhone Technologies",
    "23399": "VP - Valley Proteins, Inc.",
    "23400": "IAPC - Internet Access Point Corporation",
    "23401": "NAC-TRANSIT - Net Access Corporation",
    "23402": "KMG125 - Katz Media Group",
    "23403": "THE-COURIER-JOURNAL- - The Courier-Journal, inc.",
    "23404": "RITTERNET - Ritter Communications, Inc.",
    "23405": "COMMERZBANKUSA - Commerzbank AG",
    "23406": "CHOATEHALLSTEWART - CHOATE, HALL & STEWART, LLP",
    "23407": "ALT-N - Alt-N Technologies, Ltd.",
    "23408": "TBI-001 - Trail Blazers, Inc.",
    "23409": "-FOFCOS - Focus on the Family",
    "23410": "NET-NSAU-BOCES - Nassau County BOCES",
    "23411": "PRODUCERS-DAIRY-FOODS - Producers Dairy Foods, Inc",
    "23412": "ABAATLN2 - Abacus Solutions, LLC",
    "23413": "AIRWATCH-US - AirWatch LLC",
    "23414": "AUTORIDAD - Autoridad del Canal de Panama",
    "23415": "G5INTERNET - G5 INTERNET, LLC",
    "23416": "Telefonica Data Chile S.A.",
    "23417": "STORESONLINE-INC-2 - StoresOnline, Inc.",
    "23418": "XCOMMERCE-INC - X.commerce, Inc.",
    "23419": "SUMMADOM - Broad-Connect Telecom Inc.",
    "23420": "JMI-INTERNET1 - Jobson Medical Information, LLC",
    "23421": "CTS-MNS - Core Technology Services, Inc.",
    "23422": "ECL-1 - Endstream Communications, LLC",
    "23423": "HIGH-SPEED-UTAH - HIGH SPEED UTAH LLC",
    "23424": "STATSINC - Stats, Inc.",
    "23425": "HQ01 - CMRE FSI",
    "23426": "BKD-LLP - BKD LLP",
    "23427": "GLENBARD-HSD87 - Glenbard HSD #87",
    "23428": "-GDMX - Global Digital Media Xchange, Inc.",
    "23429": "LUCEFORWARDHS-SD-1 - Luce Forward",
    "23430": "HCCTEL - Hector Communications Corp.",
    "23431": "AHSW-ROSEVILLE - Adventist Health",
    "23432": "TUSCO-NET-1 - Tusco.Net, Inc.",
    "23433": "STAMPS-COM - STAMPS.COM",
    "23434": "SURS - State Universities Retirement System",
    "23435": "PHP-14- - Premier Health Partners",
    "23437": "WEBMETHODS - WebMethods, Inc.",
    "23438": "EZLINKS - EZLinks Golf, Inc.",
    "23439": "KQED-ORG - KQED Inc.",
    "23440": "PEAK10CIN - Peak 10, Inc.",
    "23441": "JNJMOBILE - JNJ Mobile, Inc.",
    "23442": "DMS-BUR - Deluxe Laboratories, Inc.",
    "23443": "JDCAPITAL-BGPN-001 - JD Capital Management, LLC",
    "23444": "SEVERN-TRENT-LABS - SEVERN TRENT LABS",
    "23445": "SCL-N - Sanders Capital, LLC",
    "23446": "NSAI - NSA, LLC.",
    "23447": "NETTECH-N01 - NetTech, LLC",
    "23450": "TRI-NET - Triumph Networking LLC",
    "23451": "ST-OLAF-COLLEGE-TELEPHONE-OFFICE - St. Olaf College Telephone Office",
    "23452": "-UGOTFICO - UGOTFICO, INC.",
    "23453": "NPBI-NOC - NEW PEOPLES BANK, INC",
    "23454": "AKAMAI- - Akamai Technologies, Inc.",
    "23455": "AKAMAI- - Akamai Technologies, Inc.",
    "23456": "RESERVED- assigned by IANA http://www.iana.org/assignments/as-numbers",
    "23457": "BRAMPTON - City of Brampton",
    "23458": "DHH-AUTHORITY - Denver Health and Hospital Authority",
    "23459": "MORINDA - Morinda, Inc.",
    "23460": "CISCO-SECURITY-CONSULTING-DNET - Cisco Systems, Inc.",
    "23461": "DCCA-PHOENIX-DATA-CENTER - Dell Marketing L.P.",
    "23462": "SAUNSTAR-PARKPLAZA - SaunStar Operating Company, LLC",
    "23463": "LONEPINECAPITAL - Lone Pine Capital LLC",
    "23464": "ILCSNET - ILCS Inc.",
    "23465": "NUTELECOM - NU-Telecom",
    "23467": "NEWRELIC--1 - New Relic",
    "23468": "MICROSOFT-CORP-XBOX-ONLINE - Microsoft Corporation",
    "23469": "HIGHWOODS - Highwoods Properties, Inc.",
    "23471": "GICL - GICL Inc.",
    "23472": "SONICWALL-BGP - SonicWALL, Inc.",
    "23473": "PAVLOVMEDIA - PAVLOV MEDIA INC",
    "23474": "SNL-FINANCIAL - SNL Financial",
    "23475": "MAX-CHAMP - MAX CHAMP TECHNOLOGY LIMITED",
    "23476": "SIXFLAGS - SIX FLAGS INC",
    "23477": "AMADEUS-REVENUE-INTEGRITY - Amadeus Revenue Integrity",
    "23478": "INTERNET-SECURITIES - Internet Securities, Inc.",
    "23479": "TSPEC - Technology Specialists",
    "23480": "ZOCDOC - ZocDoc, Inc.",
    "23481": "HCTC-LINK1 - Hill Country Telephone Cooperative, Inc.",
    "23482": "IMAPDATA - iMapData Inc.",
    "23483": "SHTACOE - Shasta County Office of Education",
    "23484": "PACENET - Pace University",
    "23485": "SEI-LLC--NUM - SEI LLC",
    "23486": "NETSPAN - NETSPAN CORPORATION",
    "23487": "CONECEL",
    "23488": "GLOBALECBUSINESS S.A.",
    "23489": "MARINK12 - Marin County Office of Education",
    "23490": "WESTDEVINC - West Development, INC.",
    "23491": "TPCO-NY-GW01 - Thomas Publishing Company LLC",
    "23492": "NEZPERCETRIBE - Nez Perce Tribe",
    "23493": "ACUITY - Acuity, A Mutual Insurance Company",
    "23494": "HSC - Blue Cross Blue Shield of Illinois or Blue Cross Blue Shield of Texas",
    "23495": "Hewlett-Packard Mexico, S. de R.L. de C.V.",
    "23496": "CAMBIAHEALTH - Regence Blue Cross Blue Shield of Oregon",
    "23497": "NCWCOM - NORTH COT WIRELESS COMMUNICATIONS",
    "23498": "CDSI - Cogeco Data Services LP",
    "23499": "ACM-N - Aurelius Capital Management, LP",
    "23500": "EIS - Eagle Investment Systems LLC",
    "23501": "WOLFETECH - Wolfe technologies and Consulting LLC",
    "23503": "BALTIMORE-G- Citadelgroup",
    "23504": "MEGAPATH9-US - MegaPath Corporation",
    "23505": "ECG-CHARLOTTE - Ecommerce Group, Inc. - Charlotte",
    "23506": "MOCANA-SACTO - MOCANA CORPORATION",
    "23507": "LEAFN - LEAF Commercial Capital",
    "23508": "CGH-MAIN-CAMPUS - Chesapeake General Hospital",
    "23509": "INVLOCSVC - Inventory Locator Service, LLC",
    "23510": "CORPORATE-TECHNOLOGY-GROUP-MONTANA - The Computer Shoppe, Inc.",
    "23511": "SOCOCO - Sococo",
    "23512": "RGTS-SJ - Rockefeller Group Telecommunications Service",
    "23513": "WHALEY - AL WHALEY/SUNNY SIDE COMPUTING",
    "23514": "QUANTLAB - QUANTLAB FINANCIAL LLC",
    "23515": "ITSOLUTIONS - IT Solutions Consulting, Inc.",
    "23516": "ALLOY-INC - Alloy, Inc.",
    "23517": "SYSTEMSSOLUTION - Systems Solution",
    "23518": "ICANN-DNS-OPS-E ICANN DNS Operations - East Coast",
    "23519": "NGISCORV - Exchangenet",
    "23520": "COLUMBUS-NETWORKS - Columbus Networks USA, Inc.",
    "23521": "BSERV - BankServ",
    "23522": "N-HRNET - GigeNET",
    "23523": "RAINYDAYSOFTWARECORP - Rainy Day Software Corp.",
    "23524": "MAGNUM - Magnum Communications",
    "23525": "CNC-CNB - Canandaigua National Corporation",
    "23526": "CARLSONCAPITAL - Carlson Capital, L.P.",
    "23527": "CHRISTCATHEDRALCA - Christ Catholic Cathedral Corporation",
    "23528": "SINGLEFIN-GLOBAL-PRESENCE - Singlefin",
    "23529": "BONAPPETIT - BON APPETIT MGMT CO",
    "23530": "CECENTRAL - Guidance Software, Inc.",
    "23531": "TTLC-INTERNET - TTLC",
    "23532": "YADA - Vergent Communications, LLC",
    "23533": "PIP-N - Permian Investment Partners, LP",
    "23534": "PRMSA-EMNET-N - Puerto Rico Medical Services Administration",
    "23535": "HOSTROCKET - HostRocket.com, Inc.",
    "23536": "AREATEMPS-AREANETWORKS - Area Temps, Inc.",
    "23537": "CRITIGEN - Micro Source, Inc.",
    "23538": "IPI - Infinity Pharmaceuticals, Inc.",
    "23540": "AIRTRADE-1 - Airtrade International Inc.",
    "23541": "Scarlet B.V.",
    "23542": "CWI-FNG-N - Florida's Natural Growers",
    "23543": "IDX-SYSTEMS-CORP-ISD - IDX Systems Corporation",
    "23544": "N1 - City of Mission Viejo",
    "23545": "LCA-VISION - LCA Vision, Inc.",
    "23546": "DELCOM-N - Delcom, Inc.",
    "23547": "WINSTON-STRAWN - Winston & Strawn",
    "23548": "THEDACARE - Thedacare",
    "23549": "DATA-IXP",
    "23550": "ULTRACOM - PREPA.Net International Wholesale Transport Inc.",
    "23551": "1-INGWILDE - ING Direct",
    "23552": "KORNU--KR Korea Nazarene University",
    "23553": "IITA--KR Institute of Information Technology Assessment",
    "23554": "SHB Shinhan Bank",
    "23555": "SHB1 Shinhan Bank",
    "23556": "BANKTOWN--KR INITECH",
    "23557": "YUHWA--KR Yuhwa Securities Co., LTD",
    "23558": "KNFC--KR KEPCO Nuclear Fuel Co., LTD.",
    "23559": "SENNB--KR Nambu District Office of Education in Seoul",
    "23560": "METLIFEKOREA--KR MetLife Korea",
    "23561": "YONGINUNIVERSITY--KR Yongin University",
    "23562": "BCRC--KR Busan Cycle Racing Corporation",
    "23563": "VITSSEN-SUWON--KR Tbroad Suwon Broadcating Corporati",
    "23564": "CITIBANKKOREA--KR Citibank Korea",
    "23565": "ADD--KR Agency for Defense Development",
    "23566": "HUNGKUK--KR HungKuk Life Insurance",
    "23567": "PCALIFEKR--KR PCA Life Insurance Co.",
    "23568": "CRA--KR Cycle Racing Association",
    "23569": "SEOJEONG--KR SEOJEONG COLLEGE",
    "23570": "INCHEON--KR UNIVERSITY OF INCHEON",
    "23571": "HDSBANK--KR Hyundai Swiss Savings Bank",
    "23572": "AIAK--KR American International Assurance Korea",
    "23573": "OCIC--KR OCI Information Communication",
    "23574": "KISPRICING--KR KISPricing",
    "23575": "SKN-NW-2--KR SK Networks",
    "23576": "NHN--KR NHN",
    "23577": "ATM-MPLS--KR Korea Telecom",
    "23578": "NAMDONGNET--KR Tbroad Namdong broadcasting",
    "23579": "SENNEIS--KR Seoul Metropolitan Office Of Education",
    "23580": "SEGYE--KR DAILY SPORTSWORLD",
    "23581": "HYNIX--KR HYNIX",
    "23582": "DOOSAN--KR Doosan Information Communication BU",
    "23583": "KEBNO--KR Korea Exchange Bank",
    "23584": "HYROADPUSAN--KR PUSAN CABLE TV SYSTEM CO., LTD.",
    "23585": "JNNEIS--KR Jeollanamdo Office of Education",
    "23587": "KCB--KR Korea Credit Bureau",
    "23596": "EDNSKR1 NIDA",
    "23599": "DDNSKR NIDA",
    "23600": "GDNSKR1 NIDA",
    "23601": "GDNSKR2 NIDA",
    "23602": "DTAC-CRIE--AP DTAC (CRIE Project)",
    "23603": "ICONZ--AP Housing New Zealand",
    "23604": "IBI- Velocity Internet Pty Limited",
    "23605": "DLSUSYS-PH De La Salle University Philippines",
    "23606": "BELLTELECOM-PH--PH Bell Telecommunication Philippines,",
    "23608": "LEI-TRANS-ACT--AU-AP Leading Edge Internet P/L Primary",
    "23609": "EMICNET--AP EMIC Internet Services.",
    "23610": "HZCNC--AP HangZhou City NetCom Info Port Co., Ltd",
    "23613": "NMTNET New Media Tokushima Co.,ltd.",
    "23614": "I-KOCHI Kochi Systems Co., Ltd.",
    "23615": "KUSANAGI University of Shizuoka",
    "23616": "HNB Hitachi Information Systems, Ltd.",
    "23617": "AT-HANA Koutoku-Sangyou Co,.Ltd",
    "23618": "ICV-NET Ibara Broadcasting Company",
    "23619": "E-OSAKA SMARTVALUE Co.,Ltd.",
    "23620": "DOOGA DooGA Co., Ltd.",
    "23621": "GINGANET Ginga System Solution co.,ltd.",
    "23622": "TSURU-GAKUEN Tsuru Gakuen",
    "23623": "CHUO-U Chuo University",
    "23624": "CHUKAI Chukai Television Co,.Ltd.",
    "23625": "TOKAI-WBS TOKAI Communications Corporation",
    "23626": "DILAB Verizon Japan Ltd",
    "23627": "UCVNET UEDA CABLE VISION CO.,LTD.",
    "23628": "ACCSNET Academic newtown Community Cable Service",
    "23629": "OCTV Obihiro City Cable Co.,Ltd.",
    "23630": "CAC-NET CAC Inc.",
    "23631": "KISNET Sofu System, Inc",
    "23632": "TVT-NET TVT Tsuyama Co.,Ltd.",
    "23633": "LOCAL-IX Niigata Communication Service",
    "23634": "E-DNS-JP WIDE Project",
    "23635": "CRCC CRCCMedia Co.,ltd",
    "23637": "BI-CDN-IX Bit-isle Co.,Ltd.",
    "23638": "AMIXCOM AMIXCOM Inc.",
    "23639": "NTT-BIZLINK NTT Bizlink, Inc.",
    "23640": "BBIX BBIX,Inc.",
    "23641": "NSCS-NET NS Computer Service Corporation",
    "23642": "OBIS OBIS",
    "23644": "EGAT--TH Electricity Generating Authority of Thailand",
    "23645": "BBW--AP Broadband Wireless Pty Ltd",
    "23646": "CLARINTSOL--AP Clarinet Internet Solutions",
    "23647": "CCNEP--NP Communications & Communicate Nepal Pvt Ltd",
    "23648": "TAIFOOK-HK-AP Tai Fook Securities Group HK",
    "23649": "NEWSKIES--AP New Skies Satellites, Hong Kong Teleport",
    "23650": "CHINANET-JS--AP  Number for CHINANET jiangsu province backbone",
    "23651": "IDNIC--ID Indonesia Network Information Center",
    "23652": "XLR8-TRANSIT1- XLR8 is an ISP in Australia proving direct internet access",
    "23653": "BNPP--SG BNP Paribas SG, Transit , Singapore",
    "23654": "AARNET-ADL-OFF--AP AARNet Adelaide Office",
    "23655": "SNAP-NZ- Snap Internet Limited",
    "23656": "AOT-TH- New Bangkok International Airport CO.,LTD.",
    "23657": "BLUESKY--AP Blue Sky Communications",
    "23658": "TATABPSOLAR--IN TATA BP SOLAR INDIA LIMITED",
    "23659": "HEITECH--AP APNIC HEITECH N",
    "23660": "CCTLD-PH- PH CCTLD",
    "23661": "CLARAONLINE CLARA ONLINE, Inc.",
    "23663": "YAHOO-BANGALORE--AP Yahoo Bangalore Network Monitoring Center",
    "23664": "WIPRO-TECH--AP Wipro Technologies,",
    "23665": "GSNET--AP Unit 802 Orient Square Building,",
    "23666": "SISTELINDO--ID PT Sistelindo Mitralintas",
    "23667": "BUREAU-OF-METEOROLOGY-AP Commonwealth Bureau of Meteorology",
    "23668": "KPU--KR KOREA POLYTECHNIC UNIVERSITY",
    "23669": "UIP-SYD1--AP United IP - Transit  - Broadband Provider,",
    "23670": "OZSERVERS-AU Oz Servers, Data Centres, Australia Wide",
    "23671": "JMN--ID Jogja Medianet",
    "23672": "ENETNP- Everest Net,",
    "23673": "ONLINE- Cogetel Online, Cambodia, ISP",
    "23674": "MBL--AP Micronet Broadband (Pvt) Ltd.",
    "23675": "TSMCGDN--AP Taiwan Semiconductor Manufactoring Company, Ltd.",
    "23676": "QUICKCUT-AU--AP Quickcut Pre Press Network",
    "23677": "LINK-INET-01-AP Link Innovations,",
    "23678": "MYKRIS--MY MyKRIS Asia Sdn Bhd",
    "23679": "NUSANET--ID Media Antar Nusa PT.",
    "23680": "SOTELCO--AP Southern Telecommunications Company",
    "23681": "ITU-TRANSIT--AP Paradox Digital N on behalf of IT Universe. To provide BGP interconnects to VIX and Paradox.",
    "23682": "PACENET- Broadband Pacenet Pvt. Ltd",
    "23683": "BOONRAWD--TH BoonRawd Brewery Co.,LT",
    "23684": "TAITO--AP Taito Limited,",
    "23686": "N-EQIX-MEL-EE-AP Equinix's Melbourne Peering Exchange",
    "23687": "IPST--AP The Institute for the Promotion of Teaching Science",
    "23688": "LINK3-TECH--BD-AP Link3 Technologies Ltd.",
    "23689": "MAKATISHANGRILA--AP Makati Shangri-La",
    "23690": "AU1NET--AU AU1 Net Pty Ltd,",
    "23691": "MITRA-NET--AP PT Multi Teknologi Sejahtra",
    "23692": "ER-ID- Estiko Ramanda",
    "23693": "TELKOMSEL-N-ID PT. Telekomunikasi Selular",
    "23694": "INDIKANET--ID Indika Telemedia PT.",
    "23695": "ELGANET--ID ELGANET-N PT. Elga Yasa Media Internet Service",
    "23696": "FIRSTIANET--ID PT Asia Utama.",
    "23697": "JALAWAVE--ID Jalawave Cakrawala, PT.",
    "23698": "VIPNET--ID VIP.NET - Internet Service Provider",
    "23699": "EZNET--ID IP Teknologi Komunikasi, PT.",
    "23700": "FTNET--ID Linknet-Fastnet N",
    "23701": "SYMBIO--AP Symbio Incorporated",
    "23702": "ISPONE-AU- ispONE Pty Ltd, Wholesale Telecommunications",
    "23703": "RIGNET--AP RigNet, Communication to offshore rigs in Asia/Pacific.",
    "23705": "EDUCATION-QUEENSLAND--AP Queensland State Government Department responsible",
    "23706": "TNT-AP TNT Australia, NSW",
    "23707": "ISC-PEK1 Internet Systems Consortium",
    "23708": "ISC-BNE1 Internet Systems Consortium",
    "23709": "ISC-HKG1 Internet Systems Consortium, Inc.",
    "23710": "ISC-AKL1 Internet Systems Consortium, Inc.",
    "23711": "ISC-SIN1 Internet Systems Consortium, Inc.",
    "23712": "ISC-TPE1 Internet Systems Consortium, Inc.",
    "23713": "ISC-SEL1 Internet Systems Consortium, Inc.",
    "23714": "KMUCC--KR Keimyung University",
    "23715": "SEOUL-INTGW-GXS-AP Global Exchange Services",
    "23716": "CHANGWON23716--KR Changwon College",
    "23717": "TRUE-SUB2--AP TRUE INTERNET Co.,Ltd.",
    "23718": "DESTRA-AU-AP Destra Communications",
    "23719": "USYD--AP University of Sydney",
    "23720": "FUSIONGOL--AP Fusion Communication Corporation",
    "23721": "ISONET--AU ISONet",
    "23722": "NPBS--AP Newcastle Permanent Building",
    "23723": "NNS--AP National Network Solutions",
    "23724": "CHINANET-IDC-BJ-AP IDC, China Telecommunications Corporation",
    "23725": "TUEC--AP SRIWATTANA",
    "23726": "DEDICATEDSERVERS-AP Dedicated Servers",
    "23727": "MANSOL--AU Managed Solutions Internet  Internet Service Provider",
    "23728": "REPUBLICPOLYTECHNIC- Republic Polytechnic. Multihoming  Singapore",
    "23730": "EGL-HK--AP Evergloss Tours Co. Ltd.   15/F EGL Tower,",
    "23731": "TGS--AP Tibra Global Services",
    "23732": "C3-PH--AP Customer Contact Center Inc.  Contact Center Provider",
    "23733": "BRIDGESTONE-EARTHMOVER--AP Bridgestone Earthmover Tyres Pty Ltd",
    "23735": "EOL--AP Enternet Online Ltd",
    "23736": "COINS-GLOBAL-MY-AP Coins Global Malaysia",
    "23737": "OLYMPIC-P- Olypic Software Ltd",
    "23739": "GOTALK-01-AU-AP GOtalk Pty Ltd",
    "23740": "NESTLE-AOA-MULTIHOME Nestle Globe Centre AOA",
    "23741": "PIPE-HBT- PIPE Networks Hobart Internet Exchange. Used for peering services",
    "23742": "NXGNET2--AP Nextgen Networks",
    "23743": "KDU--KR Keuk Dong University",
    "23744": "CUSTOMS--AP Australian Customs and Border Protection Service",
    "23745": "PIPE-MEL- PIPE Networks Melbourne Internet Exchange.",
    "23746": "TNZI-TELECOM-NZ Telecom New Zealand International",
    "23747": "HUTCHISONESSAR--AP Hutchison Essar Telecom Ltd.",
    "23749": "GLOBAL-TRANSIT--HKCOLO-AP HKCOLO ltd. Internet Service Provider",
    "23750": "GERRYS--AP GERRYS INFORMATION TECHNOLOGY PVT LTD.",
    "23751": "N-IVTECH Internet Vision Technologies",
    "23752": "NPTELECOM-NP- Nepal Telecommunications Corporation, Internet Services,",
    "23753": "WEBMETRIX-AP Webmetrix Pty Ltd, Transit",
    "23754": "CITYLINK--NZ Citylink",
    "23755": "CITYBRIDGE--NZ Citylink",
    "23756": "PADINET--ID PADINET - Padi Internet",
    "23757": "SAKAE--AP Thai Sakae Lace Ltd.",
    "23758": "KRS-HOSTING--AU-AP KRS Hosting",
    "23759": "PRIMENET--KR Prime Information & Telesys",
    "23760": "XPEDITE--AU Xpedite Systems",
    "23761": "XPEDITE--JP Xpedite Systems",
    "23762": "VPNSOLUTIONS-AU VPNsolutions Pty Ltd",
    "23763": "FTID-MELB--AP FT Interactive Data Melbourne",
    "23765": "EA-AU-AP Electronic Arts, Australia",
    "23766": "EA-SG-AP Electronic Arts, Singapore",
    "23767": "A-STAR--AP A-STAR",
    "23768": "ROLTANET--IN RoltaNet",
    "23769": "OSRPARR-N The Office of State Revenue is part of the NSW Treasury.",
    "23770": "NCBS-IN Tata Institute of Fundamental Research",
    "23771": "SXBCTV-AP SXBCTV ,Internet Service Provider,",
    "23772": "ORTELNET- M/s Ortel Communications  Ltd",
    "23773": "EKZM EKZM co.,ltd.",
    "23774": "A-DNS-JP Japan Registry Service Co., Ltd.",
    "23775": "TAMATELE-NET Tamashima TV Inc.",
    "23776": "NEXS NEC Nexsolutions,Ltd.",
    "23777": "VIPALETTE NTT BUSINESS SOLUTIONS CORPORATION",
    "23778": "CANET IMIZU CABLE NETWORK CO.,LTD.",
    "23779": "N-BONE NTT Communications Corporation",
    "23780": "CTB CTB Media Inc.",
    "23781": "TOYAMA-AN- Toyama University",
    "23782": "INFOTOKYO Fujitsu System Solutions Ltd",
    "23783": "CNA Cable Networks Akita Co.,ltd.",
    "23784": "POLEXCHENGE SQUARE ENIX CO., LTD.",
    "23785": "SUNFIELD SUN FIELD INTERNET LIMITED",
    "23786": "MABLE San-in Cable Vision CO.,LTD",
    "23788": "HICT JAPAN CABLENET LIMITED",
    "23790": "KCN-TV Kumamoto Cable Network Corporation",
    "23791": "LCV LCV Corporation",
    "23793": "AIST National Institute of Advanced Industrial Science and Technology",
    "23794": "BMCDN Club iT Corporation",
    "23795": "FURUKAWA Fitec Corp.",
    "23796": "GEMNET NTT Service Evolution Laboratories",
    "23797": "IXO IXO",
    "23798": "VRTC-NET VR Techno Center,inc",
    "23799": "NDA National Defense Academy",
    "23800": "FUKUI-NCT Fukui National College of Technology",
    "23801": "SOL-GIFU NTT Communications",
    "23803": "HGC The University of Tokyo",
    "23804": "AIN-NET Nonprofit Organization Kitaura Hana Net",
    "23805": "WATVNET Ashikaga Cable Television Corp.",
    "23806": "HBS Hiroshima Cablevision Inc.",
    "23807": "RITSUMEI Ritsumeikan University",
    "23808": "TOSHIMA-NET TOSHIMA CABLE NETWORK CO.,LTD",
    "23809": "TV-NARUTO Televi Naruto .CO.,LTD",
    "23810": "IC-NET IC-NET Corporation",
    "23812": "SPEEDWAY-NET Japan Broadband Communications Corporation",
    "23813": "SORUN SORUN Corporation",
    "23814": "T-LEX WIDE Project",
    "23815": "JPIX-RS Japan Internet Exchange Co., Ltd.",
    "23816": "YAHOO Yahoo Japan Corporation",
    "23817": "KOCHI-IDC FUJITSU SHIKOKU Systems Limited.",
    "23818": "JETINTERNET JETINTERNET Corporation",
    "23820": "RAKUTEN Rakuten,Inc.",
    "23822": "HAGINET Hagi Cable Network Co., Ltd",
    "23824": "FUTURE Future Spirits Co.,Ltd.",
    "23826": "DAIDO-IT Daido University",
    "23827": "ANC-NET Azumino Network Community TV",
    "23828": "CHERRY-NET Misaki Town",
    "23829": "MEON-YAMA NTT NEOMEIT YAMAGUCHI CORPORATION",
    "23830": "GAITAME Gaitame.com Co.,Ltd.",
    "23831": "CLOVERNET NISIOWARI CATV CORPORATION",
    "23833": "MARUSAN-NET Marusan Securities Co., LTD.",
    "23835": "SEGANET Sega Corporation",
    "23836": "RELNET RELATION Co., Ltd.",
    "23837": "IPMG--AP IPMG Hosting Provider AUSTRALIA",
    "23838": "SOLARIX-INTERNET--AP Solarix Networks Limited",
    "23839": "LIAOHEOILFIELD--AP LiaoHe Oilfield Telecommunication Company",
    "23840": "ITTEC--AP Tianjin Advanced Information Products Corporation Ltd.",
    "23841": "TJBTN-23841 TIANJIN BROADCT &TV NETWORK CO.LTD",
    "23842": "SZINC--AP Shenzhen Information and Network Center",
    "23843": "BTDC-BJ95795 Beijing Telecom Development Co.BJ 95795 Dept",
    "23844": "BJ-GUANGHUAN-AP Beijing Guanghuan Xinwang Digital",
    "23845": "CNNIC-COL COL CHINA ONLINE INTERNATION INC",
    "23846": "JNGDN--AP Jinan Radio &TV Wellunited",
    "23848": "CNNIC-PAIG-AP PING AN INSURANCE (GROUP) OF CHINA ,LTD.",
    "23849": "CNNIC-NET263-AP Beijing  Capital-online  science development Co.,Ltd.",
    "23850": "CNNIC-CN-COLNET Oriental Cable Network Co., Ltd.",
    "23851": "CNNIC-CQCNC-AP CHONGQING CNC BROADBAND NETWORKS CO.,LTD",
    "23852": "CNNIC-NGNNET-AP Guangdong World Crossing Technology Investment Ltd.",
    "23853": "CNNIC-DSNET-AP Shanghai Data Solution Co., Ltd.",
    "23854": "FAIRFAX--AP",
    "23855": "SINGAREN-GIX--AP Singapore Advanced Research and Education Network",
    "23857": "NEXTEP-AU-AP NEXTEP Broadband, Internet Service Provider,",
    "23858": "SAMDENTECH-BT Samden Tech Private Limited",
    "23859": "UNSW--AP University of New South Wales",
    "23860": "ALLIANCE-GATEWAY--AP Alliance Broadband Services Pvt. Ltd.",
    "23861": "ETRADING--ID-AP PT eTrading Securities",
    "23862": "DILNET--AP University of the Philippines Diliman",
    "23863": "GKY--AP GKY Distributors Pty Ltd,",
    "23864": "SINGAREN-GIX-IHPC--AP Singapre Advance Research and Education Network - National Grid Office - IHPC",
    "23865": "NEXTDIGITAL--AP Next Digital Group Pty Ltd",
    "23866": "SNET--AP Square Net,",
    "23867": "ATWWW-AU- ATWWW Pty Ltd, Web Hosting and Design, Sydney",
    "23868": "NEOCOM--AP Neocom",
    "23869": "NZRS-AP NZRS infrastructure for NZ TLD SRS and DNS servers",
    "23870": "TELEWINGS7-IN 6 Community Center",
    "23871": "AINS--AP Australia Internet Solutions",
    "23872": "DELDSLCORE--AP delDSL Internet Pvt. Ltd.",
    "23873": "TRIPETCH--TH Tripetch Isuzu Thailand, Automobile Business, Bangkok",
    "23874": "COMSSLOGICINTERNET- Commslogic Internet and VOIP",
    "23875": "CSL--AP CSL Limited",
    "23876": "BDNIX--BD Bangladesh National intenet exchange",
    "23877": "DIGITALRIVER--AP Digital River",
    "23878": "SOFTSOURCE--AP Softsource Ltd",
    "23879": "YAHOO-IN1- Internet Content Provider",
    "23880": "YAHOO-AEA Internet content provider",
    "23881": "UDOMAIN--AP UDomain Web Hosting Company Ltd",
    "23882": "NL-INET--AP NEW LITHO DIGITAL PRINTERS",
    "23883": "MOVACI-TH-AP Movaci Technology",
    "23884": "PROENNET- Proimage Engineering and Communication Co.,Ltd.",
    "23885": "ORACLEJAPAN--JP Oracle Japan Corporation",
    "23886": "PWCS--AP Port Waratah Coal Services Ltd,",
    "23887": "PRODATA-TRANSIT--AP PRODATANET INC.",
    "23888": "NTC--AP National Telecommunication Corporation HQ,",
    "23889": "MauritiusTelecom",
    "23890": "LINE--AP Global Logistics Service",
    "23891": "PATAREC--AP Merrill Lynch Phatra Securities",
    "23892": "UCOM--TH United Communication Industry PCL.",
    "23893": "BPL-BD House No:03, Road no: 23/A",
    "23894": "WIFICITY-XAVIER-SCHOOL-PH 64, Xavier St. Greenhills",
    "23895": "WESTPAC-BANKING-CORPORATION--AP Optus Customer Network",
    "23896": "EZNETSOLS--AP EZNETWORKING SOLUTIONS PTE. LTD.",
    "23897": "GLOBALTEK- Globaltek. Games on Demand online gaming company",
    "23899": "VNIX--VN Vietnam Internet network information center (VNNIC)",
    "23900": "PLANET-ONLINE--LA Planet Online Laos, Internet Service Provider in LAO PDR",
    "23901": "SYMPH Global Symphony",
    "23902": "VNNIC--VN Vietnam Internet network information center (VNNIC)",
    "23903": "AKAMAI--BANGLORE Akamai Banglore Office N",
    "23904": "MFE--AP Ministry for the Environment",
    "23905": "VUW--AP Victoria University of Wellington",
    "23906": "GETONIT--AP getonit.com Pty Ltd",
    "23908": "AIRPORT--KR IIAC",
    "23909": "IDS--AP Information Dialing Services Pty Ltd",
    "23910": "CNGI-CERNET2--AP China Next Generation Internet CERNET2",
    "23911": "CNGI-BJIX--AP China Next Generation Internet Beijing IX",
    "23912": "IPV6CJ--AP China Japan Joint IPv6 Test Network",
    "23913": "BLUEPACKETS-AU Blue Packets Trust",
    "23915": "PWC-GWAN-AU PricewaterhouseCoopers Sydney, Australia GWAN",
    "23916": "HOT-NZ HOT TECHNOLOGY",
    "23919": "RAMKHAMHAENG--AP Ramkhamhaeng University",
    "23920": "TFN--HK-AP Thomson Reuters Hong Kong Limited.",
    "23921": "INGDIRECT--AU ING Direct",
    "23922": "BHTAFE-EDU-AU Box Hill Institute of TAFE",
    "23923": "AGNI- Agni Systems Limited",
    "23925": "SS- Siam Sport Syndicate Public Co.,Ltd.",
    "23926": "YAHOO-JP3-AP JP DC",
    "23927": "MILCOM--AP Telecommunication Inc.",
    "23928": "NAMCHENP- Namche Networks P. Ltd",
    "23929": "UBIQUITOUS- Ubiquitous Corp. Data Center Network.",
    "23930": "IPVG--AP IP-Converge Data Center, Inc.",
    "23931": "ACCSYSIT--AP Accsys IT Pty Ltd",
    "23932": "WINTH--AP Internet Service Provider",
    "23933": "SLU--AP SLU Net Office",
    "23934": "TURNSTONE-NZ--AP Turnstone Technologies LTD NZ",
    "23935": "INTELLIGENT-IP-AP Intelligent IP Communications (IIPC)",
    "23936": "EPSILON-SG 151 Lorong Chuan",
    "23937": "ZYLOGAPNIC--AP Zylog Systems India Limited",
    "23938": "ARROWENERGY--AP Arrow Energy Limited",
    "23939": "EZNETSOLS--AP EZNETWORKING SOLUTIONS PTE. LTD.",
    "23940": "THOMSON-FINANCIAL-TOKYO THOMSON FINANCIAL. Financial Content provider.Tokyo",
    "23941": "I2IENTERPRISE-IN i2ienterprise  Internet Service Provider",
    "23942": "PWC-INDIA pricewaterhousecoopers",
    "23943": "HYPERSPIKE--AU-AP Hyperspike Pty Ltd,",
    "23944": "SKYBB--AP -SKYBroadband SKYCable Corporation",
    "23945": "INDOTRANS--ID Indotrans Data, PT",
    "23946": "TOPNET--ID PT Dunia Informasi Teknologi (TOPNET)",
    "23947": "MORATELINDONAP--ID PT.Mora Telematika Indonesia",
    "23948": "ORBICOMNET--ID Global Inti Corporatama PT.",
    "23949": "COMNET--ID PT Comtronics Systems",
    "23950": "GENID--ID Generasi Indonesia Digital PT.",
    "23951": "CITRA--ID PT JEMBATAN CITRA NUSANTARA",
    "23952": "THAMRINNET-ISP-ID Internet Service provider PT.",
    "23953": "SCBDNET--ID PT ARTHA TELEKOMINDO",
    "23954": "BANKMANDIRI-CBN-ID PT. Bank Mandiri (Persero) Tbk.",
    "23955": "BBSAA--AP Bilfinger Berger Services Australia",
    "23956": "DHAKACOM-BD- dhakaCom Limited",
    "23957": "SPECTRUM--IN Spectrum Softtech Solutions P Ltd.",
    "23958": "DTSNZ-GLOBAL-AP DTS ISP New Zealand",
    "23959": "CLI-CL-LINK CoreLogic Global Services",
    "23960": "DATA-TRAFFIC-SERVICES-AP Data Traffic Services",
    "23962": "VNIX--VN Vietnam Internet Network Information Center",
    "23963": "BORDERNET-AU-AP Bordernet Internet Pty Ltd",
    "23964": "GLOBALSTRIDE--AP Globalstride",
    "23965": "CEOSYD--AP Catholic Education Office, Sydney",
    "23966": "LDN--PK LINKdotNET Telecom Limited",
    "23967": "POD Produce On Demand Inc. Streaming Contents Delivery Service Tokyo",
    "23968": "AMALGAMATED-HOLDINGS-LIMITED-AP Optus Customer Network",
    "23969": "TOT-NET TOT Public Company Limited",
    "23970": "COMINDICO-BROADBAND-AP SOUL Australia",
    "23971": "CHUGYE--KR CHUGYE UNIVERSITY FOR THE ARTS",
    "23972": "ANMED--AP AN Medical Center in Seoul, Korea",
    "23973": "FIVE-STARNET--AP 5StarNet Limited,",
    "23974": "MOE-EDNET--AP Ministry of education",
    "23975": "YC--KR Yonam Institute of Digital Technology",
    "23976": "REVITSYS--IN RevitSystems, Tidel Park",
    "23977": "KATIPO--NZ Katipo Communications Limited",
    "23978": "KCRC--AP Kowloon Canton Railway Corporation",
    "23979": "MR--AP-SG S i2i Ltd.",
    "23980": "YU--KR Yeungnam University",
    "23981": "SUWON23981--KR Suwon s Women College",
    "23982": "SENDB--KR Dongbu District Office of Education in Seoul",
    "23983": "DJU--KR Daejeon University",
    "23984": "ACSIND--AP Affliated Computer Services of India P Ltd",
    "23985": "MGB--AP MGB METRO Group Buying",
    "23986": "MR--AP-HK S i2i Ltd.",
    "23987": "MR--US-LA Si2i Ltd.",
    "23988": "PLDTGLOBAL--AP PLDT GLOBAL Corp. Internet-based Services AP",
    "23989": "DGUK--KR Dongguk Univ. at Gyeongju",
    "23990": "MIGUM--KR MigumCableNetwork",
    "23991": "RANKS--BD Ranks ITT Ltd.",
    "23992": "OFFIS--AP Offis Pty Ltd",
    "23993": "OMNINETNETWORKSWA-AU-AP Internet Service Provider",
    "23994": "TRANSWORKS-TRANSIT--AP Aditya Birla Minacs Worldwide Ltd",
    "23995": "VOICEVALLEY VoiceValley Group of Companies",
    "23996": "GLOBE-MOBILE--AP Globe Telecom, Inc",
    "23997": "MOTILE--AP Motile Associates Pty Ltd,",
    "23998": "ALPHANET--AP alpha dot net Australia Pty. Ltd.",
    "23999": "VNA--VN Vietnam News Agency",
    "24000": "JARING-MY--AP  JARING Communications Sdn Bhd, Malaysia Internet Exchange (MyIX)",
    "24001": "IPNET-AU IP Networks (Australia) Pty Ltd",
    "24002": "SCMP--HK-AP South China Morning Post Publishers Limited. English",
    "24003": "JUBL-MAIN--IN JUBILANT ORGANOSYS LTD., INDIA, LEADING CHEMICAL MANUFACTURER",
    "24004": "SHYAM--IN SHYAM Internet service provider in India.",
    "24005": "SAFENZ-TRANSIT--NZ SafeNZ Networks LTD",
    "24006": "KNOSSOS--NZ Knossos Networks Limited",
    "24007": "SEVEN--AP Seven Network N",
    "24008": "HANSEN-AU Hansen Technologies Doncaster",
    "24010": "HELLMANN-HK-AP Hellmann Worldwide Logistics.",
    "24011": "HEALTHWAIKATO--AP Waikato District Health Board",
    "24012": "THOMSONREUTERS-SG 18 Science Park Drive",
    "24014": "BONDUNI--AP Bond University",
    "24015": "SPINETWORKS--AP SPI Networks, Electricity Distribution, Victoria",
    "24016": "ROL-MV--AP Focus Infocom Pvt Ltd, ISP, Male Maldives",
    "24017": "FOXTEL--AU-AP Foxtel Management Pty Ltd",
    "24018": "YAHOO-BACKBONE-AP Yahoo Backbone Network, Asia Pacific",
    "24019": "KLA--AP KLA",
    "24020": "UITM--AP University ITM, Shah Alam, Selangor Malaysia",
    "24021": "APNICRANDNET-TUI-AU TUI experiment",
    "24022": "GCGC--KR GACHONGGIL COLLEGE",
    "24023": "JNPR-APAC--AP Juniper Networks HK Ltd.",
    "24024": "HOLDEN--AU Holden Internet , for Dual ISP redundancy. Holden",
    "24025": "HELIX-WIRELESS--AP Helix Networks",
    "24026": "SUNGHWA--KR Sunghwa Colege",
    "24027": "MOKPOCATHOLIC--KR mokpo catholic university",
    "24028": "CNXNET--MY Redtone-CNX Broadband Sdn Bhd",
    "24029": "NIXI-IN- NIXI is an IXP in India",
    "24030": "SCHENKER--SG Schenker (Asia Pacific) Pte Ltd",
    "24031": "YAHOO-TPC Internet Content Provider",
    "24032": "AC3- ac3, Australian Centre for Advanced Computing and",
    "24033": "ACTIV8ME--AP Australian Private Networks Pty Ltd",
    "24035": "MOFA--VN Ministry of Foreign Affairs of Vietnam - MOFA",
    "24036": "RIVKIN--AP Rivkin Discount Stockbroking Pty Ltd",
    "24037": "FUSION--AU-AP Fusion Enterprises Pty Ltd",
    "24038": "FAPL--AP Fujitsu Asia Pte Ltd, NOC and RIM",
    "24039": "ITC-GLOBAL--AP ITC Global (Australia)",
    "24040": "D1--TH DataOne Asia (Thailand) Co.,Ltd.",
    "24041": "VCUSTOMER-INDIA--AP VCustomer Services India Pvt Ltd. Transit .",
    "24042": "BKKAIR--TH-AP Bangkok Airways Co., Ltd.",
    "24043": "DATAPIPE-HK-AP DataPipe Hong Kong",
    "24044": "BHARTI-TRANSIT--AP Leading Internet Transit IP Service Provider, New Delhi",
    "24045": "KADEO--AP Kadeo Pty Ltd",
    "24046": "PERPETUAL-AP Perpetual Services Pty Ltd",
    "24047": "ISC-KIX1 Internet Systems Consortium, Inc.",
    "24048": "ISC-CGK1 Internet Systems Consortium, Inc.",
    "24049": "ISC-MAA1 Internet Systems Consortium, Inc.",
    "24050": "ISC-DAC1 Internet Systems Consortium, Inc.",
    "24051": "ISC-KHI1 Internet Systems Consortium, Inc.",
    "24052": "INDOSATM2--ID INDOSATM2 Diamond Customer",
    "24053": "MEDNETWORK--AP Quantum Internet",
    "24054": "AIRNZ--AP Air New Zealand Limited",
    "24055": "DB-APAC-IN- Deutsche Bank AG-India Internet",
    "24056": "SINGTEL-EXPAN-JP Internet Data Centre",
    "24057": "AIGL--AP PT. AIA FINANCIAL, Insurance company, Indonesia",
    "24058": "ITPARTNERS--HK-AP IT Partners Limited",
    "24059": "CMNET2--AP China Mobile communications corporation",
    "24060": "KCS-TH- KRUNG THAI COMPUTER SERVICES",
    "24061": "DIDATA--AU-AP Dimension Data,",
    "24063": "DOCOMOINTERTOUCH-IN DOCOMO interTouch - India Operation",
    "24065": "JV14--AP PO Box 848",
    "24066": "VNNIC--VN Vietnam Internet Network Information Center",
    "24067": "TRUE-SUB3--AP TRUE INTERNET Co.,Ltd.",
    "24068": "REDTONE-MY- Broadband Service Provider",
    "24069": "STAPLES--AP 163 O'Riordan Street Mascot",
    "24070": "BAYANTEL-IPCORE Bayantel Inc. IP CORE  number",
    "24071": "GARENA-PHIL-PH Garena Philippines Inc.",
    "24072": "PROMINA-AP Suncorp",
    "24073": "WORLDNET--AP World Net Services Ltd.",
    "24074": "NZPOST-NZ-AP New Zealand Post",
    "24075": "MOE-NET-SG-AP MINISTRY OF EDUCATION, SINGAPORE",
    "24076": "SWU--AP Srinakharin Wirot University,",
    "24077": "TMHK-TRANSIT--HK-AP TMHK Global Transit",
    "24078": "TRADEME--WLG-NZ Trade Me Limited",
    "24079": "DATAONE-PH--AP DATAONE IA PHILIPPINES, INTERNET DATA",
    "24080": "ROSEITS--IN Rose IT Solutions",
    "24081": "SPITECH- SPI Technologies Inc.",
    "24083": "SCCC-TH Siam City Cement Public Company Limited",
    "24084": "HCL-TECH-IN PLOT NO: 3A, SECTOR 126, SEZ, NOIDA",
    "24085": "QTSC--VN Quang Trung Software City Development Company",
    "24086": "VIETTEL--VN Viettel Corporation",
    "24087": "VNGT--AP Vietnam New Generation Telecom",
    "24088": "HANOITELECOM--AP Hanoi Telecom Joint Stock Company - HCMC Branch",
    "24089": "VNNIC--AP Vietnam Internet Network Information Center",
    "24090": "UNISAINS--AP Universiti Sains Malaysia (USM)",
    "24091": "INNOVE-MSDDNPLUS-AP Innove Multi-Service Data Network",
    "24092": "MOORECOLLEGE--AP Moore Theological College",
    "24093": "BIGAIR-AP BIGAIR. Multihoming N",
    "24094": "DMEXCH-PH Digital Media Exchange",
    "24095": "VITRO-INTERNET-EXCHANGE ePLDT - Vitro Internet Data Center",
    "24096": "METLIFETW--AP Metlife Taiwan Taipei Office Multihomed",
    "24097": "MAGNECOMP-CSLOXINFO--TH-AP CSLOXINFO Project for Magnecomp Precision",
    "24098": "ETHERWAVE- Fish Telecom Pty. Ltd.",
    "24100": "WIREFREE-TRANSIT1-AP Wirefree Networks,",
    "24101": "UNE--AP University of New England",
    "24102": "PEOPLESUPPORT--CEBU-AP PeopleSupport Inc.",
    "24103": "GREENFIELD--AP ToLuna is in to Online Data Collection for Market Research",
    "24104": "POLYFONE--AU POLYFONE TELECOM - WIRELESS ISP - GLD CORE",
    "24105": "UNWIRED-CORE-AP Unwired Group, Fixed Wireless Broadband Access, Sydney",
    "24106": "DMPI--AP DMPI, Digitel Mobile Philippines Inc.,",
    "24107": "COMMARC-N-AP CommArc Consulting Ltd",
    "24108": "PIPE-INT--AP PIPE Networks Limited",
    "24109": "WNSNET WNS Global Services",
    "24110": "SEMA--AP Sema Operations Pty Limited, Australian ,",
    "24111": "NZWIRELESS-CO-NZ--AP nzwireless LTD",
    "24112": "SCB--HK-AP Standard Chartered Bank (Hong Kong) Limited",
    "24113": "EAIX-AP East Australian Internet Exchange",
    "24114": "N-EQIX-SGW-EE-AP Equinix Asia Pacific",
    "24115": "N-EQIX-MLPE Equinix",
    "24116": "N-EQIX-SYD-EE2-AP Equinix Asia Pacific",
    "24117": "TECHONE--AP Technology One Ltd, Fortitude Valley, QLD",
    "24118": "VIRTELA1--AP-1 Virtela Communications",
    "24119": "RCBC- RCBC Makati City Philippines",
    "24120": "AEMO-INET--AU Australian Energy Market Operator LTD",
    "24121": "N-EQIX-OSAKA-AP Equinix Asia Pacific",
    "24122": "BDCOM-BD--AP BDCOM Online Limited",
    "24123": "VIANET--NP Vianet Communications Pvt Ltd",
    "24124": "EKTOO-BD- Ektoo Limited",
    "24125": "ELDERS-LIMITED--AP Elders Limited, Rural Services Provider",
    "24126": "UNISYS-AP-UI--AP Unisys AsiaPac Intranet Access to Internet",
    "24127": "IENERGIZER--IN iEnergizer",
    "24128": "PHUKETINTERNET- Phuket Internet Co.. Ltd",
    "24129": "OFFICELINK--AP OfficeLink Plus Pty Ltd",
    "24130": "PIPETRANSIT--AP PIPE Networks Pty Limited",
    "24131": "SMARTMV-PH SMART MV NETWORK",
    "24133": "CHINA-21VIANET 21vianet(China) Inc.",
    "24134": "CNNIC-CNLINKNET-AP CNLink Networks Ltd.",
    "24135": "CNNIC-ITBN-AP BJ-SHUMA",
    "24136": "CNNIC-AP China Internet Network Information Center",
    "24137": "CNNIC-HNPCNET-AP HeNan Ping Coal Group",
    "24138": "CRNET_BJ_IDC-CNNIC-AP China Tietong Telecommunication Corporation",
    "24139": "CNNIC-WU-AP WU TV & Communication Holding Co.,Ltd.",
    "24140": "CHINA-21VIANET-AP 21VIANET(CHINA),INC",
    "24141": "CNNIC-DMTNET-AP Shanghai DMT Information Network cor.,LTD.",
    "24142": "CNNIC-BENNALONGNET-AP Shanghai Bennalong Network Technology Co.,LTD",
    "24143": "CNNIC-QCN-AP Qingdao Cable TV Network Center",
    "24144": "YITAIFENG--AP Yitaifeng",
    "24147": "CNNIC-CBDTELENET-AP BEIJING CBD TELECOM CO,.LTD",
    "24149": "CNNIC-KNET-AP KNET Techonlogy (BeiJing) Co.,Ltd.",
    "24150": "CNNIC-SCN-AP SiChuan Broadcasting & TV Net Co.,LTD",
    "24151": "CNNIC-CRITICAL-AP China Internet Network Infomation Center",
    "24152": "CNIC-IPV6TESTBED-AP Computer Network Information Center of",
    "24153": "DIGICEL Digicell Entertainment Co., Ltd",
    "24154": "APBT--TW Asia Pacific Broadband Fixed Lines Co., Ltd.",
    "24155": "APBW--TW Asia Pacific Broadband Wireless Communications Inc",
    "24156": "SONY-TW- Sony Taiwan Limited",
    "24157": "VIBO-NET- Vibo Telecom Inc.",
    "24158": "TAIWANMOBILE- Taiwan Mobile Co., Ltd.",
    "24159": "TYCATV- Tong Ya Cable T.V. Co.Ltd",
    "24160": "CHIMEI- Chi Mei Corporation",
    "24161": "SIMPLENET--TW Simple InfoComm Co., Ltd.",
    "24162": "LANWIN--TW Lanwin Communication Co. Ltd",
    "24163": "UBBNET--TW UNION BROADBAND NETWORK",
    "24164": "YJL-MEDIATV-NET YEONG  JIA  LEH CABLE TV CO., LTD.",
    "24165": "PHOENIX-NET-TW PHOENIX  CATV  CO.,LTD",
    "24166": "GTTNET--TW Grand Tainan Technology Co.Ltd.",
    "24167": "GCNET Academia Sinica Grid Computing Center",
    "24168": "WEBTAIWAN--TW WIS Internet Inc",
    "24169": "CHUAN-CHAN-NET-A Chuan Chan Co. Ltd.",
    "24170": "SPARQ-IDC- New Century InfoComm Tech. Co., Ltd.",
    "24171": "FITEL--TW FIRST INTERNATIONAL TELECOM CORP.",
    "24172": "LINCHEIN-NET- Lin Chein Technology Co. Ltd.",
    "24173": "NETNAM--AP Netnam Company",
    "24174": "EAB--AP Eastern Asia Comercial Bank",
    "24175": "VINAREN--AP VietNam Research and Education Network",
    "24176": "NETNAMHCMC--AP Branch of Netnam Company in Ho Chi Minh City",
    "24177": "INET--AP iNET Media Company Ltd",
    "24178": "GODREJ--IN Godrej Infotech limited",
    "24179": "IMI--AP IMI, Manufacturing Semiconductors and Electronics",
    "24180": "CCTLD-ID--AP ccTLD-ID Anycast N",
    "24181": "THELOOP TheLoop",
    "24182": "INTERPUBLIC--GISAP- Interpublic GIS",
    "24183": "DTS-ISP-CORE1-AP DTS LTD",
    "24184": "GOVERNMENT-NETWORK-MALDIVES National Centre for Information Technology, Male', Maldives",
    "24185": "I-FLEX- I-FLEX Solutions Limited, Software Development, Mumbai, India",
    "24186": "RAILTEL--IN RailTel Corporation of India Ltd., Internet Service Provider, New Delhi",
    "24187": "KIRZ--TH KIRZ Service Provider",
    "24188": "N-SURRENDERONLINE-AP Surrender Online",
    "24189": "IBM-GS-ITS-NZ-AP IBM New Zealand Limited,",
    "24190": "SET--TH The Stock Exchange of Thailand",
    "24192": "DIGIWEB-NET-NZ-AP Digiweb New Zealand Limited,",
    "24193": "SIFY-IN Sify Limited Service Provider India",
    "24194": "PISHON-MAGICNET--ID MAGICNET - Triple Play",
    "24195": "DHECYBER--ID Dhecyber Flow Indonesia, PT",
    "24196": "GLOBAL--ID PT Global Cibubur Access",
    "24197": "BIGNET--ID Elka Prakarsa Utama, PT",
    "24198": "JUPITERNET--ID Datakom Wijaya Pratama, P.T.",
    "24199": "DNK--ID Dini Nusa Kusuma, P.T.",
    "24200": "CAKRAMEDIA--ID PT. Cakramedia Indocyber",
    "24201": "ANDALMEDIA--ID PT. Andalas Media Informatika",
    "24202": "PAKTELNET--ID PT. PIFIKTEL INDOTAMA",
    "24203": "NAPXLNET--ID PT Excelcomindo Pratama (Network Access Provider)",
    "24204": "SATNETCOM--ID Satnetcom Balikpapan PT.",
    "24205": "BANKPERMATA-THIS--IDNIC-ID PT. Bank Permata Tbk.",
    "24206": "CHANNEL11--ID PT Cakra Lintas Nusantara",
    "24207": "EXPRESSNET--ID PT. Net2Cyber Indonesia",
    "24208": "NAPXLNET--ID PT Excelcomindo Pratama (Network Access Provider)",
    "24209": "INTERMEDIANET--ID PT. Inter Media Lintas Nusa",
    "24210": "ANGKAWAVE--ID Angkasa Sarana Teknik Komunikasi PT",
    "24211": "DETIK--ID PT. Detik Ini JUga",
    "24212": "JNET--ID PT. JNITA TELEKOMINDO",
    "24213": "ARSEN--ID PT. Arsen Kusuma Indonesia",
    "24214": "RESERVED-CSLOXINFO-TH CSLOXINFO",
    "24215": "24215-AMCOM-AP Amcom Telecommunications Ltd.",
    "24216": "VIRTELA--AP-2 Mumbai, IN",
    "24217": "SANSIRI-CSLOX--TH Sansiri",
    "24218": "GTC-MY-PIP- Global Transit Communications - Malaysia",
    "24219": "NFI--AP No Fuss Internet",
    "24220": "HOSTCENTRAL--AP Hostcentral",
    "24221": "ZZONE-PH Z-Zone Philippines, Inc",
    "24222": "OFFICETIGER-ANNANAGAR-INDIA- OFFICETIGER DATABE SYSTEMS INDIA PVT LTD",
    "24223": "PBBA--AU Personal Broadband Australia, iBusrt Wireless Network provider.",
    "24224": "ISI-CEIC--AP CEIC Data Co., Ltd.",
    "24226": "CATALYST-IT--AP Catalyst IT",
    "24228": "BARNETWORK-AP BarNetwork Pty Limited",
    "24229": "KOCHI-IX IX-layers, Inc., Regional IXP in Japan, regional ISP",
    "24231": "ATU--AP Multihomed network",
    "24232": "VIRTELA--AP-3 Frankfurt, DL",
    "24233": "BIGAIR-AU BigAir Group,",
    "24234": "OMNI-TRANSIT-AP OMNIconnect VIC Peering Transit",
    "24235": "CHIEF-TW--AP CHIEF Telecom Inc.",
    "24236": "YAHOO-BANGALORE--AP Yahoo Bangalore Network Monitoring Center",
    "24237": "RESERVED-CSLOXINFO-TH CSLOXINFO",
    "24238": "DEDICATED-SERVERS-BNE--AP Dedicated Servers - Brisbane",
    "24240": "WIZZ-WISP-AU-AP Wizz Communications",
    "24241": "LEVELUP-PH Level Up",
    "24242": "MFU--AP Education Network, Chaingrai,Thailand",
    "24243": "TELARUS--AP Telarus Pty Ltd.  xDSL Provider, Australia",
    "24244": "MULTINET-AFG- MULTINET AF",
    "24245": "PNAPSYD001--AP Internap Network Services",
    "24246": "PNAPHKG001--AP Internap Network Services",
    "24247": "PNAPSIN001--AP Internap Network Services",
    "24248": "N-WADAI-U Wakayama University",
    "24249": "JWAY JWAY co., Ltd.",
    "24250": "MC-IDC Miyagin Computer Service Co.,ltd",
    "24251": "ICNTV-NET Iwakuni Cable Network Corporation",
    "24252": "JPRS-NAYUTA Japan Registry Service Co., Ltd.",
    "24253": "J-STREAM J-Stream Inc.",
    "24254": "KYOTO-SU Kyoto Sangyo University",
    "24255": "T-CATV Tannan Cable Television Corporation",
    "24256": "SOFTBANKBB SOFTBANKBB Corp.",
    "24257": "JPIX-64ES Japan Internet Exchange Co., Ltd.",
    "24259": "BC9 kanuma cable television Corporation",
    "24260": "KINJO- Board of trusty: Kinjo-Gakuen",
    "24261": "MIE-U Mie University",
    "24262": "HICOM HAMANU INFORMATION Co., Ltd.",
    "24263": "HONDA-NET HONDA MOTOR Co., Ltd.",
    "24264": "KANAZAWA-IT Kanazawa Institute of Technology",
    "24265": "AGILIT NTT Communications Corporation",
    "24268": "SAINS National University Corporation Shizuoka University",
    "24270": "CRC-KCC CRC Solutions Corp.,",
    "24271": "ICTV Iruma CATV co.",
    "24273": "CANON CANON INC.",
    "24274": "ACTELION-JP Actelion Pharmaceuticals Japan Ltd.",
    "24275": "TOTO TOTO LTD.",
    "24276": "ICNET JCN Ichikawa Limited",
    "24277": "NIRAI Okinawa Cable Network Co.,Ltd",
    "24278": "USEN-NET USEN CORPORATION",
    "24279": "CAT-V SENDAI CATV CO.,LTD.",
    "24280": "HIS-TKIDC Hitachi Information Systems, Ltd.",
    "24281": "MCNET-T NTT SmartConnect Corporation",
    "24282": "KIR KAGOYA JAPAN Inc.",
    "24283": "MIEDEN-NET MIEDEN SYSTEM SOLUTION .LTD",
    "24284": "CYBERAGENT CyberAgent, Inc.",
    "24286": "WNI- Weathernews,Inc.",
    "24287": "TEIN2-JP National Institute of Informatics",
    "24288": "ACCUTECHS Accutechs Co., Ltd.",
    "24289": "KBN Kagawa T.V Broadcast Network Co,.Ltd",
    "24290": "HEARTNET Heart Network Co.,LTD",
    "24291": "MITSUI-NW MITSUI & CO., LTD.",
    "24292": "NSSOL NS Solutions Corporation",
    "24293": "INFOSAKYU FUJITSU SYSTEMS WEST LIMITED",
    "24295": "-PNAPOSK Internap Japan Co.,Ltd.",
    "24296": "YAHOO-2 Yahoo Japan Corporation",
    "24297": "FCN Osaka Prefecture University",
    "24298": "APOLLOGLOBAL-PH Apollo Global Net , Application Service Provider, Manila",
    "24299": "ISSP- Internet Solution & Service Provider Co., Ltd",
    "24300": "IBM-PH--AP IBM Philippine",
    "24301": "BJHDBN--AP Beijing Haidian Broadband Network",
    "24303": "GOLDCORP--AU Gold Corporation, Precious Metal Manufacturer and Retail, Perth, Western Australia",
    "24304": "ARW-HK-AP Arrow Asia Hong Kong .",
    "24305": "BRITE--AP BRITE NSW PTY LTD",
    "24306": "NETPLAY--AP NETPLAY INC. is an internet gaming provider",
    "24307": "AFTABIT- AFTAB IT  Number for BDIX Peering",
    "24308": "DAFFODILBD- Daffodil Online  for BDIX Connection",
    "24309": "CABLELITE--AP Atria Convergence Technologies Pvt. Ltd.  Broadband Internet Service Provider INDIA",
    "24310": "NGDC--AP Net-Glyph Data Center",
    "24311": "CNGI-CMNETV6--AP China Mobile Communications Corporation IPv6 network",
    "24312": "AXGNDOTCOMDOTSG-SG-SG www.axgn.com.sg",
    "24313": "NSW-DET- NSW Department of Education and Training",
    "24314": "UPSI--AP University Pendidikan Sultan Idris",
    "24315": "GATEWAY-TRANSIT- Gateway Internet. Transit  Internet Service Provider Bunbury Australia",
    "24316": "POWERLINK--AP Powerlink Queensland",
    "24317": "SHARP-CORP--AU Sharp Corporation of Australia, Manufacturer, Sydney, Australia",
    "24318": "MINEDU--NZ-AP Ministry of Education",
    "24319": "AKAMAI-TYO-AP Akamai Technologies Tokyo N",
    "24320": "RAILCOM Railcom - Commercial Center,",
    "24321": "OCENET--AP OCE Sdn Bhd ISP",
    "24323": "AAMRA-NETWORKS--AP aamra networks limited,",
    "24324": "BCL-TRANSIT--AP Kordia Limited",
    "24325": "COGETEL-AZCOMM- AZ Communications CO. Ltd, No 6C, Street 392, Boeung",
    "24326": "TTT--AP TT&T PUBLIC COMPANY LIMITED 252/30 Muang Thai-Phatra Complex Tower1 24 Flr, Ratchadaphisek Road, Huaykwang, Bangkok.",
    "24327": "ZAPAPPINDIA-IN--AP Zapapp india Pvt Ltd",
    "24328": "YRU--AP Yala Rajabhat University Education",
    "24329": "ERX-STAR Elliott Advisors (HK) LTD, Financial, Central HK",
    "24330": "NICHOLLS-PRICE--AU-AP Netregistry Pty Ltd",
    "24331": "EBAY-IA- eBay Inc IA N eCommerce San Jose",
    "24332": "LIND--AP Lason Inc",
    "24333": "JOBSDBHK Jobs DB Hong Kong Limited",
    "24334": "CYBERPORT-HK-AP Cyberport Hong Kong",
    "24335": "MSLOT--AP Customer",
    "24336": "DIGITALBANK-JP DIGITALBANK, Inc., Regional ISP in Japan",
    "24337": "SKYTELECOM--AP Skytelecom ,  Transit provider and ISP in Vientiene.",
    "24338": "SALMAT--AU-AP Salmat",
    "24339": "ZARNEX- Zarnex PTY LTD Transit",
    "24340": "LOGAN-CITY-COUNCIL--AP Optus Customer Network",
    "24341": "ALL-INTERACTIVE-DISTRIBUTION--AP ALL INTERACTIVE DISTRIBUTION",
    "24342": "BRAC-BDMAIL--BD BRAC BDMail Network Ltd.",
    "24343": "BDIGTAL-AU- B Digital Pty Ltd",
    "24344": "CMRU--AP Chiangmai Rajabhat University",
    "24346": "CROSSCITY-MOTORWAY--AP CrossCity Motorway",
    "24347": "INTERGEN-WGTN--NZ Intergen Limted. Internet Service Provider - Wellington NZ.",
    "24348": "CNGI-BJ-IX2--AP CERNET2 IX at Tsinghua University",
    "24349": "CNGI-BJ-IX3--AP CERNET2 IX at Peking University",
    "24350": "CNGI-BJ-IX4--AP CERNET2 IX at Beijing University of Posts and Telecommunications",
    "24351": "CNGI-BJ-IX5--AP CERNET2 IX at Beijing University of Aeronautics and Astronautics",
    "24352": "CNGI-TJN-IX--AP CERNET2 IX at Tianjin University",
    "24353": "CNGI-XA-IX--AP CERNET2 IX at Xi'an Jiaotong University",
    "24354": "CNGI-LZH-IX--AP CERNET2 IX at Lanzhou University",
    "24355": "CNGI-CD-IX--AP CERNET2 IX at University of Electronic Science and Technology of China",
    "24356": "CNGI-CHQ-IX--AP CERNET2 IX at Chongqing University",
    "24357": "CNGI-GZ-IX--AP CERNET2 IX at South China University of Technology",
    "24358": "CNGI-WH-IX--AP CERNET2 IX at Huazhong University of Science and Technology",
    "24359": "CNGI-CHS-IX--AP CERNET2 IX at Central South University",
    "24360": "CNGI-ZHZ-IX--AP CERNET2 IX at Zhengzhou University",
    "24361": "CNGI-NJ-IX--AP CERNET2 IX at Southeast University",
    "24362": "CNGI-HEF-IX--AP CERNET2 IX at University of Science and Technology of China",
    "24363": "CNGI-JNN-IX--AP CERNET2 IX at Shandong University",
    "24364": "CNGI-SH-IX--AP CERNET2 IX at Shanghai Jiaotong University",
    "24365": "CNGI-SH-IX2--AP CERNET2 IX at Fudan University",
    "24366": "CNGI-SH-IX3--AP CERNET2 IX at Tongji University",
    "24367": "CNGI-HZH-IX--AP CERNET2 IX at Zhejiang University",
    "24368": "CNGI-XMN-IX--AP CERNET2 IX at Xiamen University",
    "24369": "CNGI-SY-IX--AP CERNET2 IX at Northeast University",
    "24370": "CNGI-DLN-IX--AP CERNET2 IX at Dalian University of Technology",
    "24371": "CNGI-CHC-IX--AP CERNET2 IX at Jilin University",
    "24372": "CNGI-HRB-IX--AP CERNET2 IX at Harbin Institute of Technology",
    "24373": "VDSLNETWORK-MY VDSL NETWORK SDN BHD  INTERNET SERVICE PROVIDER KUALA LUMPUR",
    "24374": "HCLBPO-SERVICES HCLBPO-IN",
    "24375": "LIBERTYFIN--AP Liberty Financial Pty Ltd, Financial Services,",
    "24376": "YAHOO-CN2-AP Yahoo China Datacenter",
    "24377": "BAYANTEL-TANTRA- Bayan Telecommunications - Tantra",
    "24378": "ENGTAC--TH-AP Total Access Communication PLC.",
    "24379": "JINET-SCIB Jasmine Internet Co, Ltd. for multihome Corporate",
    "24380": "SOHONET-AP Sohonet Asia Pacific IP network",
    "24381": "FTHIT--AP Web Hosting and Colocation Services",
    "24383": "CAI-STA CAI-STA Inc.",
    "24384": "DPE--AP Dunedin Peering Exchange",
    "24385": "SMARTLINX3--AP Smartlinx3 - Wellington Regional Internet Exchange",
    "24386": "NETWORKER--AP Networker",
    "24387": "SIX--AP SDN Internet Exchange",
    "24388": "CHIX--AP Christchurch Internet Exchange",
    "24389": "GRAMEENPHONE--AP GrameenPhone Ltd.",
    "24390": "USP--AP University of the South Pacific",
    "24391": "IGATE- iGATE Global Solutions Limited is a software development company and located in India, Asia PAC countries, USA and Europe",
    "24392": "ANKHNET--AP Ankhnet Informations Pvt. Ltd., Internet Service",
    "24393": "SHR--AP The Secretariat of House of the Representive",
    "24394": "DPC--AU Department of the Premier and Cabinet",
    "24395": "DAY3_IA-PACIFIC_ Day3 Pty Ltd",
    "24396": "BOC--HK Bank Of China(Hong Kong) Limited",
    "24397": "STPI-LUCKNOW Software Technology Parks of India-Lucknow",
    "24398": "AUT-NZ-AP Auckland University of Technology",
    "24399": "ABN-PEERING--AP Asia Broadcast Networks Peering",
    "24400": "CMNET-V4SHANGHAI--AP Shanghai Mobile Communications Co.,Ltd.",
    "24402": "CNNIC-URBANNET-AP Beijing Urban Network Co.,Ltd",
    "24403": "CNNIC-CNCITYNET-AP Beijing Kuanjie Net communication technology Ltd",
    "24404": "CNNIC-TOPNEWNET-CN-AP Beijing Topnew Info&Tech co,.LTD.",
    "24406": "CNNIC-CRITICAL-AP China Internet Network Infomation Center",
    "24407": "CNNIC-YOUXINNET-AP Harbin mengxun chuanshu transmission Information technology Co., Ltd.",
    "24408": "CNNIC-CRITICAL-AP China Internet Network Infomation Center",
    "24409": "CNNIC-CRITICAL-AP China Internet Network Infomation Center",
    "24410": "CNNIC-CRITICAL-AP China Internet Network Infomation Center",
    "24413": "CNNIC-SUNRISE-AP ShenZhen Sunrise Technology Co.,Ltd.",
    "24414": "CNNIC-CHT-AP Beijing horizon telecommunication",
    "24415": "CNNIC-JXBTIN-AP Jiangxi Broadcasting and TV information Network",
    "24416": "CNNIC-PRIMETELECOM-AP Beijing Primezone Technologies Inc.",
    "24417": "CNNIC-XMGDNET-AP Xiamen Broadcasting & TV Network Transmit Co.Ltd",
    "24418": "YUELIANNET Beijing YuelianXinxi Co.Ltd",
    "24420": "CNNIC-CAFNET-AP Chinese Academy of Forestry",
    "24421": "CNNIC-SHNAP-AP SHANGHAI NETWORK ACCESS POINT",
    "24422": "CNNIC-HTXX Huatong information network",
    "24423": "CNNIC-SETVN Fujian Southeast Radio & TV Network Co Ltd.",
    "24424": "CNNIC-GOOGLECN-AP Beijing Gu Xiang Information Technology Co.,Ltd.",
    "24425": "CNNIC-CNGITN China Tietong Telecommunication Corporation",
    "24426": "CNNIC-SINO-I Beijing CE Huatong Information Technology Co., Ltd.",
    "24427": "CNNIC-FREENET Freecomm Corporation",
    "24428": "CNNIC-FOUNDERBN-AP Beijing Founder Broadband Network Technology Co.,Ltd",
    "24429": "ALISOFT Aliyun Computing Co., LTD",
    "24430": "CNNIC-CHINAPOST-AP CHINA STATE POST BUREAU",
    "24431": "QUT--AP Queensland University of Technology",
    "24432": "AXIATA-ROBI--AP TM International Bangladesh Ltd.Internet service Provider,Gulshan-1,Dhaka-1212",
    "24433": "CQU--AP Central Queensland University",
    "24434": "JCU--AP James Cook University",
    "24435": "SUPERNET-PAKISTAN--AP Supernet Limited Transit Autonomous System Number",
    "24436": "UQ--AP University of Queensland",
    "24437": "UWA--AP University of Western Australia",
    "24438": "DTDIGITAL-AP- BrightHost Pty Ltd",
    "24439": "NTAMAR--AP MARSHALL ISLANDS NTA ISP",
    "24440": "CYBERNET-APII Cyber Internet Services Pakistan",
    "24441": "CITYLINK--KH CityLink, Routing",
    "24442": "BMW--AP BMW Asia Technology Sdn Bhd",
    "24443": "ISPNET--AU ISP Networks Pty Ltd Service Provider Australia",
    "24444": "CMNET-V4SHANDONG--AP Shandong Mobile Communication Company Limited",
    "24445": "CMNET-V4HENAN--AP Henan Mobile Communications Co.,Ltd",
    "24446": "NETREGISTRY--AP NetRegsitry Pty Ltd.",
    "24447": "CLARINET-TRANSIT--AP Clarinet Australia",
    "24448": "NDSINDIA- NDS India Limited, Bangalore",
    "24449": "EMSD--HK-AP Electrical and Mechanical Services Department",
    "24450": "NPS--AU P providing Payroll Services.",
    "24451": "PDS-GROUP--AP Philippine Dealing System,",
    "24453": "CRU--AP Chandrakasem Rajabahat University",
    "24454": "SKYREACH-TRANSIT--HKN-AP Loral Skynet Inc.",
    "24455": "ITONECSLOX--TH ITONE (The Siam Cement Group)",
    "24456": "SYKES-PHILIPPINES Sykes Asia Inc. Call Center Philippines",
    "24457": "JABBAWOKIGROUP Jabbawoki Group Pty Ltd",
    "24458": "PLDT-IPCORE--AP PLDT IPCORE Backbone",
    "24459": "NETVALUE--AP NetValue Ltd",
    "24460": "CNCGROUP-OLD-CQINFO Old Chongqing CNC Broadband Networks Co.",
    "24461": "POGT-TRANSIT- P&O Global Technologies Transit  Internet Service Provider",
    "24462": "HKJC--HK-AP Network Management Section",
    "24463": "PACNAT--AP Pacific National (ACT) Ltd.,",
    "24464": "ANU--AP Australian National University",
    "24465": "KSEC-AP Kasikorn Securities PCL,",
    "24466": "HDNETNZ hd.net.nz",
    "24467": "DB-APAC-RHO- Deutsche Bank APAC RHO in Singapore Internet",
    "24468": "STREAM--IN Stream International, India",
    "24469": "QUADRAHOSTING Net Quadrant Pty Ltd",
    "24470": "MAIS--JP MAIS(Miyazaki Area Internet Society)",
    "24471": "GLOBAL-UST--IN USsoftware P Ltd.",
    "24472": "IAG-CSLOXINFO--TH-AP CSLOXINFO Project for IAG Insurance",
    "24473": "SANITYTECHNOLOGY--AU-AP Sanity Technology Pty Ltd",
    "24474": "NPANYCT Nepal Internet Exchange NP Anycast",
    "24475": "THAIREN-TRANSIT--AP ThaiREN.Thailand Research and Education Network Thailand",
    "24476": "RPL-CANBERRA--AU Rural Press",
    "24477": "NETAPP Network Appliance IAPAC",
    "24478": "ANGKORNET-CDC--AP CAMBODIA DATA COMMUNICATION CO,.LTD. CONTENT SERVICE PROVIDER PHNOMPENH.",
    "24479": "EET-NEXIUM--AP Nexium, Ergon Energy Telecommunications.",
    "24480": "EPWORTH-MULTIHOME-AU-AP Epworth Hospital",
    "24481": "CONNECTBD- ConnectBD Ltd. Internet Service provider, House#41, Road#1/A, Block#I, Banani, Dhaka",
    "24482": "SGGS--AP SG.GS",
    "24483": "SITESUITE--AP SiteSuite Australiasia P/L,",
    "24484": "PNT-ORCON-NZ-AP Orcon Internet, Palmerston North",
    "24485": "GSPC-IN- Gujarat State Petroleum Corporation",
    "24486": "VIRTELA--AP-4 Kuala Lumpur, MY",
    "24487": "EPICSOFT EPICSOFT",
    "24488": "NAVITAIRE--AU-AP Accenture Australia Pty Ltd",
    "24489": "TEIN2-NORTH-AP Trans-Eurasia Information Network (TEIN2) - North",
    "24490": "TEIN2-SG-AP Trans-Eurasia Information Network (TEIN2) - SG",
    "24491": "MTGCL--AP My Telecom Group Company Limited",
    "24492": "WICAM- WiCAM ISP Cambodia Peering",
    "24493": "STIXLITE--AP STIXLITE Transit Service Provider Singapore",
    "24494": "CBCNET--AP Chinabanking Corp.",
    "24495": "GNET-CN-AP gnet Integrated Services Co.",
    "24496": "GNET--MN GNET Co.,Ltd  Internet Service Provider Mongolia",
    "24497": "PANJANAVIT-SCHOOL--TH-AP Panjanavit School is KinderGarten and Primary School",
    "24498": "NXGNET3--AP Nextgen Networks",
    "24499": "TPP--PK Telenor Pakistan",
    "24500": "IVOX--AP 110/330 Wattle Street",
    "24501": "GLOBAL-ARVATOINDIA- Bertelsmann Marketing Services India Pvt. ltd.",
    "24502": "PARLOFWA--AU Parliament of Western Australia",
    "24503": "HIMALTECH--AP Himal Technologies Pvt Ltd",
    "24504": "COMPLAND--NP Computer Land Communications Global",
    "24505": "ABS-CBN- ABS-CBN Broadcasting Inc.",
    "24506": "YAHOO-TP2 YAHOO! TAIWAN",
    "24507": "FFTFILL-NET-AU Level 29, Tower Building",
    "24508": "MIRROR-IMAGE-AP 2 Highwood Drive",
    "24509": "XPEDITE--KR Xpedite Systems  Electronic document distribution and data messaging service provider Seoul, Korea",
    "24510": "HOLMESGLEN-INSTITUTE-OF-TAFE-AP Optus Customer Network",
    "24512": "HAL-INTERNET HAL Internet,  Internet Service Provider, Tottori, Japan",
    "24513": "DOJ-TRANSIT--AP Department of Justice",
    "24514": "MYREN-MY Malaysian Research & Education Network",
    "24515": "STPI-JAIPUR Software Technology Parks of India-Jaipur",
    "24516": "VIRTUTEL--AP Virtutel Pty Ltd",
    "24517": "FLITECH-AU Flight Centre Limited, eCommerce Travel Services",
    "24518": "AXIS--ID PT. Axis Telekom Indonesia",
    "24519": "IDNIC-ID Indonesia Network Information Center",
    "24520": "IDNIC-ID Indonesia Network Information Center",
    "24521": "DATAUTAMA-NET--ID PT. DATA Utama Dinamika",
    "24522": "GLOBALPORTNET--ID PT Global Port Binekatara",
    "24523": "ORION--ID Orion Cyber Internet",
    "24524": "IDNIC-ID Indonesia Network Information Center",
    "24525": "SAP--ID PT Solusi Aksesindo Pratama",
    "24526": "BINUS Bina Nusantara University",
    "24527": "DAKARANET--ID Internet Service Provider",
    "24528": "KTP--ID PT. Khasanah Teknologi Persada",
    "24529": "IDNIC--ID Indonesia Network Information Center",
    "24530": "POWERNET--ID PT. Power Telecom Indonesia",
    "24531": "TN--ID Telemedia Nusantara, PT.",
    "24532": "INET--ID PT. Inet Global Indo",
    "24533": "ENCIETY--ID Enciety Binakarya Cemerlang,P.T",
    "24534": "TRANSHYBRID--ID PT. Transhybrid Communication",
    "24535": "ISATNET--ID PT.Insan Sarana Telematika",
    "24536": "ELNUS--ID PT. Elektrindo Data Nusantara",
    "24537": "PDA--ID PT Paket Data Andal",
    "24538": "DIGISATNET--ID DIGITAL SATELLITE INDONESIA PT.",
    "24539": "SYNOPSYS-INDC- Synopsys Inc.",
    "24540": "TG--AP THAI AIRWAYS INTERNATIONAL PUBLIC COMPANY",
    "24541": "FORTYFIVERU--AU 45RU Pty Ltd. Internet Service Provider, Perth, Western Australia.",
    "24542": "INTERGEN--AU InterGen Australia is an electricity generator within Australia.",
    "24543": "FIRSTDATA--AU  FIRST DATA ELECTRONIC tRANSACTION PROCESSOR SYDNEY",
    "24544": "PANGNET--AP Pang International Limited- number",
    "24545": "SOUTH--AP HKCOLO LIMITED .8/F.,Sino Favour Centre ,",
    "24546": "GLOBAL-BP--AP BP Pte Limited, Energy Company, Singapore",
    "24547": "CMNET-V4HEBEI--AP Hebei Mobile Communication Company Limited",
    "24548": "BAYCITY--AP BayCity Communications Limited",
    "24549": "SPEEDVPS--AP Pacificnet Hosting Ltd",
    "24550": "WEBSURFERNP--NP Websurfer Nepal Internet Service Provider",
    "24551": "VIACOMM--AP VIACOMM is an ISP offering internet over cable. It is connected",
    "24552": "AVAGOTECH--AP Avago Technologies Asia-Pacific Zone",
    "24553": "SCBNETWORK--AP Southern Cross Broadcasting.",
    "24554": "FIVE-NET--IN Fivenetwork Solution India Pvt Ltd Internet",
    "24555": "APRICOT-APNIC-N N used for conferences in AP region",
    "24556": "BIJOY-BD--AP Bijoy Online Ltd. Multihome Internet Service Provider",
    "24557": "UBERGLOBAL--AP UberGlobal Pty Ltd",
    "24558": "AVBIHNET--IN Internet Hosting Service Provider to the Aditya",
    "24559": "GMOBILE-MN G-Mobile Corporation",
    "24560": "AIRTELBROADBAND--AP Bharti Airtel Ltd., Telemedia Services",
    "24561": "WA-POLICE-AU-AP WA Police",
    "24562": "UNESCAP--AP The United Nations Economic and Social Commission for Asia and the Pacific (ESCAP)",
    "24563": "NEWSAT-SYDNEY--AU-AP NewSat Ltd - Sydney POP",
    "24565": "NETCRAFT--AP NetCraft Australia Pty Ltd, Systems Integrator, Adelaide",
    "24566": "ETL-GPRS--AP ETL GPRS Network",
    "24567": "WINET-TRANSIT--AP Wireless Internet Provider, Transit  ISP Cambodia",
    "24568": "CITI-HK-ISP_PEER-AP Citibank N.A. - ISP Peering, Hong Kong, China",
    "24569": "N-EQIX-BRI-EE-AP Equinix's Brisbane Peering Exchange",
    "24570": "TYROPAYMENTS--AU TYRO PAYMENTS LIMITED, Specialist Credit Card Institution",
    "24571": "VIRTELA--AP-5 Bangalore, IN",
    "24572": "YAHOO-JP--AP Yahoo Japan",
    "24573": "SIAMIDC-TH- SiamIDC. Internet Data Center Thailand.",
    "24574": "NTSIPL--IN Nuance Transcription Services India Private Limited",
    "24575": "DRAGONLAB--AP DRAGONLAB",
    "24576": "NWT- OOO Nord-West Telecom",
    "24577": "ADSNET- Autonomous System Number for ADSnet, Cameroon",
    "24578": "RIP- Rudzki Inkubator Przedsiebiorczosci Sp. z o.o.",
    "24579": "POLTAVAINFOCOM- POLTAVAINFOCOM PJSC",
    "24580": "SUPSA SUPSA SUPERMERCATS PUJOL SL",
    "24581": "GIC- Equinix (Germany) GmbH",
    "24582": "SYNNET-1 synaix Gesellschaft fuer angewandte Informations-Technologien mbH",
    "24583": "BIZINFO BizNet Infoservices, P & Hosting services",
    "24584": "AEGIS Aegis Media Danmark A/S",
    "24585": "CH-SWISSLIFE Swiss Life AG",
    "24586": "NL-INTERMAX Intermax BV",
    "24587": "NL-IO Integrated Internet Services B.V.",
    "24588": "NETPROVODOV- OOO Company Tron",
    "24589": "TELENETSIA- Telenet SIA",
    "24590": "COMPLETE complete internet & security gmbh",
    "24592": "NEXICA- Nexica",
    "24593": "UATOP Global Ukraine Trade Ltd.",
    "24594": "FSYS Frontier Systems Ltd.",
    "24595": "INNOFACTOR Innofactor Ltd multi-homed network",
    "24596": "IHSENERGY- Petroconsultants MAI Limited/IHS Energy Group",
    "24597": "ITL- Instytut Lacznosci - Panstwowy Instytut Badawczy",
    "24599": "MIRTELECOM- Closed Joint-Stock Company \"MirTeleCom of name E.K. Pervishin\"",
    "24600": "WANADOOPORTAILS- Orange S.A.",
    "24601": "MWTV-2 SIA \"MWTV\"",
    "24602": "RADIONET-T- Radionet-T Ltd.",
    "24603": "XOO- Ulf Kieber",
    "24604": "ELILILLY- Eli Lilly and Company Limited",
    "24605": "FSBERG Fassberg Holding AB",
    "24606": "FINANZINFORMATIK--SUED Finanz Informatik GmbH & Co. KG",
    "24607": "LENET UAB Technologiju ir inovaciju centras",
    "24608": "H3G- H3G S.p.A.",
    "24609": "SOLAR- Solar Unity Ltd",
    "24610": "UGPPNET- ISP UGPP NET",
    "24611": "DCLUX- Datacenter Luxembourg S.A.",
    "24612": "PENZA-SVIAZINFORM- OJSC Rostelecom",
    "24613": "BURDA JSC Publishing House Burda",
    "24614": "SAKARYA-NET- Sakarya University",
    "24615": "CUKUROVA- Cukurova University",
    "24616": "BELINTERNETPAGE- BELINTERNETPAGE",
    "24618": "BIGLINE- VELTON.TELECOM Ltd",
    "24619": "CDMPEKAO- Centralny Dom Maklerski Pekao S.A",
    "24620": "RTU Rigas Tehniska Universitate",
    "24621": "STENOS- PP Stenos",
    "24622": "NATEL- Autonomous System Number for Natel, Ghana",
    "24623": "FMCOMPUTER F&M Computer GmbH & Co. KG",
    "24624": "IOFT- IA Soft Aragon  Number",
    "24625": "ACCENTURE-UK- Accenture Ltd",
    "24626": "TTKNN- CJSC TransTelecom-NN",
    "24627": "SHOWNET-KW- GULFSATCOMMUNICATIONS COMPANY K.S.C.",
    "24628": "TXU- TXU Europe",
    "24629": "NIL- NIL Data Communications Ltd.",
    "24630": "EPIXTECH- Epixtech Ltd",
    "24631": "AZADNET Azadnet Autonomous System",
    "24632": "ROSIGNOL- Markus Rosignol",
    "24633": "KMS Kuwait Messenging Services",
    "24634": "CYBERIA- Cyberia",
    "24635": "FREUDENBERG- Freudenberg IT KG",
    "24636": "TELETECH- TeleTech",
    "24637": "WEBDISCOUNT WEBDISCOUNT GmbH & Co. KG",
    "24638": "RAMBLER-TELECOM- Rambler Internet Holding LLC",
    "24639": "INFRERV- InfraServ GmbH & Co.Hoechst KG",
    "24640": "BSWS- BS Web Services N",
    "24641": "FTER- This is  for ISP Faster, Brno, CZ.",
    "24642": "NL-CAVEO  for Caveo Internet BV",
    "24643": "CHELLO--IPV6 UPC Broadband GmbH",
    "24645": "ITI UAB Informacijos Tiltas",
    "24646": "ILSE Sanoma Digital the Netherlands b.v.",
    "24647": "ECETRA- s IT Solutions AT Spardat GmbH",
    "24649": "VISUALMC Visual Mc srl",
    "24650": "CHARLES-STANLEY- Charles Stanley & Co Ltd",
    "24651": "LVBALTICOM- JSC BALTICOM",
    "24652": "JUNIPER-EMEA- Juniper Networks International B.V.",
    "24653": "MOVITEX- Movitex",
    "24654": "RETELECOM France Telecom Espana S.A.",
    "24655": "BOC- BANK OF CYPRUS PUBLIC COMPANY LIMITED",
    "24656": "ARZ ARZ ALLGEMEINES RECHENZENTRUM GmbH",
    "24657": "DOKUMENTA-1 Dokumenta AG",
    "24658": "IVC- Information & Computing Center, Ltd.",
    "24659": "VESSO-BEL JV \"Vesso-Bel\" ZAO",
    "24660": "EVOZON- EVOZON SYSTEMS SRL",
    "24661": "COMPLETEDATA- MDS Technologies Ltd - Corsham, Wiltshire UK",
    "24662": "TECHLINE- \"Technoline\" LTD",
    "24663": "COMPLAT- ISP company COMPLAT",
    "24664": "NADRA- Open Joint Stock Company Commercial Bank Nadra",
    "24665": "SUTC- OJSC Rostelecom",
    "24666": "AXA- AXA Luxembourg S.A",
    "24667": "PO- OMV Petrol Ofisi",
    "24670": "COHTECH01- Coherent Technology Solutions Limited",
    "24671": "PILICKA- MNI Telecom S.A.",
    "24672": "CALLSAT- Callsat Telecom Ltd.",
    "24673": "FIRSTSERV- Firstserv Limited",
    "24674": "TSR- RTS Radio Television Suisse",
    "24675": "LGCSB- Irish Government",
    "24676": "LINETEX- Keyweb AG",
    "24677": "TAYLOR-NELSON-SOFRES- Taylor Nelson Sofres",
    "24679": "SSERV- Hostway Deutschland GmbH",
    "24680": "COMPNET- This  intended for multihome routing of CompNet IP address space",
    "24681": "SUMIX-UA- SUMIX Ukraine LLC",
    "24682": "KSF-N KSF Ltd.",
    "24683": "OSU- State Educational Institution of Higher Professional Education Orenburg State University",
    "24684": "CYBER-HOSTING IPport ZAO",
    "24685": "ALIGOTEL- Elenkom LLC",
    "24686": "UPNET-N University of Pecs",
    "24687": "N-IANET CerTeam",
    "24688": "KHARKOVIX-N ITL Company",
    "24689": "ROSINTEL- Rosintel Network",
    "24690": "SZRT-HU-N Szerencsjatek Zrt",
    "24691": "TOGOTEL- TogoTelecom, Togo",
    "24693": "CNSYS- CNSYS PLC",
    "24694": "GIEPA-N Giegerich & Partner GmbH",
    "24695": "TMA- T.M.A Serv SRL",
    "24697": "SATURN- Saturn ISP",
    "24698": "OPTIMUS- Optimus Comunicacoes, S.A.",
    "24699": "IVTELECOM- OJSC Rostelecom",
    "24700": "YES- Yes Networks Unlimited Ltd",
    "24701": "ANOTO- Anoto AB",
    "24702": "STRATUM-IP- Autonous System of STRATUM-IP",
    "24703": "UN-UKRAINE- United Networks of Ukraine, Ltd",
    "24704": "DGI Datagroup-Int SRL",
    "24705": "COMGW The Communication Gateway Ltd",
    "24706": "KRIWEB Kriter Internet Hiz.Ltd.Sti.",
    "24707": "MSD-  for MSD Computersysteme GmbH",
    "24708": "GRZ-AT GRZ IT Center Linz GmbH",
    "24709": "MNI MNI Telecom S.A. IP Backbone",
    "24710": "N-VOKAR Vokar Autonomous system",
    "24711": "CLS-ARGOS- Collecte Localisation Satellites SA",
    "24712": "AXIGEN AXIGEN MESSAGING SRL",
    "24713": "WMDATAFI Logica Suomi Oy",
    "24714": "TIETOENATOR- TietoEnator Corporation",
    "24715": "GENESYS Genesys Systems RO SRL",
    "24716": "PRIMEX-N Interdirect Limited",
    "24717": "M-SETTIMO-N Patrimonio Citta' Di Settimo Torinese S.r.l.",
    "24719": "NETCOMM--2 Network Communications SRL",
    "24720": "AVENSYS-TRANSIT- Avensys Networks Ltd",
    "24721": "SANET- Npo \"Arkhavtomatika\"",
    "24722": "BABILON- Babilon-T",
    "24723": "ATMAN-OFFICE-INTERNET- Advanced Technology Manufacturing Inc. (ATM S.A.)",
    "24724": "ATMAN-FOREIGN- ATM S.A.",
    "24725": "N-HM Hostmaster LLC",
    "24726": "ARMNET- FOP Boyko Oleg Mikhaylovich",
    "24727": "SPP- Slovensky plynarensky priemysel a.s.",
    "24728": "SI-REDOX REDOX d.o.o. Portoroz",
    "24730": "N-NETHOLDING GarnierProjects BV",
    "24731": "N-NESMA Middle East Internet Co LTD - Cyberia",
    "24732": "GPW- Gielda Papierow Wartosciowych S.A",
    "24733": "IPRI- Institute of Information Recording Problems of the National Academy of Science of Ukraine",
    "24735": "ANTENNA Antenna S.A",
    "24736": "CAIX",
    "24738": "N-DELTAVISTA \"Deltavista Sp. z o.o.\"",
    "24739": "SEVEREN-TELECOM CJSC Severen-Telecom",
    "24740": "ITELLIGENCE- itelligence Sp. z o.o.",
    "24742": "APAKGROUP- APAK Group Limited",
    "24743": "SNERPA-NET Snerpa ehf",
    "24744": "SINET-SK- SiNET Telecom s.r.o.",
    "24745": "ROMTELECOM ROMTelecom S.A.",
    "24747": "INLIFE- Detel Global, druzba za telekomunikacije d.d.",
    "24748": "ATMAN-POLAND- ATM S.A.",
    "24749": "IMANTOVA- TEANET Mantova - 46100 - MANTOVA - ITALY",
    "24750": "CISBG FIBERMAX Ltd.",
    "24751": "MULTIFI- Jakobstadsnejdens Telefon Ab",
    "24752": "N-EMPOWER Empower Oy",
    "24753": "C2C-NET Globecomm Europe B.V.",
    "24755": "PLIVA- PLIVA d.d.",
    "24756": "LUK-BANK- Lukas Bank",
    "24757": "EthioNet-",
    "24758": "MICROEL- Microel Ltd",
    "24759": "THAMESWATER-SIEMENS- Thames Water internet resilience managed by Siemens",
    "24761": "N-APP Slovenska Agencija za placilni promet",
    "24762": "STELCOM StelcomEngineering LLC",
    "24763": "THALES Thales Services S",
    "24764": "MAX-IT- m.a.x. Informationstechnologie AG",
    "24766": "GBCNET-01 GBC Internet Center GmbH",
    "24767": "POL- \"POL-Diamant-Murmansk Ltd.\", Murmansk, Russia",
    "24768": "ALMOUROLTEC ALMOUROLTEC SERVICOS DE INFORMATICA E INTERNET LDA",
    "24770": "UX- Unix Solutions Ltd",
    "24771": "ISVOR-FIAT ISVOR FIAT",
    "24772": "IP-AIE- Agrupacion de dervicios de internet y prensa AIE",
    "24773": "N-HH-LB HSH Nordbank AG",
    "24774": "BERLINDAT- BerlinDat Autonomous System",
    "24775": "24775 QinetiQ Limited",
    "24776": "INFOCLIP- INFOCLIP SA",
    "24777": "CTBTO- Preparatory Commission for the Comprehensive Nuclear-Test-Ban Treaty Organization",
    "24778": "DATAPIPE-UK DataPipe",
    "24779": "SOL-MELIA- Sol-Melia-",
    "24780": "AUTOSTRADE- Autostrade per l'Italia S.P.A.",
    "24781": "MPSMERCHANT- MPS Capital Services Banca per le Imprese S.P.A.",
    "24783": "N-MELS-MURMANELECTROSVIAZ OJSC Rostelecom",
    "24784": "ALPHYRA Payzone Group Limited",
    "24785": "JOINTTRANSIT- Open Peering BV trading as Joint Transit",
    "24786": "PSP- ProSiebenSat.1 Produktion GmbH",
    "24787": "SPRINTNET- Sprint Net Ltd.",
    "24788": "UUNET-AFRICA",
    "24789": "NOVGORODTELECOM- OJSC Rostelecom",
    "24790": "ROMCARE ROMCARE S..R.L",
    "24791": "DIABLO Direct Development, s.r.o.",
    "24792": "KITZNET- Kitzbuehler Stadtwerke Cable Provider",
    "24793": "NLHOSTING- NL Hosting Internet",
    "24794": "IBCNET-HU- IBCNet Hungary Ltd.",
    "24795": "MBK-NETWORKS Ludwig Melosch GmbH & CO. KG",
    "24796": "NAMEX-IXP NAMEX CONSORZIO",
    "24799": "DTI2- Desarrollo de la Tecnologia de las Comunicaciones - DTI2",
    "24800": "PLEKSUS PLEKSUS Autonomous System",
    "24801": "monarch",
    "24802": "KEYCAB- KEYCAB  for announcing own prefixes",
    "24803": "TELFIN- TELFIN  for announcing own prefixes",
    "24805": "BPV- Banca Popolare di Vicenza S.C.p.A.",
    "24806": "INTERNET-CZ INTERNET CZ, a.s.,",
    "24807": "INFOCOM- Infocom UK Ltd",
    "24808": "SIOTEL- SIOtel, Nigeria",
    "24809": "SAMNETS-  of Sampo Oyj",
    "24810": "TELESET-KAZAN OJSC Rostelecom",
    "24811": "KES- Closed Joint Stock Company Kuzbassenergosviaz",
    "24812": "HOMENET NPK Home-Net Ltd.",
    "24813": "LOGICA-GLOBAL-DATACENTER-NETWORK Logica Infra Solutions  AB, Sweden",
    "24814": "SCS- Syrian Computer Society, scs",
    "24815": "IST-TICARET-NET Istanbul Ticaret Universitesi",
    "24817": "IFINET-  number of Ifinet - Verona - Italy",
    "24818": "ANRC ANRC Services GmbH",
    "24819": "NORDNET- Nordnet Bank AB",
    "24820": "LUCKYTRADE- ISP LuckyTrade autonomous system",
    "24822": "OPTICON-HU- OPTICON Telekommunikacios Halozati Szolgaltato",
    "24823": "GUTA-BANK- Bank VTB 24 (JSC)",
    "24824": "WEISS-N Gebrueder-Weiss GmbH",
    "24825": "LTMFA- Lietuvos Respublikos Uzsienio reikalu ministerija",
    "24827": "BELINFONET Belinfonet Autonomus System, Minsk, Belarus",
    "24828": "TESMEDIA- UPC Ceska Republica, s.r.o.",
    "24829": "TEL-TELECOM- Astel-Telecom",
    "24830": "INTEREC- CIRCUITOS ALJARAFE, S.L.",
    "24831": "N-TAJIKNET ITSP \"Telecomm Technology Ltd\"",
    "24832": "TCU-COM- Territorial Control Centre of Communications Ltd.",
    "24833": "LBS-WEST-NET LBS Westdeutsche Landesbausparkasse",
    "24835": "RAYA-",
    "24836": "PKIT-N pk-itservices GmbH",
    "24837": "MEGALINK- MegaLink Co.",
    "24838": "REDNET- REDNET Autonomous System",
    "24839": "UBB Universitatea Babes-Bolyai",
    "24840": "NICOS-AG NICOS AG",
    "24841": "SUPERNEWS-NL Supernews",
    "24842": "DHMS-NET DHMS Ltd",
    "24843": "OTHER Kumsal Kom Internet",
    "24844": "EUROFORUM-N Euroforum Deutschland SE",
    "24845": "LHM-  for Landeshauptstadt Muenchen",
    "24846": "BANCORP- IFC BanCorp Electronic Banking &",
    "24847": "OEVAG- Oesterreichische Volksbanken AG",
    "24848": "KIELMAN-EDU- Kielce University of Technology",
    "24849": "DELTA DELTA S.A.",
    "24850": "ROOTELECOM ROOTelecom Autonomous System",
    "24851": "UK-NETCETERA Netcetera Autonomous System Peers",
    "24852": "VINITA Init Corporation",
    "24853": "DBC- Dansk Bibliotekscenter A/S",
    "24855": "EGL- Elektrizitaets-Gesellschaft Laufenburg",
    "24856": "MUNDIVIA- Mundivia",
    "24857": "EUINF- LLC \"Euroinform\"",
    "24858": "COMTEC Comtec Net SRL",
    "24859": "MITSUMINET- Mitsuminet, Kenya",
    "24860": "HSL- HSL SystemDesign GmbH",
    "24861": "PALL- Pallas GmbH",
    "24862": "CLSE- DATAPHONE SCANDINAVIA AB",
    "24863": "LINKdotNET-",
    "24864": "R-IT- Raiffeisen Informatik GmbH",
    "24865": "KMITCHELL- Keith Mitchell",
    "24866": "SYNTERRA-DC- CJSC Synterra",
    "24867": "ADAPT- Adapt Services Ltd",
    "24868": "N-HBV Bauer Systems KG",
    "24869": "N-PCM-IT Presidenza del Consiglio dei Ministri",
    "24870": "TKB-N  Trasta Komercbanka",
    "24872": "MAGNUS- TOV \"Magnus Limited\"",
    "24873": "ELLINK- Electrosvjaz of Pskov region",
    "24874": "NYCOMED- Nycomed GmbH",
    "24875": "NL-ISPSERVICES Avira B.V.",
    "24876": "FRANAP- Autonomous System FraNAP - Frankfurt Network  Access Point",
    "24877": "INIT Init Corporation Autonomous System",
    "24878": "BIBLIOTHECA-ALEXANDRINA",
    "24879": "PEKAOSA-PL BANK POLSKA KA OPIEKI S.A.",
    "24880": "EPRESS- ePress Autonomous System",
    "24881": "INTERPHONE- Interphone Ltd.",
    "24882": "UKRINFORMJUST State enterprise \"Information Centre\" Ministry of Justice of Ukraine",
    "24883": "XANTO- Xanto Autonomous System",
    "24884": "NETMANU- Netmanufacture GmbH",
    "24885": "MFIS MFIS",
    "24887": "LONE-PINE-CAPITAL-UK- Lone Pine Capital (UK) Limited",
    "24889": "MONZOON- Monzoon Networks AG",
    "24890": "ECO- Ecoband Netwoks Ltd., Ghana",
    "24891": "OYAK-NET ORDU YARDIMLMA KURUMU",
    "24893": "POLYNET- National University Lviv Politechnika",
    "24894": "TAGWORLDWIDE Tag Europe Ltd",
    "24895": "EURAJOKI- EURAJOEN PUHELIN OSK",
    "24896": "INTELLECOM- Intellectual Communications, Limited Liability Company",
    "24897": "QTELECOM- Q Telecommunications S.A.",
    "24898": "IP-EXCHANGE2 QSC AG",
    "24899": "XG1-NET QSC AG",
    "24900": "IPX-SERVER QSC AG",
    "24901": "IP-EXCHANGE-DE-COLO QSC AG",
    "24902": "IP-EXCHANGE-DE-COLO QSC AG",
    "24903": "NORDEALU Nordea Bank Luxembourg",
    "24904": "KWAOO K-NET SARL",
    "24906": "E-POINT- e-point SA",
    "24907": "UK-ENCRYPTEC ENCRYPTEC LIMITED",
    "24908": "LEK- LEK farmacevtska druzba d.d.",
    "24909": "TIMOCOM- TimoCom Soft- und Hardware GmbH",
    "24910": "HIGHBRIDGELDN Highbridge Capital Management (UK), Ltd.",
    "24912": "BILIM- JSC BiLiM Systems Ltd",
    "24913": "BANKSPB OJSC \"Bank Saint-Petersburg\"",
    "24914": "NETLAND- Telus Net SRL",
    "24915": "N-TELEUNIT TELEUNIT S.P.A.",
    "24916": "ORBITAL-N OrbitalNet Ltd",
    "24917": "DLSECURITIES- Delta Lloyd Securities  Autonomous System",
    "24918": "DAIMLER-CHRYSLER- Daimler Chrysler Automotive Sp. z o.o. Autonomous System",
    "24919": "CUBIO- Oy Cubio Communications Ltd.",
    "24920": "SISTEM-TECNICOS-LOTERI- TECNICOS DE LOTERI DEL ESTADO",
    "24921": "LMT-3G Latvian Mobile Telephone",
    "24922": "HACETTEPE Hacettepe Universitesi",
    "24923": "SETTC South-East Transtelecom Joint Stock Co.",
    "24924": "IPBR Non-commercial 'Partnership Institute of professional accountants and auditors of Russia'",
    "24925": "EHOUSE- eHouse Holding SA",
    "24926": "HDM- Heidelberger Druckmaschinen AG",
    "24927": "IHOLDING Internet Media Holding S.A. Bucharest, Romania",
    "24928": "NORDEAPL- Nordea Bank Polska SA",
    "24929": "NETFILES- NETFILES SA",
    "24931": "DEDIPOWER DediPower Managed Hosting Limited",
    "24932": "GOODWIN- ISP Goodwin Online Autonomous System",
    "24933": "MINXS- MILLENNIUMS.NET GmbH",
    "24935": "AVENIR-TELEMATIQUE-PROJ AVENIR-TELEMATIQUE S.A.S.",
    "24936": "RIM2000M- LLC Management Company \"Svyaz\"",
    "24937": "UNTN UTEL National Network",
    "24938": "TELECITYREDBUS-IT TELECITYREDBUS IT",
    "24939": "IVV IVV Informationsverarbeitung fuer Versicherungen GmbH",
    "24940": "HETZNER- Hetzner Online AG",
    "24941": "NETSERVICE- Private Services Unitary Enterprise \"Netservice\"",
    "24942": "NAVIGATOR- TOO Mediaplus",
    "24943": "DEMIRBANK Demirbank Bucharest, Romania",
    "24944": "ARENA- ARENA  Number",
    "24945": "N-VNTP Autonomous System of Vinteleport company",
    "24946": "VND The network of V Nodarbinatibas Dienests",
    "24949": "BTCML-AXA- AXA Technology Services UK Limited",
    "24950": "SOFIAT- Venus REIT OOD",
    "24951": "EVERYWARE-NET EveryWare LTD.",
    "24952": "FIRMENICH- Firmenich SA",
    "24953": "N-CARRIER66 NETPLANET GmbH",
    "24954": "HAV HAV S.A.",
    "24955": "UBN- OJSC \"Ufanet\"",
    "24956": "GDS-1 Gaertner Datensysteme GmbH & Co. KG",
    "24957": "GN-IX- Stichting Groningen Internet Exchange (GN-IX)",
    "24958": "TBSH The Bunker Secure Hosting Limited",
    "24959": "LINJEGODS- Schenker",
    "24960": "GATCHINA- Severo-Zapad Ltd.",
    "24961": "MYLOC- myLoc managed IT AG",
    "24962": "N-TSUKRAINE \"Telesystems of Ukraine\" LLC",
    "24963": "YACT- SMARTJOG S",
    "24964": "EVO-LTD MOBILTEL EAD",
    "24966": "NETPOINT RCS & RDS SA",
    "24967": "MACH-SIX- Satellite Solution Provider",
    "24968": "RO-BACKUP- Institutul National de Cercetare - Dezvoltare in Informatica",
    "24969": "DIR- DIR A/S DK",
    "24970": "ETI- ETI, Ghana",
    "24971": "MTER- Master Internet s.r.o",
    "24972": "LURSOFT- SIA LURSOFT IT",
    "24973": "KOMPLEX- KONTENT GmbH",
    "24974": "TACHYON-EU Tachyon Europe BV",
    "24975": "SNECMA- Snecma-Moteurs Autonomous System",
    "24976": "TECHGATE-COMMUNICATIONS Techgate PLC, London, UK",
    "24977": "MONEYLINE-UK Moneyline Telerate",
    "24978": "SPRINT Aut.-System Telenec",
    "24980": "PENTA- PENTA INVESTMENTS LIMITED o.z.",
    "24981": "PRIVATBANKLV-  Privatbank",
    "24982": "BANKMED BankMed sal",
    "24983": "ALTECOM Alta Tecnologia en Comunicaciones, S.L.",
    "24984": "DNB AB DNB bankas",
    "24985": "KACZMARSKI- KACZMARSKI INKSO",
    "24986": "EUROMB Donpharmholding Ltd",
    "24987": "AFMIC",
    "24989": "IXEUROPE-DE-FRANKFURT-N Equinix Germany (Previously IX Europe Germany )",
    "24990": "EQUINIX-FR-N Equinix France Autonomous System",
    "24991": "DATATRANS- Datatrans Internet Ltd",
    "24992": "DIC- DIC Online Wolf & Co. KG",
    "24993": "POTSDAM- netzhaus AG",
    "24994": "GENESYS- genesys informatica srl",
    "24995": "MIKTELECOM- MIK Telecom ltd.",
    "24996": "LADOT- Ladot Nederland BV",
    "24997": "GE-CDN-  for CDN",
    "24998": "ORBITONE- Orbit One bvba",
    "24999": "SINSOFT- Sumy Online Ltd",
    "25000": "DVCOM- TOV DV-COM",
    "25001": "RIKOP RIKOP Ltd.",
    "25002": "AEMCOM- AEMCOM Srl multicommunication company",
    "25003": "INTERNET_BINAT Internet Binat Ltd",
    "25005": "FINIBANCO- Finibanco, SA",
    "25006": "ABNATTRSVC Abbey National Treasury services PLC",
    "25008": "ESOO- OJSC Rostelecom",
    "25009": "GRAAL- Graal Network S.a.R.L.",
    "25010": "EKOVALDA UAB EKOVALDA",
    "25011": "AUSTRIAN-RAILWAYS- OeBB Infrastruktur AG",
    "25012": "N-EUI Wien IT EDV Dienstleistungsgesellschaft mbH AND Co KG",
    "25014": "GROUP-ONE G1 Derivatives Trading Ltd",
    "25015": "ADOMIA- ADOMIA",
    "25017": "PROBANKA- Probanka d.d.",
    "25019": "SAUDINETSTC- Autonomus System Number for SaudiNet",
    "25020": "N-FACTORB Factor Banka d.d.",
    "25021": "CIEF- Centre Informatique Etat de Fribourg",
    "25022": "TDMGROUP TDM Group Limited",
    "25024": "DECEUNINCK-PLTICS Deceuninck NV",
    "25025": "NAUKABEL OOO \"Nauka-Svyaz' Chernozem'e\"",
    "25026": "VIO- Vio Worldwide Ltd",
    "25029": "ALARIT PP \"EasyDate Ukraine\"",
    "25030": "NFU- National Farmers Union Mutual Insurance Society Ltd",
    "25031": "NOVARTIS-CH Novartis",
    "25032": "TELEINTERCOM- LLC \"Gazprom telecom\"",
    "25033": "MOBITDATA- Tenue Oy",
    "25034": "N-RKB Raiffeisen banka d.d.",
    "25035": "TRANSFER- Transfer Ltd",
    "25036": "TERMSNET- Internethome, s.r.o.",
    "25037": "DREAMHACK Dreamhack AB",
    "25038": "AIXTRANET- Aixtranet",
    "25039": "N-LINDE Linde AG",
    "25040": "ITCONSULT- I.T. Consultancy Limited",
    "25041": "BRIGHTVIEW-UK- Brightview Internet Services",
    "25042": "ATOBE Bitlibre BV",
    "25043": "IVV-AACHEN- Ingenieurgruppe IVV GmbH und Co. KG",
    "25045": "EPH- EuropaPress Holding d.d.",
    "25046": "CHECKPOINT Check Point Software Technologies LTD",
    "25047": "ICT- Yesevi Universitesi",
    "25048": "DSNETHOSTING DSNet Hosting Limited",
    "25049": "STCO-UK- STCo",
    "25050": "BACS- BACS Ltd",
    "25051": "ISNET- Maintainer of \"NetLine\" Ltd",
    "25053": "EA- Generali IT-Solutions GmbH",
    "25054": "ACO- the  of ACO Computerservice GmbH Kassel -Germany-",
    "25055": "BBG-PL- Bank Millennium SA",
    "25056": "SALOMON-AT- Salomon Automation Gesellschaft m.b.H.",
    "25057": "GNT- GNT, located in Frankfurt,DE; carrier providing VoIP Carrier solutions",
    "25058": "CMO- CMO Internet Dienstleistungen GmbH",
    "25059": "NLB-SI- Nova Ljubljanska Banka, d.d. Ljubljana",
    "25060": "INE- Instituto Nacional de Estatistica Portugal, I.P.",
    "25061": "ANLX-UK Associated Networks Limited",
    "25063": "INOTRONIC-RZ1- inotronic Computers GmbH",
    "25065": "DIGIPOINT- Cegeka NV",
    "25066": "NKBM- Nova KBM d.d.",
    "25068": "KONICA-MINOLTA-EMEA-HEADQUARTER- Konica Minolta Business Solutions Europe GmbH",
    "25069": "OMV- OMV Aktiengesellschaft",
    "25070": "COMARCH- Comarch S.A.",
    "25071": "RADIOCOM- RadioCom ISP Autonomous System",
    "25072": "IRF- Institutet for Rymdfysik",
    "25073": "INETKOM- LTD \"KOMIN\"",
    "25074": "INETBONE- MESH GmbH",
    "25075": "SWPS Szkola Wyzsza Psychologii Spolecznej",
    "25076": "ISTARLINK- ISTAR-LINK Ltd",
    "25077": "BMG Bank Mendes Gans NV",
    "25078": "ANSOL Ansol Network Solutions Ltd.",
    "25079": "-TVC IIS Limited liability company",
    "25080": "MERCURY-INT- Mercury Interactive Ltd.",
    "25081": "HDIT- Heidelberg IT Management GmbH & Co.KG",
    "25082": "OBUKHOV DOMANET LIMITED",
    "25083": "FINBRIDGE- Financial Bridge Investments Company PI block",
    "25084": "CZESTMAN-COM- Non-academic  dedicated to Metropolitan Area Network",
    "25085": "DMITRY- Dmitry Kiselev",
    "25086": "URALTC- CJSC \"COMSTAR-regions\"",
    "25089": "GREINER- Greiner KG",
    "25090": "EOS- Alpiq AG",
    "25091": "IP-MAX IP-Max SA",
    "25092": "ALPHATELECOM- PE Sergii Kalutskyi",
    "25093": "CS-CZ Ceska Sporitelna a.s.",
    "25096": "CYBERNET-RU Cybernet LLC",
    "25098": "LCHOST Netcalibre Ltd",
    "25099": "25099 PE NEO-CRAFT",
    "25100": "MIPT-NET Non state educational institution \"Educational Scientific and Experimental Center of Moscow Institute of Physics and Technology\"",
    "25101": "N-EUINTERNET AZISTA GmbH",
    "25102": "N-COMPACT CompAct GmbH Computer und Kommunikation",
    "25103": "ADISAN Adisan Net SRL",
    "25104": "TECHPATH Techological Park of Thessaloniki",
    "25105": "CENTRT- CZiC Centrast S.A.",
    "25106": "MTSBY- Mobile TeleSystems JLLC",
    "25107": "MULTIBANKA-  SMP Bank",
    "25108": "BLACKCAT- RapidSwitch Ltd ex BCN",
    "25109": "HUK-COBURG HUK-Coburg Haftpflicht-Unterstuetzungs-Kasse kraftfahrender Beamter Deutschlands a.G. in Coburg",
    "25110": "N-XTDNET Xtended Internet, based at Telecity2, Amsterdam.",
    "25111": "COLOP- Coloplast A/S",
    "25113": "GLOBECT Orange S.A.",
    "25114": "GRAYDON Graydon Belgium NV",
    "25115": "DIEHL-CORP- DIEHL Informatik GmbH",
    "25116": "GAZDUIRE-WEB Gazduire WEB SRL",
    "25117": "NRJ-MOBILE Euro-Information-Europeenne de Traitement de l'Information S",
    "25118": "POLUOSTROV- \"Web-Com Plus\" Ltd",
    "25119": "UKRPRESS State Publishing House \"The Press of Ukraine\" of the State Business Management",
    "25121": "LBB-  Eesti Krediidipank Latvia",
    "25122": "GULFSAT_COMMUNICATIONS- Gulfsat Communications Co.",
    "25123": "DRS- DRS Broadcast 2000 S.L",
    "25124": "DATAK DATAK Internet Engineering, Inc",
    "25125": "ISRAEL-LCL-NET- Local Authorities Data Processing Center Company Ltd Corp",
    "25126": "TIWAG-GROUP-NET- TIWAG-Tiroler Wasserkraft AG",
    "25127": "BTOW BTopenworld Broadband & Narrowband networks located in the UK",
    "25128": "HOSTWAY-EU- Hostway Europe",
    "25129": "MONITORING- Scientific-Production Center \"Monitoring\", Ltd",
    "25131": "SWISSUPDATE- SWISSUPDATE AG",
    "25132": "RELCOM-POD- PP Relcom Podilya",
    "25133": "MCLAUT- LLC \"McLaut-Invest\"",
    "25134": "ServerShed Autonomous System",
    "25135": "VODAFONE_UK_N Vodafone Limited",
    "25136": "PORTIMA- Portima",
    "25137": "NFSI NFSi Telecom, Lda.",
    "25138": "N-MATRIXPL Infovide-MATRIX S.A.",
    "25139": "TVCABO- TVCABO - Comunicacoes Multimedia, Lda.",
    "25140": "BANCAJA- BANCAJA Autonomous System",
    "25141": "IPXION IPXion",
    "25142": "LEHMAN- N for Nomura, London GS2",
    "25143": "IU- \"Zagalni Merezhi\" Ltd",
    "25144": "TELEKOM-SRPSKE- Telekom Srpske",
    "25145": "TEKNOTEL- TEKNOTEL TELEKOMUNIKYON SANAYI VE TICARET A.S.",
    "25146": "CYPOINT- Cypoint IT Services AB Autonomous System Stockholm Sweden",
    "25147": "SOFIANET Ecoplast Autonomous system",
    "25148": "BEFARM-N Basefarm . Oslo - Norway",
    "25149": "DROGA- Droga Kolinska d.d.",
    "25150": "DCTEL- DCTel Ltd",
    "25151": "CYSO- Cyso Hosting B.V., Alkmaar, The Netherlands",
    "25152": "K-ROOT-SERVER Reseaux IP Europeens Network Coordination Centre (RIPE NCC)",
    "25153": "NAVISION- Navision A/S",
    "25155": "STARSOFT- Star Soft Ltd.",
    "25156": "INRETE- Inrete s.r.l",
    "25157": "CETTELEPORT- CET Teleport GmbH",
    "25158": "PONE-  Number of PONE COMPANY FRANCE",
    "25159": "SONICDUO- OJSC MegaFon",
    "25160": "VORBOSS_ Vorboss Limited",
    "25161": "VOIP VoIP-4U Ltd.",
    "25163": "NG-NIGERIA-",
    "25164": "FLUGHAFEN-ZUERICH Flughafen Zuerich AG, Autonomous System, Switzerland",
    "25165": "ENTRI- Entri LLC",
    "25166": "MAIL-BG MAIL.BG Ssc",
    "25167": "TUK- Tuk Datentechnik Oliver Knapp",
    "25168": "MITSUI- Mitsui & Co UK Plc Autonomous System",
    "25169": "TELENOR-SE- Telenor Sverige AB",
    "25170": "PRIVILIS PRIVILIS is an Internet Service Provider in Bordeaux, France",
    "25171": "BKAENET- Budapesti Corvinus Egyetem",
    "25172": "SOLIX- Liden Data Internetwork AB",
    "25173": "ISKRATR- ISKRA SISTEMI Avtomatizacija procesov, d.d.",
    "25174": "WCOM- World of Communications Ltd.",
    "25176": "AC-NET LaNet Vasterbotten Data och Tele AB",
    "25178": "KEYCOM- Keycom PLC",
    "25180": "EXPONENTIAL-E- Exponential-e Ltd",
    "25181": "EU-SONY Sony Europe Limited",
    "25182": "PUBLIEKE-OMROEP- Stichting  Nederlandse Publieke Omroep",
    "25183": "NTEMA- \"TOV N-Tema\"",
    "25184": "AFRANET AFRANET Co. Tehran, Iran",
    "25185": "PHARMUPPORT- PSI COMPANY LIMITED",
    "25186": "TRANSIT-VPN- Orange S.A.",
    "25187": "FCV FRANCE CITEVISION S",
    "25188": "INTERMEDIA- Intermedia Ltd",
    "25189": "NLINE- NLine LLC",
    "25190": "KIS- UAB \"Kauno Interneto Sistemos\"",
    "25191": "ESP-SA-N PGE Energia Odnawialna Spolka Akcyjna",
    "25192": "CZNIC- CZ.NIC, z.s.p.o.",
    "25193": "MISSCRITD1-1-  for Mission Critical Software /Netiq Corporation",
    "25194": "GLAVERBEL- AGC Glass Europe",
    "25195": "AVACOMNET-SERVICES- Logosnet Services Limited",
    "25196": "CALVIATERRATEL PIN Sweden AB",
    "25197": "IT-DVBCOM- DVBCOM",
    "25198": "FIL-BG wireless inet  provider",
    "25199": "UA-RELOAD Vizart Ltd.",
    "25200": "AUTOSYST01- Autonomy Systems Ltd",
    "25201": "PCB- Peder Christian Bach",
    "25203": "SIMFINET- Inkom Plus Ltd.",
    "25204": "BOLSA-VALENCIA SOCIEDAD RECTORA DE LA BOLSA DE VALORES DE VALENCIA",
    "25206": "UNACS--BG Unacs - Yuri Jordanov Ltd.",
    "25208": "PROLAIN_SIA_ Prolain SIA",
    "25210": "NEOCOM- NeoCom-service ISP",
    "25211": "EQUIFAX- Equifax Plc",
    "25212": "KHARKOV-IX- Kharkov.NET Internet Traffic Exchange Point",
    "25213": "CARGOTEC-CORPORATE- Cargotec Corporate Network",
    "25215": "BNP-PARIB BNP PARIB SA",
    "25216": "DATAGROUP-_2013035622 PRIVATE JOINT STOCK COMPANY \"DATAGROUP\"",
    "25217": "GDM-25217 GDM Konsult AB",
    "25218": "THE-ECONOMIST- The Economist Newspaper Limited",
    "25220": "GLOBALNOC- Averbo GmbH",
    "25221": "LUIS-URAL- LTD \"Luis+Ural\"",
    "25222": "XANTIC-IP XANTIC B.V.",
    "25223": "PIN PIN Sweden AB",
    "25224": "STS-HOLDING- STS Invest Holding AD",
    "25225": "LOGNO- CGI Norge",
    "25227": "N-AVANTEL-MSK Avantel, Close Joint Stock Company",
    "25228": "SKYVISION SkyVision Global Networks Ltd",
    "25229": "VOLIA- Kyivski Telekomunikatsiyni Merezhi LLC",
    "25230": "ALARKO- Alarko Holding Muallim Naci Cad. No:69 34347 Ortakoy Istanbul TURKEY",
    "25231": "BESTNET- Best Ltd",
    "25232": "VZD Valsts Zemes Diensts",
    "25233": "AWALNET-N Arab Company For Internet & Communications Services (AwalNet)LLC",
    "25234": "GLOBE- ACTIVE 24, s.r.o.",
    "25235": "KRICHEVSKY-ORG Pali Krichevsky Dasha (Delphi)",
    "25236": "HOMEUA- United Networks of Ukraine, Ltd",
    "25237": "NV-PORT- ISRAEL PORTS DEVELOPMENT and SETS COMPANY LTD",
    "25238": "GECB-CZ GE Money Bank, a.s.",
    "25240": "UMTS- National UMTS Core Network",
    "25241": "IEM- Information Centre of the Ministry of the Interior",
    "25242": "KUWAIT-UNIVERSITY Computer Information Systems Kuwait University Kuwait",
    "25243": "IITP-1 IITP of R Autonomous System",
    "25244": "DECODE- Decode Autonomous System",
    "25245": "RTDEWDF- REALTECH Verwaltungs GmbH",
    "25246": "GT- Global Telecoms Ltd, Nairobi,Kenya.",
    "25247": "IBERCAJA- AUTONOMOUS SYSTEM OF IBERCAJA, A SPANISH BANK LOCATED ON ZARAGOZA",
    "25248": "BLUETONE- RADIOKOMUNIKACE a.s.",
    "25249": "GE-MAGTICOM MAGTICOM",
    "25250": "GAMTEL-",
    "25251": "ARTCON- Art-Constructor CJSC",
    "25252": "VOLVOIT Volvo Information Technology AB",
    "25253": "CGDNET CAIXA GERAL DE DEPOSITOS, SA",
    "25254": "ISTA- Ista Shared Services GmbH",
    "25255": "H3G-AUSTRIA- Hutchison 3G Austria GmbH",
    "25256": "KAHOVKA- TOV Kahovka.net",
    "25257": "DR-SOFT- DR SOFT SRL",
    "25258": "NEPA- e-Style ISP LLC",
    "25260": "QUALITYHOSTING- QualityHosting AG",
    "25261": "IBERIA IBERIA LINE AERE DE ESPANA S.A.",
    "25264": "NEXAGENT Nexagent Ltd. Inter-carrier VPN peering organisation, London",
    "25265": "VELTON- Telecommunication Company",
    "25267": "CORPME- Colegio de Registradores de la Propiedad",
    "25268": "CARGOPARTNER- CARGO PARTNER GMBH",
    "25269": "UNEXBANK- Joint-stock commercial bank UNEX",
    "25270": "ROBRAU Brau Union S.A. Bucharest, Romania",
    "25271": "TMT-2 TMT Border Autonomous System Munich",
    "25272": "SINSTELECOM- JSC \"AKADO-Stolitsa\"",
    "25273": "BCELU S T N S",
    "25274": "SUMY- Regional Internet Company",
    "25275": "RICHEMONT- Richemont International SA",
    "25276": "ALIGIA Aligia GmbH",
    "25277": "POSLUH POSLuH d.o.o, za informaticke usluge i trgovinu",
    "25278": "CNMSI- Centrul National de Management pentru Societatea Informationala",
    "25279": "TREML-STURM- Treml-Sturm Datentechnik GmbH",
    "25280": "CRIX Cairo Regional Internet Exchange",
    "25281": "DRAGOCO- Dragoco Gerbeding & Co. AG",
    "25282": "KEEPERSOFT- Keeper-Soft Ltd.",
    "25283": "FTCENTER- FT-Center , located at Moscow offices, Russia",
    "25284": "NEXCOM-ROM Nexcom Romania SRL",
    "25285": "BOE- Boletin Oficial del Estado",
    "25286": "IPERCT- Ipercast Network",
    "25289": "BNP- BNP Paribas Partners for Innovation (Suisse) Sarl",
    "25290": "VYBORG OJSC MegaFon",
    "25291": "SYSELEVEN SysEleven GmbH",
    "25292": "VGTRK- VGTRK Enterprise",
    "25293": "KSIR- Kassir Ltd.",
    "25294": "GEMEINDEWERKE-TELFS- Gemeindewerke Telfs Ges.m.b.H",
    "25295": "KIELNET- KielNET GmbH Gesellschaft fuer Kommunikation",
    "25296": "N-UVTB OJSC MDM Bank",
    "25297": "COMSA- COMSA Autonomous System",
    "25298": "CYBER- GPC Services AG",
    "25299": "DEXP- Telephant Ltd.",
    "25300": "VEM-SISTEMI VEM SISTEMI S.p.A.",
    "25301": "WINDNET- Srnet srl",
    "25302": "BS-NET- Oliver Breuninger",
    "25303": "KDD KDD Centralna klirinsko depotna druzba d.d.",
    "25304": "UNITBV Universitatea TRANSILVANIA Brasov",
    "25305": "ALBEDO- Albedo S.r.l. Network Service Provider Operating in ITALY",
    "25306": "INSTITUTE-ISIRAN institute isiran Autonomous System Number",
    "25307": "IXEUROPE-GERMANY-2-N Equinix Lab Autonomous System",
    "25308": "CITYLAN- CityLanCom LTD",
    "25309": "TOPIX- Consorzio Topix - Torino e Piemonte Exchange Point",
    "25310": "N-CWACCESS Cable and Wireless Access Ltd",
    "25311": "FTLINK-N RCS & RDS SA",
    "25313": "PL-OPEN- Open Finance S.A",
    "25314": "EXEL- Exel Plc",
    "25315": "AVGZ TOB AVGZ",
    "25316": "CROSS-TELECOM- MWM Gas & Energy SRL",
    "25317": "MB-T- MB&T GmbH",
    "25318": "PROVISION SC Provision Software Division SRL",
    "25319": "N-MOLDINFONET State Enterprise \"Special Telecommunications Center\"",
    "25320": "SKPWRINTL- Skypower  Number",
    "25321": "G4S-NET GROUP 4 Secure Solutions a.s",
    "25322": "ACCENTURE-FRANCE ACCENTURE FRANCE  Autonomous System",
    "25323": "N-YKB YAPI VE KREDI BANKI A.S.",
    "25324": "HIN HEALTH INFO NET AG",
    "25325": "BAHN- DB Systel GmbH",
    "25326": "UNIVCB- Constantin Brancoveanu University",
    "25327": "FTSE FTSE-International Ltd.",
    "25328": "HEP- HEP d.d.",
    "25330": "KIEVWEB Scientific -Industrial Firm \"Volz\" Ltd",
    "25332": "LINKOS- Linkos LTD.",
    "25333": "SKANDIA-DE Skandia Lebensversicherung",
    "25334": "AVYS S.C. Avasys Intelligent Solutions S.R.L.",
    "25337": "SAKMA- Red de Sakma en Barcelona",
    "25338": "PROMEXIM- Promexim sp. z o.o.",
    "25339": "IGTELE OOO \"Ingame\"",
    "25341": "LINIYA- LLC \"Liniya\"",
    "25342": "KUONI- Kuoni Reisen AG",
    "25343": "COVENTRY- Coventry University Computing Services",
    "25344": "TECHNOFUTUR- Technofutur TIC BL",
    "25345": "WEBTECH- Webtech- France",
    "25346": "TISCALI- Tiscali UK Ltd",
    "25347": "CTTC- CENTRETRANSTELECOM",
    "25348": "EYWAN- Easywan",
    "25349": "N-ACADEMSET Academset Ltd",
    "25350": "N-NUOVOPIGNONE Nuovo Pignone S.p.A",
    "25351": "BROADNET-NO- Broadnet",
    "25352": "GUARDIAN-NETWORKS H B H Trade Center v/Henrik Bo Hansen",
    "25353": "BAR- BAR Informatik AG",
    "25354": "RED-ES- Entidad Publica Empresarial Red.es",
    "25355": "N-INTELE CJSC \"Intelecom\"",
    "25356": "SECURIT-DIRECT- SECURIT DIRECT ESPANA S.A.U.",
    "25357": "PANALPINA-US- PANALPINA INC",
    "25358": "NOVSO Novso SARL",
    "25361": "N-DECHERT Dechert International law firm, European headquarters. London UK",
    "25362": "IAA-",
    "25363": "N-SEGUNDAMANO ANUNTIS SEGUNDAMANO ESPANA S.L.",
    "25364": "EgyptCyberCenter-",
    "25365": "TOMSOFT- Tomsoft d.o.o.",
    "25367": "-ADTS-LU Dexia Banque Internationale a Luxembourg SA",
    "25369": "BANDWIDTH- Bandwidth Technologies Ltd",
    "25370": "OMEGA91- Private Enterpreneur Umans'kyj Ihor Leonydovych",
    "25371": "N-KIAM \"KIAM\"  - Keldysh Institute of Applied Mathematics",
    "25372": "ITCONSULTING- IT Consulting L.L.C.",
    "25373": "GOVSK- The Slovak Republic Government Office",
    "25374": "ESCOMBG- ESCOM Ltd. - Haskovo",
    "25375": "LEU- Leunet AG",
    "25376": "NETNORTH-N Netnorth Limited",
    "25377": "BUZA-NL Ministerie van Buitenlandse Zaken",
    "25378": "BCR-IG- BCR Asigurari SA",
    "25379": "PROF-TEL-COMM- Prof-Tel-Comm Ltd.",
    "25381": "SVT- JSC \"Regional company Svyaztranzit\"",
    "25384": "DMDATA- IBM Denmark ApS",
    "25385": "BELCOMUA- ZAO \"Belcom\"",
    "25386": "INTERTELECOM- PJSC Inter-Telecom",
    "25387": "N-GOTEBORG Goteborgs Stad",
    "25389": "UZ-BCC- ISP - Amaliy Aloqalar Biznesi Ltd., Tashkent, Uzbekistan",
    "25390": "BREINWEST- DOM INWESTYCYJNY BRE BANKU, SPORLA AKCYJNA",
    "25391": "SSH- SSH Communications Security Corporation",
    "25392": "GED- gedas Iberia S.A.",
    "25393": "UKRLINK Ukrlink LLC",
    "25394": "MK-NETZDIENSTE-  for MK Netzdienste GmbH & Co. KG",
    "25395": "Gateway Communications",
    "25397": "CINT- JSC Corporatsia Intersvjaz Autonomous System",
    "25398": "TSP- Technosphere Ltd.",
    "25400": "SMARTCALL- Get . Old Smartcall",
    "25402": "N-CYBERNET-ROMANIA Cybernet Ltd. Romania",
    "25403": "DELTA- Firm Delta PE",
    "25404": "BSE- Budapest Stock Exchange",
    "25405": "NMTS- OJSC Rostelecom",
    "25406": "SPLIUS- SPLIUS, UAB",
    "25407": "TAXBACK- TAXBACK.COM Bulgaria Autonomous system",
    "25408": "WESTCALL-SPB- CJSC \"WEST CALL LTD\"",
    "25409": "ALSYSDATA Alsys Net SRL",
    "25410": "BZWBK- Bank Zachodni WBK S.A.",
    "25411": "EFM- Ertel & Friends Multimedia GmbH",
    "25412": "CCMA- Corporacio Catalana de Mitjans Audiovisuals",
    "25413": "ML-NET ML Global Datacenters",
    "25414": "SMITHSGROUP Smiths Group plc",
    "25415": "ADDIX- ADDIX Internet Services GmbH",
    "25416": "AGA- AGA Gas AB",
    "25417": "LJUSNET- se.ljusnet Autonomous System",
    "25418": "CQINT-NL CQ International B.V.",
    "25419": "MEYLE-MUELLER- Meyle + Mueller GmbH & Co.KG.",
    "25420": "ISOURCE iSource AG,",
    "25421": "JOHN-LEWIS- John Lewis Plc.",
    "25422": "UK-TOEPFERNET Toepfer Organization",
    "25423": "HT The Phone House Telecom GmbH",
    "25424": "INEXT-CZ INTERNEXT 2000 s.r.o.",
    "25425": "UNICOM Unicom Management Services (Cyprus) Ltd.",
    "25426": "BRAINTEC- D.FI Services S",
    "25428": "INFOCO-COLRUYT- COLRUYT GROUP SERVICES N.V.",
    "25429": "CBI- CBINET, Bujumbura, Burundi.",
    "25430": "N-PTIC JSC \"Promtorginvest-company\"",
    "25431": "GAMAELEKTRONIK Gama Electronics d.o.o.",
    "25432": "INFINEON- Infineon AG",
    "25433": "HENZ-NL- HenZ.nl B.V.",
    "25434": "EDAG- EDAG GmbH & Co. KGaA",
    "25435": "META10-N META10 AG",
    "25436": "KIROV-CAIT- OJSC Rostelecom",
    "25437": "ALCOM- Municipal scientific production enterprise Information Centre",
    "25438": "N-ICCNET International Computer Company Ltd",
    "25439": "PWPW- Polska Wytwornia Papierow Wartosciowych S.A.",
    "25440": "NESTLE Nestle Operational Services Worldwide SA",
    "25441": "IBIS- Imagine Group Ltd.",
    "25442": "CAI-CHEVREUX Credit Agricole Cheuvreux SA",
    "25443": "IDGPL- International Data Group Poland S.A.",
    "25444": "NAFHQLV- Headquarters of National Armed Forces Republic of Latvia",
    "25445": "AUSTRIACARD- Austria Card-Plastikkarten und Ausweissysteme Gesellschaft m.b.H.",
    "25446": "N-TOMLINE Tomsk telecommunication company Ltd",
    "25447": "JM-DATA JM-DATA GmbH",
    "25448": "VOIP-UA- PE Avtsynov Mikhail Alexandrovich",
    "25449": "NEDLLOYD- Nedlloyd",
    "25450": "ZM- Zamtel, Lusaka, Zambia",
    "25451": "WEBERSHANDWICK-LON00 Weber Shandwick London",
    "25452": "AVANTIS-NET- SIIP Media GmbH",
    "25453": "MAD-IX Madrid Internet Exchange",
    "25454": "N-OMD-FNO Orange Moldova SA",
    "25456": "X-HOST Physical person-businessman Rostilo Sergey Alexandrovich",
    "25457": "SUPERMEDIA--TPNET SUPERMEDIA Sp.z.o.o.",
    "25459": "NEDZONE- NedZone Internet BV",
    "25460": "TNP- The Networking People (NorthWest) Limited",
    "25461": "RO-DCI Serviciul de Informatii Externe",
    "25462": "RETN-UA- RETN Limited",
    "25464": "TELESIGN- Telesign Mobile Limited",
    "25466": "LIDERONET Liden Data Internetwork AB",
    "25467": "AKTON- Akton Autonomous System",
    "25468": "PL-POLRZE- Academic network in Rzeszow, Poland",
    "25469": "Riga, Latvia",
    "25470": "SCOTTISH-SOUTHERN-PLC- Scottish and Southern Energy PLC",
    "25471": "SNT-HR- Hermes Plus d.o.o. S&T Croatia",
    "25472": "EVERGY- TELL Telecommunication Services S.A.",
    "25473": "N-SYSTEAM EVRY One Nat Uppsala AB",
    "25474": "OKB-TELECOM- OKB-TELECOM OJSC",
    "25475": "TECHSELL-SE- IPmovers AB",
    "25476": "DK-NETWORK DK Network AB",
    "25477": "CREATE Create Services Ltd",
    "25478": "IHOME- iHome LLC",
    "25479": "IC2- IT Now S.A.",
    "25480": "MESSAGE-PAD- Message Pad Warwick",
    "25481": "SYCOR SYCOR GmbH",
    "25482": "SELENA- Autonomous System of Selena ISP",
    "25484": "ACCELERATED- Accelerated IT Services GmbH",
    "25485": "VERISIGN-CH- VeriSign Inc.",
    "25486": "LUN- Lightup Network Solutions GmbH & Co. KG",
    "25487": "DIGITALVALUE- Digital Value Autonomous System, Valencia (Spain)",
    "25488": "COMUNE-NOVARA- Comune di novara",
    "25489": "AQUATIX- Aquatix IT-Services e.K.",
    "25490": "STC- \"Southern Telecommunications Company\" PJSC",
    "25491": "ACCUCARD routed out of 25491 peering with 8372",
    "25492": "COMPLY- Burstfire Networks Ltd",
    "25493": "CLARANEWS- Claranet News Network",
    "25494": "EL-SOFT- Electronics & Software OOD",
    "25495": "SEJM- Kancelaria Sejmu",
    "25496": "ZT- ZSR ZT Bratislava",
    "25497": "ATT-INF002-A11 AT&T-GNS-25497",
    "25498": "N-MOBICOM MOBICOM Ltd.",
    "25499": "N-TRIGLAV Zavarovalnica Triglav d.d.",
    "25500": "NTUU-KPI- Association of users of Ukrainian Research & Academic Network \"URAN\"",
    "25501": "MIRAI- TUXTEL Ltd",
    "25502": "NIP Company NIP , the devision of State Food Department,",
    "25503": "N-ONPU Odessa National Polytechnic University",
    "25504": "CRONON- Vautron Rechenzentrum AG",
    "25505": "CHEREDA-KV- GRYGORIY CHEREDA",
    "25506": "TVP- Telewizja Polska S.A.",
    "25507": "OSVITA-UA- Osvita XXI fund",
    "25508": "ARQUIRED- Caja de Arquitectos",
    "25509": "VORTEX- Hringidan ehf / Vortex Inc",
    "25510": "ROSTELECOM- OJSC Rostelecom",
    "25511": "N-NET21 CJSC \"Ruscentrosvyaz\"",
    "25512": "CDT- CD-Telematika a.s.",
    "25513": "N-MGTS-USPD OJS Moscow city telephone network",
    "25514": "MODUS- MPP Modus",
    "25515": "CTCNET- OJSC Rostelecom",
    "25516": "INIT- init AG fuer digitale Kommunikation",
    "25517": "N-IWL IWL Autonomous System",
    "25518": "ZUCCHETTI- ZUCCHETTI SPA",
    "25519": "REIC- ZAO \"Maestro Telecom\"",
    "25520": "FT- CJSC \"Futures Telecom\"",
    "25521": "N-IPN ZAT \"Industrial Media Network\"",
    "25522": "TRAVIAUSTRIA- TraviAustria Datenservice fur Reise und Touristik GMBH & CO. NFG. KG",
    "25523": "PR- Polskie Radio S.A.",
    "25524": "OTON- SC Oton SRL",
    "25525": "REONNET- Reasonnet IP Networks B.V.",
    "25526": "LAMBDANETUA TOV Lambda Net",
    "25527": "CARTELSISTEM- Cartel-Sistem SRL",
    "25528": "VODATEL- Metronet telekomunikacije d.d.",
    "25529": "SOKOL- SOKOL LTD",
    "25530": "N-SFT CJSC SFT Company, Moscow, Russia",
    "25531": "INTFRM- Intinform Ltd.",
    "25532": "MTERHOST- .masterhost autonomous system",
    "25533": "FAUST-N FAUST ISP LTD.",
    "25534": "INTELSOFT- Intelsoft Kazakstan",
    "25535": "N-RUCENTER-HOSTING Autonomous Non-commercial Organization 'Regional Network Information Center'",
    "25536": "N-METAV Metav S.A.",
    "25537": "GARANT-PARK-COLLOCATION Garant-Park-Telecom, Ltd",
    "25538": "IN-ULM Internet Ulm/Neu-Ulm e.V.",
    "25539": "MAVIR-HU- Hungarian Power System Operator Co.",
    "25540": "ALPHALINK- Alphalink ISP",
    "25541": "MERKUR-SI- MERKUR trgovina in storitve d.d.",
    "25542": "DENIT- Denit Internet Services B.V.",
    "25543": "FasoNet-",
    "25544": "EROSKI Eroski Scoop.",
    "25545": "AVANZA- Avanza Bank AB",
    "25546": "BROOKLANDCOMP- Brookland Computer Services Limited",
    "25547": "INTUIT- Intuit Maidenhead",
    "25549": "AVANTEL- Closed Joint-stock company Avantel",
    "25551": "CREDIT-AGRICOLE-CIB Credit Agricole Corporate and Investment Bank",
    "25552": "GBG- Getin Noble Bank Spolka Akcyjna",
    "25553": "GLUHOV-TRK TRK Gluhov Ltd.",
    "25554": "MINFIN- Ministry of Finance of Bulgarian Government",
    "25555": "STARTART- Start Art",
    "25556": "NEXCOM-BG- Nexcom Bulgaria EAD",
    "25557": "PKE- Poludniowy Koncern Energetyczny S.A.",
    "25559": "HARPER- MCE Ltd.",
    "25560": "RHTEC- rh-tec IP Backbone",
    "25561": "PRONTO Pronto-Moscow Autonomous System",
    "25562": "SCEE Sony Computer Entertainment Europe (SCEE)",
    "25563": "WEBLAND- Webland AG, Autonomous System",
    "25564": "N-NETSIGHT Netsight Internet Solutions Limited",
    "25565": "NETANYA-COLLEGE- Netanya Academic College",
    "25566": "SSK- Sosyal Guvenlik Kurumu(SGK)",
    "25567": "EURO6IX Euro6IX: The Pan-European IPv6 IX Backbone",
    "25568": "KENYAWEB",
    "25569": "INFOCAMERE- Infocamere represents the community of the Italian Chambers of",
    "25572": "ISC-MAD1 Internet Systems Consortium Inc.",
    "25574": "ENKA- Enka Insaat Sanayi A.S.",
    "25575": "DOMAINTECHNIK Ledl.net GmbH",
    "25576": "AFMIC",
    "25577": "C4L- Connexions4London Ltd",
    "25579": "SKYTRON SKYTRON Communications GmbH & Co KG",
    "25581": "COSBA- Cosba Private Banking AG Zuerich",
    "25582": "N-LINIX LINIX Ltd",
    "25583": "REGMERCANTIL-ES- REGISTRO MERCANTIL Autonomous System",
    "25584": "OPOLMAN--COM Opole University",
    "25585": "KENCOMP Kencomp Internet LTD",
    "25586": "P-OL Hadara Technologies Private Shareholding Company",
    "25587": "DXI-SOL-CORE MoneyAM Ltd",
    "25588": "ULTRPEED Ultraspeed UK Limited",
    "25589": "N-PAYA-SHABAKEH-ARIA Paya Shabakeh Aria",
    "25590": "N-BLAGOVEST Blagovest 2000 PB",
    "25591": "BALD- Bald Automobilgesellschaft mbH & Co. KG",
    "25592": "NETIS- NETIS TELECOM Inc. Yaroslavl region ISP provider Russia",
    "25593": "LINKBYNET- Linkbynet S.A",
    "25594": "CALIK Calik Holding",
    "25596": "CAMBRIUM- Cambrium IT Services B.V.",
    "25598": "FENACO fenaco Genossenschaft",
    "25599": "SIEMENS-NL- Atos Nederland B.V.",
    "25602": "TRAVELERSPC2 - Travelers Property Casualty Corp.",
    "25603": "SCOTTSDALE-INSURANCE - Scottsdale Insurance Company",
    "25604": "GULF-SOUTH-PIPELINE - GULF SOUTH PIPELINE CO LP",
    "25605": "SCANSAFE Cisco Scansafe Division",
    "25606": "CPVCOM - Cooperative Communications Inc.",
    "25607": "IBW Communications",
    "25608": "WISUSA - WIS International",
    "25609": "DMC - Detroit Medical Center",
    "25610": "FULLCC - Full Choice Communications, Inc.",
    "25611": "NSLIJHS - North Shore Long Island Jewish Health System",
    "25612": "DSL-EXPRESS - DSL EXPRESS",
    "25613": "ACNB - Adams County National Bank",
    "25614": "TJM-NUMBER - TJM Institutional Services, LLC.",
    "25615": "BBV - Broadband Visions, LLC",
    "25616": "EMNS - EMNS, Inc.",
    "25617": "SMITHNEPHEW - Smith and Nephew, Inc.",
    "25618": "CAM - Cameron",
    "25619": "AIROSURF - Airosurf",
    "25620": "COT LTDA.",
    "25621": "N-GENESIS - Genesis Health System",
    "25622": "TERMNET - TERMNET MERCHANT SERVICES INC",
    "25623": "CISN2-IP TOWARDEX Corporate Information Systems Network (CISN)",
    "25624": "NIGHTN - Night Technologies, LLC",
    "25625": "IPAI - IP Access International",
    "25626": "POTEN - POTEN & PARTNERS INC.",
    "25627": "BTS BTS Global",
    "25629": "ACPS-8-N - Albemarle County Public Schools",
    "25630": "CARROTWEST - Carrot Technologies",
    "25631": "GALLAUDET - Gallaudet University",
    "25632": "NFBC-BGP - Niagara Falls Bridge Commission",
    "25633": "DATAMATX-ATL - DATAMATX INC",
    "25634": "DTI-ATL - DOCUMENT TECHNOLOGIES, LLC",
    "25635": "SAIT- - Southern Alberta Institute of Technology",
    "25636": "ONTL-2002 - ONTel, Inc.",
    "25637": "PRMTC - The Park Region Mutual Telephone Co",
    "25638": "1911INT - Adaptive Imaging Solutions, LTD",
    "25639": "CEDAR-RIDGE-PARTNERS-LLC - Cedar Ridge Partners, LLC",
    "25640": "HAWAII-DEPT-OF-EDUC - Hawaii Department of Education",
    "25641": "FHCP-001 - Florida Health Care Plan, Inc.",
    "25642": "SPIDERHOST - Spiderhost Inc",
    "25643": "COLDRACK - ColdRack, Inc",
    "25644": "LOGICLINK - Logic Solutions, Inc.",
    "25645": "25645 - Momentum Telecom, Inc.",
    "25646": "TF3575FT-TNY - Tony's Fine Foods Inc",
    "25647": "SENSUS-NA - Sensus USA Inc.",
    "25648": "PARALLAXSYSTEMS - Parallax Systems",
    "25649": "AYERA- - AYERA TECHNOLOGIES, INC.",
    "25650": "IONWPB - ION MEDIA NETWORKS",
    "25651": "GRTI-NW - Gila River Telecommunications Inc.",
    "25652": "-SHCFCU - ST HELENS COMMUNITY FEDERAL CREDIT UNION",
    "25653": "FORTRESSITX - FortressITX",
    "25654": "LPCAPWILTON - Lone Pine Capital LLC",
    "25655": "OSTK-COM - Overstock.com",
    "25656": "OLEMISSS - The University of Mississippi",
    "25657": "37SIGNALS - 37signals LLC",
    "25658": "EQUINIX-RS-SJO - Equinix, Inc.",
    "25659": "MRR-NETWORK - Marketing & Research Resources, Inc.",
    "25660": "CTC - Champaign Telephone Company, INC.",
    "25661": "SUNESIS-PHARM - Sunesis Pharmaceuticals, Inc.",
    "25662": "DDPSC - Donald Danforth Plant Science Center",
    "25663": "PRIDEMOBILITY - Pride Mobility Products Corporation",
    "25664": "SOLANOCOE - Solano County Office of Education",
    "25665": "EV-CLOUD - Symantec Corporation",
    "25666": "BAREWEB - Bareweb, Inc.",
    "25667": "HOME-SHOPPING-NETWORK - Home Shopping Network",
    "25668": "CIPHERKEY - Cipherkey Exchange Corp.",
    "25669": "TOWERPRODUCTS - MARKERTEK VIDEO SUPPLY",
    "25670": "THINKCSC - Computer Site Columbus",
    "25671": "AIRENET-NEUVO-CA - Wholesale Air-time Inc.",
    "25673": "RMSSLB - Cellnet Innovations, Inc.",
    "25674": "25674 - Excel Telecommunications",
    "25676": "FEDEX-FREIGHT - FedEx Freight System",
    "25677": "AUCTIVA - Auctiva Corporation",
    "25678": "SCHIFFHARDIN - Schiff, Hardin & Waite",
    "25679": "TDC-DATA3 - Tulsa Data Center LLC",
    "25680": "EMUNET-HBGVA - Eastern Mennonite University",
    "25681": "ELEMENT-PS - Element Payment Services Incorporated",
    "25682": "CONTRACTDATCAN - Contract Datascan, Inc.",
    "25683": "FFB-NET-N - First Financial Bank, N.A",
    "25684": "MATTAWAN-CONSOLIDATED-SCHOOL- - Mattawan Consolidated School",
    "25685": "FNIS-ALB - Fidelity Integrated Financial Solutions",
    "25686": "UNGARETTI-HARRIS - Ungaretti & Harris",
    "25687": "KVH02842 - KVH INDUSTRIES,INC.",
    "25688": "AMERITIF - Amerifit Brands Inc",
    "25689": "NRCNET- - National Research Council of Canada",
    "25690": "MAMSI - Mid Atlantic Medical Services Inc.",
    "25691": "CTSTATEU - Connecticut State University System",
    "25692": "AEGISINFOSYS - AEGIS INFORMATION SYSTEMS INC",
    "25693": "CLEARPATH-NETWORKS - ClearPath Networks, Inc.",
    "25694": "ATOMIC - Atomic Data LLC",
    "25695": "LEO",
    "25696": "PDP-GROUP-INC - PDP Group, Inc.",
    "25697": "PREEM- - Pre-Employ.com",
    "25698": "SMART-CITY - Smart City Telecom",
    "25699": "WILSONART-INTL - Wilsonart International",
    "25700": "25700 - SWIFT VENTURES Inc",
    "25701": "AMERICATEL PERU S.A.",
    "25702": "NEWTECHSYS - New Tech Computer Systems",
    "25704": "AGI - The Alexander Group, Inc",
    "25705": "AMERICATEL PERU S.A.",
    "25706": "INTERLINKCI-1 - Interlink Connectivity Inc",
    "25707": "ITECH - Pennsylvania Online",
    "25708": "SNAUTO - Sonic Automotive, Inc.",
    "25709": "LAMARUNIV - Lamar University",
    "25710": "FULL-CHANNEL - Full Channel  Inc.",
    "25711": "VMC-PELLA- - Vermeer Manufacturing Company",
    "25712": "CSIPADKY - Computer Services Inc",
    "25713": "FDS - FAMILY DOLLAR, Inc.",
    "25715": "UREACH-C - UREACH TECHNOLOGIES, INC.",
    "25716": "INGERSOLL-RAND - Ingersoll Rand Company",
    "25717": "SCAAM0001 - SCA Americas",
    "25718": "Turismo Cocha S.A",
    "25719": "XMT3-001-CPR - Clear Voice Telecom Inc.",
    "25720": "HONEYCOMB - Honeycomb Internet Services",
    "25721": "13494 - Morningstar, Inc.",
    "25722": "GATEWAY-OPERATIONS - Payment Processing Inc.",
    "25723": "AOLTW-WMG-DE Autonomous System originally from AOL Inc. (ARIN)",
    "25724": "EXPENSEANYWHERE - Virtual Communications",
    "25725": "EINK - E INK CORPORATION",
    "25727": "RBNA-HQ - RED BULL NORTH AMERICA, INC.",
    "25728": "LAMBTON-COLLEGE - Lambton College of Applied Arts and Technology",
    "25729": "CITY-OF-IRVING - City of Irving",
    "25730": "USENIX - Usenix Association",
    "25731": "AEREO-BOS - Aereo, Inc.",
    "25732": "TOTALCARDINC - Total Card, Inc.",
    "25733": "EAGLENET - Eagle Ottawa, LLC",
    "25735": "MDCPA-NY - MDC PARTNERS, INC.",
    "25736": "TRADEONEMKTG - TradeOne Marketing, Inc",
    "25737": "ENFRA-AV - Enfrastructure, Inc.",
    "25738": "HERZING-UNIVERSITY - Herzing INC",
    "25739": "ADTRAN - Adtran, Inc.",
    "25740": "SAC - SAC CAPITAL ADVISORS, LLC",
    "25741": "SKYBEAM-25741 - JAB Wireless, INC.",
    "25742": "DONERUS - W.B. Doner",
    "25743": "EEA-EPSON - EPSON ELECTRONICS AMERICA, INC.",
    "25744": "LOGIC-SPRINGS-TECHNOLOGIES - Logic Springs Technologies",
    "25745": "ALENTUS - Alentus Corporation",
    "25747": "VSC-SATELLITE-CO - VSC Satellite Co.",
    "25748": "CQGNET-CHICAGO - CQG, Inc.",
    "25749": "UNISERVE-ISLAND - Uniserve On Line",
    "25750": "SVHC - Southwestern Vermont Health Care",
    "25751": "VALUECLICK - Valueclick, Inc.",
    "25752": "METHEAN-25752 - Methean Professional, LLC",
    "25753": "CALPERS - CalPERS",
    "25754": "BLUEPRINT - Blueprint America, Inc.",
    "25755": "NPR - National Public Radio",
    "25756": "MS-SOC - Symantec Corporation",
    "25757": "VISC-VAILNET - Visionary Communications, Inc.",
    "25758": "MEG-OH - MIDWEST EXPRESS INC",
    "25759": "CLOUD9 - C9 Edge, Inc.",
    "25760": "MTI - Mellanox Technologies",
    "25761": "STAMINUS-COMM - Staminus Communications",
    "25762": "BOCUSA - BANK OF CHINA, NY BRANCH",
    "25763": "SDIINC - SDI INC",
    "25764": "IFIBER-COMMUNICATIONS - iFiber Communications Corp.",
    "25765": "CQGNET-NEWYORK - CQG, Inc.",
    "25766": "MAXUPTIME - Maxuptime, LLC",
    "25767": "WAVEFORM - Waveform Technology, LLC",
    "25768": "AQ-1 - Aquent, LLC",
    "25769": "GVTEL - Garden Valley Telephone Company",
    "25770": "GLOBALHRLEADER - Society for Human Resource Management",
    "25772": "NCARB - National Council of Architectural Registration Boards",
    "25773": "EJOURNEY - Endless Journey, Inc.",
    "25774": "THOUGHTCONVERGENCE - Thought Convergence, Inc.",
    "25775": "GLADSON-LISLE - Gladson, LLC",
    "25776": "UNIV-OF-OKLAHOMA - University of Oklahoma",
    "25777": "SNE - Subaru of New England",
    "25778": "URBAN-INSTITUTE - The Urban Institute",
    "25779": "HAMAMATSU-CORPORATION - Hamamatsu Corporation",
    "25780": "HUGESERVER-NETWORKS - HugeServer Networks, LLC",
    "25781": "GREENHILL - Greenhill & Co LLC",
    "25782": "AIRLOGIC - AirLogic Internet Services",
    "25783": "AGENT-EBUSINESS - Farmers Group, Inc.",
    "25784": "CSC-IGN-AMER-HOU - Computer Sciences Corporation",
    "25785": "REDL-1 - Real Estate Digital LLC",
    "25787": "ROWE-NETWORKS - Rowe Wireless Networks LLC",
    "25788": "CPL- - Centerview Partners, LLC",
    "25789": "LMU - Loyola Marymount University",
    "25790": "GAMMANETWORKING - Gamma Networking Inc.",
    "25791": "SE-NET - Stack Exchange, Inc.",
    "25792": "TMC-HEALTHCARE - TMC Healthcare",
    "25793": "EDSZA-WAN",
    "25794": "DPCLAX - Dairyland Power Cooperative",
    "25795": "ARPNET - ARP NETWORKS, INC.",
    "25797": "TERANET - Teranet Inc.",
    "25798": "FIGMENT - Figment Cablesystems Inc.",
    "25799": "HOLMAN - Holman Enterprises",
    "25801": "AUTOMATED-FINANCIAL - Automated Financial Systems",
    "25802": "HBO - Home Box Office",
    "25803": "KYUS - KENTUCKY UNDERGROUND STORAGE",
    "25804": "LLNW-LGA - Limelight Networks, Inc.",
    "25805": "STIKEMAN - Stikeman Elliott, LLP",
    "25806": "RALEYNET - Raleys",
    "25807": "ARLINGTONVA - Arlington County Government",
    "25808": "CONCORD-MA - Town of Concord MA",
    "25809": "BOSE-CORPORATION-US - Bose Corporation",
    "25811": "CAPCO - Capco",
    "25812": "Estafeta Mexicana S.A. de C.V.",
    "25813": "HOVS-MI - HOV Services, Inc.",
    "25814": "VMT-ADC - Virtual Management Technologies, Inc.",
    "25815": "USITEK- - US ITEK Incorporated",
    "25816": "TOURO - Touro College",
    "25817": "SMARTECHCORP - SMARTECH CORPORATION",
    "25818": "CMCNETWORKS",
    "25819": "ZONERESEAU - Zonereseau.com",
    "25820": "IT7NET - IT7 Networks Inc",
    "25821": "NET-SCNB - Suffolk County National Bank",
    "25822": "ACUMENSOL - Acumen Solutions",
    "25823": "FLAG-ORG - CHURCH OF SCIENTOLOGY FLAG SERVICE ORGANIZATION, INC.",
    "25824": "CONAGRA-FOODS - ConAgra Foods, Inc.",
    "25825": "PVH-N-1 - Poudre Valley Health Care, Inc.",
    "25826": "UOTTAWA - University of Ottawa",
    "25827": "N02-SOGE - SOGETEL INC",
    "25828": "STATE-OF-IDAHO - State of Idaho",
    "25829": "SMITHSONIAN - Smithsonian Institution",
    "25830": "BLUE-VALLEY - Blue Valley Tele-communications, Inc.",
    "25831": "AINA-DSM - Aviva Investors North America, Inc.",
    "25832": "Cia. de Processamento de Dados do Estado da Bahia",
    "25833": "TOCT - The Ontario College of Teachers",
    "25835": "RBH-CLT-NET1 - Robinson, Bradshaw & Hinson, P.A.",
    "25836": "STERLING-JEWELERS - Sterling Jewlers Inc.",
    "25838": "OMANET - AAA Ohio Motorists Association",
    "25839": "REDHAWK-NETWORK-ENGINEERING - Redhawk Network Engineering, Inc.",
    "25840": "CCADE-ACCESS-LLC-CA-ESTOR1 - Cascade Access, LLC",
    "25841": "FUSIONAPPS - Fusionapps, LLC.",
    "25842": "ADVANCE2K - Advance 2000, Inc.",
    "25843": "EVOLVEIP - EvolveIP, LLC",
    "25844": "SKADDEN1 - Skadden, Arps, Slate, Meagher & Flom LLP",
    "25845": "VIRGINIA-MON - Virginia Mason Medical Center",
    "25847": "SERVINT - ServInt",
    "25848": "LTGC - LAND TITLE GUARANTEE COMPANY",
    "25849": "FILOGIX - FiLogix Inc.",
    "25850": "CARESTREAMHEALTH - Carestream Health, Inc.",
    "25851": "ZIGWIRELESS - ZigWireless LLC",
    "25852": "HUTCHTEL - Hutchinson Telephone Company",
    "25853": "ELJY30540 - Ellijay Telephone Company",
    "25855": "DNS-NY - Digital Networking Systems, INC.",
    "25856": "ERATRANS - Edith Roman Holdings, Inc.",
    "25857": "ACS-N - American Chemical Society",
    "25858": "PCNET-WICHITA - PCNET",
    "25859": "CFS - Central Refrigerated Service,Inc.",
    "25860": "WEBJUICE-NETWORK - WebJuice, LLC",
    "25861": "NDEVIX - nDeviX",
    "25862": "TRADEONE2 - TRADEONE MARKETING, INC",
    "25863": "HUNTERENG - Hunter Engineering Company",
    "25864": "INTELENET-ALT - Latisys-Irvine, LLC",
    "25865": "PINNA-86 - Pinnacle Telecom, LLC.",
    "25866": "ND-K12-I2 - State of North Dakota, ITD",
    "25867": "INTRIA-HP-CORP - INTRIA-HP Corporation",
    "25868": "INSURE-COM - Insure.com",
    "25869": "HSBC-US - HSBC Bank USA",
    "25870": "PCFCOM - PACIFIC COT FEATHER CO.",
    "25871": "WFG - Willkie, Farr & Gallagher",
    "25872": "RVSD41 - Rocky View Schools",
    "25873": "MERCY - MERCY MEDICAL CENTER",
    "25874": "LS-1 - Liquidity Services Inc.",
    "25875": "VARIOUS - FriendFinder Networks Inc",
    "25876": "LADWP-INTERNET - Los Angeles Department of Water & Power",
    "25877": "OPEN-MOBILE-PUERTO-RICO - Open Mobile",
    "25878": "QNST-DC01 - Quinstreet, Inc.",
    "25879": "MGHS - Marquette General Health Systems",
    "25880": "YURGATELEKOM- OAO Yurgatelekom",
    "25881": "SINGLE-DIGITS - Single Digits, Inc.",
    "25882": "SITE2 - Site2BC",
    "25883": "CITIGROUP - Citigroup",
    "25884": "WIZARDS - Wizards of the Coast",
    "25885": "BATBLUE - Bat Blue Corporation",
    "25886": "HPES - Hewlett-Packard Company",
    "25887": "SLIAC - St. Louis Internet Access Consortium",
    "25888": "CPQ-CXO-IOMC - Hewlett-Packard Company",
    "25889": "BXS-NET- - BancorpSouth, Inc.",
    "25890": "ADEMCONET - Ademco",
    "25891": "SVA-ANS - School Of Visual Arts, Inc.",
    "25892": "VERTEX - Vertex Telecom, Inc.",
    "25893": "VPB - ViewPoint Bank",
    "25894": "WIRECOM - WIRECOM TECHNOLOGIES, CORP.",
    "25896": "IPC-NETWORK-SERVICES-INC - IPC Network Services Inc.",
    "25897": "SERVERBEACH - ServerBeach",
    "25898": "FULL-SAIL-INC - Full Sail, Inc.",
    "25899": "LSNET - LS Networks",
    "25900": "HEMETUSD - Hemet Unified School District",
    "25901": "CP-MEDIA - Community Newspaper Company",
    "25902": "EUROPEAN-INVESTORS-INC - European Investors Inc",
    "25903": "MEINTL - Meetings & Events Intl.",
    "25904": "N-CXA-GC-25904-CBS - Cox Communications Inc.",
    "25905": "FIRESERVE - FireServe, LLC",
    "25906": "IVGNCB - Life Technologies Corp.",
    "25907": "BRINKER-INT - BRINKER INTERNATIONAL",
    "25908": "Unitel",
    "25909": "STEVE-MADDEN - Steven Madden, LTD.",
    "25910": "TELTRAX-ARIN - TELTRAX CORP.",
    "25911": "TALISMAN-CH3 - TALISMAN ENERGY INC.",
    "25912": "GETCO1 - GETCO, LLC",
    "25913": "I-DCO--109 - APPLIED SYSTEMS, INC",
    "25914": "QCC- - Quadro Communications Co-Operative Inc",
    "25915": "GETJAR - Getjar, Inc.",
    "25916": "FREEMAN-COMPANIES - The Freeman Companies",
    "25917": "N-TEP - Trilogy Partners LLP",
    "25918": "LMHS - Lima Memorial Hospital",
    "25919": "RBI1 - Reed Business Information",
    "25920": "BDSL-3 - Baseline Data Services LLC",
    "25921": "LAF-CONSOLIDATED-GOV - Lafayette Consolidated Government",
    "25922": "CHS-1 - Comprehensive Health Services, Inc.",
    "25923": "LEXISNEXIS-RISK-SETS - ChoicePoint, Inc.",
    "25924": "GCM - Graham Capital Management, L.P.",
    "25925": "CITYOFLETH - City of Lethbridge",
    "25927": "Telecomunicaciones de America S.A. de C.V.",
    "25928": "LAZERNET-WIRELESS - Lazernet, Inc.",
    "25929": "MILLENNIUM-PHARMACEUTICALS-INC - Millennium Pharmaceuticals, Inc.",
    "25930": "GENESIS-HEALTHCARE - Genesis Healthcare Corporation",
    "25931": "SDXBF-DC-1 - Sodexo, Inc.",
    "25932": "DWSI - Disney Worldwide Services, Inc.",
    "25933": "Sul Americana Tecnologia e Inform\u00e1tica Ltda.",
    "25934": "SVR-MAIN - Syniverse Technologies, LLC",
    "25935": "WNYRIC-NET - Erie 1 BOCES",
    "25936": "MJH-SYSTEM - METROPOLITAN JEWISH HEALTH SYSTEM",
    "25937": "TRANS-VIDEO - Trans-video cable, Inc.",
    "25938": "SOROS-FUND-MANAGEMENT-LLC SOROS FUND MANAGEMENT LLC",
    "25939": "COBA-3 - Commerzbank AG",
    "25940": "TIBCO - TIBCO Software Inc.",
    "25941": "SUPERCLUBS-25941 - SuperClubs.com",
    "25942": "CRITICALTECH - Critical Technologies, Inc.",
    "25943": "COUNTRY-CONNECTIONS-LLC - Country Connections LLC",
    "25944": "WITTSEND - Thaumaturgy & Speculums Technology",
    "25945": "CBSNSOC-LR - Leidos CBSNSOC (commercial Business Services Network Security Operations Center)",
    "25946": "NETACCESS-SYSTEMS - NetAccess Systems Inc",
    "25947": "ABIL-5025 - Arizona Bridge to Independent Living",
    "25948": "FHMNET - 1882914 Ontario Inc",
    "25949": "CISCOTTGOPS - Cisco Systems Inc.",
    "25950": "BEGGSTELEPHONE - Beggs Telephone Company, Inc.",
    "25951": "HPES - Hewlett-Packard Company",
    "25952": "AEAINVESTORS - AEA Investors Inc.",
    "25953": "WHAFHNY-1 - Wolf Haldenstein Adler Freeman & Herz LLP",
    "25954": "STERNE - Sterne, Agee & Leach, Inc.",
    "25955": "PROSKAUER-1 - Proskauer Rose LLP",
    "25956": "ALPHEUS - Alpheus Data Services, L.L.C.",
    "25957": "MADRIVERACCESS - Mad River Access",
    "25958": "MSGCORP-01 - Marketing Systems Group, Inc.",
    "25959": "SUNTRUST - SunTrust Banks, Inc.",
    "25960": "SFP - Schurman Fine Papers, Inc.",
    "25961": "ALYRICA - Alyrica Networks Inc.",
    "25962": "ALC - Atlantic Lottery Corporation",
    "25963": "TCCD-1 - Tarrant County College District",
    "25964": "CT-PROVIDENCE - Ingenix CareTracker",
    "25965": "BRAMCO - BRAMCO, LLC",
    "25966": "COHERENT - Coherent Inc.",
    "25967": "OATI-2300 - OPEN ACCESS TECHNOLOGY INTERNATIONAL, INC.",
    "25968": "SELUNET - Southeastern Louisiana University",
    "25969": "SLU - St. Louis University",
    "25970": "IAC - IAC Services LLC",
    "25971": "MILWAUKEE-PS - Milwaukee Public Schools",
    "25972": "SAP-AG-PAL - SAP Labs",
    "25973": "GTT Global Telecom & Technology N",
    "25974": "HOTWIRE - Hotwire, Inc.",
    "25975": "NET2ATLANTA-GA - NET2ATLANTA.COM LLC",
    "25976": "METROBRIDGE-NET - TeraGo Networks Inc.",
    "25977": "HCCS - HOUSTON COMMUNITY COLLEGE SYSTEM",
    "25978": "RUSH-UNIVERSITY - Rush University Medical Center",
    "25979": "COMDC-WI - CITY OF MADISON",
    "25980": "NORTHWEST-MAILING-SERVICE - Northwest Mailing Service, Inc.",
    "25981": "QSI - QS Investors Holdings, LLC",
    "25982": "NORTH-DALL-BANK - North Dallas Bank and Trust",
    "25983": "SHAW-ENVISION - Enmax Envision Inc.",
    "25984": "MEDSTARHEALTH - MedStar Health",
    "25985": "SYMBIOSYSTEMS - SymbioSystems LLC",
    "25986": "TICKE-6-N - Citysearch.com",
    "25987": "WESTCHESTER-LIBRARY - Westchester Library System",
    "25988": "BOG - Bank of Georgetown",
    "25989": "STONEEAGLE - StoneEagle Insurance Systems, Inc.",
    "25990": "PROVIDYN--01 - ProviDyn, Inc.",
    "25991": "BENDIXCVS - Bendix Commerical Vehicle Systems",
    "25992": "PRODUCTION-NETWORK - Vericom Corporation",
    "25993": "-25993 - AT&T Labs, Inc.",
    "25994": "SUDDE2 - Suddenlink Communications",
    "25995": "CALTELEHEALTHNET - California Telehealth Network",
    "25996": "FBICJIS - FBI Criminal Justice Information Systems",
    "25997": "OMMLA-1 - O'Melveny & Myers LLP",
    "25998": "U.N.D.P. (United Nations Development Programme)",
    "25999": "DARGAL - Dargal Interline Wroldwide ULC",
    "26000": "COHN-WOLFE - Cohn & Wolfe",
    "26001": "BLUIP - BLUIP INC",
    "26002": "SU-NOC - Southern University",
    "26003": "MBCSEA - MBC Telecom, LLC",
    "26004": "AUTOWEB-01 - Trubiquity Inc",
    "26005": "CALLAWAYGOLF - Callaway Golf",
    "26006": "MON-HILL-ADVISORS - Mason Hill Advisors, LLC",
    "26008": "NOMINUM-SKYE1 - SKYE",
    "26010": "QL-N-AV - Qlogic Corporation",
    "26011": "LMCSC - Lexington Medical Center",
    "26012": "NET-OHIO-BWC - Ohio Bureau of Worker's Compensation",
    "26014": "FECI-FDG - Florida East Coast Industries",
    "26015": "JACOBS-VEHICLE-SYSTEMS-BGP - JACOBS VEHICLE SYSTEMS",
    "26017": "BETTENDORF-LIBRARY - Bettendorf Public Library",
    "26018": "TENG - Teng & Associates, Inc.",
    "26019": "MONSTERCABLE - Monster Cable Products, Inc.",
    "26020": "STSCI-NET - Space Telescope Science Institute",
    "26021": "QL-N-EP - Qlogic Corporation",
    "26022": "FIRST-NORTHERN-BANK - First Northern Bank",
    "26024": "VIEWQ-NET - Viewqwest, Inc",
    "26025": "COC - City of Calgary",
    "26026": "BUTLER-UNIVERSITY - Butler University",
    "26027": "SSCN - SeaStone Capital Management, L.P.",
    "26028": "PANDUIT - Panduit Corp.",
    "26029": "BHRCA - BHR Capital, LLC",
    "26030": "GHSINC - GHS Data Management",
    "26031": "MONMOUTH-COUNTY - Monmouth County",
    "26032": "FDMS - First Data Merchant Services",
    "26033": "EDGETRADE - Knight Capital Group, Inc",
    "26034": "N-DELTA-OUT - Delta Technology",
    "26035": "SKYLINE3355 - Skyline Exhibits",
    "26036": "KOOTENAIHEALTH - Kootenai Medical Center",
    "26037": "RED-DEER-COLLEGE - Red Deer College",
    "26038": "RHY-US1 - Rhythm NewMedia, Inc.",
    "26039": "AVIVA-USA - Aviva USA Corporation",
    "26040": "STARWOODHOTELS-PHOENIX - Starwood Hotels and Resorts",
    "26041": "MINDSHARE - Mindshare Design, Inc.",
    "26042": "TENEX-SYSTEMS - TENEX Systems, Inc.",
    "26043": "NATL-EDU - National Education Association",
    "26044": "DEDIPRO - Dedicated Professionals, LLC",
    "26045": "NOC24-LLC - NOC24 LLC",
    "26046": "USU-EDU - Utah State University",
    "26047": "MGMEAD - M.G. Mead and Company",
    "26048": "CHILENA CONSOLIDADA SEGUROS S.A.",
    "26049": "SES-AMERICOM-WBES - SES Americom",
    "26050": "SAM-CHAR - SOUTHETERN SET MANAGEMENT, INC.",
    "26052": "ABN-AMRO-CLEARING-CHICAGO-LLC - Fortis Clearing Chicago LLC",
    "26053": "N1 - Dialectic Capital Management, LLC",
    "26054": "YPC-NET - YellowPages.com LLC",
    "26055": "INTELLITRANS-LLC - Intellitrans Inc",
    "26056": "PCMALL - PC Mall, Inc.",
    "26057": "MEDIAOCEAN - Mediaocean LLC",
    "26058": "NTST - Netsmart Technologies",
    "26059": "PGH- - City of Pittsburgh",
    "26060": "EMERGING-132 - EMERGING TECHNOLOGY CENTER",
    "26061": "Orange Business Services Colombia S.A.",
    "26062": "IBMCCH-LAX - IBM",
    "26063": "ALCONLABS-11975 - Alcon Labs, Inc.",
    "26064": "COFKM - City of Kings Mountain",
    "26065": "ABA-1375 - Anchin, Block & Anchin LLP",
    "26066": "NVUSD - Napa Valley Unified School District",
    "26067": "WMG-NYC - Warner Bros. Records",
    "26068": "ONSH-NET-CHGO-BLK01 - OnShore, Inc.",
    "26069": "ALVERNIAUNIVERSITY-01 - Alvernia University",
    "26071": "LAKEHEAD - Lakehead University",
    "26073": "QSIAL-N - Quadrant Structured Investment Advisers, LLC",
    "26074": "FRESHDIRECTINC - Fresh Direct, Inc.",
    "26075": "MCUNY-01 - Municipal Credit Union of NY",
    "26076": "INFINITECOM - Infinite Communication, LLC",
    "26077": "NEXTLINK-TEX - Nextlink Broadband",
    "26078": "JRTHOMPSON-NOC - J.R. Thompson Company",
    "26079": "MOMEN-26079 - Momentum Telecom, Inc.",
    "26080": "IMPREZZIO - Imprezzio Inc",
    "26081": "SANTEECOOPER - Santee Cooper",
    "26082": "POWERSHIFT-PLAINFIELD-VT - Power Shift Computer Services, Inc.",
    "26083": "NEWEDGE-N1 - Newedge Facilities Management, Inc.",
    "26084": "PCI - PCI",
    "26085": "YAHOO-2 - Yahoo!",
    "26086": "BESTBUY-2 - Best Buy Co., Inc.",
    "26087": "GARDNER-WEBB - Gardner-Webb University",
    "26088": "INLANDTELEPHONE - Inland Internet",
    "26089": "SETINTERNATIONAL - Asset International",
    "26090": "ITE Internet e Tecnologia Ltda",
    "26091": "INDDC - Indiana Data Center, LLC",
    "26092": "LANCOPE-HQ - Lancope",
    "26093": "HAR - Houston Association of Realtors",
    "26094": "BTP - Baltimore Technology Park, LLC",
    "26095": "FUTURELOGIC - FUTURELOGIC INCORPORATED",
    "26096": "LODDEN - Lodden Services",
    "26097": "LABYRINTH - Labyrinth Solutions Inc",
    "26099": "I-1 - Institute for Advanced Study",
    "26100": "NOAA-PACIFIC-REGION-CENTER - National Oceanic and Atmospheric Administration",
    "26101": "YAHOO-3 - Yahoo!",
    "26102": "CALIBRE6354 - CALIBRE Systems Inc.",
    "26103": "ACIG - ACIG",
    "26104": "Telespazio Brasil S.A.",
    "26105": "Telecarrier, Inc",
    "26106": "ALTONET-ZA",
    "26107": "BSA Brasil Com\u00e9rcio e Servi\u00e7os de Inform\u00e1tica Ltda",
    "26108": "PRICEGRABBER- - PriceGrabber.com",
    "26109": "L-PERRIGO-GLOBAL - L. Perrigo Company",
    "26110": "MHT-N - Manitoba Hydro International LTD",
    "26111": "WEBRWEST - RnD Media LLC",
    "26113": "TNS-N - Triware Networld Systems",
    "26114": "ANAPLAN - Anaplan, Inc.",
    "26115": "MIDATL-1 - MidAtlanticBroadband Maryland, Inc.",
    "26116": "INDRA - Indra's Net Inc",
    "26118": "MINISTERIO PUBLICO FEDERAL - PROCURADORIA GERAL DA",
    "26119": "Orden S.A",
    "26121": "JEPPESEN - Jeppesen",
    "26122": "SJHHC-N - St. Joseph's Hospital Health Center",
    "26123": "ITU-NET-1 - Independence Telecommunications Utility",
    "26124": "EOLNET-ECUADOR-ONLINE Grupo Coripar Corisat America",
    "26125": "HOLCIMUSINC - Holcim (US), Inc.",
    "26126": "LUKE-N - LUKE & SOCIATES, INC.",
    "26127": "FRONTIERLABRESEARCH - Frontier Communications of America, Inc.",
    "26128": "-360WISP - 360 Communications, LLC",
    "26129": "HOLLYWOOD-CENTER - Hollywood Center Studios",
    "26130": "LIPTINFOR-",
    "26131": "TMC1 - Harley-Davidson, Inc.",
    "26132": "GLENN-INTERNATIONAL - GLENN International",
    "26133": "FEWPB - Frankfort Plant Board",
    "26134": "BROAD-RUN-BORDER- - VeriSign Infrastructure & Operations",
    "26135": "NETGAIN-TECHNOLOGY - Netgain Technology, Inc.",
    "26136": "The American School of Lima",
    "26137": "BALLY-TECHNOLOGIES-US - Bally Technologies, Inc.",
    "26138": "SKYFIRE-DC1 - Skyfire Labs, Inc.",
    "26139": "ECR - ECR Internet Services, Inc.",
    "26141": "CORN - Corn Products International",
    "26142": "MANNINGTON-SALEM - MANNINGTON MILLS",
    "26143": "PROSITES-WC1 - ProSites, Inc.",
    "26144": "FISERV-EFT - Fiserv Solutions, Inc.",
    "26145": "TP-IX - Paul Bunyan Communications",
    "26146": "EYTEL - EasyTEL Communications, Inc.",
    "26147": "APCAP - Atlantic Pacific Capital",
    "26148": "CSMPR - Cooperativa de Seguros Multiples de Puerto Rico",
    "26149": "SETNI- - SetNine",
    "26150": "BC-MAR-N - Bracebridge Capital, LLC",
    "26151": "ARTHREXINC - Arthrex Inc.",
    "26152": "VL-AMERIC-A - VoIP Rental",
    "26153": "BCBSSC - Blue Cross Blue Shield of South Carolina",
    "26154": "Q-CAPITAL-STRATEGIES - Q Capital Strategies, LLC",
    "26155": "LAO- - Legal Aid Ontario",
    "26156": "VERUS - Verus Corporation",
    "26157": "LIMONET - El Paso - Los Angeles Limousine Express, Inc.",
    "26158": "WEYRICH-CRONIN-SORRA - Weyrich Cronin and Sorra",
    "26159": "UMB - UMB Bank, NA",
    "26160": "LCEC-BGPNET-YHWH - LCEC",
    "26161": "TMEIC-A - TMEIC Corporation",
    "26162": "N\u00facleo de Inf. e Coord. do Ponto BR - NIC.BR",
    "26163": "DATAGRAM - Datagram, Inc.",
    "26164": "PERFORMANCE-FOODS - Performance Food Group Company LLC",
    "26165": "CHSCC - Chattanooga State Community College",
    "26166": "COMWAVZ - Watch TV",
    "26167": "N-MARKLEY - Markley Group",
    "26168": "AUBONPAIN-NET - Au Bon Pain",
    "26169": "VERTEKCORP - Vertek Corporation",
    "26170": "FRTCI-DOM - Flat Rock Internet Service",
    "26171": "GW-TECHNOLOGY-US - Groupware Technology, Inc.",
    "26172": "CREDIT-INDUSTRIEL-ET-COMMERCIAL - Credit Industriel Et Commercial",
    "26173": "King's Cross N.V.",
    "26174": "SVSU - Saginaw Valley State University",
    "26175": "ALLIED-COMPANIES - Allied Companies",
    "26176": "AJA - AJA Video Systems, Inc.",
    "26177": "NETIQ-BELLEVUE - NetIQ Corporation",
    "26178": "ATKINS-NORTH-AMERICA - Atkins",
    "26179": "NETIQ-RALEIGH-1100 - NetIQ Corporation",
    "26180": "NETIQ-HOUSTON-13939 - NetIQ Corporation",
    "26181": "NCPRPDC-NCI - North Central Pennsylvania Regional Planning and Development Commission",
    "26182": "-EXCELLUS - Excellus Health Plan, Inc.",
    "26183": "OTSM - On The Spot Media LLC",
    "26184": "A-HQ - American Society of Anesthesiologists",
    "26185": "WORLDWINNER - WORLDWINNER.COM, INC.",
    "26186": "TOPCON-COM - Topcon America Corp.",
    "26187": "TWYXO - TWYXO",
    "26188": "SPE - Sony Pictures Entertainment Inc",
    "26189": "SCI-N - SCI Funeral & Cemetery Purchasing Cooperative, Inc.",
    "26190": "SENTRY - Sentry Insurance a Mutual Company",
    "26191": "-SANFORDFGO - Sanford Health",
    "26192": "IMPAC-FUNDING - Impac Funding Corporation",
    "26193": "WHOLESALE-DATACENTER - Wholesale Data Center, LLC",
    "26194": "123.com.ve, C.A.",
    "26195": "DCHUSA - DCH Auto Group",
    "26196": "NNMT - NNMT",
    "26197": "HIGHJUMPSOFTWARE - HighJump Software Inc.",
    "26198": "3MENATWORK - 3Men@Work Integrated Networks, Inc.",
    "26199": "NKCHA - North Kansas City Hospital Auxiliary",
    "26200": "PSAM-N - P. Schoenfeld Asset Management, LLC",
    "26201": "ABOUT-COM - ABOUT, INC.",
    "26202": "KINEX-NETWORKING - Kinex Networking Solutions, Inc.",
    "26203": "ALLEGHENYINTEL-ALT - Atlantic Broadband Finance, LLC",
    "26204": "N-CXA-RI-26204-CBS - Cox Communications Inc.",
    "26205": "MIC-MARCO - MARCO ISLAND CABLE INC",
    "26206": "N-UREGINA - University of Regina",
    "26208": "WEYRICH-CRONIN-SORRA1 - Weyrich Cronin and Sorra",
    "26209": "NETWORK-TOOL - Network Tool and Die Company, Inc.",
    "26210": "AXS Bolivia S. A.",
    "26211": "PROOFPOINT-N-US-WEST - Proofpoint, Inc.",
    "26212": "DRF-IXNET-HI - DR Fortress, LLC",
    "26213": "DMSMAIN - Dealer Marketing Services",
    "26214": "KERN-BGP - County of Kern",
    "26215": "XCLUTEL - Xclutel LLC",
    "26217": "CTM-MEDIA - Cox Target Media, Inc.",
    "26218": "DATAPREV EMPRESA DE PROC. DE DADOS DA PREVIDENCIA",
    "26219": "NETHERE - NetHere Inc.",
    "26220": "ANALYSISGROUP - Analysis Group, Inc.",
    "26221": "N-BMONB-1 - Bank of Montreal",
    "26222": "MS-DANGER - Microsoft Corporation",
    "26223": "SILVERSTAR-TELEPHONE - Silverstar Telephone Co.",
    "26225": "PCM-ATL-HOSTING - PCM Sales, Inc",
    "26226": "LOYOL-1-N - Loyola High School of Los Angeles",
    "26227": "COOPERIX-NET - Sandelman Software Works Corporation",
    "26228": "SERVEPATH - GoGrid, LLC",
    "26229": "US-SEC - U.S. Securities & Exchange Commission",
    "26230": "TOTTAWA - Telecom Ottawa Limited",
    "26231": "SFIA-N - San Francisco International Airport",
    "26232": "VYATTA - Vyatta, Inc.",
    "26233": "SPORTSDIRECT-INC - SportsDirect Inc.",
    "26234": "VERIF-MSO-PC - VeriFone Inc.",
    "26235": "FIRSTG - First Guaranty Mortgage Corporation",
    "26236": "NEXON - Nexon America Inc.",
    "26238": "OPTICALS - OPTICAL SOCIETY OF AMERICA",
    "26239": "ATLAIR - Atlas Air, Inc.",
    "26240": "SSKC1 - STATE STREET",
    "26241": "3ZNET-CVG001 - 3z.net",
    "26242": "INFOTRIEVE - Infotrieve Inc.",
    "26243": "INTELSAT-S - Intelsat Servco",
    "26244": "BGMU - Bowling Green Municipal Utilities",
    "26245": "ROBERT-H - Robert Half International",
    "26246": "JPI - JPI Partners LLC",
    "26247": "HCCA - Hamilton-Clermont Cooperative Assn.",
    "26248": "MESSAGELABS - MessageLabs Inc.",
    "26249": "MAI-CRO - MAI",
    "26250": "WEBROOT-CORP-1 - Webroot Inc.",
    "26251": "SIRIUS-1 - Prospeed.Net,Inc.",
    "26252": "LNA- - Legrand North America, Inc.",
    "26253": "SCINTERNET - South Central Communications, Inc.",
    "26254": "568721-017489901135-1 - Mail2world INC.",
    "26255": "OAKTONCOMMUNITYCOLLEGE - Oakton Community College",
    "26256": "ACTIVEHOST - ActiveHost Corporation",
    "26257": "WHINGTON-COUNTY-OF-PA - County Of Washington",
    "26258": "BF-CORP - BF Corporation",
    "26259": "TELEGIA- - Telegia",
    "26260": "WAUSAU-BENEFITS-INC - Wausau Benefits, Inc",
    "26261": "E2CNET - E Squared C Inc.",
    "26263": "CLV-MULTIHOME - City of Las Vegas",
    "26265": "H3NET - Hypercube LLC",
    "26266": "WWUSAINC - WATERFORD WEDGWOOD USA INC",
    "26267": "SIMPLER-WEBB - Simpler-Webb, Inc.",
    "26268": "NJVCL-ARIN - NJVC, LLC",
    "26269": "HAEFELETV - Haefele TV Inc.",
    "26270": "ECHELONCORPORATION - Echelon Corporation",
    "26271": "CMSINTERNET - CMSInter.net LLC",
    "26272": "FT-N-1001 - FortaTrust USA Corporation",
    "26273": "SKTH- - Sukatash",
    "26274": "REGIONS-N-2 - REGIONS FINANCIAL CORPORATION",
    "26275": "PTCT - Patient Care Technologies",
    "26276": "TIMKEN-USA - The Timken Company",
    "26277": "PREMIANET - Las Vegas NV Datacenter",
    "26278": "BLUEMILE-VOICE - Bluemile, Inc.",
    "26279": "ANCC - Advanced Networking and Communication Corporation",
    "26280": "POLARIS - Polaris Industries, Inc.",
    "26281": "RIML-CORP--1 - Research In Motion Limited",
    "26282": "MESSAGELABS-NAM - MessageLabs Inc.",
    "26283": "NCIC - Northern Colorado Internet Coop",
    "26284": "BADGER-INTERNET-INC - Badger Internet, Inc.",
    "26285": "WESTERN-STATES-TELEPORT - Western States Teleport",
    "26286": "ACTIVESERVERS - ActiveServers, Inc",
    "26287": "NBER- - National Bureau of Economic Research, Inc.",
    "26288": "KNET-1 - Keewaytinook Okimakanak",
    "26290": "VALIANT-COMM - Valiant Solutions Inc.",
    "26291": "ACML-N - AI CAPITAL MANAGEMENT LLC.",
    "26292": "N-SHREWS - Shrewsbury Electric and Cable Operations",
    "26293": "DATE-COM - Date.com, Inc.",
    "26294": "MILLENIANET - KEYSTONE DIGITAL IMAGING INCORPORATED",
    "26296": "VYBRENT-INC - Vybrent Inc.",
    "26298": "NET-BCBSF-N - Blue Cross Blue Shield of Florida, Inc.",
    "26299": "ICANN-DNS-OPS-W ICANN DNS Operations - West Coast",
    "26300": "SK-RESEARCH-NETWORK - SRNet Saskatchewan Research Network Inc.",
    "26301": "I-BRIDGE-CHAR01 - Dimension Data",
    "26302": "SOBOBA - Soboba Casino",
    "26303": "LSUAGCENTER - LSU AgCenter",
    "26304": "FFTW - Fischer Franics Trees& Watts",
    "26305": "N-SSM - SSM Health Care",
    "26306": "KARCHER - The Karcher Group Inc.",
    "26308": "NETWORKATS - American Technology Services, Inc.",
    "26309": "CAIRN-CAPITAL - Cairn Capital North America Inc.",
    "26310": "SANDICOR-1 - SANDICOR, INC.",
    "26312": "AXIA-TECHNOLOGY-PARTNERS-LLC - Axia Technology Partners, LLC",
    "26313": "VCAD-SANJOSE - Cadence Vcad",
    "26314": "TI-AUTOMOTIVE - TI GROUP AUTOMOTIVE SYSTEMS, L.L.C.",
    "26315": "SILKROAD - Silk Road Technology Inc",
    "26316": "N-ALTAVISTA-CRWL - AltaVista Company",
    "26317": "Lisa Communications Ltd",
    "26318": "VINMAR - Vinmar International Ltd.",
    "26319": "CHFCU - CoastHills Federal Credit Union",
    "26320": "MONARCH-IND-CA - MONARCH INDUSTRIES LIMITED",
    "26321": "TSX-GROUP - The Toronto Stock Exchange",
    "26322": "DIGICOMM - DIGITAL COMM LINK, INC.",
    "26323": "DIGITALPAYTECH - Digital Payment Technologies Corp.",
    "26324": "GARMIN-N-1 - GARMIN INTERNATIONAL",
    "26325": "TECHCU- - Technology Credit Union",
    "26326": "ONENECK-IT-SERVICES - OneNeck IT Services",
    "26327": "WORLDCAREGLOBAL - WorldCare International, Inc.",
    "26328": "BLTCOMM - Blast Communications Inc.",
    "26329": "INSERVER-NETWORKS - InServer Networks",
    "26330": "AVFUEL-CORPORATION - Avfuel Corporation",
    "26331": "CACU - Community America Credit Union",
    "26332": "DRAPERANDKRAMER - Draper and Kramer, Incorporated",
    "26333": "UNONET - University of New Orleans",
    "26334": "BAIN-WTR - Bain & Company",
    "26335": "MTSU - Middle Tennessee State University",
    "26336": "TFHD-INTERNET1 - Tahoe Forest Hospital District",
    "26337": "OIS1 - Oso Grande IP Services, LLC",
    "26338": "INTERMODALSOCIATIONOFNORTHAMERICA - Intermodal Association of North America",
    "26339": "J-NETWORKS-INC - The Iserv Company, LLC",
    "26340": "ALIPHCOM - Jawbone",
    "26341": "OSI-P - Open Solutions Inc.",
    "26342": "DTTS-N - Deloitte Touche Tohmatsu Services, Inc.",
    "26343": "SPT-N-001 - Sterling Payment Technologies, LLC",
    "26344": "REALPAGE-INC - Real Page, Inc.",
    "26345": "TREK - Trek Bicycle Corporation",
    "26346": "WCIXN3 - WCIX.Net, Inc.",
    "26347": "DREAMHOST- - New Dream Network, LLC",
    "26348": "-US-OWTEL - Owtel",
    "26349": "PZLQS- - Shell Information Technology International, Inc.",
    "26350": "CDN - Complex Drive, Inc.",
    "26351": "MARYVILLE-DATA-CENTER - First Horizon National Corporation",
    "26352": "SHIPCO-TRANSPORT - Shipco Transport",
    "26353": "REALNETWORK REALNETWORK",
    "26354": "VISTO-UK - Visto Corporation",
    "26355": "TIDIPRODUCTSBGP - TIDI Products LLc",
    "26356": "UNOPS - United Nations Office for Project Services",
    "26357": "ORISO- - Oriso Solutions Inc.",
    "26358": "NFSMT - NATIONAL FLOOD SERVICES",
    "26359": "CARDINALCOMMERCE6119 - Cardinal Commerce Corporation",
    "26360": "FIFTH-THIRD-BANCORP - Fifth Third Bank",
    "26361": "RC2D - Learning Curve Brands. Inc.",
    "26362": "TRAVISCU - Travis Credit Union",
    "26363": "COV-HC - COVIDIEN LP",
    "26364": "RDV-CORP - RDV Corporation",
    "26365": "IOT-PRIMARY - Image One Technologies",
    "26366": "TICOMIX - Ticomix, Inc.",
    "26367": "BRADLEY-UNIVERSITY - Bradley University",
    "26368": "WGWILKINS - Integral Identity",
    "26369": "BLISTEX-INC-1800SWIFT - Blistex, Inc.",
    "26370": "VARNA - Varna Capital Management LLC",
    "26371": "SWMC - Southwest Washington Medical Center",
    "26372": "VERMONTINFORMATION - Vermont Information Processing",
    "26373": "AMCON - AMCON Distributing Company",
    "26374": "BONDUELLENAM - Bonduelle Canada Inc.",
    "26375": "AIRESPRING - AIRESPRING, INC.",
    "26376": "IBC4- - International Bonded Couriers, Inc.",
    "26377": "STATLINE-INTERNET - Statline, LLC",
    "26378": "ADORAMA - ADORAMA",
    "26379": "AGILENT-FIREHUNTER - Agilent Technologies",
    "26380": "MTER-7- - MasterCard Technologies LLC",
    "26382": "E2020 - EDUCATION 2020",
    "26383": "CHILITECH - CHILITECH INTERNET SOLUTIONS, INC.",
    "26384": "ALLEGHENYINTEL-CUM - Atlantic Broadband Finance, LLC",
    "26385": "FLETCHER-ALLEN-HEALTH-CARE-1 - Fletcher Allen Health Care",
    "26386": "-DSP - THE DESERT SUN PUBLISHING CO.",
    "26387": "WSC-WYOMISSINGPA - Weidenhammer",
    "26388": "RLMNY - ROBINSON LERER AND MONTGOMERY",
    "26389": "N-NEXTCOMM - NEXT COMMUNICATION INC",
    "26390": "TKL-INTERACTIVE - TKL Interactive, Inc.",
    "26391": "CRITICALMENTIONINC-1 - Critical Mention, Inc",
    "26392": "-26392 - Tyco Electronics Corporation",
    "26393": "FCHS - FitzPatrick, Cella, Harper and Scinto",
    "26394": "CHOA - Egleston Children's Hospital",
    "26395": "JCI-200 - Johnson Controls Inc",
    "26397": "OPTIPUTER - The Regents of the University of California; University of California, San Diego.",
    "26398": "COMMAND-INFORMATION - Command Information Inc.",
    "26400": "NAVIMEDIX - NaviMedix, Inc.",
    "26401": "PREMIER-COOP-CMI-1 - Premier Cooperative, Inc.",
    "26402": "SANTABARBARACITY - City of Santa Barbara",
    "26403": "MADERACOE - Madera County Office of Education",
    "26404": "N-INT - Integrated Network Technologies, Inc.",
    "26405": "HDCS - HORIZON DATA SOLUTIONS, LLC",
    "26406": "XSEDE-NET - National Center for Supercomputing Applications",
    "26407": "GUILFORD-COMMUNICATIONS - Guilford Communications, Inc.",
    "26408": "EAGLE-RIVER-SET-MANAGEMENT - Eagle River Asset Management, LLC",
    "26409": "PULTEMORTGAGE - Pulte Mortgage, LLC",
    "26410": "PTPA - Point To Point Access.Com",
    "26411": "STRZ-1 - Strasz Computer Consulting, Inc.",
    "26412": "AGILISYS-MALVERN - Agilisys",
    "26413": "NOVAVISION-TELECOM - NovaVision Telecom inc.",
    "26414": "LVCINT - LVC International, LLC",
    "26415": "VERISIGN-INC Verisign",
    "26416": "OC - OC Application Services Inc.",
    "26417": "SCOPIA-NY - Scopia Fund Management, LLC",
    "26418": "BOANN GROUP LLC DBA SAYO COMM.",
    "26420": "SCHOOLLINK-NETWORK - Schoollink, Inc.",
    "26421": "PONDEROSA-INTERNET - Ponderosa Cablevision",
    "26422": "ABOUTIT-ONLINE",
    "26423": "DOMRES - VA Power Co.",
    "26424": "WINTECIND - Wintec Industries, Inc.",
    "26425": "EXELON-CORPORATION - Exelon Corporation",
    "26426": "Columbus Networks Panama",
    "26427": "ENTER-N - Enterprise Integration, Inc.",
    "26428": "TALBOTS - The Talbots, Inc.",
    "26429": "SIERRA-PACIFIC-INDUSTRIES-N - Sierra Pacific Industries",
    "26430": "LHGROUP-A - Lash Group",
    "26431": "SDS-WDFC - Spectrum Data Services",
    "26432": "HSBGROUP - Hartford Steam Boiler Inspection & Insurance Company",
    "26433": "BRESOURCE - B Resource, Inc.",
    "26434": "Dynamic Air Spectrum N.V.",
    "26435": "LITLECO1 - Litle & Co.",
    "26436": "ACT-NET - All Continents Travel, Inc",
    "26437": "TCH- - THE CLEARING HOUSE PAYMENTS COMPANY L.L.C.",
    "26438": "MONROE-COMMUNITY-COLLEGE - Monroe Community College",
    "26439": "CITY-OF-ABQ - City of Albuquerque",
    "26440": "SPRAGUE-ENERGY - Sprague Operating Resources LLC",
    "26441": "FNBC - FNB of Cherokee",
    "26442": "DNB-US - Dun & Bradstreet",
    "26443": "QIAGEN-GERMANTOWN - QIAGEN Shared Services, Inc.",
    "26444": "PAYDIANT - Paydiant, Inc.",
    "26445": "VCAL-N - Vision Capital Americas LLC",
    "26446": "STOUFFER-COMMUNICATIONS-INC - Stouffer Communications, Inc.",
    "26447": "SHUTTERFLY - Shutterfly, Inc.",
    "26448": "CBD - Christian Book Distributors, LLC",
    "26449": "GENEVAONLINE - Geneva On-Line, Inc.",
    "26450": "MAPNS - MAPNS, LLC",
    "26451": "FUTURE-WIRELESS-TECHNOLOGIES-OF-NEBRKA - FUTURE WIRELESS TECHNOLOGIES OF NEBRKA, INC.",
    "26452": "BRING- - BringCom, Inc.",
    "26453": "INFINISOURCE-INC - Infinisource, Inc.",
    "26454": "HENRYSCHEIN - Henry Schein Inc",
    "26455": "-CELGENE - Celgene Corporation",
    "26456": "JHN-26456 - John Hancock Life Insurance Company (U.S.A.)",
    "26457": "TSM-TMS - Townsquare Media, LLC",
    "26458": "CENTRALHOST - Central Host Inc.",
    "26459": "LIBGO-CORP - Lib/Go Travel, Inc.",
    "26460": "26460 - Fidelity National Information Services, Inc.",
    "26461": "CARDHOLDER-MANAGEMENT-SERVICES - Cardworks Servicing, LLC",
    "26462": "-GENESEO - SUNY Geneseo Computer Center",
    "26463": "MISD-NET - Macomb Intermediate School District",
    "26464": "JOYENT-26464 Joyent 26464",
    "26465": "CCMP-CAPITAL-LLC - CCMP Capital Advisors, LLC",
    "26466": "HCL - Hotel Connections Ltd.",
    "26467": "HYPERTEK - HyperTEK Corporation",
    "26468": "LEARN - LEARN",
    "26469": "ALLEGHENYINTEL-SCR - Atlantic Broadband Finance, LLC",
    "26470": "-26470 - Group M Worldwide, Inc.",
    "26471": "STIFEL - Stifel, Nicolaus & C",
    "26472": "CHIBARDUN-TEL - Mosaic Telecom",
    "26473": "EOCG Wireless NV",
    "26474": "MYPOINTS-SCH - MyPoints.com, Inc.",
    "26475": "ALTAWAY - Altaway Technologies, Inc.",
    "26476": "CYBERU - CyberU, Inc.",
    "26477": "-VCU - Vantage Credit Union",
    "26478": "NOVARTIS-PHARMA Novartis AG Easthanover",
    "26479": "SDC- - Sunset Digital Communications, Inc.",
    "26480": "MEGA-N - Mega Quebec",
    "26481": "REBEL-HOSTING - Rebel Hosting",
    "26482": "PING-N - PingTone Communications, Inc",
    "26483": "AIA-4 - The American Institute of Architects",
    "26484": "HOSTSPACE - HOSTSPACE NETWORKS LLC",
    "26485": "SIXCONTINENTS - Six Continents Hotels, Inc.",
    "26486": "SWIFTWILL1 - Swiftwill, Inc.",
    "26487": "NEWPIRVINE - Newport Corporation",
    "26488": "SCU-N - Santa Clara University",
    "26489": "N-POLUNS - Polunsky & Beitel",
    "26490": "PIKE-EXTERNAL-BGP - Pike Energy Solutions",
    "26491": "GEEKSTORAGE - GEEKSTORAGE.COM, LLC",
    "26492": "VCCCD-NET - VCCCD",
    "26493": "GHI - Group Health Incorporated",
    "26494": "CBOE-C2 - Chicago Board Options Exchange",
    "26495": "MCWHINNEY-MRES - McWhinney Real Estate Services, Inc.",
    "26496": "-26496-GO-DADDY-COM-LLC - GoDaddy.com, LLC",
    "26497": "QXSNET- - Worldwide TechServices, LLC.",
    "26498": "SANFORD-LAB - Sanford Underground Laboratory at Homestake",
    "26499": "MOMENTOUS - MOMENTOUS.CA Corporation",
    "26500": "FISHER-TITUS - Fisher-Titus Medical Center",
    "26501": "CPC-NETWORKS - CPC Networks Corp.",
    "26502": "MOMEN-5-N - Momentum Telecom, Inc.",
    "26504": "METRO-VA-KG - MetroCast Communications",
    "26505": "E-Commerce Park, N.V.",
    "26506": "LLNW-SEA - Limelight Networks, Inc.",
    "26507": "CTSINET - Computer Transition Services, Inc.",
    "26508": "SMARTONLINE - Smart Online, Inc.",
    "26509": "-CDS-OFFICE-1 - Computer Development Systems, LLC",
    "26510": "BODEK-AND-RHODES - Bodek and Rhodes",
    "26511": "AACT-INTERNET - AAA Cooper Transportation, Inc.",
    "26512": "BMSL-2-ARIN - NewCoIT Corporation",
    "26513": "TGSNOPEC-GEOPHYSICAL - TGS-NOPEC Geophysical Co.",
    "26514": "TAYLORFARMS - Taylor Fresh Farm Foods",
    "26515": "AFFYMETRIX--AFFYMETRIX-INC - Affymetrix, Inc",
    "26516": "OMDHM - OFFICE MUNICIPAL D HABITATION DE MONTREAL",
    "26517": "OXYHOU-01 - Occidental Petroleum Corporation",
    "26518": "RTINET - Roome Telecommunications",
    "26519": "TSSI-NET1 - Technical Software Services Inc.",
    "26520": "NATIONAL-PRINT-GROUP-INC - National Print Group, Inc.",
    "26521": "BMTC- - Bryn Mawr Trust Company",
    "26522": "NETWAVE - Netwave Technologies Inc.",
    "26523": "NUTECH-COMM-1 - NuTech Communications, LLC",
    "26524": "BUDCO - BUDCO",
    "26525": "NYCSCA - NYC SCHOOL CONSTRUCTION AUTHORITY",
    "26526": "ENVESTNETPMC - EnvestnetPMC",
    "26527": "WISCONSIN-RSA-7-LIMITED-PARTNERSHIP - Wisconsin RSA #7",
    "26528": "HPES - Hewlett-Packard Company",
    "26529": "HHC-CORP - Hilton Hotels Corporation",
    "26530": "SIRUS-1 - Sirus, Inc",
    "26531": "NEXUSDS - NEXUSDS.COM",
    "26532": "MACLEAN-FOGG - Mac Lean-Fogg Company",
    "26533": "LECROY-CORPORATION-NY - LECROY",
    "26534": "AIM-N - Accurate Information Management, LLC",
    "26535": "AMDA - American Musical & Dramatic Academy Inc.",
    "26536": "DYCOM - Dycom Industries, Inc.",
    "26537": "FITCHRATINGS-NEWYORK - FITCHRATINGS",
    "26538": "SINGLE-DIGITS - Single Digits, Inc.",
    "26539": "GIANT-FOOD-INC - Ahold U.S.A., Inc.",
    "26540": "TNA-IEL - Tradition North America Inc.",
    "26541": "GUAVA- - GuavaTech Inc.",
    "26542": "BETA-SYSTEMS - Beta Systems",
    "26543": "IBMCCH-SUC - IBM",
    "26544": "MOORE-CONCEPTS - Moore Concepts",
    "26545": "THE-BANKERS-BANK - The Bankers Bank",
    "26546": "NUCLEUS-INC - Nucleus Information Service, Inc.",
    "26547": "YOUSENDIT2 - YouSendIt Inc",
    "26548": "PUREVOLTAGE - Purevoltage Enterprises Inc.",
    "26549": "MY-PBX-MANAGER - The Flat Planet Phone Company Inc.",
    "26550": "PROVIDENT-FUNDING-SOC - Provident Funding",
    "26551": "SARGENT-AND-LUNDY - Sargent & Lundy Engineers",
    "26552": "PROMCAP - Promontory Interfinancial Network, LLC",
    "26553": "PSE--ESO - Puget Sound Energy",
    "26554": "US-SIGNAL - US Signal Company, L.L.C.",
    "26555": "AVMLP - AVM,LP",
    "26556": "AAPH - AAPH, INC.",
    "26557": "CARLET-NET - Carleton College",
    "26558": "FREEWHEEL - Freewheel Media Inc.",
    "26559": "BERMUDA-DIGITAL-COMMS - Bermuda Digital Communications Ltd.",
    "26560": "JUNIATA - Juniata College",
    "26561": "BLUEWATER-DR - BlueWater Communications Group",
    "26562": "SPHERION-N - Spherion Corporation",
    "26563": "REALEC-TECHNOLOGIES - REALEC TECHNOLOGIES",
    "26564": "NEW-CANAAN - Town of New Canaan",
    "26565": "MDFDOR-N - City of Medford",
    "26566": "ARETTA - Aretta Communications, Inc.",
    "26567": "-LMGC-TOR-01 - Loyalty Management Group, Inc.",
    "26568": "JADE - Jade Communications LLC",
    "26569": "COLLEGENET - CollegeNET",
    "26570": "EXCALTECH-NOC - Excalibur Technology Corporation",
    "26571": "ZBI - Ziff Brothers Investments, LLC",
    "26572": "CAMDEN-SET-MANAGEMENT - Camden Asset Management",
    "26573": "JOULE - JOULE",
    "26574": "STANTEC - STANTEC CONSULTING SERVICES INC.",
    "26575": "SERENA01 - Serena Software, Inc.",
    "26576": "MERCURIA-ENERGY-TRADING-INC - MERCURIA ENERGY TRADING, INC.",
    "26577": "BAESYSTEMS - BAE Systems Inc.",
    "26578": "NATIONWIDEN2 - Nationwide Services, Inc",
    "26579": "WALMART-DR - WALMART.COM",
    "26581": "ENTERINFO - EnterInfo",
    "26582": "IADB-NETWORKS - The Inter-American Development Bank",
    "26583": "MDEA-IRVINE - Mitsubishi Digital Electronics America, Inc.",
    "26584": "AMS-SERVICES - AMS Services, Inc.",
    "26585": "SIAC-SFTI - Securities Industry Automation Corporation",
    "26586": "COMENTUM - Comentum Corp.",
    "26587": "ICE-MILLER-DONADIO-RYAN - Ice Miller Donadio & Ryan",
    "26588": "NOVATEL0001 - Novatel LTD. Inc.",
    "26590": "CENT-SOLUTIONS - Ascent Solutions",
    "26591": "PEGUS - Pegasus Transtech",
    "26592": "ALOG SOLUCOES DE TECNOLOGIA EM INFORMATICA S.A.",
    "26593": "Telespazio Argentina",
    "26594": "PETROBR ENERGIA S.A.",
    "26595": "Enlaces y Comunicaciones del Sureste SA de CV",
    "26596": "SUPERCABLE TELECOMUNICACIONES",
    "26598": "IT2B TECNOLOGIA E SERVI\u00c7OS LTDA.",
    "26599": "TELEF\u00d4NICA BRIL S.A",
    "26600": "M.I. WEBWORKS S.A.",
    "26601": "Publigu\u00edas",
    "26602": "Nilram Internet e Servi\u00e7os Ltda",
    "26603": "Telmex Colombia S.A.",
    "26604": "Euroamerica Seguros de Vida S.A",
    "26605": "Universidad Industrial de Santander - UIS",
    "26606": "Cia de Proc. de Dado do Munic\u00edpio de Porto Alegre",
    "26607": "IBM Brasil Industria Maquinas e Servicos LTDA",
    "26608": "SkyOnline de Argentina S.A.",
    "26609": "Universal Telecom S.A.",
    "26610": "Universidad Tecnica Federico Santa Maria",
    "26611": "COMCEL S.A.",
    "26612": "CGI TELEPORTS",
    "26613": "CORPORACION NACIONAL DE TELECOMUNICACIONES - CNT EP",
    "26614": "ING Afore, S.A. de C.V.",
    "26615": "Tim Celular S.A.",
    "26616": "URBI NETWORK LTDA.",
    "26617": "Navega.com S.A.",
    "26618": "Banco Interacciones, S.A., Institucion de Banca Multiple, Grupo Financiero Interacciones",
    "26619": "Flycom Comunicaciones",
    "26620": "BANCA AFIRME, S.A.",
    "26622": "COMMCORP COMUNICACOES LTDA",
    "26624": "MOMEN-5-N2 - Momentum Telecom, Inc.",
    "26626": "VTS-N - Virginia Theological Seminary",
    "26627": "-PILOSOFT - Pilosoft, Inc.",
    "26628": "ADIVI-NET-1 - Adivi Corporation",
    "26629": "JFMC - Jewish Federation of Metropolitan Chicago",
    "26630": "LPS-3 - Lender Processing Services Inc",
    "26631": "BROWN-PRINTING-COMPANY-INTERNET- - Brown Printing Company Corporate",
    "26632": "CONNETRIX-01 - Connetrix",
    "26634": "FIRST-433 - First Caribbean International Bank Limited",
    "26635": "MCCC-10152002-NJEDGE - MERCER COLLEGE",
    "26636": "CONATUS-CAPITAL - CONATUS CAPITAL MANAGEMENT LP",
    "26638": "MPLS-PUBLIC-SCHOOLS - Minneapolis Public Schools",
    "26639": "MTGWKS - Mortgage Works Systems",
    "26640": "2901 - Oso Grande Technologies, Inc.",
    "26641": "VODAFONE-US - Vodafone",
    "26642": "AF - AnchorFree Inc.",
    "26643": "SCGN - Skill City Games",
    "26644": "LUMETA-SOM-NJ - Lumeta Corporation - Somerset NJ",
    "26645": "ODECN - Old Dominion Electric Cooperative",
    "26646": "TRAVELCLICKCORP1 - TravelCLICK Inc.",
    "26647": "MSS1 - Movers Specialty Service",
    "26648": "MERITENERGY - Merit Energy Company",
    "26649": "GDCLSD- - General Dynamics Corporation, Land Systems Division",
    "26650": "ALPHA-TECHNOLOGIES - Alpha Technologies Inc",
    "26651": "CAREFUSION- - CareFusion Corporation",
    "26652": "BROADBAND-INC- - BroadNet connect",
    "26653": "GEOLOGICS - GeoLogics Corporation",
    "26654": "RFA-IDC - Richard Fleischman & Assoc., Inc.",
    "26655": "PSFC - Pacific Service Federal Credit",
    "26656": "MISYS- - Misys International Banking Systems Inc.",
    "26657": "NEUROPACE-CORPORATE-SITE - Neuropace",
    "26659": "ZURICHNA - Zurich American Insurance Company",
    "26660": "NEW-ENGLAND-DATA-SERVICES - New England Data Services Holdings, LLC",
    "26661": "JCPS-N - Jeffco Public Schools",
    "26662": "XEROX-WV - XEROX CORPORATION",
    "26663": "SIMS-NET - SUNGARD INVESTMENT SYSTEMS LLC",
    "26664": "BECU - BECU",
    "26665": "ZBUSA - zbusa LLC",
    "26666": "CHEERCO - Cheerleading Company",
    "26667": "N-RUBICONPROJECT - The Rubicon Project Inc.",
    "26668": "AFFMDSYS - Affirmed Systems",
    "26669": "HEADLAND-COMMUNICATIONS - Headland Communications",
    "26670": "MCISD- - Mission CISD",
    "26671": "WRL-12 - Wynn Resorts Limited",
    "26672": "EACANADA - Electronic Arts Canada",
    "26674": "ARGON-TECHNOLOGIES-INCORPORATED - Argon Technologies, Inc.",
    "26675": "REGIONIVESC - Region IV Education Service Center",
    "26676": "GENPAC - General Pacific, Inc.",
    "26677": "ORION-N - ORANO",
    "26678": "N-QMFI - QUINCY MUTUAL FIRE INSURANCE, CO.",
    "26679": "GORUCK- - GORUCK LLC",
    "26680": "JDSMITH - J.D. SMITH AND SONS LTD",
    "26681": "TENMT - Tenmast Software",
    "26682": "GREENMTN - Green Mountain College",
    "26683": "CONVERGEX-CCN - LiquidPoint, LLC",
    "26684": "-MEEBO - Meebo, Inc.",
    "26685": "FRK-SMO - Franklin Resources",
    "26686": "ATUM-NETWORK - ATUM CORPORATION",
    "26687": "BUTTERFLYNETWORKS - Butterfly Communications Inc",
    "26688": "PFTC-33 - PFTC Trading LLC",
    "26689": "LIGHTPOINT-COMMUNICATIONS - LIGHTPOINT COLOCATION & HOSTING LLC",
    "26690": "CBCTBGP - The Credit Bureau of Connecticut, Inc.",
    "26691": "CIT-N-NA-01 - The CIT Group",
    "26692": "WORLDCALL - WorldCall Communications International, Inc.",
    "26693": "VNU-CHICAGO - VNU, Inc.",
    "26694": "ADMIS- - Adm Investor Services, Inc",
    "26695": "IMI-BEVCORE-SOLUTIONS-INC - IMI BEVCORe Solutions Inc.",
    "26696": "ARTIO-GLOBAL-INVESTORS-NYC - Artio Global Investors",
    "26697": "INTERNATIONAL-SECURITIES-EXCHANGE - International Securities Exchange",
    "26698": "GOODBYSILVERSTEIN - Goodby, Silverstein & Partners, Inc.",
    "26699": "MUHLENBERG-COLLEGE - Muhlenberg College",
    "26700": "FORTRESS - FORTRESS INVESTMENT GROUP LLC",
    "26701": "-HMC - Harrison Medical Center",
    "26702": "LEARNING-TREE-INTL-CORPORATE - Learning Tree International, Inc.",
    "26703": "KALONA-TELCO- - Kalona Cooperative Telephone Company",
    "26704": "INOVIS - Inovis Inc.",
    "26705": "MESSAGEONE-NET-ONESWITCH2 - MessageOne Inc.",
    "26706": "CBSMD-1 - Broadstripe",
    "26707": "N1 - Bronson Point Management LLC",
    "26708": "CCS- - Center for Computing Sciences",
    "26709": "THE-WSERSTROM-COMPANY - The Wasserstrom Company",
    "26710": "ICANN-DNS-ANYCT ICANN DNS Operations Anycast",
    "26711": "ICANN-MDR - ICANN",
    "26712": "LGMC-009 - Lafayette General Medical Center",
    "26713": "BPS-NOG - The School Board of Brevard County",
    "26714": "MCLABS - Microtek Computer Labs",
    "26715": "COBHAM-02 - Sensor and Antenna Systems, Lansdale, Inc.",
    "26716": "NETCRACKER - NetCracker Technology, Corporation",
    "26717": "-RPS - Richmond Public Schools",
    "26718": "WOLVERINE-TRADING-TECHNOLOGIES-LLC - WOLVERINE TRADING TECHNOLOGIES, LLC",
    "26719": "ANDRE-1-123 - Andrew Communications",
    "26720": "SCHAEFFERS-INVESTMENT-RESEARCH - Schaeffer's Investment Research",
    "26721": "SILVERCIRCUIT - Silver Circuit, LLC",
    "26722": "MAIN-SEQUENCE-TECHNOLOGIES - Main Sequence Technology, Inc.",
    "26723": "SJCRH - St. Jude Children's Research Hospital",
    "26724": "NEPTEL- - The North-Eastern Pennsylvania Telephone Company",
    "26725": "LCOM-NET - Liberty Communications",
    "26726": "THERE47 - The Reinvestment Fund",
    "26727": "DAYTIMERS- - Day-Timer's Inc.",
    "26728": "INTELLICORP - INTELLICORP, LTD",
    "26729": "MW-NET- - Midwest Internet, Inc.",
    "26730": "HEDGEOP-COMPLIANCE - HedgeOp Compliance, LLC",
    "26731": "AIHA- - American International Health Alliance, Inc.",
    "26732": "HALLDATA- - HALLMARK DATA SYSTEMS",
    "26733": "AISN - AMERICAN INTERNET SERVICES NETWORK",
    "26734": "PWR-NET - Shelby Electric Cooperative",
    "26735": "MLGW - Memphis Light, Gas & Water",
    "26736": "HERALD-MAIL-COMPANY - The Herald-Mail Company",
    "26737": "PRIDE001 - Pride Marketing and Procurement, Inc.",
    "26738": "DEERFIELD - Deerfield Partners, L.P.",
    "26739": "SIRIUS-X - SIRIUS TELECOMMUNICATIONS, INC.",
    "26740": "ELM-RIDGE-CAPITAL - Elm Ridge Capital",
    "26741": "CEMC - CarolinaEast Medical Center",
    "26742": "MAXNOC-N - MaxNOC Communications, LLC.",
    "26743": "NETSCOUT-ARIN - Networkscout Inc",
    "26744": "PRTC - Planters Rural Telephone Cooperative",
    "26745": "AEL-WPS - Air Medical Group Holdings",
    "26746": "HARVARD-PILGRIM-HEALTH-CARE - Harvard Community Health Plan",
    "26747": "PCTCNET-1 - Phillips County Telephone Company",
    "26748": "-HSHS - Hospital Sisters Health Systems",
    "26749": "CALLTOWER - CallTower, Inc.",
    "26750": "FSC- - Fayez Sarofim & Co.",
    "26751": "IGT--26751 - IGT",
    "26752": "BAC-CFC-CW-BANK - Bank of America",
    "26753": "IN2NET-NETWORK In2Net network inc.",
    "26754": "SPIDD-AFRICA",
    "26755": "ACALANES-UNION-HIGH-SCHOOL-DISTRICT - Acalanes Union High School District",
    "26756": "MARINER - Mariner Investment Group",
    "26757": "ADPCSG-ECOMM - ADP CSG",
    "26758": "MCNABWEB - MCNAB EXECUTIVE PLAZA",
    "26759": "TNCII - TNCI",
    "26760": "SKTC-NET - Southern Kansas Telephone Co., Inc.",
    "26761": "CMAL-ECOM - Designs Apparel, Inc.",
    "26762": "LEXICON - Lexicon Genetics Incorporated",
    "26763": "DART-DALL - Dallas Area Rapid Transit (DART)",
    "26764": "RWJF- - The Robert Wood Johnson Foundation",
    "26765": "NFDC-INTERNET1 - NFDC INTERNET",
    "26766": "STANS-NET - Stan's Office Technologies",
    "26767": "NGP-SOFTWARE - NGP VAN, Inc.",
    "26768": "N1 - Israel A Englander & Co Inc.",
    "26769": "BANDCON - Bandcon",
    "26770": "DAUGHERTY - Daugherty Systems, Inc.",
    "26771": "WANTEL-C1-1 - Comspan Communications Inc.",
    "26772": "TIE-SOLUTIONS - Tie Solutions Inc.",
    "26773": "DATAVO- - Datavo Inc.",
    "26774": "PACKETFOUNDRY - Packet Foundry Corp",
    "26775": "K-SWISS - K-Swiss",
    "26776": "INFO-TECH1 - Info Tech Corporation",
    "26777": "CBC-COMPANIES-INC - CBC Companies, Inc.",
    "26778": "TGH-TAMPA - Tampa General Hospital",
    "26779": "PANDO-NETWORKS - Pando Networks",
    "26780": "KMOB - Knobbe, Martens, Olson & Bear, LLP.",
    "26781": "BHSALA - Baptist Health System of Alabama",
    "26782": "FSI-NET1- - Financial Services, Inc.",
    "26783": "MARICOPA-COUNTY-COMMUNITY-COLLEGE-DISTRICT - Maricopa County Community College District",
    "26784": "SEATONCORP - Seaton Corp",
    "26785": "NETWURX- - Netwurx LLC",
    "26786": "RDMANAGEMENTCORP - RDMANAGEMENT",
    "26787": "NORTHWESTERN-MUTUAL - Northwestern Mutual",
    "26788": "BLINK-2 - RCP",
    "26789": "USERSONLNET - USERS, INC",
    "26790": "SPHEREXX - Spherexx.com",
    "26791": "MESSAGEONE-NET-ONESWITCH1 - MessageOne Inc.",
    "26792": "CSSNW - CSS Integration, Inc.",
    "26793": "ICS-LLC - ICS Advanced Technologies",
    "26794": "DCN- - Dakota Carrier Network",
    "26795": "BOWNE - Bowne & Co.",
    "26796": "GROUP-1-SOFTWARE - Group 1 Software, Inc.",
    "26797": "SNSC - SN Servicing Corporation",
    "26798": "SOUTH-ET-ATLANTIC-TAP - University of Miami",
    "26800": "TECHNOLOGY-REVIEW - TECHNOLOGY REVIEW, INC.",
    "26801": "ZITOMEDIA611 - Zito Media, L.P.",
    "26802": "OTN - Ontario Telemedicine Network",
    "26803": "FIBERNOC - Fiber Internet Center",
    "26804": "INTERTECH-USA - Intertech USA, Inc.",
    "26805": "FHLB - Federal Home Loan Bank of San Francisco",
    "26806": "SK-RESEARCH-NETWORK-2 - SRNet Saskatchewan Research Network Inc.",
    "26807": "LANDAM - LandAmerica Financial Group, Inc.",
    "26808": "UTICA-COLLEGE - Utica College",
    "26809": "SCOTTEPB - Scottsboro Electric Power Board",
    "26810": "HHSNET-NOC-N - U.S. Dept. of Health and Human Services",
    "26811": "GMACRFC - Residential Funding Company LLC",
    "26812": "ROTARYORC - Rotary International",
    "26813": "MARON - Maron Electric",
    "26814": "N-COBNET - City of Birmingham",
    "26815": "LOWENS01 - Lowenstein Sandler",
    "26816": "BLACKROCK-FINANCIAL-MANAGEMENT - BlackRock Financial Management, Inc.",
    "26817": "MICROC-N - Microchip Technology Inc.",
    "26818": "COL-PUB-SCHOOLS-OH - Columbus Public Schools",
    "26819": "TOIBGP1 - Telos Online, Inc",
    "26820": "ARROWINTL - Arrow International Inc.",
    "26821": "REVNET - Revelation Networks, Inc.",
    "26822": "DIBC-INTERNET - DO IT BEST CORP.",
    "26823": "INTERCEPT1 - INTERCEPT CORPORATION",
    "26824": "CLICKMAN - clickMAN LLC",
    "26825": "ACNIELSEN-CANADA - ACNielsen Canada",
    "26826": "CALPINEENERGYSERVICES-1 - CALPINE ENERGY SERVICES",
    "26827": "EPBTELECOM - EPB Fiber Optics",
    "26828": "IDSK - InfoDesk",
    "26829": "YKK-USA - YKK USA,INC",
    "26830": "N-OPERS - OPERS",
    "26831": "GTI-MORRNJ-1 - Global Telecom, INC (GTI)",
    "26832": "RICAWEBSERVICES - Rica Web Services",
    "26833": "ETCC - Electronic Transaction Consultants Corporation",
    "26835": "MAPOLCE - M.A. POLCE CONSULTING INC.",
    "26836": "-MARCHESE-NET - Marchese Computer Products, Inc.",
    "26837": "STS- - Swift Trade Securities Inc.",
    "26838": "MAGNANET - Magna International Inc.",
    "26839": "CBS-FULTON - CREDIT BUREAU SYSTEMS",
    "26840": "ABG - Advanced Business Group, LLC",
    "26841": "HIDDEN-VILLA-RANCH - Hidden Villa Ranch",
    "26842": "ATLANTICMUTUAL - Atlantic Mutual Companies",
    "26843": "UICI-STUDENT-INSURANCE - UICI Student Insurance Division",
    "26844": "PACTIV - Pactiv Corporation",
    "26845": "CFN - Fleetcor Technologies Operating Company, LLC",
    "26846": "NAZARETH-COLLEGE - Nazareth College of Rochester",
    "26847": "MEG-N-01 - MEG, LLC",
    "26848": "PFG-N-1 - The Principal Financial Group",
    "26849": "AGFIRST-FARM-CREDIT-BANK - AgFirst Farm Credit Bank",
    "26850": "ENPROINDUSTRIES - EnPro Industries, Inc.",
    "26851": "PBCC - Palm Beach State College",
    "26852": "FAFCU-BGP-01 - F&A Federal Credit Union",
    "26853": "SURFM - SURFMORE.NET INC",
    "26854": "NYS - New York State",
    "26855": "IBL-N - IndiGO Networks",
    "26856": "AUTODATA-SOLUTIONS-COMPANY - Autodata Solutions Company",
    "26857": "TRUSTCOMM- - TrustComm, Inc.",
    "26858": "TWACOMM - TWACOMM.COM, INC.",
    "26859": "TELENET-INTL - Fortis Communications, Inc.",
    "26860": "SWTC - SWIFTEL COMMUNICATIONS",
    "26861": "ADDISONAVENUE-COM - Addison Avenue FCU",
    "26862": "FULLNETINC - FULLNET INC",
    "26863": "LONGMONTUNITEDHOSPITAL - Longmont United Hospital",
    "26864": "CSYSTEMS-1 - 4DVISION LLC",
    "26865": "FORBES-MEDIA-LLC - Forbes Media LLC.",
    "26866": "ALTURACU - ALTURA CREDIT UNION",
    "26867": "BGC-NETWORK - Brookshire Grocery Company",
    "26868": "NCTA-WHINGTONDC - National Cable & Telecommunications Association",
    "26869": "N-STPSB - ST. TAMMANY PARISH SCHOOL BOARD",
    "26870": "N1 - Vedette Private Wealth Management LLC",
    "26871": "EPSB-1 - Edmonton Public School Board, District No. 7",
    "26872": "BREWERSRETAILINC - Brewer's Retail, Inc.",
    "26873": "QCOL- - QCOL INC",
    "26874": "LTC-INET - Fidelity National Financial Inc.",
    "26875": "STPUSANET1 - Sigma-Tau Pharmaceuticals, Inc.",
    "26876": "CHICOS - chico's fas inc",
    "26877": "LLS- - Locke Lord Bissell & Liddell LLP",
    "26878": "TWRS-NYC - Towerstream I, Inc.",
    "26879": "GXT - GX Technology Corp",
    "26880": "MTM-IRV - MTM Technologies, LLC",
    "26881": "IPR-INTERNATIONAL-LLC - IPR International, LLC.",
    "26882": "ABACON-ONENET - Onenetplace, Inc.",
    "26884": "VALE - Vale Canada Limited",
    "26886": "HMONNET01 - HMon Networks",
    "26887": "ACSL-2 - American Century Services, LLC",
    "26888": "UPLOGON- - U.P. Logon",
    "26889": "STARTECH-LTD - Startech Computer Accessories",
    "26890": "AIPIV-N - AIP IV, LLC",
    "26891": "MICROTECH-TEL - Microtech-tel",
    "26892": "JOHNS-MANVILLE - Johns Manville",
    "26893": "TVGNTUL-01 - TV Guide Networks, LLC",
    "26894": "NOACSC- - Northwest Ohio Area Computer Services Cooperative",
    "26895": "CIMCO1 - CIMCO Communications, Inc.",
    "26896": "D102-ITC - Data 102, LLC",
    "26897": "EDF-MANCM - E D & F Man Capital Markets, Inc.",
    "26898": "LNOCA-ORG - Lakeshore Northeast Ohio Computer Association (LNOCA)",
    "26899": "LEWIN--NUM - The Lewin Group",
    "26900": "LPS-6 - Lender Processing Services Inc",
    "26901": "WRIGHTRESEARCH2-DOM - Wright State University",
    "26902": "HOCHTIEFNA - HOCHTIEF PPP Solutions North America, Inc.",
    "26903": "SALISBURY-N - City of Salisbury, North Carolina",
    "26904": "BEL-AIR-INVESTMENT-ADVISORS-LLC - BEL AIR INVESTMENT ADVISORS LLC",
    "26905": "LIFEC - LifeCare Inc.",
    "26907": "JFG-RACINE-N - Johnson Financial Group, Inc.",
    "26908": "26908 - DOCUMENT TECHNOLOGIES, LLC",
    "26909": "WBS- - WHEATLAND ELECTRIC COOP",
    "26910": "POSTINI-NET1 - Postini, Inc.",
    "26911": "FREEVERSE-NGMOCO - FREEVERSE CORPORATION",
    "26912": "BRANDUPNET - Brand Up LLC",
    "26913": "WMRE- - Sirius Insurance Company of America",
    "26914": "FUSIONSTORM-GNI - FusionStorm",
    "26915": "WERNER-OMA - Werner Enterprises",
    "26916": "TCW--NY - Trust Company of the West",
    "26917": "COVENTRY-N - The Coventry Group",
    "26918": "LOOKOUT - Lookout, Inc.",
    "26919": "N-CBCBH - Champion Broadband",
    "26920": "DUNAVANT-OF-CALIFORNIA - Dunavant of California",
    "26921": "CYBERSHARKS-NET - CYBERSHARKS.NET",
    "26922": "GPINET - General Parts Incorporated",
    "26923": "OPLIN - Ohio Public Library Information Network (OPLIN)",
    "26924": "SANJOSE-SCHOOLS - San Jose Unified School District",
    "26925": "SMARTCITY-DCCC - Smart City Networks, L.P.",
    "26926": "LINDEN-LAB - Linden Lab",
    "26927": "KENYON- - Kenyon & Kenyon",
    "26928": "PARK-NICOLLET-HEALTH-SERVICES - PARK NICOLLET HEALTH SERVICES",
    "26929": "DOLLAR-PHONE-CORP-SUPERNET - Dollar Phone Corp / Supernet",
    "26930": "CG-ADVANCED-DEVELOPMENT - Cap Gemini Ernst& Young U.S., LLC - ADC",
    "26931": "SCHONFELD-NET - Schonfeld Tools, LLC.",
    "26932": "BRAVO-TELECOM - BRAVO TELECOM",
    "26934": "UNIVERSITY-OF-MISSOURI---COLUMBIA - University of Missouri-Columbia",
    "26935": "NOEL-COMMUNICATIONS-INC - Noel Communications, Inc.",
    "26936": "FOXRAC-MORGAN-HILL - Fox Racing",
    "26937": "MUNICH-RE-AMERICA - The Midland Company",
    "26938": "COMPUSOURCE - CompuSOURCE Communications Corp.",
    "26940": "LEVI-STRAUSS-CO 1155 Battery Street",
    "26941": "SHUTTERSTOCK - Shutterstock Inc",
    "26942": "HOSTING-COM-ARIN - WCP/32POINTS INTERMEDIATE HOLDING COMPANY, INC.",
    "26943": "YOUR-ORG-INC-EURO - YOUR.ORG, INC.",
    "26944": "MLMC-CA-1 - Munich Life Management Corporation, LTD",
    "26945": "-AMRI - Albany Molecular Research, Inc.",
    "26946": "KIRKWOOD-COMMUNTIY-COLLEGE - Kirkwood Community College",
    "26947": "-PAC-OPS - Pacificorp",
    "26948": "OLCC-1 - Orange Lake Country Club, Inc",
    "26949": "HARBOR-COMMUNICATIONS-LLC - Harbor Communications, LLC",
    "26950": "LIPPERT-1 - Lippert Components Manufacturing, Inc.",
    "26951": "CYGEM-HQ-AKRON-OH - CYGEM LTD",
    "26952": "ABRH - American Blue Ribbon Holdings, LLC.",
    "26953": "AJGCO-GB - Gallagher Bassett Services, Inc.",
    "26954": "NETNET-CET - Northeast Texas Consortium (NETnet)",
    "26955": "ITAGROUP- - ITA GROUP",
    "26956": "OSG-SHIP-MANAGMENT-INC - OSG Ship Management, Inc",
    "26957": "RN-N - Recovery Networks, Inc.",
    "26958": "ONCOR-1 - Oncor Electric Delivery Company, LLC",
    "26959": "TRIZETTO- - Trizetto Group",
    "26960": "MICHELIN-NORTH-AMERICA-I1 - MICHELIN NORTH AMERICA",
    "26961": "VIRTUOL - Virtuasol Inc.",
    "26962": "IPROT - IPROT, Inc.",
    "26963": "HM-SYSTEMS-SOFTWARE - H & M Systems Softwa",
    "26964": "INGRAMBARGE-1 - INGRAM BARGE COMPANY",
    "26966": "SPRAY- - Spraying Systems Co.",
    "26967": "SJTG - Shelton Johns",
    "26968": "PSD-ROCKET- - Rocket Networks",
    "26969": "WHALE-ROCK-CAPITAL-MANAGEMENT---N - Whale Rock Capital Management LLC",
    "26970": "ALLSTON-TRADING-LLC - Allston Trading LLC",
    "26971": "UTHSCSA- - University of Texas",
    "26972": "SIRIUS-FIBER - Sirius Fiber, Inc.",
    "26973": "COLBECK - Colbeck Capital Management, LLC",
    "26974": "BIGBYTECC - bigbyte.cc Corp",
    "26975": "TEX-HEALTH-RESOURCES - Texas Health Resources",
    "26976": "LIZ-CLAIBORNE-INC - Liz Claiborne,Inc.",
    "26977": "ETON-BELL-SPORTS - Easton-Bell Sports, Inc.",
    "26978": "CARPATHIA-N Carpathia Hosting, Phoenix",
    "26979": "LD-BGP - LANDesk Software Inc.",
    "26980": "CHURCH-DWIGHT - Church & Dwight Company, Inc.",
    "26981": "GLIGHT - Gaslight Media",
    "26983": "HPES - Hewlett-Packard Company",
    "26984": "MONTE-25- - Monte Carlo Online llc",
    "26985": "MACERICH - THE MACERICH COMPANY",
    "26986": "N1 - ESI Canada",
    "26987": "LAURUSINTL - Laurus International",
    "26989": "HR-WORLD-HEADQUARTERS - H&R Block",
    "26990": "N-NPG-NY-NYC - NATURE AMERICA, INC",
    "26991": "PERSH - Pershing Square Capital Management, L.P.",
    "26992": "UHG-CIMPLIFY - CIMplify",
    "26993": "STANDARDN - STANDARD TEXTILE CO., INC.",
    "26994": "VERISPACE - VeriSpace LLC",
    "26995": "TELENETWORK - TeleNetwork",
    "26996": "RYERSON-UNIVERSITY - RYERSON UNIVERSITY",
    "26997": "GPJOSEPH - Gregory P Joseph Law Offices LLC",
    "26998": "NFII-N - NFI Industries, Inc",
    "26999": "BEDROCK-N - Bedrock Venture, LLC",
    "27000": "COTYINC - Coty Inc.",
    "27001": "NCB1333 - National Cooperative Bank",
    "27002": "MIAX-MIAMI-INTERNATIONAL-HOLDINGS - Miami International Holdings",
    "27003": "AMERICAN-BANKERS-SOCIATION - American Bankers Association",
    "27004": "SFB - Star Financial Bank",
    "27005": "PNPT-N - Pinpoint Communications, Inc.",
    "27006": "IMPACTBUSINESS - Impact Business Solutions",
    "27007": "ADPSLC - ADP-SLC",
    "27008": "BDC - BendTel",
    "27009": "CUSD - Clovis Unified School District",
    "27010": "DIPLOMAT - Westin Diplomat Resort",
    "27011": "XSR-N - XM Satellite Radio",
    "27013": "GOLDBERG-LINDSAY - Goldberg Lindsay",
    "27014": "ORLANDO-HEALTH - Orlando Health, INC",
    "27016": "NRC-NET - United States Nuclear Regulatory Commission",
    "27017": "GLOBAL-IX - Global Voicecom Inc.",
    "27018": "WAGEWORKS - WAGEWORKS, Inc.",
    "27019": "BALLNET - Ball Horticulture",
    "27020": "PRIMET-NET- - Prime Therapeutics LLC",
    "27021": "-DGX - Quest Diagnostics, Inc.",
    "27022": "KABAM - Kabam, Inc.",
    "27023": "NTT-DATA-INC - NTT Data Inc",
    "27024": "NETSTREAM - NETSTREAM",
    "27025": "EDR- - Environmental Data Resources, Inc.",
    "27026": "NETWORKMARYLAND - networkMaryland",
    "27027": "ANBELL N-ANBELL",
    "27028": "SNEDG-LAN-WAN - SNET Diversified Group",
    "27029": "ATLMTI - Message Technologies",
    "27030": "USCG- - United States Coast Guard",
    "27031": "SCNM-TEMPE-1 - Southwest College of Naturopathic Medicine & Health Sciences Inc.",
    "27032": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27033": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27034": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27035": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27036": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27037": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27038": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27039": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27040": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27041": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27042": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27043": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27044": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27045": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27046": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27047": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27048": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27049": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27050": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27051": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27052": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27053": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27054": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27055": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27056": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27057": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27058": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27059": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27060": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27061": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27062": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27063": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27064": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27065": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27066": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27067": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27068": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27069": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27070": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27071": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27072": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27073": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27074": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27075": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27076": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27077": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27078": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27079": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27080": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27081": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27082": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27083": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27084": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27085": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27086": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27087": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27088": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27089": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27090": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27091": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27092": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27093": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27094": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27095": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27096": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27097": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27098": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27099": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27100": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27101": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27102": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27103": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27104": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27105": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27106": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27107": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27108": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27109": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27110": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27111": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27112": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27113": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27114": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27115": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27116": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27117": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27118": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27119": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27120": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27121": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27122": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27123": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27124": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27125": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27126": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27127": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27128": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27129": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27130": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27131": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27132": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27133": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27134": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27135": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27136": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27137": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27138": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27139": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27140": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27141": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27142": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27143": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27144": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27145": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27146": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27147": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27148": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27149": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27150": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27151": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27152": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27153": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27154": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27155": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27156": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27157": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27158": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27159": "DNIC-BLK-27032-27159 - DoD Network Information Center",
    "27160": "IPS-BB - Integrated Payment Systems",
    "27161": "POLARIS-N1 - Polaris Venture Partners",
    "27162": "CALWESTERN - California Western School of Law",
    "27163": "KARSCH-CAPITAL - Karsch Capital Management, LP",
    "27164": "US-INTERNET - Global Reach Communications LLC",
    "27165": "IBIDATA - IBI DATA INC.",
    "27166": "SPIRELLC - Spire Capital Management LLC",
    "27167": "FERRUM - Ferrum College",
    "27168": "-MAX - MaXess Networx",
    "27169": "TRIDENT - Trident Systems, Inc.",
    "27170": "UNIVISION-ONLINE - Univision Online",
    "27171": "WINDSTREAM - Windstream Communications Inc",
    "27172": "AIT-HQ01 - AIT Worldwide Logistics, Inc.",
    "27174": "OTC - Overnite Transportation",
    "27175": "ATNETHOST-02 - AtNetHost LLC",
    "27177": "GS1US-CHI - GS1 US, Inc.",
    "27178": "HSPS-HQ - Practice Management Technologies and Services",
    "27179": "MUTALDATA - Mutual Data Services, Inc.",
    "27180": "HCREIT - Health Care REIT, Inc.",
    "27181": "KMTSNET - KMTS Internet",
    "27182": "PEREGRINECAPITAL - Peregrine Capital Management",
    "27183": "NSD417 - Northshore School District",
    "27184": "IFOXNETBD - INFOCROSSING, INC.",
    "27185": "DHS-INTERNET - Danbury Hospital - ITG",
    "27186": "REXINDUSTRIES - Rexnord Industries, LLC",
    "27187": "INDIANA-RMC - Indiana Regional Medical Center",
    "27188": "CUOFCO-N - Credit Union of Colorado",
    "27189": "MARTEN-TRANSPORT-LTD - Marten Transport, Ltd.",
    "27190": "MICRO-BEEF-TECHNOLOGIES - Micro Beef Technologies, Ltd.",
    "27191": "LLNW-IAD - Limelight Networks, Inc.",
    "27192": "COLI-NET - Chain O' Lakes  Internet",
    "27193": "SKYRIVER - Skyriver Communications, Inc.",
    "27194": "REALLYFT - ReallyFast.net",
    "27195": "CAVERN-TECHNOLOGIES - EPIC Alliance, Inc.",
    "27196": "27196 - Cynergy Data, LLC",
    "27197": "PEPB - Princeton Electric Plant Board",
    "27198": "PATH-HINTING - Indiana University",
    "27199": "VELOCITY-NETWORKS-INC - Velocity Networks, Inc.",
    "27200": "SOCIETY-OF-AUTOMOTIVE-ENGINEERS - Society of Automotive Engineers",
    "27201": "COLVA - CITY OF LYNCHBURG",
    "27202": "CBK- - City of Bardstown, Kentucky",
    "27203": "TRIHEALTH-1 - Trihealth",
    "27204": "NCW- - NewCore Wireless, LLC",
    "27205": "MARKIT Markit",
    "27206": "ADPSIS- - ADP BROKERAGE INFORMATION SERVICE",
    "27207": "CORPORATE-ONE-FCU - Corporate One Federal Credit",
    "27208": "RSRCORP - RSR Corporation",
    "27209": "ERF- - ERF Wireless, Inc.",
    "27210": "RMIC - RMIC",
    "27211": "ACSI - Affiliated Computer Services",
    "27212": "CKG - Carl K. Gumpert, Inc.",
    "27213": "PRCINTERNET-GATEWAY - PRC Internet Corp",
    "27214": "INSITU- - Insitu, Inc",
    "27215": "DATAFRAMELO - Dataframe Logistics, Inc.",
    "27216": "AIR-ADVANTAGE-N - Air Advantage LLC",
    "27217": "ACN-2 - America's Collectibles Network",
    "27219": "MILLIKINFITTONLAWFIRM - MILLIKIN & FITTON LAW FIRM, A LEGAL PROFESSIONAL SOCIATION",
    "27220": "ECHOINC - ECHO",
    "27221": "ARDMORE-TEL - Ardmore Telephone Company Inc.",
    "27222": "AUTONATION-P2 - Autonation, Inc",
    "27223": "LOATHING - Bare Metal Hosting",
    "27224": "DIGINETITCC- Web Africa",
    "27225": "TBI-N-1 - TrueBlue, Inc.",
    "27226": "HARBOURVEST - Harbourvest Partners, LLC",
    "27227": "DILLARDS-STORE-SERVICES - Dillard's Store Services Inc.",
    "27228": "ADVANTESTAMERICA - Advantest America Inc",
    "27229": "WEBHOST-N1 - Webhosting.Net, Inc.",
    "27230": "MEIKO - Meiko America, Inc",
    "27231": "CARILION-HEALTH-SYSTEM - CARILION HEALTH SYSTEM",
    "27232": "VOXTE---VOXTER-COMMUNICATIONS-INC - Voxter Communications, Inc.",
    "27233": "27233 - Ascena",
    "27234": "VEROXITY-CUST - Veroxity Technology Partners, Inc.",
    "27235": "CVC-INET-33 - COLORADO VALLEY COMMUNICATIONS, INC.",
    "27236": "CLEVELANDHEIGHTSUNIVERSITYHEIGHTSCITYSCHOOLS - Cleveland Heights University Heights City Schools",
    "27237": "AHSNET-01 - Ardent Health Services, Inc.",
    "27238": "KANE - Kane Warehousing, Inc",
    "27239": "MIN-N-01 - Minerva Engineering, LLC",
    "27240": "NET-STL - Netelligent Corporation",
    "27241": "-CP01 - Community Products, LLC",
    "27242": "ATI-LAX - AMERICANTOURS INTERNATIONAL INC.",
    "27243": "BLINKMIND-DAL - BlinkMind, Inc.",
    "27244": "SMI-NET - Speedway Motorsports, Inc.",
    "27245": "HEIDRICK-CHICAGO - HEIDRICK",
    "27246": "SAUCON- - SAUCON TECHNOLOGIES, INC",
    "27247": "SCHWARZ - Schwarz Paper",
    "27248": "N-NPG-DC - NATURE AMERICA, INC",
    "27249": "SENECA-INSURANCE-NYC - Seneca Insurance Co. Inc,",
    "27250": "FNCINC - FNC INC",
    "27251": "SYNCRO- - Syncro Services Inc.",
    "27252": "-WBDETE - Warner Bros. Advanced Digital Services",
    "27253": "N1 - AMERICAN RESIDENTIAL SERVICES L.L.C.",
    "27254": "ATCJET-NET - ATC COMMUNICATIONS",
    "27255": "N-SERVTIC - Servastic",
    "27256": "CBNBC-NET - Cybernet Communications Ltd",
    "27257": "WEBAIR-INTERNET - Webair Internet Development Company Inc.",
    "27258": "KAMOPOWER - KAMO Electric Cooperative, Inc.",
    "27259": "AMERICAN-STUDENT-SISTANCE - American Student Assistance",
    "27260": "NDW66-1 - New Dimension Wireless Ltd.",
    "27262": "TVCCONNECT- - Thames Valley Communications, Inc.",
    "27263": "AVONNET",
    "27264": "MI-CONNECTION - MI-Connection Communications System",
    "27265": "CERIDIAN-CANADA - Ceridian Canada Ltd.",
    "27266": "SN-155 - Supernova Networks, INC",
    "27267": "GLOBALTAP - The Globaltap Corporation",
    "27268": "CHICKAW - The Chickasaw Nation",
    "27269": "SNPS-DMZ - Synopsys Inc.",
    "27270": "SFM - SFM Mutual Insurance Company",
    "27271": "URNA-1 - United Rentals (North America), Inc.",
    "27272": "Q9--CAL3 - Q9 Networks Inc.",
    "27273": "DC37 - District Council 37",
    "27274": "CMICH - Central Michigan University",
    "27275": "TBC - The Banff Centre for Continuing Education",
    "27276": "N-LOUDPACKET - Loud Packet Inc.",
    "27277": "SPACEX - Space Exploration Technologies Corporation",
    "27278": "TTL-N-01 - Teza Technologies, LLC",
    "27279": "ST-AGNES - St. Agnes Healthcare",
    "27280": "ITS - International Telecom Solutions, Inc.",
    "27281": "QUANTCT - Quantcast Corporation",
    "27282": "NIC - North Idaho College",
    "27283": "RJF-INTERNET - Raymond James Financial, Inc.",
    "27284": "ERIETIMESPUBLISHING - Times Publishing Company",
    "27285": "ADAM-N - Oppenheimer Capital\\Quest for Value",
    "27286": "CSI-NET - C D C A. CHARMING SHOPPES OF DELAWARE, INC.",
    "27287": "SECANTNET - SECANT TECHNOLOGIES",
    "27288": "DPCHICO-1 - Digital Path",
    "27289": "CLEOCOMMUNICATIONS - CLEO COMMUNICATIONS INC",
    "27290": "XEROX-FS - Xerox Commercial Solutions LLC",
    "27291": "FRYS-ELECT - Fry's Electronics Inc.",
    "27292": "RESMED--SAN - ResMed Corp.",
    "27293": "BANKOFCANADA - The Bank of Canada",
    "27294": "ST-JOHN-NETWORK - Reserve Long Distance Company, Inc",
    "27295": "GENICA - Genica Corporation",
    "27296": "WU-PRIMARY - Wilmington University, Inc.",
    "27297": "PGTECHNOLOGY - PG TECHNOLOGY, INC.",
    "27298": "RCSACCESS - Gonthier Inc.",
    "27299": "CIRA - CIRA Canadian Internet Registration Authority Autorit Canadienne pour les enregistrements Internet",
    "27300": "BEATS-MUSIC - Beats Music",
    "27301": "CERNER-ETREBY - Cerner Corporation",
    "27302": "PUBLIC-CLOTHING-COMPANY-INC - Public Clothing Company , Inc",
    "27304": "DUHAWKS - Loras College",
    "27305": "IAVI - International AIDS Vaccine Initiative",
    "27306": "MTCUTNEYHOSPITALANDHEALTHCENTER - Mt. Ascutney Hospital and Health Center",
    "27307": "NABORS - Nabors Corporate Services, Inc.",
    "27308": "INTELEMAGE - Intelemage, LLC",
    "27309": "TCC - The Computer Company, Inc.",
    "27310": "180SERVERS - 180Servers.com",
    "27311": "BIOGEN - Biogen Inc.",
    "27312": "CARSWELL - Carswell, a division of Thomson Canada Ltd",
    "27313": "SPENCER-STUART RIPE Object for Route Advertisments",
    "27314": "HIU - Hope International University",
    "27315": "EQUINIX-MLPE-DC - Equinix, Inc.",
    "27316": "EICCD - Eastern Iowa Community College District",
    "27317": "SNRZ1 - Sunrise Senior Living, Inc.",
    "27318": "ISC-LAX1 Internet Systems Consortium, Inc.",
    "27319": "ISC-DAR1 Internet Systems Consortium, Inc.",
    "27320": "ISC-ROM1 Internet Systems Consortium, Inc.",
    "27321": "ISC-SJC1 Internet Systems Consortium, Inc.",
    "27322": "ISC-JNB1 Internet Systems Consortium, Inc.",
    "27323": "WORLDLINK - Worldlink, Inc.",
    "27324": "CBC-N - Canadian Broadcasting Corporation",
    "27325": "CORENAP- - Core NAP, L.P.",
    "27326": "VHSA- - VCU HEALTH SYSTEM AUTHORITY",
    "27327": "INSINC - Dowco Computer Systems Ltd.",
    "27328": "DUQUESNE-CAPITAL-MANAGEMENT-LLC-PA - DUQUESNE CAPITAL MANAGEMENT LLC",
    "27329": "DUANE-MORRIS-PHILADELPHIA - Duane Morris",
    "27330": "EQUINIX-MA-SV8 - Equinix, Inc.",
    "27331": "4INFO- - 4INFO, Inc.",
    "27332": "UNITY-VILLAGE-TELECOMM - Unity School of Christianity",
    "27333": "EBRPD- - East Bay Regional Park District",
    "27334": "MEGAGATE - Megagate Broadband, Inc.",
    "27335": "BLUERIDGE-CAPITAL - Blueridge Capital",
    "27336": "SENTARA-HEALTH-CARE - Sentara Healthcare",
    "27337": "PTY1 - PTY.NET, INC.",
    "27338": "OTELCO-AL - Otelco Telephone, LLC",
    "27339": "RICERCA - Ricerca Biosciences",
    "27340": "MI-MUN - Memorial University of Newfoundland",
    "27341": "GFNET-01 - Gannet Fleming, Inc.",
    "27342": "CAHILL01 - Cahill Gordon & Reindel",
    "27343": "MONSANTO-INET - Monsanto",
    "27344": "READING-HOSPITAL - Reading Hospital",
    "27345": "MDBC - Miami-Dade Broadband Coalition, Inc.",
    "27347": "HCSINC - HILLMAN CONSULTING SERVICES,IN",
    "27348": "SURFNET-1 - Surfnet Communications, Inc.",
    "27349": "DNI-4305 - Definitive Networks, Inc.",
    "27350": "EDPROPN - EDISON PROPERTIES, LLC",
    "27352": "-KDE - Kentucky Department of Education",
    "27353": "CLARIAN-N - Methodist Hospital of Indiana",
    "27354": "27354 - Equinix, Inc.",
    "27355": "SPELN - Spelman College",
    "27356": "PARKCFCU- - Park Community Federal Credit Union",
    "27357": "RACKSPACE - Rackspace Hosting",
    "27358": "TRUSTMARK-INSURANCE-INTERNET - TRUSTMARK INSURANCE CO.",
    "27359": "UNCOMMON-NET-1 - Uncommon Technology Incorporated",
    "27360": "KWIKTRIP- - Kwik Trip Inc.",
    "27361": "ARIEL - Ariel Capital Management, Inc.",
    "27362": "N-ARCHON - ARCHON DEVELOPMENT CORP.",
    "27363": "SWISSRE-US- Swiss Re America Holding Corporation",
    "27364": "ACS-INTERNET - Armstrong Cable Services",
    "27365": "MONDC - Cengage Learning Inc",
    "27366": "ANDOR-CAPITAL - Andor Capital Management",
    "27367": "-PUSHWARE - Pushware Wireless Inc",
    "27368": "SOLOCUP-N - Solo Cup Company",
    "27369": "SWEDISH - Swedish Covenant Hospital",
    "27370": "CITYOFBOSTON - City of Boston",
    "27371": "SCGN - Starwood Capital Group, LLC",
    "27372": "UNCOMMON-NET-2 - Uncommon Technology Incorporated",
    "27373": "DOUGL-COUNTY-COMMUNITY-NETWORK - Douglas County PUD",
    "27374": "PFCS - Penn Foster Career School",
    "27375": "MEDITURE-LLC - Mediture LLC",
    "27376": "MNAO-N1 - Mazda Motor of America, Inc. d/b/a Mazda North American Operations",
    "27377": "FTICON-909 - FTI CONSULTING",
    "27378": "GARDEREWYNNESEWELL - Gardere Wynne Sewell LLP",
    "27379": "SELECT-STAFFING - Select Staffing",
    "27380": "UNISYS-CA - Unisys Inc.",
    "27381": "CALE-MEDIA - Casale Media",
    "27382": "COLOSPACE - ColoSpace, Inc.",
    "27383": "ALLSCRIPTS-HEALTHCARE-SOLUTIONS - Allscripts Healthcare Solutions, Inc.",
    "27384": "UNITED-DYNACARE - UNITED DYNACARE, LLC",
    "27385": "QUALYS - QUALYS, Inc.",
    "27387": "OSTROW - Ostrow Reisin Berk & Abrams, Ltd.",
    "27388": "WNCC-BGP - Western Nebraska Community College",
    "27389": "MANSFIELDISD - Mansfield Independent School District",
    "27390": "ALG - Fred Alger & Co Inc.",
    "27391": "WHCORP-1 - Washington Corporation",
    "27392": "AVSC - AUDIO VISUAL SERVICES CORPORATION",
    "27394": "NHDSC-ORG - Northern Hospital District of Surry County",
    "27395": "OSONET - OSOLABS LLC",
    "27396": "SOCI-BR-1 - Associated Grocers",
    "27397": "CABLERACER - Beaver Valley Cable Co. Inc.",
    "27398": "VGL-1 - Vortex Gateway, LLC",
    "27399": "BAM-US - Balyasny Asset Management",
    "27400": "CLEARFLY - Clearfly Communications",
    "27401": "KROLL-EP - Kroll Ontrack Inc.",
    "27402": "IBC-N1 - Independence Blue Cross",
    "27403": "APA-CTY - Apache County Schools Superintendents Office",
    "27404": "CBL-INTERNET-SERVICES - CBL Consulting LLC",
    "27405": "PSC - Plymouth State College",
    "27406": "CITIZENS-PROPERTY-INSURANCE-CORPORATION - Citizens Property Insurance Corporation",
    "27407": "EQUINIX-MLPE-SV - Equinix, Inc.",
    "27408": "H2-DESIGN - H2 Design Group",
    "27409": "ROCKBRIDGE-GLOBAL-VILLAGE - Rockbridge Global Village, Inc.",
    "27410": "BSWA - Baca, Stein, White & Associates, Inc.",
    "27411": "SOLSYS - Solution Systems, Inc.",
    "27412": "NCHE - American Council on Education",
    "27413": "DALLNAP- - Global Net Access, LLC",
    "27414": "CARISDX - Caris Diagnostics, Inc.",
    "27415": "2-JDOFTRCKVLLE - JDA Software Group Inc.",
    "27416": "VIKING-RANGE - Viking Range Corp",
    "27417": "DIALSURANCE - Dial Assurance, Inc.",
    "27418": "OOW-INC - OUTOFWALL INC.",
    "27419": "BIGRIVER - Big River Telephone",
    "27420": "THE-ROHATYN-GROUP - The Rohatyn Group",
    "27421": "RIVERPARK-CAPITAL-LLC - RIVERPARK CAPITAL LLC",
    "27422": "TNSTATE - Tennessee State University",
    "27423": "CAITHNESS - Caithness Energy LLC.",
    "27424": "N1 - Manikay Partners LLC",
    "27425": "N-IDK-27425 - IdeaTek",
    "27426": "NDSUS- - NDS AMERIC",
    "27427": "SAMC - Saint Agnes Medical Center",
    "27428": "VERTISINC-STLOUIS - Vertis Inc.",
    "27429": "SISU-MED - SISU Medical Solutions, LLC",
    "27430": "DEXXONDIGITALSTORAGE - DEXXON DIGITAL STORAGE, INC.",
    "27431": "JTLNET - JTL Networks Inc.",
    "27432": "WILSON-LEARNING - Wilson Learning Corporation",
    "27433": "EQUINIX-MLPE-CH - Equinix, Inc.",
    "27434": "DG-FTCHANNEL - DG",
    "27435": "OPSOURCE-INC - Dimension Data Cloud Solutions, Inc.",
    "27436": "EDELMAN-CHI - Edelman Public Relat",
    "27437": "IGN - IGN Entertainment",
    "27438": "EQUINIX-MLPE-NY - Equinix, Inc.",
    "27440": "SSNC-CHI - SS&C Technologies, Inc.",
    "27441": "SSN-US - Silver Spring Networks Inc.",
    "27442": "USCELLULAR - United States Cellular Telephone Company, LP",
    "27443": "LIFEGRID-INTERNET - LifeGrid Internet",
    "27444": "EQUINIX-MLPE-LA - Equinix, Inc.",
    "27445": "BSINET - Brainstorm Internet, Inc.",
    "27446": "ERCWC-N - Education and Research Consortium of the Western Carolinas",
    "27447": "SRZLLP - Schulte Roth & Zabel LLP",
    "27448": "3-WAVE - Kayenta Technologies",
    "27449": "IPN-TELECOM - IPN Telecom, LLC",
    "27450": "C-IV - California Statewide Automated Welfare System Consortium IV",
    "27451": "USO-N - US Oncology, Inc.",
    "27452": "ICI-SJ - Incomm",
    "27453": "N1 - Systemax Inc.",
    "27454": "CGCI-N - Cadaret Grant & Co., Inc.",
    "27455": "WTCO Williams Trading Europe, LLP",
    "27456": "EADOC1 - EADOC LLC",
    "27457": "LANDATA-TECHNOLOGIES - Landata Technologies, Inc.",
    "27458": "NEXTGROWTH - Next Growth, LLC",
    "27459": "TRUSTCOMPANY - Trust Company of America",
    "27460": "CHEMTURA - Chemtura Corporation",
    "27461": "ALIQ-N0 - ALIQUANT CORP",
    "27462": "KDVTECH- - KDV Technology and Consulting Services Inc.",
    "27463": "MARCUS-SCHLOSS-CO - Marcus Schloss & Co., Inc.",
    "27464": "-JAINA - Jaina Systems Network Inc.",
    "27465": "HIGLLC-1 - The Herring Impact Group LLC",
    "27466": "EQUINIX-MLPE-DA - Equinix, Inc.",
    "27467": "RACKMY-STL-1 - XIOLINK, LLC",
    "27468": "GOODWILL-INDUSTRIES-OF-ORANGE-COUNTY - Goodwill Industries of Orange County",
    "27469": "BSAA-CTDLC - Connecticut Distance Learning Consortium",
    "27471": "BC-CLOUD-SERVICES",
    "27472": "GTAM - GoldenTree Asset Management LLC",
    "27473": "CORESPACE-DAL2 - CoreSpace, Inc.",
    "27474": "IVN-LV - I-View Now, LLC",
    "27475": "WAYFAIR-N - Wayfair LLC",
    "27476": "TWCME - Time Warner Cable of Maine",
    "27477": "IBMCCH-MIA-BS - IBM",
    "27478": "AKR-WPNY - Acadia Realty Trust",
    "27479": "LNSP - Lake Norman Security Patrol, Inc.",
    "27480": "MTC-CORP - Management & Training Corporation",
    "27481": "CTG-335 - Corporate Transportation Group LTD",
    "27482": "AECP- - American Eagle Computer Products, Inc.",
    "27483": "DDS - The Darby Group Co.",
    "27484": "ACML-N - Atalaya Capital Management LP",
    "27485": "MYWEBSITE - MyWebSiteControlPanel",
    "27486": "MCF-SOFTWARE - MCF Software, LLC",
    "27487": "FHLBNY- - FEDERAL HOME LOAN BANK OF NY",
    "27488": "CITIZENS-TELEPHONE-COMPANY - ISP Alliance, INC.",
    "27489": "LAUREATE - Laureate Education Inc.",
    "27490": "AGRACEHOSPICE-MSN-DR - Agrace Hospicecare Inc",
    "27491": "NATIONAL-FINANCIAL-PARTNERS-CORP - NATIONAL FINANCIAL PARTNERS CORP.",
    "27492": "RGC - Rochling Glastic Composites",
    "27493": "SXC-LOMBARD - Systems Xcellence, Inc.",
    "27494": "NATL-MACH10 - NationalNet, Inc.",
    "27495": "XPEDITE Xpedite",
    "27496": "VENETIAN-RHC - Venetian Resort Hotel Casino",
    "27497": "EMBARQ-NETBRKA2 - Embarq Corporation",
    "27498": "FLO13-COM - Community WISP, Inc.",
    "27499": "SWL-31 - SI Wireless, LLC",
    "27500": "ICANN - ICANN",
    "27501": "LVEGNET- - LasVegas.Net LLC",
    "27502": "CHOWCHILLADIST - Madera County Office of Education",
    "27503": "ICI-LA - Incomm",
    "27504": "WOODHOUSE-AUTO-FAMILY - Woodhouse Auto Family",
    "27505": "DARK-PALADIN - Dark Paladin Productions",
    "27506": "RBS-NYC - Sidera Networks LLC",
    "27507": "METRO-BANK - Metro Bank",
    "27508": "TRDLNK - TradeLink, LLC",
    "27509": "DMG--1 - Delta Media Group, Inc",
    "27510": "CRAY - Cray Inc.",
    "27511": "PUNAHOU - Punahou School",
    "27512": "STATERI - State of Rhode Island",
    "27513": "ICI-DAL - Incomm",
    "27514": "KCML - Kingdon Capital Management, LLC",
    "27515": "MISSOURI-TELEHEALTH-NETWORK - Missouri Telehealth Network",
    "27516": "NEXUS-MANAGEMENT - Nexus Management Inc.",
    "27517": "RPS- - Rochester Public Schools",
    "27518": "FAB - First American Bank",
    "27519": "CIOI - Casio America, Inc.",
    "27520": "CCC-1919 - Community Coffee Company, L.L.C.",
    "27521": "CATCOMM-N - CATCOMM INTERNET SERCIVES, LLC",
    "27522": "ATT-MOBILITY-LLC-27522 - AT&T Mobility LLC",
    "27523": "DMB-N - DMB Associates, Inc.",
    "27524": "XEEX-COMMUNICATIONS - Xeex",
    "27525": "GAFACHI- - Gafachi, Inc.",
    "27526": "ENDAI-NETWORKS-N - Endai Corporation",
    "27527": "HTFCU- - Heritage Trust Federal Credit Union",
    "27528": "ENAP-1 - ENAP Inc.",
    "27529": "CSC-EMEDNY - Computer Sciences Corporation",
    "27530": "IBM-DC-SF - IBM",
    "27531": "RSTFIBER - RST Communications LLC",
    "27532": "MODUSLINK-RALEIGH - ModusLink Corporation",
    "27533": "OMGEO - Omgeo LLC",
    "27534": "27534 - Mutual of Omaha Insurance Company",
    "27535": "SUREBUY-SCHM-NET - AssureBuy, Inc.",
    "27536": "GLENVIEW-CAPITAL - Glenview Capital",
    "27537": "ACCA - Callcentric Wholesale, Inc.",
    "27538": "ROSETTARESOURCES - Rosetta Resources Inc.",
    "27539": "WRT- - West River Telecommunications Cooperative",
    "27540": "VELO-SANTAFE - American Fiber Systems, Inc.",
    "27541": "FTNET - Frontier Telenet",
    "27542": "KKAMERICA - K+K America Corporation",
    "27543": "ELLIOTTMGMT - Elliott Associates",
    "27544": "SPECIALAI-COGENT-1 - Special Applied Intelligence Corp",
    "27545": "2-BYTE - City National Bank",
    "27546": "CPA-CSN01 - Canadian Payments Association",
    "27547": "PMI-1 - PMI Mortgage Insurance",
    "27548": "USAN--A - United States Advanced Network Inc.",
    "27549": "MOREH-3- - Morehead Memorial Hospital",
    "27550": "FEYNMANGROUP - Feynman Group, Inc.",
    "27551": "NJ-LUX - LUXMOVERA, LLC",
    "27552": "TWDX TOWARDEX Carrier Services IP TRANSIT BACKBONE",
    "27553": "TELNET - Telnet Worldwide, Inc.",
    "27554": "VA - 1010Data, Inc.",
    "27555": "BEND-RESEARCH - Bend Research, Inc.",
    "27556": "FRACRACKVCLOUD - Frac Rack LLC",
    "27557": "27557 - Catalina Broadband Solutions, LLC",
    "27558": "FAR-N - Florida Assoc of Realtors",
    "27559": "N-PCT - Peets Coffee & Tea",
    "27560": "ULTCO - Universal Leaf Tobacco Company Inc.",
    "27561": "ILIANT - ILiant Corporation",
    "27562": "RHC-INT - Ressurrection Health Care",
    "27563": "SCANA - SCANA COMMUNICATIONS INC",
    "27564": "CGEYKCSC-1 - Cap Gemini Ernst & Young Kansas City Service Center, LLC",
    "27565": "BRIDGEWATER - Bridgewater Associates, Inc.",
    "27566": "EQUINIX-MA-NY4 - Equinix, Inc.",
    "27567": "GRAY- - Gray & Company, Inc.",
    "27568": "WBB-BNW-27568 - Broadstripe",
    "27569": "GVII - Grand Valley Internet",
    "27570": "STAMFORD-HOSPITAL-CT - Stamford Hospital",
    "27571": "TRADEBOT- - Tradebot Systems, Inc",
    "27572": "THEBOE-27572 - The Boeing Company",
    "27573": "OSLA--1 - OKLAHOMA STUDENT LOAN AUTHORITY",
    "27574": "AIMNET - AimNet Solutions",
    "27575": "PROVAK - Providence Hospital",
    "27576": "AfOL-Zw-NET",
    "27577": "OOE-BGP - Odessa Office Equipment",
    "27578": "ITLLC - INTERNET & TELEPHONE, LLC",
    "27579": "KISP151 - KiSP Inc",
    "27581": "ICI-MIA - Incomm",
    "27582": "PTC-OKC-N - Perimeter Technology Center, LLC",
    "27583": "REGISCORP - Regis Corporation",
    "27585": "WEIL - Weil, Gotshal & Manges LLP",
    "27586": "AWSCONVERGENCE - Earth Networks, Inc.",
    "27587": "PETER-LIFE-LLP - Peter Life LLP",
    "27588": "MIDWESTMEDICAL - MIDWEST MEDICAL",
    "27589": "MOJOHOST - MOJOHOST",
    "27590": "HMSRACING - Hendrick Motorsports",
    "27591": "SLC-10 - Scientific Learning Corporation",
    "27592": "MSICONNECT - Management Systems International",
    "27593": "POWERINFONET - Power Information Network",
    "27594": "UTSA - University of Texas at San Antonio",
    "27595": "COLUM-600 - Columbia College Chicago",
    "27596": "REDWIRE - VoloNet Technologies, Inc",
    "27597": "SITESERVER-IDC1 - Siteserver Hosting, Inc.",
    "27598": "INTERNET-SOLUTIONS-MI-NETWORK",
    "27599": "UNCOMMON-NET-3 - Uncommon Technology Incorporated",
    "27601": "MCA - MCA",
    "27603": "SPIRITAIR - Spirit Airlines, Inc.",
    "27605": "SUSQTECH - Technology Solution Partners, Inc.",
    "27606": "RUNZNET - RUNZHEIMER INTERNATIONAL",
    "27607": "NWFCU-200 - NORTHWEST FEDERAL CREDIT UNION",
    "27608": "SUNGEVITY - Sungevity, Inc.",
    "27610": "WOOT - Woot Services LLC",
    "27611": "-NATIVEHOSTING - Native Hosting, Inc.",
    "27612": "WYLTK-N-1 - wyltK, LLC",
    "27613": "XPLORATIONS-1 - CD-Explorations",
    "27614": "ELDERHOSTEL - Elderhostel, Inc.",
    "27615": "HOVRS - Purple Language Services Co.",
    "27616": "-NEWSCHOOL - The New School",
    "27617": "N-WBTO - Warner Bros. Advanced Digital Services",
    "27618": "QUICKSTREAM - T. Grand Networks Inc.",
    "27619": "-CUSTOMCRITICAL - FedEx Custom Critical",
    "27620": "UTIWORLDWIDE UTI WORLDWIDE,  Number",
    "27621": "AMERICAN-COMPUTER-SOCIATES-SCHUYL-INC - AMERICAN COMPUTER SOCIATES",
    "27623": "EDM-PUBLIC-LIBRARY - Edmonton Public Library",
    "27624": "-ELCA-CWO - ELCA",
    "27625": "ROCKSTAR-GAMES-NYC - Rockstar Games , Inc",
    "27626": "-JOYTEL - Joytel",
    "27627": "KINGDOM-TECHNOLOGY-SOLUTIONS - Kingdom Technology Solutions",
    "27628": "IPRPSK - Innovation Place Research Park",
    "27629": "NCDC-ERC - National Climatic Data Center",
    "27630": "PREMIER - Premier Innovations, LLC",
    "27631": "PANGAEA - PANGAEA",
    "27632": "TRACTORSUPPLY - Tractor Supply Company",
    "27633": "THOMSON-CMGARL - Thomson Reuters Holdings Inc",
    "27634": "MICRODG- - Microdynamics Group",
    "27635": "FSB - NCB Savings Bank, FS",
    "27636": "NCB1725 - National Cooperative Bank",
    "27637": "FIXAUTOBGP - Fix Auto",
    "27638": "CBSITE-QTS-WEB - CareerBuilder, LLC",
    "27639": "TEVA-NA - Teva Pharmaceuticals USA, INC",
    "27640": "GIGNET- - GIG HOSTING USA, LLC",
    "27641": "N-SURESOURCE - SureSource, LLC",
    "27642": "THEDOCTORSCOMPANY - The Doctors Company",
    "27643": "NBINTERNET - NB INTERNET, LLC",
    "27645": "N-DCS-03 - DCS Pacific Star, LLC",
    "27646": "COPART - Copart, Inc",
    "27647": "WEEBLY - Weebly, Inc.",
    "27648": "TELECOMUNICACIONES BANTEL, C.A.",
    "27649": "Banco Aliado",
    "27650": "EMTEL S.A. E.S.P.",
    "27651": "ENTEL CHILE S.A.",
    "27652": "STAR ONE S.A.",
    "27653": "Alpha Communications Network",
    "27654": "Universidad Francisco Marroquin",
    "27655": "YPF S.A.",
    "27656": "DCN Solu\u00e7\u00f5es em Tecnologia Ltda - EPP",
    "27657": "GlobalCom S.A.",
    "27658": "LATIN AMERICAN ENTERPRISES",
    "27659": "Ingenier\u00eda e Inform\u00e1tica Asociada Ltda (IIA Ltda)",
    "27660": "Curacao Telecom",
    "27661": "NIC M\u00e9xico, S.C.",
    "27662": "Trafico Mundial SA",
    "27663": "BRINKS DE COLOMBIA S.A.",
    "27664": "CTBC MULTIMIDIA DATA NET S/A",
    "27665": "Columbus Communications Trinidad Limited.",
    "27666": "INSTITUTO TECNOLOGICO DE TELEFONOS DE MEXICO",
    "27667": "Universidad Autonoma de la Laguna",
    "27668": "ETAPA EP",
    "27669": "E-life Paraguay S.A.",
    "27670": "Universidad de San Buenaventura - Cali",
    "27671": "Tele Cable Centro Occidente, S.A. de C.V.",
    "27672": "Tele Cable Centro Occidente, S.A. de C.V.",
    "27673": "Instituto Nacional de Estadistica Geografia e Info",
    "27674": "SERVICIO METEOROLOGICO NACIONAL",
    "27675": "ARINET",
    "27676": "ALMA - Atacama Large Millimeter Array",
    "27677": "Telefonica Moviles Soluciones y Aplicaciones",
    "27678": "NIC Chile",
    "27679": "Copa Airlines",
    "27680": "TELEFONICA MOVIL DE CHILE S.A.",
    "27681": "Grupo Roche Syntex de Mexico S.A. de C.V.",
    "27682": "Greco Comunica\u00e7\u00f5es e Servi\u00e7os LTDA",
    "27683": "VPN de Mexico, S.A. de C.V.",
    "27684": "Kern Technologies do Brasil",
    "27686": "Universidad Centro Occidental Lisandro Alvarado",
    "27687": "Banco General, S.A.",
    "27688": "Novanet da Barra Ass e Inf LTDA",
    "27689": "Laboratorio Nacional de Inform\u00e1tica Avanzada AC",
    "27690": "FST S.A.",
    "27691": "Velconet SA",
    "27692": "GIRE S.A.",
    "27693": "NipBr - NipCable do Brasil Telecom LTDA",
    "27694": "Flamingo TV Bonaire N.V.",
    "27695": "EDATEL S.A. E.S.P",
    "27696": "Multidata S.A.",
    "27697": "NITNET INFORMATICA S/C LTDA.",
    "27698": "TELETULUA S.A. E.S.P.",
    "27699": "TELEF\u00d4NICA BRIL S.A",
    "27700": "Cooperativa NAP Internacional",
    "27701": "Netline",
    "27702": "America Movil Peru S.A.C.",
    "27704": "Tiendas Comercial Mexicana, S.A. de C.V.",
    "27705": "Grupo Empresarial Mexicano en Telecomunicaciones, S.A. de C.V.",
    "27706": "Resource Recovery",
    "27708": "GCA Telecom",
    "27709": "Netpad S.R.L.",
    "27710": "Brasil Telecom S.A.",
    "27711": "Transportadora de Gas del Norte S.A.",
    "27712": "Paulo Dias de Araujo Filho.",
    "27713": "General Motors Argentina",
    "27714": "Unete Telecomunicaciones Ltda.",
    "27715": "Locaweb Servi\u00e7os de Internet S/A",
    "27716": "Advanced Communication Network, S.A.",
    "27717": "Corporacion Digitel C.A.",
    "27718": "Latin American Nautilus",
    "27719": "Difarma Ltda",
    "27720": "CITTA TELECOM LTDA",
    "27721": "Informacion y Tecnologia",
    "27723": "Rich International",
    "27724": "Nelson Quintas Telecom. do Brasil Ltda.",
    "27725": "Empresa de Telecomunicaciones de Cuba, S.A.",
    "27726": "GLOBAL BANK",
    "27727": "Consultronic S.A.E.C.A.",
    "27728": "Ocean Communications",
    "27729": "Globalnet.hn",
    "27730": "BBVA Banco Frances SA",
    "27731": "ACH Colombia",
    "27732": "A.F.P. Habitat S.A.",
    "27733": "Centro Nacional de Computacion",
    "27734": "New Technologies Group N.V.",
    "27735": "Synapsis Soluciones y Servicios IT LTDA",
    "27736": "Tecnomedia S.R.L",
    "27737": "Cablenet, S. A.",
    "27738": "Ecuadortelecom S.A.",
    "27739": "Close Up Sociedad Anonima de Serv. Comer. y Finam.",
    "27740": "NEW ACCESS S.A.",
    "27741": "Superintendencia de Valores y Seguros",
    "27742": "Amnet Telecomunicaciones S.A.",
    "27744": "Tecoar SA",
    "27745": "Telefonia Bonairiano N.V.",
    "27746": "LAN CHILE (Lineas Aereas de Chile)",
    "27747": "Telecentro S.A.",
    "27748": "NetPro N.V.",
    "27749": "BCG, Business Computer Group",
    "27750": "Cooperaci\u00f3n Latino Americana de Redes Avanzadas",
    "27751": "Neunet S.A.",
    "27752": "Cano Systems, Inc.",
    "27753": "Coomeva Cali Principal",
    "27754": "Cooperativa Batan de Obras y Serv. Publicos Ltda",
    "27755": "Mobilphone de Panama",
    "27756": "Servicio Satelital S.A.",
    "27757": "CORPORACION NACIONAL DE TELECOMUNICACIONES - CNT EP",
    "27758": "Redes Integrales S.A.",
    "27759": "ACCESS HAITI S.A.",
    "27760": "Asociaci\u00f3n Paname\u00f1a de Cr\u00e9dito (APC)",
    "27761": "Cablenet S.A",
    "27762": "Conet N.V.",
    "27763": "ANDINET ON LINE",
    "27764": "BANCO CONTINENTAL",
    "27765": "TRANSNEXA S.A. E.M.A.",
    "27766": "LAN CHILE (Lineas Aereas de Chile)",
    "27767": "MULTILINK SA",
    "27768": "CO.PA.CO.",
    "27769": "DSR Comunicaciones S.A.",
    "27770": "Universidad Nacional de Rio Cuarto",
    "27771": "Instituto Venezolano de Investigaciones Cientificas",
    "27773": "MILLICOM CABLE EL SALVADOR S.A. DE C.V.",
    "27774": "Haiti Networking Group S.A.",
    "27775": "Telecommunicationcompany Suriname - TeleSur",
    "27776": "Inversiones y servicios EL BOLDO S.A",
    "27777": "Haiti Networking Group S.A.",
    "27778": "HNA Panama S.A.",
    "27779": "Darcom S.A.",
    "27780": "Aeropuertos y Servicios Auxiliares",
    "27781": "SMITCOMS N.V.",
    "27782": "Electricidad de Caracas",
    "27783": "ITOCHU PANAMA, S.A.",
    "27784": "Bco. Pichincha Matriz",
    "27785": "Scotiabank El Salvador",
    "27786": "SSA SISTEM S.A.",
    "27787": "LOS AMORES S.A.",
    "27788": "Atlantic Security Bank",
    "27789": "GREENDOT",
    "27790": "Universidad Nacional de Cordoba",
    "27791": "Universidad Ricardo Palma",
    "27792": "Wiltel Comunicaciones SA",
    "27793": "Inform\u00e1tica Atl\u00e1ntida",
    "27794": "STANFORD CORPORATE SERVICES (VENEZUELA) C.A",
    "27795": "Netvision S.A.",
    "27796": "Galaxy Communications",
    "27797": "IBM Argentina S.A.",
    "27798": "EPM Telecomunicaciones S.A. E.S.P.",
    "27799": "Amnet Guatemala S.A.",
    "27800": "Digicel Trinidad and Tobago Ltd.",
    "27802": "Popular Bank LTD",
    "27803": "WorldAdmin Colombia Ltda",
    "27804": "AMNET HONDUR S. DE R.L.",
    "27805": "EPM Telecomunicaciones S.A. E.S.P.",
    "27806": "WAYSCOM",
    "27807": "Fundaci\u00f3n Centro Nacional de Innovaci\u00f3n Tecnol\u00f3gica (CENIT)",
    "27808": "Centro Nacional de Tecnolog\u00edas de Informaci\u00f3n (CNTI)",
    "27809": "Alignet S.A.C",
    "27810": "MERCANET LTDA",
    "27811": "Banco ProCredit Nicaragua",
    "27812": "Banco de Credito HFS Panama S.A.",
    "27813": "Teledifusora S.A.",
    "27814": "Aeprovi",
    "27816": "ESPOLTEL",
    "27817": "Red Nacional Acad\u00e9mica de Tecnolog\u00eda Avanzada - RENATA",
    "27818": "Cotesma",
    "27819": "Ministerio de Econ\u00f3mica y Finanzas - MEF",
    "27820": "Universidad Tecnica Particular de Loja",
    "27822": "Emerging Markets Communications de Argentina S.R.L",
    "27823": "Dattatec.com",
    "27824": "TRICOM",
    "27825": "Ventana Networks, S.A.",
    "27826": "Omnivision Argentina",
    "27827": "Gualberto Larrauri",
    "27828": "Universidad Mayor de San Andres",
    "27830": "Pan American Energy LLC",
    "27831": "Colombia M\u00f3vil",
    "27832": "Golden Palace",
    "27833": "BVNET S.A.",
    "27834": "Infomed",
    "27835": "Ministerio de Educacion Superior",
    "27836": "Smartcom",
    "27837": "Dialnet de Colombia S.A. E.S.P.",
    "27838": "Servibanca S.A.",
    "27839": "Comteco Ltda",
    "27841": "CEDIA",
    "27842": "Grupo FA",
    "27843": "OPTICAL IP",
    "27844": "ETAPA EP",
    "27845": "Empresa de Recursos Tecnologicos S.A E.S.P",
    "27847": "Tecnolog\u00eda Digital",
    "27848": "Internet Systems Consortium",
    "27850": "Data Support Services",
    "27851": "Coop. El\u00e9ctrica y de Servicios P\u00fablicos Luj\u00e1n",
    "27852": "Transcom Colombia",
    "27853": "Administradora BANCHILE de Fondos Mutuos",
    "27854": "Transactional Services",
    "27855": "AXESAT S.A",
    "27856": "UNIVERSIDAD UNIACC",
    "27858": "Service Bureau Intetel S.A.",
    "27859": "Internet Systems Consortium",
    "27860": "TECNOLOGIA APLICADA, S.A (TECNA)",
    "27862": "Banesco Banco Universal",
    "27864": "Telmex Colombia S.A.",
    "27865": "Tecnologia WorkOut S.A.",
    "27866": "CO.PA.CO.",
    "27867": "Grupo FA",
    "27868": "Ecuaonline",
    "27870": "CSCOM",
    "27871": "NEXTEL COMMUNICATIONS ARGENTINA S.A.",
    "27872": "URBE - Universidad Dr. Rafael Belloso",
    "27873": "Compa\u00f1ia Goly, S.A.",
    "27874": "ENAP - Empresa Nacional del Petroleos Chile",
    "27875": "Universidad Nacional de Cuyo",
    "27876": "American Data Networks",
    "27877": "Coop. Telefonica de Capit\u00e1n Berm\u00fadez",
    "27878": "Carib International, Ltd",
    "27879": "Inform\u00e1tica y Telecomunicaciones S.A.",
    "27880": "ATENTO CHILE S.A.",
    "27881": "IPNEXT S.A.",
    "27882": "Telef\u00f3nica Celular de Bolivia S.A.",
    "27883": "Universidad Tecnologica Nacional",
    "27884": "CABLECOLOR S.A.",
    "27885": "American Networks",
    "27886": "Efectivo Ltda",
    "27887": "WIND Telecom S.A.",
    "27888": "Caja de Compensaci\u00f3n de Asignaci\u00f3n Familiar La Araucana",
    "27889": "Telecomunicaciones MOVILNET",
    "27890": "Universidad de Oriente",
    "27891": "Universidad Pedag\u00f3gica Experimental Libertador",
    "27892": "Universidad del Zulia",
    "27893": "Universidad de Carabobo",
    "27894": "PODER JUDICIAL DE MENDOZA",
    "27895": "N\u00facleo S.A.",
    "27896": "All America Cables & Radio/Centennial Dominicana",
    "27897": "SEGIC USACH LTDA",
    "27898": "Redynet SRL",
    "27899": "Quintec Soluciones Informaticas S.A.",
    "27900": "Platinum Enterprises S.A. de C.V",
    "27901": "Pacifico Cable S.A.",
    "27902": "GPF CORPORACION - POWERFT",
    "27903": "Digicelgroup El Salvador",
    "27904": "Virutex Ilko S.A.",
    "27905": "Banco de Finanzas",
    "27907": "Neoris Argentina S.A",
    "27908": "Tracity Inc.",
    "27909": "Correos Chile",
    "27910": "Banco Industrial",
    "27911": "Metlife Chile Seguros de Vida",
    "27912": "UNIVERSIDAD TECNOLOGICA CENTROAMERICANA",
    "27913": "Internet Systems Consortium",
    "27914": "International Call Center Services",
    "27915": "Processing Center, S.A.",
    "27916": "Internet Systems Consortium",
    "27917": "BT LATAM Venezuela, S.A.",
    "27918": "Sinacofi S.A.",
    "27919": "LUTROL S.A.",
    "27920": "SERCOM de Honduras",
    "27921": "Telefonica Moviles Colombia",
    "27922": "Smithsonian Tropical Research Institute",
    "27923": "TEVISAT, S.A.",
    "27924": "Three Sixty Communications",
    "27925": "Entel PCS Telecomunicaciones S.A.",
    "27926": "A SRL",
    "27927": "Coop. Popular de Elec., Obras y Servicios Pub. de Santa Rosa LTDA",
    "27928": "Liberty Technologies Corp.",
    "27929": "Red Avanzada Guatemalteca para la Investigacion y Educacion",
    "27930": "Shadwell International Inc",
    "27931": "Tecnolex Ltda.",
    "27932": "Redes y Telecomunicaciones",
    "27933": "Universidad Galileo",
    "27934": "JSNet S.A.",
    "27935": "Cooperativa de provicion de servicios telefonicos La Lonja Ltda",
    "27936": "CREDICORP BANK S.A",
    "27937": "INGELCOM LTDA",
    "27938": "Ministerio de Obras P\u00fablicas",
    "27939": "N2P S.A",
    "27940": "Cooperativa Colonia Caroya",
    "27941": "CONSULNETWORK LTDA",
    "27942": "BICE Vida Compa\u00f1\u00eda de Seguros de Vida S.A.",
    "27943": "Laboratorios Recalcine S.A.",
    "27944": "Panama Ports Company",
    "27945": "NEW OPPORTUNITIES, S. DE R.L.",
    "27946": "Direcci\u00f3n General del Territorio Mar\u00edtimo",
    "27947": "Telconet S.A",
    "27948": "CORPORACION NACIONAL DE TELECOMUNICACIONES - CNT EP",
    "27949": "ANSES - Administraci\u00f3n Nacional de la Seguridad Social",
    "27950": "Cooperativa Telefonica Benavidez Ltda",
    "27951": "Media Commerce Partners S.A",
    "27952": "Banco Central de Chile",
    "27953": "Coop. El\u00e9ct. y de Obras y Serv. P\u00fablico Ltda de Justiniano Posse",
    "27954": "FARMALINK S.A.",
    "27955": "Cooperativa de Provisi\u00f3n de Servicios Publicos de Tortuguitas",
    "27956": "Cyber Cast International, S.A.",
    "27957": "Banco Mercantil C.A., S.A.C.A.-S.A.I.C.A",
    "27958": "FIX GROUP",
    "27959": "SERVICIOS CENTENARIOS DE PANAMA S.A.",
    "27960": "Coop. de Obras y Serv. Pub. Ltda. de Rio Tercero",
    "27961": "Jefatura de Gabinete de Ministros",
    "27962": "AltaVoz S.A.",
    "27963": "Anglo American Chile",
    "27964": "RSONet",
    "27965": "Intcomex Chile S.A.",
    "27966": "Telecorp",
    "27967": "Gobernacion de la Provincia de Buenos Aires",
    "27968": "CORPORACION NACIONAL DE TELECOMUNICACIONES - CNT EP",
    "27969": "BairesWeb",
    "27970": "OnePacket Networks Inc.",
    "27971": "Alberto Oscar Genovese",
    "27972": "Balboa Bank Trust",
    "27973": "Constructora Pura Vida S.A.",
    "27974": "Association OCIX (Open Caribbean Internet Exchange)",
    "27975": "SYNAPSIS COLOMBIA S",
    "27976": "Coop. de Servicios P\u00fablicos de Morteros Ltda.",
    "27977": "IBM Argentina S.A.",
    "27978": "Telmex Servicios Empresariales S.A.",
    "27979": "Stel Chile S.A.",
    "27980": "Weatherford International Inc.",
    "27981": "Universidad Nacional de Mar del Plata",
    "27983": "Red Intercable Digital S.A.",
    "27984": "Ver Tv S.A.",
    "27986": "ENTEL CHILE S.A.",
    "27987": "NODOCOOP Federaci\u00f3n de Cooperativas Ltda.",
    "27988": "Servicios y Telecomunicaciones S.A.",
    "27989": "BANCOLOMBIA S.A",
    "27990": "Hosting Panama",
    "27991": "Terremark del Caribe a BVI",
    "27992": "Terremark Colombia Inc.",
    "27993": "Universidad Nacional del Litoral",
    "27994": "Servicios para el Transporte de Informaci\u00f3n S.A.",
    "27995": "CLARO CHILE S.A.",
    "27996": "Cooperativa Electrica de Colon (BA) LTDA",
    "27997": "Coop. Ltda de Electricidad y Servicios Anexos de Huinca Renanc\u00f3",
    "27998": "Contecon Guayaquil S.A.",
    "27999": "Banco de la Producci\u00f3n, S.A.",
    "28000": "LACNIC - Latin American and Caribbean IP address",
    "28001": "LACNIC - Latin American and Caribbean IP address",
    "28002": "LACNIC - Latin American and Caribbean IP address",
    "28005": "Digicel (Panama), S.A",
    "28006": "CORPORACION NACIONAL DE TELECOMUNICACIONES - CNT EP",
    "28007": "Gold Data C.A.",
    "28008": "Get Line Internet S.A.",
    "28009": "Davitel S.A.",
    "28011": "CORPORACION NACIONAL DE TELECOMUNICACIONES - CNT EP",
    "28012": "BBVA Banco Provincial S.A.",
    "28013": "MINISTERIO DE COMERCIO INDUSTRIA Y TURISMO",
    "28015": "MERCO COMUNICACIONES",
    "28017": "Caribbean Internet Exchange (CAR-IX)",
    "28018": "BANESCO INTERNATIONAL BANK",
    "28019": "Interdotnet Argentina S.A.",
    "28020": "Municipalidad de Rosario",
    "28021": "EGLOB S.A.",
    "28022": "CRISP S.A.",
    "28023": "COOPERATIVA DE OBR, SERV. PUBL. Y SOCIALES DE HERNANDO LTDA.",
    "28024": "Nuevatel PCS de Bolivia S.A.",
    "28025": "CENTROSUR",
    "28026": "Grape S.A.",
    "28027": "Escuela Superior Politecnica del Litoral",
    "28028": "FastBee Argentina S.A.",
    "28029": "Sersat S.A.",
    "28030": "PANAMA STAR, S.A.",
    "28031": "Copa Airlines",
    "28032": "INTERNEXA PERU S.A",
    "28033": "Banco Familiar SAECA",
    "28034": "Toyota Argentina S.A.",
    "28035": "BANCO SUPERVIELLE SOCIEDAD ANONIMA",
    "28036": "Telefonia Celular de Nicaragua SA.",
    "28037": "Alpha 2000 Soluciones Infomaticas SRL",
    "28038": "SAN LUIS CTV S.A.",
    "28039": "Universidad EAN",
    "28040": "TOYOTA TSUSHO ARGENTINA S.A.",
    "28041": "PANCHONET S.A",
    "28043": "Importadora Ricamar, S.A.",
    "28044": "ADT SECURITY SERVICES",
    "28045": "Pantel Communications",
    "28046": "Ingenieria, Servicios y Comunicaciones S.A.",
    "28047": "ENTEL CHILE S.A.",
    "28048": "Internet Para Todos - Gobierno de La Rioja",
    "28049": "ISP SOLUTIONS S.A.",
    "28050": "ADN Solutions S.A. (Rokru Int.)",
    "28051": "Coop. Telef\u00f3nica y de obras y serv. p\u00fablicos de Villa Flandria",
    "28052": "Arte Radiotelevisivo Argentino",
    "28053": "ONEMAX S.A.",
    "28054": "Internet Systems Consortium",
    "28055": "Banco Azteca Honduras",
    "28056": "AHTIC",
    "28057": "KMA TECHNOLOGY",
    "28058": "Stealth Telecom del Ecuador",
    "28059": "Banco Hipotecario de Fomento",
    "28060": "Pullman Cargo S.A",
    "28061": "Ministerio de la Presidencia",
    "28062": "Ministerio de Educacion - MEDUCA",
    "28063": "Advanced Communication Network, S.A.",
    "28064": "Smart Data Center S.A.",
    "28065": "CITARELLA S.A.",
    "28066": "COOP. MARIANO ACOSTA",
    "28067": "The University of the West IndiesSt Augustine Camp",
    "28068": "Universidad Nacional de San Luis",
    "28069": "Banco Azteca de Guatemala, S.A.",
    "28070": "Banco Colpatria Red Multibanca Colpatria S.A.",
    "28071": "Tech International S.A.",
    "28072": "Instituto Nicaraguense de Seguridad Social (INSS)",
    "28073": "Cooperativa Electrica Trenque Lauquen",
    "28074": "Banco Azteca El Salvador",
    "28075": "ARLINK S.A.",
    "28076": "Benson Communications S.A. de C.V.",
    "28077": "Informes Garantizados S.A.",
    "28078": "PrimeTel Services Inc.",
    "28079": "Cooperativa Profesionales",
    "28080": "Interredes S.A.",
    "28081": "Instituto Costarricense de Electricidad y Telecom.",
    "28082": "MISA S.A.",
    "28083": "GILAT Colombia S.A. E.S.P.",
    "28084": "Infatlan S.A",
    "28085": "Sociedad Portuaria Regional de Cartagena S.A.",
    "28086": "Worldcom de Costa Rica, S.A.",
    "28087": "COMNET,S.A.",
    "28088": "Inversiones Apolo S.A. de C.V.",
    "28089": "BANCO CENTRAL DE VENEZUELA",
    "28090": "Elektra de Argentina S.A.",
    "28091": "Soluciones Integrales S.A",
    "28092": "Panama Hosting Technologies",
    "28093": "Cooperativa de Electricidad y Servicios Publicos de Arroyito Ltda",
    "28094": "Southern Cable Network",
    "28095": "Red Acad\u00e9mica Peruana-RAAP",
    "28096": "Sociedad de Telecomunicaciones Geonet Ltda.",
    "28097": "Farcomed",
    "28098": "ABGON COMUNICACIONES",
    "28099": "iHosting Servicios Internet Ltda.",
    "28100": "Cooperativa Villa del Rosario (Coovilros)",
    "28101": "NC IT SRL",
    "28102": "Banco Azteca Peru",
    "28103": "TEISA",
    "28104": "Eutel N.V.",
    "28105": "DENIMATRIX",
    "28106": "BANCO PENTA",
    "28107": "UNIVERSIDAD NACIONAL DE SAN JUAN",
    "28108": "NETCRC S.A.",
    "28109": "FUNDACION DEL SUR PARA EL DESARROLLO TECNOLOGICO (FUNDUR)",
    "28110": "RACK LODGE S.A.",
    "28111": "Grupo Solunet SRL",
    "28112": "Banco Prival",
    "28113": "Intratex",
    "28114": "Alpha Tel S.A.",
    "28115": "Direcci\u00f3n General de Aduanas",
    "28116": "Universidad de Adolfo Ibanez",
    "28117": "Crisil Irevna Argentina S.A.",
    "28118": "Orange Dominicana",
    "28119": "LACNIC - Latin American and Caribbean IP address",
    "28120": "Arquicomp Ltda.",
    "28121": "COBRA TECNOLOGIA S/A",
    "28122": "Yahoo! do Brasil Internet Ltda.",
    "28123": "Actual Network Internet Ltda",
    "28124": "NETELL TELECOMUNICACOES LTDA",
    "28125": "Elo.Net Tecnologia Ltda. - ME",
    "28126": "BRISANET SERVICOS DE TELECOMUNICACOES LTDA",
    "28127": "Cambridge Telecomunica\u00e7\u00f5es Ltda.",
    "28128": "Infolic Comercial de Informatica Ltda.",
    "28129": "Uni\u00e3o Norte do Paran\u00e1 de Ensino LTDA",
    "28130": "NETCERTTO INFORMATICA LTDA.",
    "28131": "NET.COM TELECOMUNICA\u00c7\u00d5ES LTDA",
    "28132": "TRI TELECOM LTDA",
    "28133": "Provedor Eloinet Ltda",
    "28134": "TKNET COM. EQUIP. INFORM\u00c1TICA LTDA",
    "28135": "SOCIA\u00c7\u00c3O NACIONAL PARA INCLUS\u00c3O DIGITAL - ANID",
    "28136": "SPACnet - Projetos Avan\u00e7ados em Computa\u00e7\u00e3o",
    "28137": "Vialink Inform\u00e1tica Ltda.",
    "28138": "SCW Telecom",
    "28139": "ItaSis Inform\u00e1tica Ltda",
    "28140": "Maxiweb Internet Provider",
    "28141": "Datavag Informatica Ltda",
    "28142": "DIGITAL DESIGN - SERVICOS DE INFORMATICA LTDA",
    "28143": "E Greco Falchione Manutencao ME",
    "28144": "G3 TELECOM",
    "28145": "RLINE - Solu\u00e7\u00f5es Inteligentes",
    "28146": "Mhnet Empreendimentos Ltda",
    "28148": "Safeweb Seguran\u00e7a da Informa\u00e7\u00e3o Ltda",
    "28149": "SOCIACAO DE ENSINO DE MARILIA",
    "28150": "CDT Network Ltda",
    "28151": "Datora Telecomunica\u00e7\u00f5es Ltda.",
    "28152": "Navinet Ltda",
    "28153": "Micropic Ltda",
    "28154": "AR TELECOM PROVEDOR DE INTERNET LTDA",
    "28155": "Jop Comunica\u00e7\u00e3o Virtual Ltda",
    "28156": "Linhares Servi\u00e7os Online LTDA EPP",
    "28157": "Comunidade Evangelica Luterana - ULBRA",
    "28158": "Ampernet Telecomunica\u00e7\u00f5es Ltda",
    "28159": "PRODERJ-Centro de Tecnologia da Informa\u00e7\u00e3o do RJ",
    "28160": "MEGALINK - Diana A. de Oliveira ME",
    "28161": "A.F.B. RODRIGUES - ME",
    "28162": "IBL Telecomunica\u00e7\u00f5es Ltda.",
    "28163": "CosmoNET - Cosmonline Inform\u00e1tica Ltda",
    "28164": "AMPLANET LTDA",
    "28165": "Wireless Comm Services LTDA",
    "28166": "Telecom South America S/A",
    "28167": "Acotel do Brasil LTDA",
    "28168": "Minas Mais Telecomunica\u00e7\u00f5es Ltda -ME",
    "28169": "Visao Tecnologia em Transmissao de Dados Ltda",
    "28170": "Wal-Mart Brasil LTDA",
    "28171": "S. O. do Brasil Telecomunica\u00e7\u00f5es LTDA ME",
    "28172": "PROJESOM INTERNET LTDA",
    "28173": "Din\u00e2mica Telecomunica\u00e7\u00f5es Ltda",
    "28174": "A REDE SERVI\u00c7OS DE INFORM\u00c1TICA LTDA",
    "28175": "Online Telecomunica\u00e7\u00f5es, Info e internet Ltda",
    "28176": "Quick Soft Sistemas de Informacao Ltda",
    "28177": "NETWORKBRIL Ltda.",
    "28178": "Networld Provedor e Servicos de Internet Ltda",
    "28180": "DIGITRO TECNOLOGIA LTDA.",
    "28181": "MTER TELECOM LTDA ME",
    "28182": "TeleSA Telecomunicacoes S.A",
    "28183": "MICRON LINE SERVICOS DE INFORMATICA LTDA - ME",
    "28184": "Interjato Servi\u00e7os de Telecomunica\u00e7\u00f5es Ltda.",
    "28185": "Totvs S.A.",
    "28186": "ITS TELECOMUNICA\u00c7\u00d5ES LTDA",
    "28187": "Stratus Telecomunicacoes Ltda",
    "28188": "Pronto Net Ltda.",
    "28189": "CMA Consultoria Metodos Assessoria e Mercantil S/A",
    "28190": "FORTALNET BUREAU DE COMERCIO E SERVICOS LTDA",
    "28191": "Jupiter Telecomunicacoes e Informatica Ltda",
    "28192": "Globalwave Telecom",
    "28193": "UNIVERSIDADE ESTADUAL DE LONDRINA",
    "28194": "R & F BSAN COM\u00c9RCIO SERVI\u00c7OS E SISTEMA LTDA - ME",
    "28195": "Com4 Data Center Ltda EPP",
    "28196": "BANCO VOTORANTIM S/A",
    "28197": "EMPRESA DE TECNOLOGIA DA INFORMACAO DO CEARA-ETICE",
    "28198": "Isimples Telecom e Hardware Ltda",
    "28199": "SERVPRO-SERVICOS DE PROCESSAMENTO E COMERCIO LTDA",
    "28200": "Sotech Servicos em Informatica Ltda",
    "28201": "CIA ITABIRANA DE TELECOMUNICACOES",
    "28202": "Rede Brasileira de Comunicacao Ltda",
    "28203": "Webcenter Sist Prest de Servicos de Informatica",
    "28204": "Keraxweb Servi\u00e7os de Interliga\u00e7\u00e3o e Internet Ltda.",
    "28205": "Ibituruna TV por assinatura S/C Ltda",
    "28206": "ABRIL COMUNICACOES S/A",
    "28207": "Teleon Telecomunica\u00e7oes Ltda",
    "28208": "Superline Telecomunica\u00e7\u00f5es Ltda",
    "28209": "Desenvolve Solucoes de Internet Ltda",
    "28210": "VM OPENLINK COMUNICA\u00c7\u00c3O MULTIMIDIA E INFORM\u00c1TICA L",
    "28211": "Bidobens Participa\u00e7\u00f5es e Empreendimentos Ltda",
    "28212": "DGNet Telecom",
    "28213": "LCI Equipamentos de Inform\u00e1tica LTDA",
    "28214": "Trinn Servi\u00e7os de Comunica\u00e7\u00e3o Ltda.",
    "28215": "Onixsat Rastreamento de Ve\u00edculos Ltda",
    "28216": "Host Revenda",
    "28217": "SIM CONECTE - Solu\u00e7\u00f5es Integradas de Multim\u00eddia",
    "28218": "Tv Cabo de Presidente Venceslau S/S Ltda. EPP",
    "28219": "Net Rosas Com\u00e9rcio e Servi\u00e7os em Inform\u00e1tica Ltda.",
    "28220": "CABO SERVICOS DE TELECOMUNICACOES LTDA",
    "28222": "INSTITUTO NACIONAL DE PESQUIS ESPACIAIS",
    "28223": "NETSAT FOZ DO IGUACU LTDA",
    "28224": "CPNET Com. e Serv. Telecomunica\u00e7\u00f5es Ltda.",
    "28225": "Provedornet Telecom. e Servi\u00e7os de Internet Ltda",
    "28226": "iPredia Telecomunica\u00e7\u00f5es Ltda",
    "28227": "NOVACIA TECNOLOGIA E TELECOMUNICACOES LTDA",
    "28228": "MVF.NET SERVICOS DE TELECOMUNICACOES LTDA",
    "28229": "HARDONLINE LTDA",
    "28230": "MS LINK-TECNOLOGIA E COMUNICA\u00c7\u00d5ES LTDA ME",
    "28231": "Gigawire Informatica Ltda",
    "28232": "Bit Informatica Ltda",
    "28233": "I-CONECTA REDES DE TELECOMUNICACAO LTDA EPP",
    "28234": "Wireless Desenvolvimento de Sistemas Informatizada",
    "28235": "NIPONET TELECOMUNICACOES LTDA",
    "28236": "PRTURBO INTERNET WIRELLESS EPP LTDA",
    "28237": "RNLINK Provedor de Acesso a Internet LTDA",
    "28238": "Sator Engenharia Ltda.",
    "28239": "IWserver Internet Banda Larga Ltda.",
    "28240": "VIP - SERVI\u00c7OS DE TELECOMUNICA\u00c7\u00d5ES LTDA.",
    "28241": "Viaceu Internet Ltda",
    "28242": "NOLVER INFORMATICA LTDA",
    "28243": "Fiat Autom\u00f3veis S/A",
    "28244": "Sendnet Provider Ltda",
    "28245": "NETDIGIT TELECOMUNICACOES LTDA",
    "28246": "REDE SIVNET TELECOMUNICACOES LTDA",
    "28247": "Intercampo Empreendimentos Tecnol\u00f3gicos Ltda",
    "28248": "BRB - Banco de Bras\u00edlia S/A",
    "28249": "EMPRESA EDITORA A TARDE S.A.",
    "28250": "Telbrax Ltda",
    "28251": "Flashnet Com e Serv de Telecomunica\u00e7\u00f5es LTDA",
    "28252": "JRT Servi\u00e7os e Consultoria LDTA",
    "28253": "ONS - Operador Nacional do Sistema Eletrico",
    "28254": "Arganet Comunica\u00e7\u00e3o e Monitoramento Digital Ltda",
    "28255": "WEST INTERNET BANDA LARGA",
    "28256": "MMC AUTOMOTORES DO BRIL S.A.",
    "28257": "G. DE SOUSA ARAUJO",
    "28258": "Infoline - Comunica\u00e7\u00f5es e Informa\u00e7\u00f5es Eletr\u00f4nicas",
    "28259": "COOPERATIVA REGIONAL DE DESENVOLVIMENTO TEUTONIA",
    "28260": "Altarede de Teresopolis Provedor de Internet Ltda",
    "28261": "EMPRESA SERGIPANA DE TECNOLOGIA DA INFORMA\u00c7\u00c3O",
    "28262": "INTERNEXO LTDA.",
    "28263": "Ensite Brasil Telecomunica\u00e7\u00f5es Ltda - ME",
    "28264": "ADLLink Provedor de Internet Via Radio LTDA",
    "28265": "abcRede LTDA ME",
    "28266": "Vante Provedor de Internet Ltda",
    "28267": "LANTEC COMUNICACAO MULTIMIDIA LTDA",
    "28268": "Link Sol LTDA - ME",
    "28269": "COMPUTADORES E SISTEM LTDA",
    "28270": "Videomar Rede Nordeste S/A",
    "28271": "DataCorpore Servi\u00e7os e Representa\u00e7\u00f5es",
    "28272": "F-TELECOM TELECOMUNICA\u00c7\u00d5ES LTDA",
    "28273": "Hispamar Sat\u00e9lites S/A",
    "28274": "Hewlett-Packard Brasil Ltda",
    "28275": "Funda\u00e7\u00e3o C\u00e1sper L\u00edbero",
    "28276": "Mikrocenter Inform\u00e1tica Ltda.",
    "28277": "VMAX NET TELECOMUNICACOES DO BRIL LTDA",
    "28278": "TELLFREE BRIL TELEFONIA IP S.A.",
    "28279": "Turboseg Provedor de Internet Ltda",
    "28280": "A. P. OLIVEIRA & CIA. S/C. LTDA.",
    "28281": "VCB PROVEDOR DE ACESSO LTDA",
    "28282": "DW7 CENTRO DE DADOS LTDA",
    "28283": "Adylnet Telecom",
    "28284": "Genius On Line Comercios e Serv. Ltda. EPP",
    "28285": "World Line Ltda",
    "28286": "RN Brasil - Servi\u00e7os de Provedores Ltda",
    "28287": "Acer Telecomunica\u00e7\u00f5es ltda",
    "28288": "Adatel TV e Comunicacoes Sao Jose S/A",
    "28289": "Americana Digital Ltda.",
    "28290": "WB LINK Tecnologia e Comunicacao Ltda",
    "28291": "MINISTERIO DA SAUDE",
    "28292": "ENGEPLUS INFORMATICA LTDA",
    "28293": "InterCorp Provedor de Internet LTDA ME",
    "28294": "Minas Gerais Telecomunica\u00e7\u00f5es Ltda ME",
    "28295": "Diagnosticos da America S.A.",
    "28296": "Acessa Telecomunica\u00e7\u00f5es Ltda",
    "28297": "Digiweb Brasil Ltda.",
    "28298": "Sky Brasil Servicos Ltda.",
    "28299": "IPV6 Internet Ltda",
    "28300": "MMA ACESSORIOS E SERVICOS DE INFORMATICA LTDA.",
    "28301": "Departamento de Educa\u00e7\u00e3o e Cultura do Ex\u00e9rcito",
    "28302": "Bon Line Internet Ltda",
    "28303": "Rede OptiTel",
    "28304": "Banco Safra SA.",
    "28305": "SVA INTERNET LTDA",
    "28306": "Britis Telecom LTDA",
    "28307": "Wideway do Brasil Ltda",
    "28308": "Orion Telecomunica\u00e7\u00f5es Com\u00e9rcio e Servi\u00e7os LTDA",
    "28309": "WGO Telecomunica\u00e7\u00f5es Ltda",
    "28310": "SMART TELECOMUNICA\u00c7\u00d5ES E SERVI\u00c7OS LTDA.",
    "28311": "FOX TELECOMUNICA\u00c7\u00c3O E INTERNET LTDA.",
    "28313": "Ci&T Software S/A",
    "28315": "ADP Brasil LTDA - Sede ADP Labs",
    "28316": "Metrobank, S.A.",
    "28320": "Dialdata Telecomunicacoes Ltda.",
    "28321": "Federa\u00e7\u00e3o das C\u00e2maras de Dirigentes Lojistas SC",
    "28322": "Mar Internet Provider Ltda.",
    "28323": "VIPRede Telecomunica\u00e7\u00f5es Ltda",
    "28324": "USINA COLOMBO S/A - A\u00c7\u00daCAR E \u00c1LCOOL",
    "28325": "NOKIA SOLUTIONS AND NETWORKS DO BRIL TELEC. LTDA",
    "28326": "Urbi Telecom Provider",
    "28327": "PS5 Internet",
    "28328": "EBR Inform\u00e1tica Ltda",
    "28329": "G8 NETWORKS LTDA",
    "28330": "IFTNET Informatica Ltda",
    "28331": "PaintWeb Internet Ltda",
    "28332": "BOA VISTA SERVICOS S.A.",
    "28333": "Local Datacenter Solu\u00e7\u00f5es em Comunica\u00e7\u00e3o Ltda.",
    "28334": "PROCESS INFORMATICA LTDA.",
    "28335": "MAXCOMM TELECOM LTDA",
    "28336": "Dekanet Comunica\u00e7\u00e3o Multim\u00eddia Ltda.",
    "28337": "Claudio Jos\u00e9 da Trindade Jr - ME",
    "28338": "Net Botanic Internet Inteligente Ltda",
    "28339": "MACH4 Telecomunica\u00e7\u00f5es, Com\u00e9rcio e Servi\u00e7os Ltda",
    "28340": "In\u00e9dito Telecom Ltda",
    "28341": "WESTNET SERVICOS DE INFORMATICA S/C LTDA",
    "28342": "Antenor Campos Puchetti",
    "28343": "TPA TELECOMUNICACOES LTDA",
    "28344": "FIDELITY PROCESSADORA E SERVICOS S.A.",
    "28345": "VR InterNet Telecomunica\u00e7\u00f5es Ltda - ME",
    "28346": "IB TELECOMUNICA\u00c7\u00d5ES LTDA",
    "28347": "UNOTEL TELECOM S/A",
    "28348": "LUMA INFORMATICA LTDA",
    "28349": "TVC Tupa Ltda.",
    "28350": "Globecall do Brasil Ltda.",
    "28351": "NEXTEL TELECOMUNICA\u00c7\u00d5ES LTDA",
    "28352": "NETSPEED LTDA",
    "28353": "Golnet Sistemas e Telecomunica\u00e7\u00f5es Ltda",
    "28354": "J.A.M INFORMATICA LTDA - ME",
    "28355": "Connect Servico de Acesso a Internet Ltda",
    "28356": "Angellira Rastreamento Satelital Ltda",
    "28357": "RBS - Zero Hora Editora Jornal\u00edstica S.A.",
    "28358": "INTERTELCO TELECOMUNICA\u00c7\u00d5ES MULTIM\u00cdDIA LTDA",
    "28359": "VIS\u00c3ONET TELECOM LTDA.",
    "28360": "WKVE Asses. em Servi\u00e7os de Inform. e Telecom. Ltda",
    "28361": "rrconect - internet",
    "28362": "Onda Internet",
    "28364": "GYORFI E GYORFI LTDA",
    "28366": "Marinter Telecom Ltda.",
    "28367": "Complexx Tecnologia Ltda",
    "28368": "Infoway Servicos de Informatica Ltda",
    "28369": "SIGNALLINK INFORMATICA LTDA",
    "28370": "GUIFAMI Inform\u00e1tica Ltda.",
    "28371": "Gobierno del Estado de Guanajuato",
    "28372": "Neoris de Mexico, S.A. de C.V.",
    "28373": "Bajanet Comunicaciones, S.A. de C.V.",
    "28374": "Expansion S.A. de C.V.",
    "28375": "Cydsa Corporativo, S.A. de C.V.",
    "28376": "Gigacable de Aguascalientes, S.A. de C.V.",
    "28377": "NIC M\u00e9xico, S.C.",
    "28378": "TV Rey de Occidente, S.A. de C.V.",
    "28379": "MANPOWER, S.A. DE C.V.",
    "28381": "Grupo Hidalguense de Desarrollo, S.A. de C.V.",
    "28382": "Universidad Iberoamericana, A.C.",
    "28383": "Instituto Jalisciense de Tecnologias de la Informacion A.C.",
    "28384": "NII DIGITAL S DE RL DE CV",
    "28385": "Consorcio para el Intercambio de Trafico de Internet A. C.",
    "28386": "Binbit Mexico SA de CV",
    "28387": "COMPUTADOR Y SERVICIOS ESPECIALES SA DE CV",
    "28388": "GRUPO GOR, S.A. DE C.V.",
    "28389": "BBG Wireless, S.A. de C.V.",
    "28399": "BTU Comunicacion SA de CV",
    "28400": "SECRETARIA DE COMUNICACIONES Y TRANSPORTES COORDINACION DE LA SOCIEDAD DE LA INFORMACION Y EL CONOCI",
    "28403": "RadioMovil Dipsa, S.A. de C.V.",
    "28415": "Grupo de Telecomunicaciones Mexicanas, S.A. de C.V.",
    "28416": "CORE MULTISERVICE STRATEGIES, S. DE RL DE C.V.",
    "28438": "Metro Net, S.A.P.I. de C.V.",
    "28449": "Home Interiors de Mexico S. de R.L. de C.V.",
    "28454": "Servicios DR de M\u00e9xico SA de CV",
    "28457": "UNIVERSIDAD LATINOAMERICANA, S.C.",
    "28460": "ESORIA DE EMPRES S.A. DE C.V.",
    "28469": "NII DIGITAL S DE RL DE CV",
    "28470": "FOMENTO E INVESTIGACION INTEGRAL S.C.",
    "28471": "Resource Recovery",
    "28472": "Universidad Autonoma del Estado de Hidalgo",
    "28473": "Resource Recovery",
    "28474": "Colegio de Postgraduados",
    "28475": "Fomento Econ\u00f3mico Mexicano S. A. de C. V.",
    "28476": "Aeropuerto Internacional de la Ciudad de Mexico, S.A. de C.V.",
    "28477": "UNIVERSIDAD AUTONOMA DEL ESTADO DE MORELOS",
    "28478": "Escuela Bancaria y Comercial, S.C.",
    "28479": "Pegaso PCS, S.A. de C.V.",
    "28480": "Industrias Xignux, S.A. de C.V.",
    "28481": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28482": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28483": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28484": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28485": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28486": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28487": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28488": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28489": "Tele Cable Centro Occidente, S.A. de C.V.",
    "28490": "TELEVISION POR CABLE DEL NORTE DE SONORA S.A. DE C.V.",
    "28491": "INSTITUTO NACIONAL DE ESTADISTICA Y GEOGRAFIA",
    "28492": "Softtek Servicios Corporativos, S.A. de C.V.",
    "28493": "Universidad Pedagogica Nacional",
    "28494": "Corporacion Nacional de Radiodeterminacion S.A. de C.V.",
    "28495": "NIC M\u00e9xico, S.C.",
    "28496": "NIC M\u00e9xico, S.C.",
    "28497": "NIC M\u00e9xico, S.C.",
    "28498": "NIC M\u00e9xico, S.C.",
    "28499": "NIC M\u00e9xico, S.C.",
    "28500": "NIC M\u00e9xico, S.C.",
    "28501": "Centro Estatal de Tecnologias de Informacion y Comunicaciones",
    "28502": "G TEL Comunicacion, S.A.P.I. de C.V.",
    "28503": "GSAT COMUNICACIONES SA DE CV",
    "28504": "NIC M\u00e9xico, S.C.",
    "28505": "Universidad Regiomontana, A.C.",
    "28506": "Sistemas de Communicacion GM S.A. de C.V.",
    "28507": "TV Azteca, S.A.B. de C.V.",
    "28508": "Desarollo Integral Administrativo S.A. de C.V.",
    "28509": "Cablemas Telecomunicaciones SA de CV",
    "28510": "NIC M\u00e9xico, S.C.",
    "28511": "NIC M\u00e9xico, S.C.",
    "28512": "Cablemas Telecomunicaciones SA de CV",
    "28513": "Uninet S.A. de C.V.",
    "28514": "Abastecedora de Conectividad, S.A. de C.V.",
    "28515": "Servicios Electronicos Globales, S.A. de C.V.",
    "28516": "Cablemas Telecomunicaciones SA de CV",
    "28517": "TV Azteca, S.A.B. de C.V.",
    "28518": "Television Internacional, S.A. de C.V.",
    "28519": "Universidad Autonoma de Guadalajara, A.C.",
    "28520": "Omnilife de Mexico, S.A. de C.V.",
    "28521": "Comunicaciones Nextel de Mexico, S.A. de C.V.",
    "28522": "Microenlace de Mexico, S. de R.L. de C.V.",
    "28523": "Cablevision Red, S.A de C.V.",
    "28524": "Imatech Networks, S.A. de C.V.",
    "28525": "Television por Cable de Tabasco, S.A. de C.V.",
    "28526": "Universidad Autonoma del Estado de Mexico",
    "28527": "Resource Recovery",
    "28529": "Red Five Two, S.A. de C.V.",
    "28530": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28531": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28532": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28533": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28534": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28535": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28536": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28537": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28538": "Cablemas Telecomunicaciones SA de CV",
    "28539": "Creatividad Internet Enlaces, S.A. de C.V.",
    "28540": "NIC M\u00e9xico, S.C.",
    "28541": "Mega Cable, S.A. de C.V.",
    "28542": "Resource Recovery",
    "28543": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28544": "Mexico Red de Telecomunicaciones, S. de R.L. de C.V.",
    "28545": "Cablemas Telecomunicaciones SA de CV",
    "28546": "Servnet Mexico, S.A. de C.V.",
    "28547": "Home Depot Mexico, S. de R.L. de C.V.",
    "28548": "Cablevisi\u00f3n, S.A. de C.V.",
    "28549": "Cable y Comunicacion de Campeche, S.A. de C.V.",
    "28550": "Uninet S.A. de C.V.",
    "28551": "SERVICIOS ADMINISTRATIVOS WALMART S DE RL DE CV",
    "28552": "Enlaces Integra, S. de R.L. de C.V.",
    "28553": "Mabe, S.A. de C.V.",
    "28554": "Cablemas Telecomunicaciones SA de CV",
    "28555": "Cablemas Telecomunicaciones SA de CV",
    "28556": "Cablemas Telecomunicaciones SA de CV",
    "28557": "Cablemas Telecomunicaciones SA de CV",
    "28558": "Cablemas Telecomunicaciones SA de CV",
    "28559": "Universidad Autonoma de Coahuila",
    "28560": "Arnecom, S.A. de C.V.",
    "28561": "Micronet de Mexico, S.A. de C.V.",
    "28562": "Resource Recovery",
    "28563": "Instituto Nacional de Salud P\u00fablica",
    "28564": "NIC M\u00e9xico, S.C.",
    "28565": "Logica Industrial, S.A. de C.V.",
    "28566": "Autotransportes Herradura de Plata, S.A. de C.V.",
    "28567": "Operadora de Rastreos UDA, S.A. de C.V.",
    "28568": "Resource Recovery",
    "28569": "Corporacion Universitaria para el Desarrollo de Internet, A.C.",
    "28570": "Ryder Capital, S. de R.L. de C.V.",
    "28571": "UNIVERSIDADE DE SAO PAULO",
    "28572": "Apoiocom Digital Ltda - EPP",
    "28573": "NET Servi\u00e7os de Comunica\u00e7\u00e3o S.A.",
    "28574": "CEPEL - CENTRO PESQUIS DE ENERGIA ELETRICA",
    "28575": "Baxglobal do Brasil Ltda",
    "28576": "ITIBR - Instituto de Tecnologia Informacao Brasil",
    "28577": "AZEVEDO E FLORIANI TELECOMUNICA\u00c7\u00d5ES LTDA.",
    "28578": "EYTONE TELECOMUNICACOES LTDA.",
    "28579": "Fundacao Universidade do Sul de Santa Catarina",
    "28580": "CILNET Comunicacao e Informatica LTDA.",
    "28581": "BANCO DO ESTADO DE SAO PAULO",
    "28582": "COMPULAND INFORMATICA LTDA. M.E.",
    "28583": "RuralWeb Telecomunica\u00e7\u00f5es Ltda",
    "28584": "Netwizard Informatica Ltda",
    "28585": "NLINK Com\u00e9rcio e Servi\u00e7os Ltda",
    "28586": "BANCO BRADESCO SA",
    "28587": "HadNet Telecom",
    "28588": "LEVEL UP! INTERACTIVE S/A",
    "28589": "Luis Gustavo Zuccolotto de Assis - ME",
    "28590": "Directnet Prestacao de Servicos Ltda.",
    "28591": "MCM Telecom Ltda.",
    "28592": "FastSoft Informatica Ltda",
    "28593": "Hisecur Security Solution Ltda",
    "28594": "All Net Informatica Ltda",
    "28595": "Quantiza Desenvolvimento Ltda",
    "28596": "BM&FBOVESPA SA Bolsa de Valores Mercadorias e Futu",
    "28597": "SERA S.A",
    "28598": "Mob Servicos de Telecomunicacoes Ltda",
    "28599": "Italnet Telecomunica\u00e7\u00f5es Ltda",
    "28600": "DGX Servi\u00e7os Digitais Ltda",
    "28601": "UNIVERSIDADE DO ESTADO DE SANTA CATARINA",
    "28602": "CENTRO DE PROC. DE DADOS DO ESTADO DE MATO GROSSO",
    "28603": "STIHL Ferramentas Motorizadas LTDA",
    "28604": "Globo Comunica\u00e7\u00e3o e Participa\u00e7oes SA",
    "28605": "Defferrari Inform\u00e1tica Ltda.",
    "28606": "ITM Tecnologia de Redes Ltda",
    "28607": "EYTONE TELECOMUNICACOES LTDA.",
    "28608": "ERICSSON TELECOMUNICACOES S.A.",
    "28609": "Instituto Nupef",
    "28610": "DEBIAN SIGNAL COMUNICA\u00c7\u00c3O MULTIMIDIA LTDA ME",
    "28612": "Convention Corporate Plaza-Com. State",
    "28613": "HUGHES TELECOMUNICACOES DO BRIL LTDA.",
    "28614": "Fundacao Universidade Regional de Blumenau",
    "28615": "Televisao Cidade S/A",
    "28616": "Emp. Informat. Informa\u00e7ao Mun. BH/SA",
    "28617": "Constru\u00e7\u00f5es e Com\u00e9rcio Camargo Corr\u00eaa S.A.",
    "28618": "LINKTEL TELECOMUNICACOES DO BRIL LTDA",
    "28619": "TAM Linhas Aereas S/A",
    "28620": "WI - Provedor de Telecomunica\u00e7\u00f5es Ltda.",
    "28621": "NetOeste Telecomunica\u00e7\u00f5es Ltda",
    "28622": "Vector X - Provedor de Servi\u00e7os de Internet Ltda",
    "28623": "PONTIFICIA UNIVERSIDADE CATOLICA DO RIO GRANDE DO",
    "28624": "Oops Telecom",
    "28625": "Terremark do Brasil Ltda.",
    "28626": "Dimension Data Brasil Tecnologia da Informacao",
    "28627": "EMPRESA BRILEIRA DE AERONAUTICA S/A",
    "28628": "ERICSSON TELECOMUNICACOES S.A.",
    "28629": "SENADO FEDERAL",
    "28630": "Sucesso Servi\u00e7os de Loc. de Maq. e Eq. de Inf ltda",
    "28631": "Banrisul - Banco do Estado do Rio Grande do Sul",
    "28632": "AF Silva Sistemas",
    "28633": "Produtos Roche Quimicos e Farmaceuticos S/A",
    "28634": "Life Servi\u00e7os de Comunica\u00e7\u00e3o Multimidia Ltda.",
    "28635": "Titania - VSW Virtual Solution Wireless Ltda",
    "28636": "BRAUN OTTO INFORMATICA LTDA. EPP",
    "28637": "Cia Proc. de Dados do Estado de S Paulo - Prodesp",
    "28638": "EMTEC EMPRESA DE TECNOLOGIA EMPREENDIMENTOS DE COM",
    "28639": "LocalNet Internet (Ropke & Kruger LTDA)",
    "28640": "VIPWay Servi\u00e7os de Telecomunica\u00e7\u00f5es Ltda",
    "28641": "EBF VAZ INDUSTRIA E COMERCIO LTDA",
    "28642": "Contato Internet Ltda EPP",
    "28643": "Wivox Sevi\u00e7os de Comunica\u00e7\u00e3o Multim\u00eddia Ltda",
    "28644": "Brasilsite Telecomunica\u00e7\u00f5es Ltda.",
    "28645": "Itapecerica On-Line Telecomunicacoes e Informatica",
    "28646": "Confedera\u00e7\u00e3o Int. das Coop. Ligadas ao SICREDI",
    "28647": "Adatel TV e Comunica\u00e7\u00f5es Osasco S/A",
    "28649": "Desktop Sigmanet Comunica\u00e7\u00e3o Multim\u00eddia Ltda",
    "28650": "Lojas Simonetti Ltda",
    "28651": "SIGMABBS Comercio e Inf por Telep Ltda",
    "28652": "Telecomunica\u00e7\u00f5es Nordeste Ltda.",
    "28653": "Wireless Internet S.A.",
    "28654": "Axtelecom Telecomunica\u00e7\u00f5es Ltda ME",
    "28656": "Suporte Tecnologia e Instala\u00e7\u00f5es Ltda.",
    "28657": "MD Brasil - Tecnologia da Informa\u00e7\u00e3o Ltda",
    "28658": "Gigalink de Nova Friburgo Solu\u00e7\u00f5es em Rede Multimi",
    "28660": "Open System Ltda",
    "28661": "HOTLINK INTERNET LTDA",
    "28662": "Sascar Tecnologia e Seguran\u00e7a Automotiva S/A",
    "28663": "FLYS INTERATIVA LTDA",
    "28664": "T-LESTE TELECOMUNICA\u00c7\u00d5ES LESTE DE S\u00c3O PAULO LTDA",
    "28665": "PREDIALNET PROVEDOR DE INTERNET LTDA",
    "28666": "HOSTLOCATION LTDA",
    "28667": "NETWORK TELECOMUNICACOES LTDA EPP",
    "28668": "SILVA & SILVEIRA S/C LTDA - ME",
    "28669": "America-NET Ltda.",
    "28670": "REDEL SERVI\u00c7OS DE TELECOMUNICA\u00c7\u00d5ES LTDA",
    "28671": "Conecta Telecomunica\u00e7\u00f5es S.A.",
    "28672": "BPNNET- BANCO BIC PORTUGUES, SA",
    "28673": "N-ITEC Internet Technology Products",
    "28674": "ITERGO-CORP- ITERGO Informationstechnologie GmbH",
    "28675": "AGSMTEL- AGSM Verona Spa",
    "28676": "WITCOM- WITCOM Wiesbadener Informations- und Telekommunikations GmbH",
    "28677": "AMEN AMEN Network",
    "28678": "KOSMAN-EDU- Technical University of Koszalin",
    "28680": "IKEA- Ikea Corporate Network",
    "28681": "UA-KM Internet Exchange point (KM-IX)",
    "28682": "N-POSTA Posta Slovenije, d.o.o.",
    "28683": "BENINTELECOM",
    "28684": "BESTNET-SERVICE-SRL BestNet Service SRL",
    "28685": "N-ROUTIT Routit BV",
    "28686": "AXI- Axpo Informatik AG",
    "28687": "KBCI- KBC Investments Limited",
    "28688": "MINDSHARE- WPP Group Technology Services",
    "28689": "ZEP-INFO- ENERGA Informatyka i Technologia Sp. z o.o",
    "28690": "ING-DIRECT-UK ING DIRECT UK N.V.",
    "28691": "EUROCDN- Jean-Francois Stenuit",
    "28692": "EUROPAPRESS- Global network of EuroaPress Noticias to provide services to",
    "28693": "KHS- KHS AG",
    "28694": "ISD- ISD - Internet Systems GmbH Dresden",
    "28695": "N-TRMEDIA Trader Publishing Ltd.",
    "28697": "NITREX- Nitrex LTD",
    "28698": "UUNETZM-",
    "28699": "UNISTAR- UNISTARS SIA",
    "28701": "LENZMOSER- Ing. Buero Lenz & Moser GmbH",
    "28702": "DELTATELECOM- Delta Telecom inc.",
    "28703": "URAL-INTERCARD- OJSC \"Vimpelcom\"",
    "28704": "TELINDUS- Telindus N.V.",
    "28705": "CYBE- Cybase Limited, ISP, Liverpool",
    "28706": "STRM- \"TC Stream\" Ltd",
    "28707": "KANGAROOT- Kangaroot BVBA",
    "28708": "ORANGEFR-PORTAL- Orange S.A.",
    "28709": "VKONTAKTE-CACHE- Vkontakte Ltd",
    "28711": "RIGTIKLI- Rigas Tikli, SIA",
    "28712": "TELSYCOM- Joint Stock Company TELSYCOM",
    "28713": "SOVTEST- Sovtest-Internet Limited Company",
    "28714": "FHI-SIT Fraunhofer-Gesellschaft zur Foerderung der angewandten Forschung e.v.",
    "28715": "ARP-DATACON- ARP Datacon AG",
    "28716": "RETELIT- Reti Telematiche Italiane S.p.A. (Retelit S.p.A.)",
    "28717": "ZENSYSTEMS- Zen Systems A/S",
    "28719": "HMFES OJSC Rostelecom",
    "28720": "GLOBTEL Globtel Internet srl",
    "28721": "OPENSYSRO OPEN SYSTEMS S.R.L.",
    "28722": "ENERGETYKA-KALISKA- ENERGA-OPERATOR SA",
    "28723": "NOKIA-APAC NOKIA Corporation",
    "28724": "SOFTLINE-KIEV- JSC \"SOFTLINE\"",
    "28725": "CZ-EUROTEL-  of Eurotel Praha",
    "28726": "N-EDB-UNIGRID EDB Drift AB",
    "28727": "N-NRACTI Autoritatea Nationala pentru Administrare si Reglementare in Comunicatii",
    "28728": "INFORNAX- The  includes the network infrastructure of Infornax, an Internet Service Provider in Veszperm County, Hungary.",
    "28729": "FORD- Ford Motor Company Limited",
    "28730": "BLINK Broadband Communications",
    "28731": "WSELTD- WSE Limited, Juelich, Germany Internet-provider, Database, we",
    "28732": "ANIXE Anixe Polska Sp. z o.o.",
    "28733": "AVIGAL- IT master LLC",
    "28734": "ATON- Aton LLC",
    "28736": "TELECOMNET OOO Telecom-net",
    "28737": "KONSTANTA- Mobile Service Ltd.",
    "28738": "INTERLAN- LLC Company Interlan Communications",
    "28739": "NEWEDGEGROUP- Newedge Group S.A.",
    "28740": "TENETA- Teneta LTD",
    "28741": "CBOSS- ZAO CBOSS",
    "28742": "GOLDNET-ITALY- Goldnet Italy Srl",
    "28743": "VOXLINE SC VOXLINE Communication S.R.L.",
    "28744": "TCIE- TELECITYGROUP INTERNATIONAL LIMITED",
    "28745": "SUTTK- Southern Urals TransTelecom Regional Office of TransTelecom Largest fiber-optic carrier ISP/P Chelyabinsk, Russia",
    "28747": "EYHOST-COLO- Easyhost BVBA",
    "28748": "ALPHACRON- Marc Pauls (AlphaCron Datensysteme)",
    "28749": "MSC- Mediterranean Shipping Company S.A.",
    "28750": "VINNEST- Vinnitsa Chamber of Commerce and Industry",
    "28751": "CAUCUS-NET- Caucasus Online Ltd.",
    "28752": "TTR ZAO Tatris Telecom",
    "28753": "LEEWEB-DE Leaseweb Germany GmbH",
    "28754": "CBS- Het Centraal Bureau voor de Statistiek",
    "28755": "HA-VEL-TRANSIT- ha-vel internet s r.o.",
    "28756": "EPO- European Patent Office",
    "28757": "N-SCOTNET Scotnet",
    "28759": "UBISOFT- Ubisoft GmbH",
    "28760": "INFOTECH-AT- Infotech EDV-Systeme GmbH, Austria",
    "28761": "SCIENTIFIC-INDUSTRIAL_ENTERPRISE_MYST Scientific-Industrial Enterprise \"Myst\" LLC",
    "28762": "AWAX- AWAX Telecom Ltd",
    "28763": "NOBEL Nobel Romania S.R.L.",
    "28764": "CSERV Communication Services SRL",
    "28765": "SCANNET-NETWORK- ScanNet A/S",
    "28766": "OGLNIK- Oglasnik d.o.o.",
    "28767": "SECSERVIZI- Sec Servizi S.c.p.A",
    "28768": "XSALTO- XSALTO",
    "28769": "STTK- Closed Joint Stock Company SibTransTelecom",
    "28770": "IGEPA- igepa papertec GmbH",
    "28771": "VIE- Flughafen Wien AG",
    "28772": "BANIFTEC-N Baniftec Limited",
    "28773": "MTER-SERVICE- Global Technology Ukraine Ltd",
    "28775": "TTCNET OAO TRANSTELECOM",
    "28776": "SOFTSERVE- SoftServe Ltd.",
    "28777": "CREDICOM Emporiki Credicom Bank S.A.",
    "28779": "NEMI-CAI- North of England Microelectronics Institute",
    "28780": "PCMS- The PCMS Group Plc",
    "28781": "EST- Asseco See Teknoloji",
    "28782": "N-VISTORM-02 Vistorm Ltd Secondary",
    "28783": "NETAFIM- Netafim LTD",
    "28784": "OKB-TELECOM- OKB-TELECOM OJSC",
    "28785": "UNIZETO Unizeto Sp. z o.o.",
    "28786": "N-INSL Endava Managed Services Ltd",
    "28787": "BAKINTER- Baktelekom",
    "28788": "UNILOGICNET- Unilogic Networks B.V. Autonomous System",
    "28789": "ROMSOFT Romsoft SA",
    "28790": "MEGABANK- MEGABANK PJSC",
    "28791": "N-BANKADATI Bankadati Servizi Informatici S.p.A.",
    "28792": "PUBLIC-INTERNET Public Internet Ltd",
    "28793": "OFI Atlantic Fund Services Sp.z.o.o.",
    "28794": "GTS-CE- GTS Hungary Telecommunications Limited Liability Company",
    "28795": "ELKEM- Elkem",
    "28797": "KOSMAN-COM- Technical University of Koszalin",
    "28798": "TRAFFIC-WALES Traffic Wales",
    "28799": "OMNITECH Omnitech",
    "28800": "N-MIREA State Educational Institution of Higher Professional Education \"Moscow State Institute of a Radio engineering, Electronics and Automatics\" (MIREA)",
    "28801": "HRS Hotel Reservation Service Robert Ragge GmbH",
    "28802": "KALMYKIA- OJSC Rostelecom",
    "28803": "-OPTRIXLV Optrix Ltd.",
    "28804": "UKMA- National University Kievo-Mohylanska Academia",
    "28805": "N-ITACERVICE Itaca Service S.p.A.",
    "28806": "KLMNET- Koninklijke Luchtvaart Maatschappij N.V.",
    "28809": "NAUKANET- LLC \"Nauka-Svyaz\"",
    "28810": "WHO- World Health Organization",
    "28811": "TOMUTA-DANIEL-PERSOANA-FIZICA-AUTORIZATA TOMUTA DANIEL PERSOANA FIZICA AUTORIZATA",
    "28812": "JSCBIS- OJSC \"Bashinformsvyaz\"",
    "28813": "VECERNJI- Vecernji list d.d.",
    "28815": "LERKINS-MNT Lerkins Group Sp.z o.o.",
    "28816": "ABEL Abel & Co (Scotland) Ltd",
    "28818": "DTT-EUROPE- Deloitte Touche Tohmatsu Services Inc",
    "28819": "ECM-SOFIA E-COMMERA LIMITED",
    "28820": "INTERTEL- Eastern telecommunication Company AD",
    "28821": "TSL- Telecom Solutions Ltd Online, Kenya",
    "28822": "CREATIVITATE- CREATIVITATE RPM SRL",
    "28823": "N-SIG Sviluppo Italia Spa",
    "28824": "N-HIPERCOM Hipercom",
    "28825": "TELE21 Telecommunications 21 century LLC",
    "28826": "IHI-DK International Health Insurance danmark a/s",
    "28827": "FORTIS-INTERNET- Fortis Bank  in Belgium",
    "28828": "CA- CA Haustechnik-Handelsgesellschaft mbH",
    "28829": "NOMOS- Open Joint-Stock Company NOMOS-BANK",
    "28830": "BTSAU-ISP- Bilotcerkivskiy National Agrarian University",
    "28831": "PHOENIX- Phoenix Informatica srl",
    "28832": "MKS-CHEL- CJSC \"COMSTAR-regions\"",
    "28833": "EILATINTER- Eilat Inter Ltd. Internet Provider in Eilat",
    "28834": "TA-GRX-AT A1 Telekom Austria AG",
    "28835": "MEDIADATA- Oberoesterreichische Media Data Vertriebs- und Verlags GmbH",
    "28836": "IC-S-NL IC&S",
    "28837": "VM-DE-NET Vox Mundi LLC.",
    "28838": "ES- EasternSolutions",
    "28839": "N-UNOV United Nations Office at Vienna",
    "28840": "TATTELECOM- OJSC \"OAO TATTELECOM\"",
    "28842": "VELOXIA- acens Technologies, S.L.",
    "28843": "DAUTKOM- DauTKom TV",
    "28844": "SCHERINGALMAN- Schering Alman is the turkish subsidiary",
    "28845": "BSHTR BSH EV Aletleri San. ve Tic A.S",
    "28846": "CARLTONTV ITV PLC",
    "28847": "SE-TEKNIKPARK Soderhamn NARA AB",
    "28848": "UNIDO- United Nations Industrial Development Organization",
    "28849": "N-GLOBALONEBEL-CORE GlobalOneBel JSC",
    "28850": "ZZZS-SI-N Zavod za zdravstveno zavarovanje Slovenije",
    "28851": "FORTECH-CZ Fortech s.r.o.",
    "28852": "ERICSSON-M2M-INET- Telefonaktiebolaget L M Ericsson",
    "28853": "RAIFFEISEN- Raiffeisen Bank SA",
    "28854": "NAVABNET-SWEDEN SavMAN AB",
    "28855": "GALACSYS- GalacSYS is an hosting and managed services provider",
    "28857": "CSC- CSC Computer Sciences Consulting Austria GmbH",
    "28858": "LECOS Lecos Online Ltd.",
    "28859": "ZUGERNET- acdalis informatik ag",
    "28860": "PARMA-INFORM- OJSC Rostelecom",
    "28861": "NEWEDGE- Newedge UK Financial Ltd",
    "28862": "INA-HR- INA Industrija nafte, d.d.",
    "28863": "THALES-TTLS Thales Transport and Security Ltd",
    "28864": "GUSGROUP- GUS Group AG & Co. KG",
    "28865": "N-SEKERBANK SEKERBANK T.A.S.",
    "28867": "SIEMENS-IT-SOLUTIONS-AND-SERVICES-IRELAND- ATOS IT SOLUTIONS AND SERVICES LIMITED",
    "28868": "NETGIRE- NETg Ireland Distance Learning Company",
    "28870": "PLUSINFO- PlusInfo Ltd",
    "28871": "INFOGLOBAL- *********************************",
    "28872": "N-ITLS Spacegate Ltd.",
    "28873": "NAFTEX-BG- Petrol Holding AD",
    "28874": "BLERMEDIENGRUPPE- National Zeitung und Basler Nachrichten AG",
    "28876": "SUEC-DACOR- suec // dacor GmbH",
    "28877": "AZURIA- Azuria",
    "28878": "SIGNET- Signet B.V.",
    "28879": "SATURN-MEDIA- Media-Saturn group",
    "28880": "NEXTLAYER-1 Next Layer Telekommunikationsdienstleistungs- und Beratungs GmbH",
    "28881": "BHNET- \"BashTelecomService\" Limited Company",
    "28883": "SAMLINK- Oy Samlink Ab",
    "28884": "MR-SIB-MTS MTS OJSC",
    "28885": "OMANTEL-NAP- OmanTel NAP",
    "28886": "OPTRON- SIA \"OPTRON\"",
    "28887": "PORTPC PortPC Autonomous System",
    "28888": "DTT-NL- Deloitte Group Support Center",
    "28889": "LINZNET- LinzNet Internet Service Provider GmbH",
    "28890": "INSYS- INSYS JSC",
    "28891": "CITTEL CJSC City Telecom",
    "28892": "CUZK-NET Cesky urad zememericky a katastralni",
    "28893": "TRECOM- TRECOM SP. Z O.O.",
    "28896": "28896-DATAGROUP PRIVATE JOINT STOCK COMPANY \"DATAGROUP\"",
    "28897": "ETWARDCAPITAL- \"Eastward Capital\" LLC",
    "28899": "URIIT- Autonomous Institution of the Khanty-Mansi Autonomous Okrug Ugra \"Ugra Research Institute of Information Technology\"",
    "28900": "ATLNN- STC 'Atlas'",
    "28902": "BIGPOINT BIGPOINT GmbH",
    "28903": "SEON- SEON, Kyiv, Ukraine",
    "28904": "SKYNET- SkyNet a.s.",
    "28905": "BECOLINK- BECO Link,spol.s.r.o.",
    "28906": "TTKNN-1 CJSC TransTelecom-NN",
    "28907": "MIROHOST Internet Invest Ltd.",
    "28908": "T3 Telecom3 Sverige AB",
    "28909": "BG-TVSAT- TV SAT NET",
    "28910": "INTAL-N \"Uzbektelekom\" Joint Stock Company",
    "28912": "OLMA- OAO Investment Firm Olma",
    "28913": "CADBURY-EGYPT-",
    "28914": "WIRENINE- Cloud9 Communications Ltd",
    "28915": "ICCNET- ICCnet, Cameroon",
    "28916": "ILO-NET- International Labour Organization",
    "28917": "FIORD- JSC \"TRC FIORD\"",
    "28918": "DETDSRZ4 TDS Informationstechnologie AG",
    "28919": "STWKUFSTEIN- Stadtwerke Kufstein GmbH",
    "28921": "NTXN- National Traffic eXchange Network Autonomous System",
    "28922": "TELECALL Digit One LLC",
    "28924": "INTEGRITY-HU- INTEGRITY Informatics Ltd.",
    "28925": "SIGMOFT SIGMA SOFT SRL",
    "28926": "DONTELE- Telenet LLC",
    "28927": "MAYAK- Telecom Ltd",
    "28928": "SZKB- Schwyzer Kantonalbank",
    "28929": "DD- DD srl",
    "28932": "GFK- GFK SE",
    "28933": "LTFE- University of  Ljubljana, Faculty of Electrical Engineering",
    "28934": "MIZUHO- Mizuho International PLC",
    "28935": "ODEC-ES- ODEC, CENTRO DE CALCULO Y APLICACIONES INFORMATIC, S.A.",
    "28936": "NIK- Nik.Ru LTD",
    "28937": "ENERGIT- ENERG.IT SpA",
    "28938": "MEDUNET- Sultan Bin Abdulaziz Foundation Program for",
    "28939": "ARM- ARM Ltd",
    "28940": "GTZ- Deutsche Gesellschaft fuer Internationale Zusammenarbeit (GIZ) GmbH",
    "28941": "ONE2NET-  for ONE2NET, Uganda",
    "28942": "DATAVERKET- Foreningen Dataverket",
    "28943": "ATLC- Autostrada Telecomunicazioni S.p.a.",
    "28944": "ITXC-DE 1441 Carrie-Derick",
    "28946": "BITR BANCA ITALO ROMENA SPA ITALIA TREVISO SUCURSALA BUCURESTI",
    "28947": "INTURAL- CJSC \"InT\"",
    "28949": "TUSNET- Technical University of Sofia",
    "28950": "ZSZIK- AGENCJA RESTRUKTURYZACJI I MODERNIZACJI ROLNICTWA",
    "28951": "ATNET- Atnet d.o.o. Koper",
    "28952": "DATHARE- Datashare, Teleccomunication Services",
    "28953": "PIRAEUSBANK Piraeusbank S.A.",
    "28954": "HUDIKSVALL- Hudiksvalls stadsnat",
    "28955": "SAMPOEE- Danske Bank A/S Estonia branch (Sampo Pank)",
    "28958": "TRINEC- TRINEC Autonomous System",
    "28959": "VITOL- Vitol London Ltd.",
    "28960": "DREI-BANKEN- Drei-Banken-EDV GmbH",
    "28961": "RSC- RSC Retail Services & Co Ohg",
    "28962": "UNREN- Ukrainian National Research and Education Network",
    "28963": "IPNG-UK- IPNG",
    "28964": "ORIONTELEKOMTIM- Orion Telekom Tim d.o.o.Beograd, Nehruova 93A",
    "28965": "TRK5- OJSC Teleradiocompany \"Petersburg\"",
    "28966": "INETON INETON RETELE DE COMUNICATII S.R.L.",
    "28967": "FIBABANKA- FIBABANKA ANONIM SIRKETI",
    "28968": "EUT- EUT IP Network",
    "28969": "AB-VSILOPOULOS- AB Vassilopoulos SA",
    "28970": "TRANSRS- OOO TransRadioService",
    "28971": "MEDIAFUSION-ES- MEDIAFUSION ESPANA, S.A.",
    "28972": "MSOFT- M-SOFT s.r.o.",
    "28974": "INFOSYSUA- Information Systems LLC",
    "28975": "MTB- PJSC MARFIN BANK",
    "28976": "HORDA UAB Horda",
    "28977": "UN-UNLB United Nations Logistics Base",
    "28978": "COIG- Centralny Osrodek Informatyki Gornictwa S.A.",
    "28979": "FILIADATA- Filiadata Informationssysteme fuer den Handel GmbH",
    "28980": "KTC- KUBTELECOM Ltd.",
    "28981": "ETM- Styria Multi Media GmbH & Co KG",
    "28982": "E-WRO E-WRO Autonomous System",
    "28983": "ACB- Open Joint-Stock Company \"Capital Merchant Bank\"",
    "28984": "ZHKS- Dezelna Banka Slovenije d.d.",
    "28985": "TESOSTANJ- TERMOELEKTRARNA SOSTANJ d.o.o.",
    "28986": "LOUDNCLEAR Loud-n-Clear Ltd.",
    "28987": "ZAJIL-WP- GulfNet KSA",
    "28988": "FLUXYS- Fluxys Belgium sa",
    "28989": "EXPOBANK- KB EXPOBANK",
    "28990": "MOLDDATA- MoldData",
    "28991": "ZABCOMNET- OAO Russian Railway",
    "28992": "ZUUUM- ZUUUM Autonomous System Number ES",
    "28993": "NETVAULTING- EuroTrust NetVaulting A/S",
    "28994": "SITEL- ISP SITEL",
    "28995": "ANTHOS- Anthos Amsterdam",
    "28996": "IMPULS- Impuls",
    "28997": "NEDCOMP- Nedcomp Hosting B.V.",
    "28998": "MONTEPIO-GERAL-PT- Caixa Economica Montepio Geral",
    "28999": "SIPORTAL- Siportal Srl",
    "29000": "SENSYS- Sensor Systems Limited Company",
    "29001": "DMA- DMA Computer Services",
    "29003": "REFERTELECOM- Refer Telecom",
    "29004": "N-BIT BIT ISP",
    "29005": "PROXIMUS- Belgacom S.A.",
    "29006": "POBOX- POBox Hosting Limited",
    "29007": "PETROTEL- Petrotel Sp. z o.o.",
    "29008": "NIEDERMAYR F.A.N.-Internet Service GmbH",
    "29009": "UKBROADBAND- UK Wireless Broadband Network",
    "29010": "KNET- Asknet AG",
    "29012": "SCANA- Scana LTD",
    "29013": "LINKKREMEN- Telecommunication company \"Link Telecom\" LTD",
    "29014": "INTERNET4YOU internet4YOU GmbH & Co. KG",
    "29015": "KRKA-N KRKA, d.d., Novo mesto",
    "29016": "PEARSON- Pearson Shared Services Ltd",
    "29017": "GYRON ====",
    "29018": "WEBCONTROL- SmartTERRA GmbH",
    "29019": "MORNINGSTAR-EUROPE Morningstar Europe Limited",
    "29020": "OFOGHNET- Mortabet Rayaneh Ofogh",
    "29021": "ECC-HU- ECC Hungary Ltd.",
    "29022": "CAJACANTABRIA- Global network of Caja Cantabria",
    "29023": "RABEN- Raben Management Services Sp. z o. o.",
    "29024": "BALLOU- Ballou Internet Services AB",
    "29026": "CTAYLOR- Charles Taylor Consulting PLC",
    "29027": "SIMPLY- Simply primary  number",
    "29028": "COMPUKOS- DirectVPS B.V.",
    "29029": "KNPC- Kowait National Petroleum Company",
    "29030": "TELECABLE- SA Telecable",
    "29031": "LTC Lugansk Telephone Company",
    "29032": "DATANET-UG DATANET LLC",
    "29033": "N-MEDIUS Eckoh UK Limited",
    "29034": "ONET- \"Nascha Merezha\" LTD",
    "29036": "N-NOTARTEL Notartel S.p.A.",
    "29037": "TELIKO- Teliko gmbh",
    "29038": "PARLIAMENT-UG Parliament of Uganda",
    "29039": "AFRICAONLINE-UG Africa Online Uganda",
    "29040": "AFSAT-UG Afsat Communications Uganda, Ltd.",
    "29041": "INFOCOM-UG Infocom, Ltd.",
    "29042": "HERMES- Hermes Europe GmbH",
    "29043": "SIPGATEWAY- LLC SipGateway",
    "29044": "IFINFOCOM- Ivano-Frankivsk Infocom LLC",
    "29045": "ITACTION IT Action Limited",
    "29046": "RBK- Radiobaylanys LLP  Number",
    "29047": "N-STACKLTD Stack Ltd. Autonomous System",
    "29048": "EQUIDUCT Equiduct Systems Limited",
    "29049": "DELTA-TELECOM- Delta Telecom LTD.",
    "29050": "TERRECABLATE Terrecablate Reti e Servizi S.R.L.",
    "29051": "ELES- Elektro - Slovenija, d.o.o.",
    "29052": "LYCOS- INFORM P. LYKOS A.E",
    "29053": "TELENET-JSC- Telenet Ltd.",
    "29054": "29054 NSE Global N",
    "29055": "PRODIGY- Prodigy N",
    "29056": "GSTW- Citycom Telekommunikation GmbH",
    "29057": "TEX- Texas Instruments France S.A.",
    "29058": "CIO-IOC International Olympic Committee (IOC)",
    "29060": "ALKIM- Alkim Basin Yayin Iletisim Ltd. STI.",
    "29061": "SAIMANET- Saimanet Telecomunications",
    "29062": "VOKS- VOKS Ltd.",
    "29063": "ATOSORIGIN- Atos Nederland B.V.",
    "29065": "ALLIANSE-BRD-N EVRY",
    "29066": "VELIANET- velia.net Internetdienste GmbH",
    "29067": "UATLD- Hostmaster LLC",
    "29068": "UT- University of Tehran Informatics Center",
    "29069": "TLK- Morton-Telekom Ltd",
    "29071": "RU-ISKRANET- ISKRA R&D Corporation",
    "29072": "RDTC- Regional Digital Telecommunication Company",
    "29073": "ECATEL- 29073, Ecatel Network",
    "29074": "FAUST-N FAUST ISP LTD.",
    "29075": "IELO- IELO Main Network",
    "29076": "CITYTELECOM- Filanco LTD",
    "29077": "GCYB- Gulf Cyberian Trading LLC",
    "29078": "GE-HU- GE Hungary Ipari es Kereskedelmi Kft",
    "29079": "IRNA- IRNA",
    "29080": "BULBANK- Unicredit-Bulbank-AD",
    "29081": "WVNET-AT- WVNET Information und Kommunikation GmbH",
    "29082": "BARTOLINI- Bartolini S.p.A.",
    "29083": "DE-WORLDBONE- Webplus24 GmbH",
    "29084": "COMNET- Comnet Bulgaria Holding Ltd.",
    "29085": "PORSCHE- Porsche Informatik GmbH",
    "29086": "GITY- G-NET",
    "29088": "SCALEON- Bayer Business Services GmbH",
    "29089": "PBS- Post Bank of Slovenia Ltd.",
    "29090": "55555 PIX, Palestinian Internet Exchange , this node will route all",
    "29091": "IPNXng",
    "29092": "NEXTIRAONE-FR Nextiraone Europe B.V.",
    "29093": "FINGRID Fingrid Oyj",
    "29094": "MEDIOLANUM- Banca Mediolanum S.p.A.",
    "29095": "CYBIC- National Taras Shevchenko University of Kyiv",
    "29096": "B_LITE_TELECOM- B.Lite Telecom SPRL/BVBA",
    "29097": "HOSTPOINT- Hostpoint AG, Switzerland",
    "29098": "IPSO- IPSO S.R.L.",
    "29099": "EY-COMM Easy Comm S.R.L.",
    "29100": "BROADCOMDK Sagitta ApS",
    "29101": "INTER-TRADE- Inter-trade LLC",
    "29102": "UPC-NET PJSC Ukrainian Processing Center",
    "29103": "GSR Gdanska Stocznia \"Remontowa\" im. J.Pilsudskiego S.A.",
    "29104": "THALESGROUP- Thales Services S",
    "29105": "BARMENIA- Barmenia Krankenversicherung a.G.",
    "29106": "VOLGAHOST- PE Bondarenko Dmitriy Vladimirovich",
    "29107": "SYNAPSE- Open JSC \"Stock company \"Sater\"",
    "29109": "MEDIOSAVANZADOS- Medios Avanzados de Calculo y Diseno",
    "29110": "PTEUR- Institut Pasteur",
    "29113": "SLOANE- UPC Ceska Republica, s.r.o.",
    "29115": "N-DOMINET-BANK Dominet Bank SA",
    "29116": "CSTU- Chernihiv State Technological University",
    "29117": "IRC-HISPANO Asociacion IRC Hispano",
    "29118": "WURTH- WURTH FRANCE S.A.",
    "29119": "SERVIHOSTING- ServiHosting Networks S.L.",
    "29120": "ROWEMAW- Mayer Brown International LLP",
    "29121": "CANKARJEVDOM- Cankarjev dom",
    "29122": "IWET- i-Wet Ltd",
    "29123": "SOTELGUI- Societe Des Telecommunications De Guinee",
    "29124": "SU29- ISP \"Gorcom\"",
    "29125": "TATINT- Tatintelcom Inc Autonomous System Russia",
    "29126": "DATIQ- Datiq B.V.",
    "29127": "GECAPITAL-IT GE Capital Servizi Finanziari S.p.a",
    "29128": "DSIP- Digital Service Ltd",
    "29129": "VISPA-N Vispa Internet Limited",
    "29130": "CORNEL- PE Cornel Communications",
    "29131": "RAPIDSWITCH- Iomart",
    "29132": "IWNET- Our company name is Oy IW-Net Ltd. located at Kuopio at central Finland.",
    "29134": "IGNUM- Ignum s.r.o.",
    "29136": "RIMBLACKBERRY- Research In Motion UK Limited",
    "29137": "EUTELSAT- EUTELSAT SA",
    "29139": "SCL-  from Safmarine Container Lines NV",
    "29140": "HOSTSERVER- Autonomous System Hostserver GmbH",
    "29141": "BKVG- Bradler & Krantz GmbH & Co. KG",
    "29143": "MAGAZ- Magistrat Graz",
    "29144": "VOB-TR Vadeli Islem ve Opsiyon Borsasi A.S.",
    "29145": "CENTAUR-GMBH- CENTAUR GmbH Internet Service Provider",
    "29146": "UAIC- IT Consulting Group LTD",
    "29147": "NSTU- State Educational Enterprise of Higher Professional Education Novosibirsk State Technical University",
    "29148": "SURANY SURANY.NET s.r.o.",
    "29149": "AMSALEM- Amsalem Tours & Travel Ltd.",
    "29150": "ALCANET Alcatel-Lucent International S",
    "29152": "DECKNET- DECKNET",
    "29153": "E-SIGN- E-SIGN, Str. General David Praporgescu 1-5",
    "29154": "ACADEMICA- Academica Oy",
    "29155": "SICS- Swedish Institute of Computer Science (SICS)",
    "29156": "CSC-SWEDEN CSC Sweden",
    "29159": "SECURINFOR- SECURINFOR",
    "29160": "ACIS- Arabcircle Internet Services for Saudi Arabia",
    "29161": "VERBUNDAT- Verbund Management Service GmbH",
    "29162": "TEXNOPOLIS Technopolis SA",
    "29163": "BANCAINTESA_BEOGRAD-  number will be used for PI address space of this Bank",
    "29164": "TITAN- Titan Internet Ltd",
    "29165": "ARIDOR- Aridor Communications Ltd",
    "29166": "NZZ- Neue Zuercher Zeitung AG",
    "29167": "ELNET- El-Net S.A. Regional Telecommunication Operator, Cable Television Operator",
    "29169": "GANDI- Gandi S",
    "29170": "KUJTESA- Kujtesa Net Sh.p.k.",
    "29171": "NETCONNECT NET-CONNECT INTERNET S.R.L",
    "29172": "RADTEL- Radio - Telecommunications Iran Administration Tehran, Iran",
    "29173": "MARKETS-RU- MARKETS-RU",
    "29174": "N-IATEL Asia Telecom Co., Ltd.",
    "29176": "LISIT-CRS-SISS- Lombardia Integrata S.p.A.",
    "29177": "COTLC- Asco TLC S.p.A.",
    "29178": "PHONONET- Phononet GmbH",
    "29179": "KIBRISONLINE- Kibrisonline Ltd.",
    "29180": "O2-ONLINE- Telefonica UK Limited",
    "29181": "UKRANEWS TOV Information Agency 'Ukrainian News'",
    "29182": "ISPSYSTEM- ISPsystem Autonomous System",
    "29183": "BUDACH- Buda-Cash Brokerhaz Zrt",
    "29184": "CNPADC- Cassa Nazionale di Previdenza e Assistenza per i Dottori Commercialisti",
    "29185": "RINGIER Ringier Romania s.r.l",
    "29186": "DIATEK- Innovative company \"Diatek\" LLC",
    "29187": "POLESYENET TOV ORTA Polesye",
    "29189": "AXAOYAK-TR- AXA Holding A.S",
    "29190": "OVERTA- CJSC \"Comstar-Regions\"",
    "29191": "UAI- JSC Uralaviainform",
    "29192": "VNG- VNG-Verbundnetz Gas Aktiengesellschaft",
    "29193": "ADSYS- ADSystems Autonomous System",
    "29194": "N-TVT Television Radio Company \"TBT\" OJSC",
    "29195": "SKGMI- North-Caucasian Institute of Mining and Metallurgical",
    "29196": "UCSNET- Universal Communication Systems",
    "29197": "LEHMAN-3 Nomura International Plc",
    "29198": "SCHENKER- Schenker und Co. AG",
    "29199": "ESCP-EUROPE- ESCP EUROPE",
    "29200": "SIMSL- Steamship Insurance Management Services",
    "29201": "GESA- netplusFR SA",
    "29202": "EMPICS PA Sport UK Ltd",
    "29203": "BITUA House Information Technology Ltd.",
    "29204": "B3G- B3G Telecom backbone",
    "29205": "VIDEOHIT- Videohit Ltd",
    "29207": "SHIRE-UK- Shire Pharmaceuticals Group PLC",
    "29208": "DIALTELECOM- Dial Telecom, a.s.",
    "29209": "SPBMTS- MTS OJSC",
    "29210": "INTERNEWS-BG Internews 98 OOD",
    "29211": "INTERGAME Intergame-Holding, Ltd.",
    "29212": "SYNETRIX- Synetrix Ltd.",
    "29213": "GULAN- Neonet Ltd",
    "29214": "HOUSES-OF-PARLIAMENT HOUSES OF PARLIAMENT",
    "29215": "SH Smart Holding",
    "29216": "I-ROOT NETNOD Internet Exchange i Sverige AB",
    "29217": "WM-DATA Logica AB",
    "29218": "HTK- HiTeKnowledge Ltd",
    "29219": "SAQ-UK- SEMTEC Limited",
    "29220": "MARTINSSON Martinsson Informationssystems AB",
    "29221": "CUHE- AvivaSA Emeklilik ve Hayat A.S.",
    "29222": "INFOMANIAK- Infomaniak Network SA",
    "29223": "KDPW- Krajowy Depozyt Papierow Wartosciowych",
    "29224": "HELLMANN Hellmann Worldwide Logistics GmbH & Co KG",
    "29225": "TAIF-TELCOM- \"MTS\" OJSC",
    "29226": "MTERTEL- CJSC Mastertel",
    "29227": "DRQ- Asseco Poland S.A.",
    "29228": "KP- KP Autonomus System",
    "29229": "DA- Anaptiksiakos Sindesmos Ditikis Athinas",
    "29230": "BIOCHIM- Biochim AD - Commercial Bank",
    "29231": "GRUPALIA- Grupalia Internet S.A.",
    "29232": "N-PAI Powszechna Agencja Internet S.A.",
    "29233": "IIP-NET-29233 \"UMOS CENTER\" LLC",
    "29234": "N-WESTLUCKY Zahidna Merezha Uspihu ISP",
    "29235": "BANK-BPH- Bank BPH S.A.",
    "29236": "SCHWEICKERT-DE-WDF- Schweickert Netzwerktechnik GmbH",
    "29237": "TETRA- TETRA ISP & ITSP company",
    "29238": "NISATEL Nisatel sh.p.k.",
    "29239": "I-NETPARTNER- I-NetPartner GmbH",
    "29240": "LANWAN- Nordic LAN & WAN Communication, Finland",
    "29241": "DI- Dias S.A.",
    "29243": "MMD- MMD Networks Oy",
    "29244": "GLOBULBG- Cosmo Bulgaria Mobile EAD",
    "29245": "PL-REYU-NET REYU.COM Rafal Reinert",
    "29246": "OPTILIAN- OPTILIAN SARL",
    "29247": "COSMOTE-GR Cosmote Mobile Telecommunications S.A.",
    "29248": "INTERSAT- Intersat Ltd., Plovdiv, Bulgaria,",
    "29249": "SIGMA- Auditorska firma \"Audit Consalting\" LLC",
    "29250": "CPSPERM- Centre of Special Communication and Information of the Federal Security Service of the Russian Federation in the Perm region",
    "29251": "SCANIA-NET- SCANIA POLSKA S.A.",
    "29252": "ODR-TKG- ODR Technologie Services GmbH",
    "29254": "ZE-WALBRZYCH- ZAKLAD ENERGRTYCZNY WALBRZYCH S.A.",
    "29255": "ZAJIL- GulfNet KSA",
    "29256": "INT-PDN-STE- Syrian Telecommunications Establishment",
    "29257": "CBB-IE- Connexion by Boeing Ireland, Ltd.",
    "29258": "JETINFO- CJSC Jet Infosystems",
    "29259": "DE-IABG-TELEPORT IABG mbH",
    "29260": "NETLANTIS Autonomus System for NetLantis RouteServers",
    "29261": "PITO1- Police Information Technology Organisation (PITO)",
    "29263": "HAAGNET- HAAGnet, Municipality of The Hague network",
    "29264": "UAISC- Autonomous system of Information Security Center Ltd., Ukraine",
    "29265": "DNSEUROPE- DNS Europe Ltd",
    "29266": "DANMARKS-RADIO- DR",
    "29267": "RO-QUEST Quest Communication SRL",
    "29268": "BULSTAR- BulStar 2000 Ltd. , Bulgaria",
    "29269": "INNOVATECMALAGA2005- CLOUDGLOBAL FRANCE S",
    "29270": "TRISKEL- Triskel srl",
    "29271": "MOSTCOM- JSC \"Mostcom PK\"",
    "29272": "WARTA- Towarzystwo Ubezpieczen i Reasekuracji WARTA S.A.",
    "29273": "IUS-SW-N IUS SOFTWARE d.o.o.",
    "29275": "MIRATECH- Miratech Ltd.",
    "29276": "MOBITEL-GPRS Telekom Slovenije, d.d.",
    "29277": "DIGITONE-VT- Digit One - VostokTelecom",
    "29278": "DENINET-HU- Deninet KFT",
    "29280": "Steria Denmark Data Center",
    "29282": "ENFO-FI- Enfo Oyj",
    "29283": "ADP-TELECOM- HUB TELECOM SA",
    "29284": "CREDITLYONNAISE-  for Credit Lyonnaise Group Management",
    "29285": "AMTMGTS- AMT closed joint-stock company Russia Moscow",
    "29286": "SKYLOGIC- SKYLOGIC S.P.A.",
    "29287": "AT-WZN- Wien Energie GmbH",
    "29289": "FOURENET- 4Enet Corp. Moskovskaya str.",
    "29290": "ALPHAMEGA Alphamega Autonomous System",
    "29291": "N-E-IX Patrick Koehne",
    "29293": "LUOTTOKUNTA- Luottokunta",
    "29294": "OPERATELECOMKAZAN Opera Telecom ltd.",
    "29295": "NORTHGATE-IS Northgate Information Solutions UK Limited",
    "29296": "AIOS- Amt fuer Informatik und Organisation des Kantons Solothurn",
    "29297": "LINKCONNECT- Linkconnect services Ltd, UK Business to business ISP",
    "29298": "29298 SUSE LINUX GmbH",
    "29300": "DIRECTCONNECT- Direct Connect",
    "29301": "KARAVEL- KARAVEL S",
    "29302": "HSI-EUROPE Hosting Services Inc",
    "29303": "PIC- PermInterCom Ltd",
    "29304": "SATISNET- JSC SATIS-TL-94",
    "29305": "OF-PL- OF.PL SP. Z O.O.",
    "29306": "INTESA-SANPAOLO- BANCA COMERCIALA INTESA SANPAOLO ROMANIA S.A.",
    "29307": "QUESSE- QS Telemed Sr",
    "29308": "SIEMENS Siemens AG",
    "29310": "JAWWAL Jawwal",
    "29311": "P4ALL-NL P4all Hosting B.V.",
    "29312": "COMUNEMILANO- Comune di Milano",
    "29313": "LEXMARK Lexmark International S.A.S.",
    "29314": "VECTRANET- VECTRA S.A.",
    "29316": "OH22- oh22systems GmbH",
    "29317": "SLZ- s-lz.net",
    "29318": "WINCANTON-PL- Raben Polska sp. z o.o.",
    "29319": "N-IMSYS Informational-measuring systems Ltd",
    "29320": "N-RGC-SAT Closed Joint Stock Company \"RGC Satellite Service\"",
    "29321": "CENTRONET Centronet, a.s.",
    "29322": "STREAMWIDE- The company STREAMWIDE located in Paris, France",
    "29324": "N-ROEON S.C. Wolters Kluwer S.R.L",
    "29325": "UZ-GOV-UA State Enterprise \"Main Information-Calculating Center of the State Administration of the Ukrainian Railway\"",
    "29328": "N-TMOBILEUK T-Mobile (UK) Limited",
    "29329": "NODEX- NODEX Fiber Optic Network Saint-Petersburg, Russia",
    "29330": "NEXTLAYER-2 Next Layer Telekommunikationsdienstleistungs- und Beratungs GmbH",
    "29331": "FDC-NETWORK Forsikringens Datacenter A/S",
    "29332": "FORRESTER-NL- Forrester Research Netherlands",
    "29333": "NORDAC- Capgemini Outsourcing Services GmbH",
    "29334": "PRNET-TR Prnet Halkla iliSkiler AraS. ve DeGer. Hiz. A.S.",
    "29335": "RADAUA Verkhovna Rada",
    "29336": "TEXNIKA1- JSC Technika",
    "29337": "DRAGONET- Dragonet Comunicaciones",
    "29338": "safaribet",
    "29339": "MBBG- Markus Bach Betriebs GmbH",
    "29340": "AFOL-GH",
    "29341": "WELDE- wel.de Gesellschaft fuer Internetdienste mbH",
    "29342": "KIYAVIA- CJSC Kiyv Agency of Air Services 'Kiy Avia'",
    "29343": "AKVANET Akvanet Ltd.",
    "29344": "SCHLYTER Jakob Hermansson Schlyter",
    "29345": "MISSION-TIC-CR-CENTRE MISSION TIC CONSEIL REGIONAL CENTRE",
    "29346": "HARDSOFTWAREHAUS viventu Systemhaus GmbH",
    "29347": "ECOFIS- ECOFIS GmbH",
    "29348": "FSNET- FSNET",
    "29350": "IRPOST-QOM Iran Post Company",
    "29351": "STO-NETWORK-HG zonepro france",
    "29353": "TITAN TITAN CEMENT COMPANY S.A.",
    "29354": "PCE-NET-N PCE-NET GmbH",
    "29355": "KCELL- \"KCell\" JSC",
    "29356": "NESTLE Nestle Operational Services Worldwide SA",
    "29357": "WATANIYATELECOM- WATANIYA TELECOM",
    "29358": "DBAP- dbap GmbH",
    "29359": "MEDIACOMSAT- JSC Web Media Services",
    "29363": "DALMATOVO- OOO 'RUS'",
    "29366": "AIIDATAPRO- AII Data Processing OOD",
    "29367": "RMS- RMS Radio Marketing Service GmbH & Co. KG",
    "29368": "EGN- Egnatia Finance",
    "29372": "SFR-NETWORK SFR",
    "29373": "WEISSDRUCK- Weiss-Druck GmbH & Co. KG",
    "29374": "ADRIATIC- Adriatic Zavarovalna druzba d.d.",
    "29375": "TDB- Technics for Business Ltd.",
    "29376": "WESTPORTAL- WestPortal Ltd.",
    "29378": "EUROTAX- EurotaxGlass's International AG",
    "29379": "MERMAID-CONSULTING- Mermaid Consulting ApS",
    "29380": "DWMS DWMS Direkt Werbung und Media Service",
    "29381": "INET- Internet Service Provider",
    "29382": "DIAWEST- Diawest end kompleksni rishennya Ltd.",
    "29383": "ACTELION-CH Actelion Pharmaceuticals Ltd.",
    "29384": "Qatar Foundation for Education, Science and Community Development",
    "29385": "BUZTON-JV- BUZTON J.V.",
    "29386": "EXT-PDN-STE- Syrian Telecommunications Establishment",
    "29387": "EUROWEBMALTA GO p.l.c.",
    "29388": "N-BESTCOM Best Telecom ISP",
    "29389": "UNIAN- Ukrainian Independent Information News Agency Ltd.",
    "29390": "CTU- NetAssist LLC",
    "29391": "COMPUWARE- Compuware Limited",
    "29392": "DNC- Dagestan Science Center",
    "29393": "CLUEFULCOLO- Noam Freedman",
    "29394": "OEKONET-1 Oeko.net Mueller & Brandt GbR",
    "29395": "WEBQUAKE- Webquake eBusiness Consulting GmbH",
    "29396": "UNET Unet Network, The Netherlands",
    "29397": "HP-WEBVAULT Hewlett-Packard Outsourcing Espana SL",
    "29398": "PETROBALTIC Lotos Petrobaltic Spolka Akcyjna",
    "29399": "RAMTEK- Ramtek Telekomunikasyon Hizmetleri Sanayi Ve Ticaret Limited Sirketi",
    "29400": "TULLETT- Tullett Prebon Group Ltd",
    "29401": "GCTIBERICA- GLOBAL CONSULTING TOUCH IBERICA",
    "29402": "DNS Digital Netcom",
    "29403": "DK-EUROTRUST VeriSign Inc.",
    "29404": "ELBRACHT-COMPUTER- ELBRACHT Autonomous System",
    "29405": "VNET- VNET a.s. Bratislava, Slovakia, SK",
    "29406": "O2-UK- O2 UK",
    "29407": "N-SIBSUTIS GOU WPO \"Siberian State University of Telecommunication And Informatics\"",
    "29408": "GAH- Gustav Alberts GmbH & Co. KG",
    "29410": "MAARIV- Maariv-Modiin Publishing house LTD",
    "29411": "N-ETI ETI S.p.A.",
    "29412": "APEX-MGN- OJSC \"APEX\"",
    "29413": "KOMRO- komro GmbH",
    "29414": "N-BIAMAN-COM Politechnika Bialostocka",
    "29416": "N-CODALIS Codalis SA",
    "29419": "ALMAVIVA Almaviva S.p.A.",
    "29420": "NLINE- NLine LLC",
    "29421": "DCI- Digital Communications Incorporated Ltd.",
    "29422": "NBLNETWORKS- Nebula Oy",
    "29424": "JATODYNA-  for Jato Dynamics Ltd",
    "29425": "SAKHCOM- Sakh.com LLC",
    "29426": "CONNECTO- CJSC Connecto",
    "29427": "AZM- Mercury Auto Aggregate Plant Co.Ltd.",
    "29428": "EGYPTNETWORK-",
    "29429": "ALLIANZAT- Allianz Elementar Versicherungs AG",
    "29430": "AXCP Audatex (Schweiz) GmbH",
    "29431": "PEKINPEKIN- Pekin & Pekin Law Firm, www.pekin-pekin.com",
    "29432": "TREX- TREX Regional Exchanges Oy",
    "29434": "DENIZBANK Denizbank A.S.",
    "29435": "IPOWER- @iPower N.V.",
    "29436": "N-IMPERIAL The private businessman Buryanov Konstantin Volodimirovich",
    "29437": "NCH- NCH Advisors INC. Wilmington sucursala Bucuresti",
    "29438": "MOMAX- MOMAX S.r.l.",
    "29439": "N-CPUA PP Contour Plus",
    "29440": "KRONOS-NED- Kronos Development B.V.",
    "29442": "INETCOM- Internet Communications LLC",
    "29443": "MEGATC- PP Technical Company Mega",
    "29444": "REFLEX- Burstfire Networks Ltd",
    "29445": "BSB-N Bazy i Systemy Bankowe Sp. z o.o.",
    "29446": "CHUNKYCHIPS- ChunkyChips.net Limited",
    "29447": "TIF- ONLINE S.A.S.",
    "29448": "OPTILINK Optilink N",
    "29449": "TPN- TopneT Telecomunicazioni S.r.L.",
    "29450": "ATL-NW- Federal State Unitary Enterprise CenterInform",
    "29451": "NET-SERWIS- Net-Serwis Sp. z o. o.",
    "29452": "SECURA- Secura Hosting Ltd",
    "29453": "TELEKOM-MPLS Telekom Montenegro mpls network",
    "29454": "MOBILE Mobile.international GmbH",
    "29455": "COMCOR-HOSTING  for Moscow Telecommunication Corporation (COMCOR)",
    "29456": "BELSVYAZ- OJSC Rostelecom",
    "29457": "OPTIONS- Options Technology Ltd.",
    "29458": "TECH-DATA- Tech Data Polska",
    "29459": "N-AGCM Autorit. Garante della Concorrenza e del Mercato",
    "29460": "ADEPT- HalmstAdept AB",
    "29462": "DSD- DSD Automatisering B.V.",
    "29463": "DATALINE- DataLine Multihomed Colocation",
    "29464": "FILMAC-ES- FILMAC Centre SL",
    "29465": "VCG- VGC Communication Ltd.",
    "29466": "VID- Valsts Ienemumu Dienests",
    "29467": "N-LUXNETWORK LUXNETWORK S.A.",
    "29468": "INFRACOM PIN Sweden AB",
    "29469": "GTU Global Technology Ukraine Ltd",
    "29470": "RUBYCOM- CJSC \"RetnNet\"",
    "29471": "WEBJANSSEN-DE WebJanssen ISP ltd & Co KG",
    "29472": "ADDICT-  of Addict Networks",
    "29473": "DATALINE-COMPUTERS DATA LINE COMPUTER SA",
    "29474": "GHOTI- Ghoti Limited",
    "29475": "CCS-ODESSA Complex Communication Systems Ltd",
    "29476": "OOO-TELEKOM-HOLDING- OOO \"Telecom-Holding\"",
    "29477": "ETCOMM- East Telecom Autonomous System",
    "29479": "CLUSTERTECH-NO- Clustertech Group",
    "29480": "N-CCN CC Network Inc",
    "29481": "JCYL- Junta de Castilla y Leon Autonomous System",
    "29482": "DETALEE- Detalee Trade",
    "29483": "OMYWITZERLAND OMYA",
    "29484": "RUB- Ruhr-Universitaet Bochum",
    "29485": "AMISHR Amis Telekom d.o.o",
    "29486": "WEBHUSET- Webhuset Datasenter",
    "29487": "PFIZERSWITZERLAND- Pfizer Manufacturing Deutschland GmbH",
    "29488": "CCN  of ccn",
    "29489": "TMOTION- T-Mobile (UK) Limited",
    "29490": "ITNETPLC- Serco Group PLC",
    "29491": "TERABIT TERABIT LLC",
    "29492": "EIDSIVA-N Eidsiva bredband",
    "29493": "GRIDPNPI Federal State Budget Institution Petersburg Institute of Nuclear Physics of B.P. Konstantinov",
    "29494": "MESSE-DUESSELDORF- Messe Duesseldorf GmbH",
    "29495": "C-",
    "29496": "LINK-SERVICE- Link-Service Ltd.",
    "29497": "KUBANGSM Mobile TeleSystems Open Joint Stock Company",
    "29498": "MAJAR- PC Majar-2",
    "29499": "VECTOR- Vector-Info, OOO",
    "29500": "SWISSRE- Schweizerische Rueckversicherungs-Gesellschaft AG",
    "29501": "NFZ-POZ Narodowy Fundusz Zdrowia",
    "29503": "RATMIR-MOSCOW- Ratmir KDS",
    "29504": "TWININGS Twinings N Andover",
    "29505": "TRAVEKOM- TraveKom Telekommunikationsgesellschaft mbH",
    "29506": "SE-RTRS-1 Network to deliver Reuters Online information.",
    "29507": "WHEELSLOGISTICS WHEELS Logistics GmbH & Co. KG",
    "29508": "TANAT- TANAT LLC",
    "29510": "INTERNETT- internett GmbH",
    "29511": "LUCKYNET- FOP Kryvosheenko Vitalij Oleksandrovitch",
    "29512": "TVK-WROC- TVK Tel-Ka Wroclaw",
    "29513": "INITIALSONLINE Acropolis Telecom SA",
    "29514": "INFOTEL- Info-tel Communication S.r.l.",
    "29515": "HZD- Hessische Zentrale fuer Datenverarbeitung",
    "29516": "CORKBIC- The Software Development Centre Limited",
    "29517": "REGISTRAR- Registrar",
    "29518": "BREDBAND2 Bredband2 AB",
    "29519": "AOIS- Atos Nederland BV",
    "29520": "ROSINTEL- Locked Joint Stock Company OGANER-SERVICE",
    "29521": "CIDR- Movenix International Inc.",
    "29522": "KEI Krakowskie e-Centrum Informatyczne JUMP",
    "29523": "CONET Asconet N",
    "29525": "VIRTUALMTER- Virtualmaster, s.r.o.",
    "29526": "RRC- Federal State Educational Institution of Higher Professional Education \"Saratov state Socio-Economic University\"",
    "29527": "TUTIUM- Astutium Limited",
    "29529": "ITECOM-N iTecom bvba",
    "29530": "TRUSTINTEL Trustintel Autonomous System",
    "29531": "VM- VM Telecom, s.r.o.",
    "29532": "ITH-VIX Virtual Internet Xchange",
    "29533": "FREEBIX FreeBIX VZW / BL",
    "29534": "ITUA- IntornTechnic, Ltd",
    "29535": "TPIX Telekomunikacja Polska S.A.",
    "29536": "EUROBANK- Eurobank S.A.",
    "29538": "LINKOTEL- LINKOTELUS, UAB",
    "29539": "BOGAZICI- Bogazici Bilgisayar A.S.",
    "29540": "REMOTEDESKS-N Remote Desks Limited",
    "29541": "TXNET ISP TXNET autonomous system, Lviv, Ukraine",
    "29542": "DANSKETELECOM- Zen Systems A/S",
    "29543": "RINGSTAD- Ringstad Consulting ENK",
    "29544": "MAURITEL",
    "29545": "IPLACE iPlace Internet & Network Services GmbH",
    "29546": "ECOMIT- ECom-IT Limited",
    "29548": "VIRCONN- Virtual Connection Lda",
    "29549": "ZIRAATBANK- T.C. Ziraat Bankasi A.S.",
    "29550": "SIMPLYTRANSIT Simply Transit Ltd",
    "29551": "HGCOMP-N Aixit GmbH",
    "29552": "CUBESYS- SC CUBE PROGRAMS & SYSTEMS SRL",
    "29553": "VLINE- Virtual Line",
    "29554": "SVYAZNOY ZAO \"Svyaznoy Logistika\"",
    "29555": "ALTEL- ALTEL CDMA cellular provider",
    "29556": "VARIANT6-NOC Variant6 AD - PA Space",
    "29558": "HOSTALIA acens Technologies, S.L.",
    "29559": "QUARTSOFT- QuartSoft Ltd.",
    "29560": "ILL- Industrie Logistik Linz GmbH und Co KG",
    "29561": "PROTEK- ZAO Firma Center Vnedreniya Protek",
    "29562": "KABELBW-N Kabel BW GmbH",
    "29563": "ELTERIXPL-NET Elterix S.A.",
    "29564": "N-ITALDATA Italdata S.p.A",
    "29565": "ONETOOLTD One Too Ltd",
    "29566": "N-INNETWORK InNetwork San Benedetto D.Tronto (AP)",
    "29567": "SITENETWORK- Site LLC",
    "29568": "COMTEL- SYSNET SECURE S.R.L.",
    "29569": "ERGO- Ergo Insurance Company",
    "29570": "STC-NET PE Sven Callender",
    "29571": "CITelecom-",
    "29572": "GIMAX- IPport ZAO",
    "29573": "DNESTRNET- ITMaster LLC",
    "29574": "VNTU- Vinnytsia National Technical University",
    "29575": "LONDSTOCK-  for London Stock Exchange",
    "29576": "POISK-UA PP \"Poisk-Lugansk\"",
    "29577": "IUT- Isfahan University of Technology",
    "29578": "GLOBALPROOF- GlobalProof s.a.r.l.",
    "29579": "SW-SERVICE- \"SW SERVICE\" Ltd.",
    "29580": "HOMELAN- MOBILTEL EAD",
    "29581": "U State Educational Institution",
    "29582": "SATCOM- Optisprint",
    "29583": "UNIENT- Spinoco Czech Republic, a.s.",
    "29584": "AZEDUNET- AZEDUNET LLC",
    "29585": "MALAWINET Malawi.Net",
    "29587": "SCHEDOM- Schedom Vof",
    "29588": "IVSTARNET- Ivstar Ltd",
    "29589": "INTERSTAR- ISP InterStar",
    "29590": "DIGITALUS- Digitalus Internet Services B.V.",
    "29591": "NETAPP-EMEA- NETAPP Holding and Manufacturing BV",
    "29592": "FOGBG- \"Centrum group-Europe\" EOOD",
    "29593": "ENDOR- WOJCIECH LOREK ENDOR COMPUTERS",
    "29594": "NETWORKSTUDIO- Network Studio SARL",
    "29595": "IPGLOBAL IPG Global Care&Contact Center",
    "29596": "GENERACJA- Telekomunikacja Internetowa Sp. z o.o.",
    "29597": "X-NETWORK- X-Net Ltd",
    "29598": "RAVDA- Regione Autonoma Valle d'Aosta",
    "29599": "ZNTU- Zaporizhzhe National Technical University",
    "29600": "LATVENERGO- Latvenergo",
    "29601": "UPM-KYMMENE- UPM-Kymmene Oyj",
    "29602": "WWWGBG- PIN Sweden AB",
    "29603": "CAPITAL-KREDIT-RU- Commercial Bank \"Capital Kredit\", Ltd",
    "29604": "VTKOM Orion Telekom Tim d.o.o.",
    "29605": "BCS BCS Technologies SA",
    "29606": "BORWOOD-UK- Borwood UK Network",
    "29607": "SYSTEMNET-NO- SystemNet",
    "29608": "WAN2MANY- Absolight",
    "29609": "ITC- Istituto Trentino di Cultura",
    "29610": "VERSATEL-BREISNET Versatel Deutschland GmbH",
    "29611": "ELITE- Elite Limited",
    "29612": "PRISANET- Promotora de Informaciones SA",
    "29613": "IDEENKAPITAL- Ideenkapital Financial Services Holding",
    "29614": "GHANATEL-",
    "29617": "EWB-NET Energy Water Bern",
    "29618": "KORONA- Korona Ltd",
    "29619": "LMS-TELECOM- Lenmontazhstroy-Telecom CJSC",
    "29620": "TAMI- P.H.U. TAMI - Wojciech Sterna",
    "29621": "A11- A11, Vladivostok",
    "29622": "ICONBG- ICON Ltd",
    "29624": "KRICK-TECHNOLOGIC- Krick Technologic GmbH -",
    "29625": "ELEKTA- Elekta",
    "29626": "STAFFSCC Staffordshire County Council",
    "29627": "SAB-N Saechsische Aufbaubank - Foerderbank",
    "29628": "ROMPETROL- Rompetrol S.A.",
    "29629": "INETWORK- DIGITALVOX s.a.r.l.",
    "29630": "AZRENA- Azerbaijan Research and Educational Networking Association (AzRENA)",
    "29632": "NSIST- NetAssist LLC",
    "29633": "KELAG-AT-  for Kaerntner Elektrizitaets AG",
    "29634": "ADBRU- ADB.RU, Ltd.",
    "29635": "BANVIT- BANVIT-BANDIRMA VITAMINLI YEM SANAYI A.S.",
    "29636": "CATALYST2- Catalyst2 Services Ltd",
    "29637": "DFC- Digital Fiber Communications Ltd.",
    "29638": "VIKA- CJSC NAMITEC",
    "29639": "EUROCENTER- EUROCENTER GAMES SARL",
    "29640": "COMNED Network Management Development Organisation BV",
    "29641": "ALLIANZ- Allianz Suisse Versicherungs-Gesellschaft AG",
    "29642": "CITY-NET- CityNet sp. z o.o.",
    "29643": "KBENDLOS- kb-endlos Kroiss and Bichler GmbH",
    "29644": "AIRSPEED- AirSpeed Communications Ltd.",
    "29645": "SMAF- SMAF DINU COM SRL",
    "29646": "FFTFILL- FFastfill UK Limited",
    "29647": "HINA- Hrvatska izvjestajna novinska agencija",
    "29648": "COMLINE- OJSC MegaFon",
    "29649": "LIMES- LIMES s.c.",
    "29650": "HOSTING365- Sungard Availability Services (Ireland) Ltd.",
    "29651": "CTCS OJSC \"RT Labs\"",
    "29652": "NTI- SC Different Media SRL",
    "29653": "ELPOINFORMATYKA-NET- Elpoinformatyka Sp. z.o.o.",
    "29654": "BACKBONE- backbone internet service GmbH - Autonomous System",
    "29655": "TRENKA Trenka Informatik AG",
    "29656": "CCBILL-EU PHOENIX NAP, LLC.",
    "29657": "N-6NETWORK Last-Mile Ltd.",
    "29658": "HEURECOM- HeureCom GmbH",
    "29659": "STAYCLOSE- StayClose N",
    "29660": "MACSF- Mutuelle Assurances Corps Sante Francais",
    "29661": "ANCERT- AGENCIA NOTARIAL DE CERTIFICACION S.L",
    "29662": "TRANSAT- Transat JSC Autonomous System",
    "29663": "SNU Olga Soroka",
    "29664": "RGCOM-VANCO-HAI Reliance Globalcom Limited",
    "29665": "SPEED-SOFT- Speed-Soft Andrzej Pomesny",
    "29666": "TRHENKEL Turk Henkel Kimya Sanayi",
    "29667": "ATLANTISNET- Atlantis NET Network",
    "29668": "QUBE Qube Managed Services Limited",
    "29669": "GEMEDICAL GE Medical Systems Societe en Commandite Simple",
    "29670": "IN-BERLIN- Individual Network Berlin e.V.",
    "29671": "SERVAGE Servage GmbH",
    "29672": "STEK- S:t Erik Kommunikation AB",
    "29673": "IMPRENSANACIONAL-PT- Imprensa Nacional-Casa da Moeda, S.A.",
    "29674": "GSTA-",
    "29676": "GRADWELL Gradwell dot com Limited",
    "29677": "ILS- IMTECH ICT Austria GmbH",
    "29678": "XARANET XaraNet",
    "29679": "N-EXPANSION Groupe Express-Roularta",
    "29680": "VOZTELECOM VozTelecom Network",
    "29682": "LBANK-DE-KA- Landeskreditbank Baden-Wuerttemberg - Foerderbank",
    "29683": "CMS-VSMU- Vinnica State Medical University of M.I.Pirogov",
    "29684": "NOURNET-N Nour Communication Co.Ltd - Nournet",
    "29685": "OK-NET-UA Aplha Oil Ltd.",
    "29686": "PROBENETWORKS- Probe Networks",
    "29687": "BGWAN- Geodim Ltd.",
    "29688": "VOSTOKLTD VOSTOK Ltd.",
    "29689": "SKYGGNIR- Nyherji hf",
    "29690": "ATHEER Atheer Jeraisy Autonomous System",
    "29691": "NINE Nine Internet Solutions AG",
    "29693": "IMMT Private Enterprise A2",
    "29694": "SNVC- SNVC ltd. autonomous system",
    "29695": "LYSE- Altibox",
    "29696": "ECARTHAGE - Carthage Water and Electric",
    "29698": "INVESTOOLS - INVESTools Inc",
    "29699": "DS-LVEG - Dataside, LLC",
    "29700": "CYPRESS-SEMICONDUCTOR - Cypress Semiconductor",
    "29701": "CUTCO-NETWORK - Cutco Corporation",
    "29702": "VCB - Virginia Commerce Bank",
    "29704": "PTSY - Power & Telephone Supply Company",
    "29705": "MOTIVE-COMMUNICATIONS-INCORPORATED - MOTIVE,  INC.",
    "29706": "MIXEDSIGNAL - Mixed Signal Solutions",
    "29707": "MATCU - Orion Federal Credit Union",
    "29708": "FINANCIAL-SECURITY-SURANCE - Assured Guaranty Corp",
    "29709": "NEONET - Northeast Ohio Network for Education Technology",
    "29710": "BUNCOMBECOSCHOOLS - Buncombe County Schools",
    "29711": "MAPLE-FINANCIAL - Maple Financial",
    "29712": "GALAXY - FiservGALAXY 2000 Division",
    "29713": "ELIA-60 - Reliable Hosting Services",
    "29714": "NAHB-RESEARCH-CENTER - NAHB Research Center",
    "29715": "LCCC - Laramie County Community College",
    "29716": "NOTS - Otsuka America Pharmaceutical, Inc.",
    "29717": "OMEDA-SPRINT - Omeda Communications",
    "29718": "TNEMEC- - Tnemec Company Incorporated",
    "29719": "XTIVA - Xtiva Financial Systems, Inc.",
    "29720": "PDS - Paragon Development Systems, Inc",
    "29721": "CSHS-ELSEGUNDO - Cedars-Sinai Health Systems",
    "29722": "PHX-IX - Phoenix Internet Exchange LLC",
    "29723": "CENTRO-INSPECTION - Centro Inspection Agency",
    "29724": "CITINTERNET - CIT Internet",
    "29725": "CONSENSUS-SFO - Consensus Corp.",
    "29726": "VONAGE-02 - Vonage Holdings, Inc.",
    "29727": "N-BAY-VIEW - Bayview Technologies, LLC.",
    "29728": "N-BUDGETPHONE - BUDGET PHONE",
    "29729": "TELEFLORA-OKC - Teleflora LLC",
    "29730": "NOVOLINK - NovoLink Communications, Inc. - Houston",
    "29731": "ING-BANK-OF-CANADA---MULTI-HOMED - ING Bank of Canada",
    "29733": "USFOOD - US FOODSERVICE INC.",
    "29734": "IAP-CHARLOTTESVILLE - International Auto Parts Inc.",
    "29735": "FSU-RES - Florida State University",
    "29736": "DWS-ORL - Disney Worldwide Services, Inc.",
    "29737": "WOW-INTERNET - WideOpenWest Finance LLC",
    "29738": "C7-DATA-CENTERS-N-2 - C7 Data Centers, Inc.",
    "29739": "NEO2 - Neopolitan Networks",
    "29740": "SSI-BGP4 - Schaefer Systems International",
    "29741": "RADIANT-CAL - Radiant Communications Corp. (Alberta)",
    "29742": "DDS-BUR - Deluxe Digital Studios, Inc.",
    "29743": "NO-2-BYTE--NUMBER - Apptix, Inc.",
    "29744": "UTMA - United Telephone Mutual Aid Corporation",
    "29745": "WILSON- - Wilson Tool Enterprises, Inc.",
    "29746": "S3PL-N - S3 Partners LLC",
    "29747": "PRSD-N - Prairie Rose School Division No. 8",
    "29748": "CARPATHIA-N Carpathia Hosting",
    "29749": "ECFCU-INTERNET - EMPIRE CORPORATE FCU",
    "29750": "SIBCYCLINE-COM - Sibcy Cline",
    "29751": "ST-CLAIR-CO-MICHIGAN - SAINT CLAIR COUNTY",
    "29752": "-INDIECLICK - IndieClick Media Group, Inc.",
    "29753": "BROISDTXN - Brownsville Independent School District",
    "29754": "GO2TEL GO2TEL.COM INC.",
    "29755": "SOUTHWEST-DISPATCH-CENTER - Southwest Dispatch Center",
    "29756": "RPE - RPE Outsourcing",
    "29757": "WEBLINE19 - Webline Services Inc",
    "29758": "WATC-1 - West Alabama T.V. Cable Company, Inc.",
    "29759": "OXFORD-INDUSTRIES - Oxford Industries",
    "29760": "M2-CONNECTIONS - M2 Connections",
    "29761": "OC3-NETWORKS--NUMBER Web Africa Proxy aut-num object",
    "29762": "29762 - Emergent Networks",
    "29763": "JMC- - Jason Malacko Consulting",
    "29764": "-MISI - Municipal Information Systems, Inc.",
    "29765": "DATACHAMBERS - Data Chambers, LLC",
    "29766": "CHSPSC-29766 - Community Health Systems Professional Services Corporation",
    "29767": "COMMERCE-BANCSHARES - Commerce Bank",
    "29768": "MWLLC - MOFFATT WIRELESS LLC",
    "29770": "RCICORP - ROWAN COMPANIES, INC.",
    "29771": "EXPRESS-LLC-PUBLIC - Express LLC",
    "29772": "MYSTROTV - Mystro TV",
    "29773": "CARLETON-U - Carleton University",
    "29774": "POVN - Pend Oreille Valley Network",
    "29775": "WESTERN-STATES-ENVELOPE-CO - Western States Envelope Co",
    "29776": "LRRANET - Lubbock Reese Redevelopment Authority",
    "29777": "YOURSITERIGHT - Manage Your Site Right",
    "29778": "GLIQ - Global IntelliSystems",
    "29779": "OPOLISMEDIA - Opus Creative Group",
    "29780": "WOW-INTERNET-CLV - WideOpenWest Finance LLC",
    "29781": "ECPI- - ECPI Colleges, Inc.",
    "29782": "VIDEOJET-TECHNOLOGIES - Videojet Technologies",
    "29784": "GREENLIGHT-CAPITAL - Greenlight Capital",
    "29785": "MTRX-PDX - Matrix Networks",
    "29786": "ABRAMSCAPITALMANAGEMENTLLC - Abrams Capital Management, LLC",
    "29787": "WEBFORCE - Web Force Systems",
    "29788": "GYM-SOURCE-NJ - Gym Source, Inc.",
    "29789": "REFLECTED - Reflected Networks, Inc.",
    "29790": "NEW-LIBERTY-HOSPITAL - New Liberty Hospital District of Clay County, Missouri",
    "29791": "VOXEL-DOT-NET - Voxel Dot Net, Inc.",
    "29792": "NETAPP--2 - NetApp, Inc.",
    "29793": "BRIDGE-3640-N - Broadview Networks, Inc.",
    "29795": "LATISYS-DENVER - Latisys-Denver, LLC",
    "29796": "MARKETTOOLS-INC - MarketTools Inc.",
    "29798": "HIGHWINDS5 - Highwinds Network Group, Inc.",
    "29799": "WANLINK-CHIGAGO - Guggenheim Services LLC",
    "29800": "WANLINK-NEWYORK - Guggenheim Services LLC",
    "29801": "BRUNDAGE-MANAGEMENT-COMPANY - Brundage Management Company, Inc.",
    "29802": "HVC- - HIVELOCITY VENTURES CORP",
    "29803": "ESCO-TECH - ESCO Technologies, LLC",
    "29804": "VALU-NET - Valu-Net LLC.",
    "29805": "OGILVYNA - The Ogilvy Group, Inc.",
    "29806": "EMERGIS--3 - Emergis Inc.",
    "29807": "SYLLO - Syllogisteks",
    "29808": "AKL-4-HOUSTON - Andrews & Kurth L.L.P.",
    "29810": "ITCAN- - Imperial Tobacco Canada Ltd.",
    "29811": "SCHOLTIC-INC - Scholastic Inc.",
    "29812": "ONEZERO - One Zero Hosting Inc.",
    "29813": "WNB - Woodforest National Bank",
    "29814": "JH-N - Jupiter Hosting Corporation",
    "29815": "N-LP - Latigo Partners, LP",
    "29816": "SWA-MKT-INET-2 - Southwest Airlines Co.",
    "29817": "LCB-ARIN-113 - LAKE CITY BANK",
    "29818": "RHAPSODY - Rhapsody International, Inc.",
    "29819": "MIS124 - Natural Networks, Inc.",
    "29820": "-CEDROM - Cedrom-Sni Inc.",
    "29821": "EFCU-INET - Elevations Credit Union",
    "29822": "ARCHER1 - Archer and Greiner",
    "29823": "PBC-WA - Premera Blue Cross",
    "29824": "RRC-INTERNET - RUSS REID COMPANY",
    "29825": "IIT-NETWORK- - Illinois Institute of Technology",
    "29826": "JH-N - John Hancock Life Insurance Company (U.S.A.)",
    "29827": "BROCADE-NMS - Brocade Communications Systems, Inc.",
    "29828": "ANIXTER-INC - ANIXTER INC.",
    "29829": "BTSINCUSA - Bancomer Transfer Services",
    "29830": "WWSC - Worldwide Security",
    "29831": "FONENET - FONE NET, LLC",
    "29832": "METTLER-TOLEDO-AM-NOC-N - Mettler-Toledo, Inc.",
    "29833": "MEDICAL-INFORMATICS-ENGINEERING - MEDICAL INFORMATICS ENGINEERING",
    "29834": "USTREAM Ustream Inc.",
    "29835": "NSS-CA - New Skies Satellites, Inc.",
    "29836": "11420 - Tribune Company",
    "29838": "AMC - Atlantic Metro Communications",
    "29839": "REGISTRYPRO RegistryPro - DNS registry for .pro gTLD",
    "29840": "GRAM-NET2 - Grambling State University",
    "29842": "ETSU-NET - East Tennessee State University",
    "29843": "FIVEA-1 - FIVE AREA SYSTEMS, INC",
    "29844": "SENAWAVE - Sena Wave LLC",
    "29845": "DAVISMALM-N - Davis Malm & D'Agostine P.C.",
    "29846": "NITNETWORK - NITNETWORK",
    "29847": "SI-1 - Screws Industries, Inc.",
    "29848": "WCU-N - West Chester University",
    "29849": "-M9SYS - M9 Systems",
    "29850": "MHN- - Memorial Healthcare",
    "29851": "WARBURGPINCUS - E.M. Warburg, Pincus & Co. Inc.",
    "29852": "RSINVSAC001 - RS Investments",
    "29853": "L3HN - LOYAL3",
    "29854": "WESTHOST - WestHost, Inc.",
    "29856": "ACC- - Association of Corporate Counsel",
    "29857": "FIRM58 - Firm58, Inc.",
    "29858": "ONQ-COLODC-HOU01 - On Q Operating Company LLC",
    "29859": "WOW-INTERNET-ILL - WideOpenWest Finance LLC",
    "29860": "MYFLORIDAHOUSE - Florida House of Representatives",
    "29861": "SYNTAX - Syntax Systems Limited",
    "29862": "OFINA - Ontario Financing Authority",
    "29863": "LATISYS-DENVER - Latisys-Denver, LLC",
    "29864": "SPORTSMANS-WAREHOUSE - Sportsman's Warehouse, Inc.",
    "29865": "CONTREALTYCORP - Continental Realty Corporation",
    "29866": "OPTICALTEL - HCONTROL CORP",
    "29867": "FAIRFIELD-UNIVERSITY - Fairfield University",
    "29868": "DRW-HOLDINGS - DRW Holdings, LLC",
    "29869": "DOTBLOCK-3 - HostRocket.com, Inc.",
    "29870": "CCADE-NETWORKS-INCORPORATED - Cascade Networks Incorporated",
    "29871": "N-SCAD - Savannah College of Art and Design",
    "29873": "BIZLAND-SD - The Endurance International Group, Inc.",
    "29875": "CPLSW- - Clinical Pathology Laboratories",
    "29876": "KUHNCOMM - KUHN.COMMUNICATIONS.COM, INC.",
    "29877": "STS-TELECOM--1 - STS TELECOM",
    "29878": "CHMP-N - Community Hospital of the Monterey Peninsula",
    "29879": "RBDIS80 - RB Distribution Inc",
    "29880": "STELLARISHEALTH - Stellaris Health Network",
    "29882": "-ATLANTABROADBAND - @tlanta Broadband, Inc.",
    "29883": "-IHS - Internet Hosting Servers",
    "29884": "EQUINIX-MA-DA1 - Equinix, Inc.",
    "29885": "UCHHS- - Univeristy of Chicago Hospitals & Health System",
    "29886": "ESVBA-N1 - Eastern Shore of Virginia Broadband Authority",
    "29887": "GOODRICH - Goodrich Quality Theaters, Inc",
    "29888": "UNUMGROUP- - Unum Group",
    "29889": "FSNET-1 - Fast Serv Networks, LLC",
    "29890": "CARCO - Carco Group, Inc.",
    "29891": "NCCWO-N1-VZBLVL3CMCST - National Cable Communications LLC",
    "29892": "BLUELOCK - BlueLock, LLC",
    "29893": "CHATANGO - Chatango LLC",
    "29894": "COMPS-GLOBAL - Compass Global INC",
    "29895": "WOW-INTERNET-COL - WideOpenWest Finance LLC",
    "29896": "INNOVATIVE-INTERFACES-INC-2 - Innovative Interfaces, Inc.",
    "29897": "ATG-COMMUNICATIONS-LLC - ATG Communications, LLC",
    "29898": "MONEYGRAM-INTERNATIONAL-INC - MoneyGram International Inc",
    "29899": "GEISINGER - Geisinger System Services",
    "29900": "GTMCNET - GLENWOOD TELEPHONE MEMBERSHIP",
    "29901": "MECK-COUNTY-INET - Mecklenburg County, NC",
    "29902": "COMPLETE-COMPUTERS - Complete Computers",
    "29903": "WRLC- - Washington Research Library Consortium",
    "29904": "THEBOE-29904 - The Boeing Company",
    "29905": "BAIN-CAPITAL - Bain Capital LLC",
    "29906": "WESTAT-1 - Westat, Inc.",
    "29907": "CIRRUS9-INC - Cirrus9 Inc.",
    "29908": "HOYA-NORTH-AMERICA - HOYA NORTH AMERICA",
    "29909": "LESSE - MetroOptic, Inc.",
    "29910": "IACP - INTL. SN OF CHIEF OF POLICEI",
    "29911": "XTIME-US - Xtime",
    "29912": "CITIZENS-PROPERTY-INSURANCE-CORPORATION - Citizens Property Insurance Corporation",
    "29913": "GEICO03 - GEICO",
    "29914": "MIDATL-3 - Economic Computer Systems Inc. dba Mid Atlantic Broadband",
    "29915": "STATEFARM-ISCE - State Farm Mutual  Automobile Insurance Company",
    "29916": "WFMU - WFMU",
    "29917": "KSC - Keene State College",
    "29918": "IMPOL-N",
    "29920": "SEQ001 - Sequent, Inc.",
    "29921": "SAIFCO - State Accident Insurance Fund Corporation",
    "29922": "SANFORD-AIRPORT-AUTHORITY - Sanford Airport Authority",
    "29923": "NPC--1 - Northland Pioneer College",
    "29924": "MONOGRAMBGP - Monogram Biosciences, Inc.",
    "29925": "OESUS - OnX Enterprise Solutions (US) Ltd.",
    "29926": "PT1-LSAN - PointOne",
    "29927": "CONCEPTUS - Conceptus, Inc.",
    "29928": "EDATA - Seisint, Inc.",
    "29929": "HCMLP-N1 - Highfields Capital Management LP",
    "29930": "TWRS-CBB - Towerstream I, Inc.",
    "29931": "SUPERIORBEVERAGEGROUP - Superior Beverage Group, Ltd.",
    "29932": "DANTOM-SYSTEMS - DANTOM Systems, Inc.",
    "29933": "OFF-CAMPUS-TELECOMMUNICATIONS - Off Campus Telecommunications",
    "29934": "NETACOM - Netadyne Networks, Inc.",
    "29935": "COTNET - City of Tampa, Florida",
    "29936": "GPREG - GPREG.COM",
    "29937": "CONEXIS - CONEXIS BENEFITS ADMINISTRATORS, L.P.",
    "29938": "MMSIN-1- - MMS International",
    "29939": "NSRFC- - Nova Scotia Research Foundation Corporation",
    "29940": "LORETTO-MANAGEMENT-CORP - Loretto Management Corp.",
    "29941": "TCCSA - Tri-County Computer Services Association",
    "29942": "TPLP - Tanger Properties Limited Partnership",
    "29943": "UNITEDSOLUTIONS - United Solutions Company",
    "29944": "LATISYS-HBURN - Latisys-Ashburn, LLC",
    "29945": "TALK-WIRELESS-INC - Internet Access Worldwide",
    "29946": "UNION-CELL - Union Cellular",
    "29947": "CCA - Connolly Consulting Associates Inc.",
    "29948": "EMPIRICAL-NET - Empirical Networks, Ltd.",
    "29949": "ADP-ICD - AUTOMATIC DATA PROCESSING-INVESTOR COMMUNICATION DIVISION",
    "29950": "ICI-TPA - Incomm",
    "29951": "SYPTEC-NOC - Syptec",
    "29952": "XVAND-ISUTILITY - Xvand Technology Corp.",
    "29953": "MORNCOMM - Cygnet Internet Services Inc",
    "29954": "JLL-AM-CHI - Jones Lang LaSalle, Inc.",
    "29955": "WHBURN-UNIVERSITY - Washburn University",
    "29956": "KOMEN - The Susan G. Komen Breast Cancer Foundation",
    "29957": "TRPC - TRIB TOTAL MEDIA, INC",
    "29958": "IPN-TELECOM-PHX - IPN Telecom, LLC",
    "29959": "UWCU-ORG-WI - University of Wisconsin Credit Union",
    "29960": "QUALTRICS-01 - Qualtrics LLC",
    "29962": "DWNI-B-NETWORK - Digital West Networks, Inc.",
    "29963": "MARYKAY-NA - Mary Kay Inc.",
    "29964": "MCCORMICK-AND-COMPANY - McCormick & Company Inc.",
    "29966": "MAILWELL-PRINT-DRS - MAILWELL PRINT",
    "29967": "ARAMARK-NS - ARAMARK",
    "29968": "N-NETSYNC - Dunkirk & Fredonia Telephone Company",
    "29969": "-PROTOCOL - Protocol",
    "29970": "DEVONCORP - Devon Energy Corporation",
    "29971": "CTRL-ALT-DEST - CTRL ALT Destination, Inc.",
    "29972": "MOREHOUSEMEDICAL - Morehouse School of Medicine",
    "29973": "CLICKACTION - Yesmail Inc",
    "29974": "WIGHT- - Wightman Telecom",
    "29975": "VODACOM-ZA",
    "29976": "NETSUITE-CORP - Netsuite Inc.",
    "29977": "DAZZEE- - Dazzee Integrations",
    "29978": "SCRIPTLOGIC - ScriptLogic",
    "29979": "PWN-BLK - Pioneer Broadband",
    "29980": "NEWWAVECOMM - New Wave Communications",
    "29981": "USTOY - US TOY",
    "29982": "AMR01 - American Airlines Inc.",
    "29983": "INTEGRATELECOM - Integra Telecom, Inc.",
    "29984": "WILLAMETTE - Willamette University",
    "29985": "AMN-HEALTHCARE - AMN Healthcare",
    "29987": "NEWCORP - N.E.W Customer Service Companies LLC",
    "29988": "IAI- - INTERNETWORKING ATLANTIC INCORPORATED",
    "29989": "URM-1 - URM Stores Inc",
    "29990": "N-APPNEXUS - AppNexus, Inc",
    "29991": "NTREIS - NTREIS",
    "29992": "VA-TMP-CORE - Department of Veterans Affairs",
    "29993": "NCC-23-N - North Central College",
    "29994": "ARGENTCOMM - Argent Communications, LLC",
    "29995": "TAXACT1 - 2nd Story Software, Inc.",
    "29996": "APORTER - Arnold & Porter",
    "29997": "NOIP Vitalwerks Anycast",
    "29998": "AZCOLO - ZoyAR Inc",
    "29999": "CONNAUGHT- - The Connaught Group",
    "30000": "KRAMERLEVIN-1 - Kramer Levin Naftalis & Frankel LLP",
    "30001": "TECHEVOLUTION - Techevolution",
    "30002": "ITSERVICES- - DDB WORLDWIDE - IT SERVICES",
    "30003": "FBLG-SUMMIT - Summit-Tech Multimedia Communications, Inc.",
    "30005": "CORENET-ET - Coretel America, Inc.",
    "30006": "DFKING - D. F. King & Co., Inc.",
    "30007": "ICI-CHI - Incomm",
    "30008": "COLOGUYS - ColoGuys, Inc.",
    "30009": "FAPS-INC - First American Payment Systems Inc.",
    "30010": "STUTMAN-TREISTER-AND-GLATT - STUTMAN TREISTER & GLATT",
    "30011": "ESCHOOL - eSchool Solutions, Inc.",
    "30012": "N-UMGGNS - Universal Music Group, INC.",
    "30013": "PIXAR- - Pixar",
    "30014": "BAIRD-AND-WARNER-REAL-ESTATE - Baird & Warner Real Estate",
    "30015": "PRAIRIEINET-MICROLNK - JAB Wireless, INC.",
    "30016": "01-NATC-4-NA - North American Telecommunications Corporation",
    "30018": "REDGAP-N - Red Gap Communications, Inc.",
    "30019": "PSBC - Puget Sound Blood Center and Program",
    "30020": "BENFIELD-2003N - BENFIELD HOLDINGS INC",
    "30021": "SNWL-COLO-SJL - SonicWALL, Inc.",
    "30023": "CYRUSONE-CIN - CyrusOne LLC",
    "30024": "-MNI - Market News",
    "30025": "CLC - College Loan Corporation",
    "30026": "WWD-INTERNET - Woodward, Inc.",
    "30027": "STINET-1 - S & T COMMUNICATIONS LLC",
    "30028": "MBNETSET - Manitoba NetSet Ltd.",
    "30029": "DOBSONTECHTTS - Dobson Technologies - Transport and Telecom Solutions, LLC",
    "30030": "SIMPLEXITY - Simplexity LLC.",
    "30031": "SWISSFONE- Swissfone",
    "30032": "GENESIS-TECHNOLOGY - GENESIS TECHNOLOGY COMMUNICATION, LLC",
    "30033": "CHI-BIGTEN-FOX - Big Ten Network, LLC",
    "30034": "VCS-N - The Vermont Country Store, Inc.",
    "30035": "HEAVENWIRE - Mobilcomm, Inc",
    "30036": "MEDIACOM-ENTERPRISE-BUSINESS - Mediacom Communications Corp",
    "30037": "FDCIPS4151EXEC - First Data Corporation - TPS",
    "30038": "N-OPERATIVE - Operative, Inc.",
    "30039": "SN4ENDO - Smith and Nephew - Endoscopy",
    "30040": "PIM-N - Pioneer Investment Management, Inc.",
    "30041": "RACE - Race Technologies, Inc.",
    "30042": "DIGIT - Digitas",
    "30043": "RBAND-30043 - Resort Broadband, LLC.",
    "30044": "DMIX - Dayton Metro Internet Exchange",
    "30045": "UHN-N - University Health Network",
    "30046": "EIC - Erie Indemnity Company",
    "30047": "SNAPFISH - Snapfish",
    "30048": "CONVERGIA-NET - Convergia Inc.",
    "30049": "METRO - Metropolitan Transit Authority",
    "30050": "MARATHON-SET - Marathon Asset",
    "30051": "SCCGOV - Santa Clara County",
    "30052": "WAYNE-CO-AIR-LDMI-SPRINT - Wayne County Airport Authority",
    "30053": "DUQUESNE-CAPITAL-MANAGEMENT-LLC - DUQUESNE CAPITAL MANAGEMENT LLC",
    "30054": "THE-COLLEGE-OF-WESTCHESTER - The College of Westchester",
    "30055": "CROSSLAKECOMMUNICATIONS - Crosslake Communications",
    "30056": "AVAILMEDIA - Avail Media",
    "30057": "SURFCONTROLSV-N - Websense, Inc",
    "30058": "FDCSERVERS - FDCservers.net",
    "30059": "ZIMCOM - Zimcom Network Solutions Inc.",
    "30060": "VERISIGN-ILG1 - VeriSign Infrastructure & Operations",
    "30062": "TTEMI-N - Tetra Tech EM Inc.",
    "30063": "DEDICONET - Dedico.com",
    "30064": "FRONTIER-FRTR - Frontier Communications of America, Inc.",
    "30065": "DIETZ-WATSON - Dietz & Watson, Inc.",
    "30066": "NCL-MIA1 - Norwegian Cruise Lines",
    "30067": "AACG- - Anne Arundel County Govt",
    "30068": "-SKYTRAC - SkyTrac Systems LTD",
    "30069": "VNU-CORALSPRINGS - VNU, Inc.",
    "30070": "HERSHEYFOODS1 - Hershey Chocolate & Confectionery Corporation",
    "30071": "OCCAID - TowardEX Technologies International, Inc.",
    "30072": "WESTEX-1 - Wes-Tex Telecommunications LTD",
    "30073": "NAMIT-N",
    "30074": "GLOBET-300S - Globetrotters Engineering",
    "30075": "LWSD414 - Lake Washington School District #414",
    "30076": "INHS-N - Inland Northwest Health Services",
    "30077": "VIBRANT-ANYC - Vibrant Media Inc",
    "30078": "HUNTELP - Hunt Building Corporation",
    "30079": "CHCM-BGP - Columbus Hill Capital Management, LP",
    "30080": "ARNOLD-MAGNETIC-TECHNOLOGIES-CORP-BGP - Arnold Magnetic Technologies Corporation",
    "30081": "CACHENETWORKS - CacheNetworks, Inc.",
    "30082": "QS1-DATA-SYSTEMS - QS1 Data Systems",
    "30083": "SERVER4YOU - Hosting Solutions International, Inc.",
    "30084": "SRI-CONSULTING-BUSINESS-INTELLIGENCE - SRI Consulting Business Intelligence",
    "30085": "ISOHUNT-NDC - isoHunt Web Technologies, Inc.",
    "30087": "APCO - Automobile Protection Corporation",
    "30088": "WHSD - Woodland Hills School District",
    "30089": "ETMANCU-KPT - Eastman Credit Union",
    "30090": "COMMUNITY-OK-74070 - Community Cable & Broadband, Inc.",
    "30091": "ACCESS-CABLE - Access Cable Television, Inc.",
    "30092": "SERTIVE-NETWORKS - SERTIVENET",
    "30093": "INFOADVISORY - Information Advisory Group",
    "30094": "GIGANEWS - Giganews, Inc.",
    "30095": "-30095 - Group M Worldwide, Inc.",
    "30096": "SAML-N - Serengeti Asset Management LP",
    "30097": "NUWAVE - NuWave",
    "30098": "INFB-N - Farm Bureau Insurance",
    "30099": "SB-2 - ServerBeach",
    "30100": "ATLWORLDGROUP- - Atlas Van Lines",
    "30101": "SPEEDBEAM-WIRELESS - SpeedBeam Wireless, Inc.",
    "30102": "BALDWIN - Baldwin County Commission",
    "30104": "GTELNET-1 - GTel Networks inc.",
    "30105": "NORTHROAD-CAPTIAL-MANAGEMENT - NorthRoad Capital Management",
    "30106": "ANCOR - Ancor Information Management",
    "30107": "JOHN-L-WORTHAM - John L. Wortham & Son, L.P.",
    "30108": "XTX-DALL - CROSSTEX ENERGY",
    "30109": "MEDALLIA-INC - Medallia Inc.",
    "30110": "ADVANCED-COMMUNICATIONS-TECHNOLOGY - Advanced Communications Technology",
    "30111": "COMMAUTO - Commonwealth Automobile Reinsurers",
    "30112": "ALTA-1828 - AMERICAN LAND TITLE SOCIATION",
    "30113": "DEMATIC-US - Dematic Corp.",
    "30114": "TRANSCOM-ES - Transcom Enhanced Services, LLC",
    "30115": "WIDEVOICE - WideVoice Communications, Inc.",
    "30116": "WNI-NORMAN - WEATHERNEWS AMERICA INC.",
    "30117": "CCV-EXPE- - Classic Vacations, LLC",
    "30118": "LFI-US-SOUTHWEST - Life Force International",
    "30119": "PLUM-SIERRA-TELECOMMUNICATIONS - Plumas Sierra Telecommunications",
    "30120": "SGNE- - Sempra Global",
    "30121": "24-7--IDC-001 - 24/7 Customer, Inc.",
    "30122": "ISC-GRU1 Internet Systems Consortium, Inc.",
    "30123": "ISC-YOW1 Internet Systems Consortium, Inc.",
    "30124": "ISC-SVO1 Internet Systems Consortium, Inc.",
    "30125": "ISC-DXB1 Internet Systems Consortium, Inc.",
    "30126": "ISC-CDG1 Internet Systems Consortium, Inc.",
    "30127": "ISC-MTY1 Internet Systems Consortium, Inc.",
    "30128": "KBP1 Internet Systems Consortium, Inc.",
    "30129": "ISC-LIS1 Internet Systems Consortium, Inc.",
    "30130": "ISC-YYZ1 Internet Systems Consortium, Inc.",
    "30131": "ISC-TLV1 Internet Systems Consortium, Inc.",
    "30132": "ISC-AMS1 Internet Systems Consortium, Inc.",
    "30133": "ISC-F- - Internet Systems Consortium, Inc.",
    "30134": "ISC-PRG1 Internet Systems Consortium, Inc.",
    "30135": "MSFT-30135 - Microsoft Corporation",
    "30136": "TOPSY - Topsy Labs, Inc.",
    "30137": "SEA-BROADBAND - Sea Broadband, LLC",
    "30138": "ARTECH-INFO - Artech Information Systems LLC",
    "30139": "UPM - UPM Telecom, Inc",
    "30140": "BXP-HQ - BOSTON PROPERTIES LIMITED PARTNERSHIP",
    "30141": "DEMOCRATIC-NATIONAL-COMMITTEE - Democratic National Committee",
    "30142": "24-7--IDC-002 - 24/7 Customer, Inc.",
    "30143": "BEKENG-N - BE&K Engineering Company, LLC",
    "30144": "BQI - BQ Internet Corporation",
    "30145": "SKYLIST - SKYLIST INC",
    "30146": "TIBCO - TIBCO Software Inc.",
    "30147": "ATRIA - Atria Networks LP.",
    "30148": "INVESTORSELECTADVISORS - INVESTORS SELECT ADVISORS",
    "30149": "FFN1-N - FOLIOfn, Inc.",
    "30150": "EXEGY - Exegy Inc.",
    "30151": "INNOVATIVEAIRN - InnovativeAir, LLC",
    "30152": "BEYOND-HOSTING - Beyond Hosting, LLC",
    "30153": "IMPLANT - Biomet 3i, LLC",
    "30154": "DAVEN - Davenport University",
    "30155": "MENTT-N - Menttium Corporation",
    "30156": "CIRCLETELECOM-N COPY OF 30156@ARIN FOR ROUTING POLICY",
    "30157": "EQUINIX-EDMA-SJO-N - Equinix, Inc.",
    "30158": "ARIMA-NETWORKS - ARIMA Networks Inc.",
    "30159": "EQUINIX-EDMA-H-N - Equinix, Inc.",
    "30160": "WINDSTREAM - Windstream Communications Inc",
    "30161": "MOCANMEDIA - Firebrand Group SL LLC",
    "30162": "ETHOPLEX - Ethoplex, LLC",
    "30163": "GE-INDUSTRIAL-SYSTEMS - General Electric Company",
    "30164": "USACOMMUNICATIONS-1 - USA COMPANIES, LP",
    "30165": "DALTON-U2 - Dalton Utilities",
    "30166": "EX3IN - Ex3",
    "30167": "XCNETWORKS-30167 - XC Networks, Ltd.",
    "30168": "DVOX-PGH - DynaVox Systems LLC",
    "30169": "MFGLOBAL-NY - MFGlobal",
    "30170": "OPTICFUSION - Optic Fusion",
    "30171": "NCAR-N - NCAR",
    "30172": "FAMC-1 - Franklin American Mortgage Company",
    "30173": "RSM-NET-1 - RSM McGladrey, Inc.",
    "30174": "UTA - United Telephone Association, Inc.",
    "30175": "CCITRIAD - Activant Solutions Inc.",
    "30176": "-PRIORITYCOLO - Priority Colo Inc",
    "30177": "ARTHROCARE-CORP- - ArthroCare Corporation",
    "30178": "CSI-N - College of Southern Idaho",
    "30179": "ATX-FTF-USRICR1 - A. T. Cross Co.",
    "30180": "MEDIAGRIF - Mediagrif Interactive Technologies Inc.",
    "30181": "QHG - Intuit Inc.",
    "30182": "WJ-1 - Wyndham Jade, L.P.",
    "30183": "BESPACE- - BaseSpace.net",
    "30184": "RESI-BGP1 - RESI",
    "30185": "URBAN-RETAIL - Urban Retail Properties, LLC",
    "30186": "TOQEN - Toqen LLC",
    "30187": "BROWARD-COUNTY-COMMISION - Broward County Commission",
    "30188": "TELEVERGENCE - Televergence Solutions Inc.",
    "30189": "CRUMP--30189 - Crump Life Insurance Services, Inc",
    "30190": "SAIA-N - Saia Motor Freight Line",
    "30191": "SALIX-1 - Salix",
    "30192": "NSX-BGP-1 - NSX",
    "30193": "LAUSD- - Los Angeles Unified School District",
    "30195": "CHARLESBANK - Charlesbank Capital Partners",
    "30196": "CAPSCENTERS - CAPS",
    "30197": "BEST-WESTERN-INTERNATIONAL-INC - Best Western International",
    "30198": "KENT-SCHOOL-DISTRICT - Kent School District",
    "30199": "LAN-1234 - Lantrax Inc.",
    "30200": "DERBY - DerbyTech Computer Works",
    "30202": "LEVEL-IV - Level IV",
    "30203": "EMDSERONO-NA-BOS1 - EMD Serono, Inc.",
    "30204": "MILLWA-UK - Millward Brown, Inc.",
    "30205": "LUXOR-1 - LUXOR CAPITAL GROUP, LP",
    "30206": "BSFMNA - The Royal Bank of Scotland Financial Markets",
    "30207": "EDELMAN-NYC - Edleman Public Relat",
    "30208": "EDELMAN-WDC - Edelman PR-Worldwide",
    "30209": "GSI - GSI Hosting",
    "30210": "JDPA - J.D. POWER AND SOCIATES",
    "30211": "WISPWEST - wispwest.net",
    "30212": "HYPERMEDIA-SYSTEMS - Hypermedia Systems, Inc.",
    "30213": "AURORA-LOAN-SERIVES - Aurora Loan Services LLC",
    "30214": "-IRONP-CP - Cisco Systems Ironport Division",
    "30215": "-IRONP-ELM - Cisco Systems Ironport Division",
    "30216": "STARMAX - StarMax Corporation",
    "30217": "DESYNC - Desync Networks",
    "30219": "CODEREADY-SOLUTIONS - CodeReady Solutions, Inc.",
    "30220": "SWTELCOOP - SWWC Service Cooperatives",
    "30221": "T3COM - T3 Communications, Inc.",
    "30222": "XEROSCAPE - Project Management, Inc.",
    "30223": "SACLANT - Supreme Allied Commander Transformation (SACT)",
    "30224": "QUEBECOR-PRINTING - Quebecor Printing (USA) Corp.",
    "30225": "NEXTCO- - Nextera Communications LLC",
    "30226": "NEOSPIRE-1 - NeoSpire, Inc.",
    "30228": "TEVA-NA - Teva Pharmaceuticals USA, INC",
    "30229": "SE2-BGP- - SE2, Inc",
    "30230": "DATAFRAMELO - Dataframe Logistics, Inc.",
    "30231": "ARCADIA - Arcadia University",
    "30232": "MOVACI - Movaci Technology",
    "30233": "SAFEPAGES-NETWORK - Safepages.com",
    "30234": "AMERICANPROSERVERS - WebHostPlus Inc",
    "30236": "CRONOMAGIC-1 - Cronomagic Canada Inc.",
    "30237": "CHANEYSYS - Chaney Systems, Inc.",
    "30238": "-IRONP-VEGA - Cisco Systems Ironport Division",
    "30239": "TRAVELPORT - Travelport Operations, Inc.",
    "30240": "RXN3 - RADIANZ Americas, Inc.",
    "30241": "ATL-BROADBAND - Ignisis",
    "30242": "SAMSA - SAMSA",
    "30243": "SPSD - The School District of the City of Saginaw",
    "30244": "FTG1 - FACILITIES TECHNOLOGY GROUP, INC.",
    "30245": "BLUEFIRE-CAPITAL - BLUEFIRE CAPITAL",
    "30246": "CYRUSONE-CIN2 - CyrusOne LLC",
    "30247": "VOONAMI - Voonami, Inc.",
    "30248": "LIPINSKI-LI - Lipinski Landscape and Irrigation, LLC",
    "30249": "JIVESOFTWARE - Jive Software, Inc.",
    "30250": "-ALLENISD-610 - Allen Independent School District",
    "30251": "FALKEN - Falken Tire Corporation",
    "30253": "DEMANDCHAININC - Demand Chain, Inc.",
    "30255": "ICS-SA - Innovative Communication Systems",
    "30256": "ACADIAU - Acadia University",
    "30257": "GEMC - Gibson Electric Membership Corporation",
    "30258": "HUNTINGTONMEMORIALHOSPITAL - Huntington Memorial Hospital",
    "30259": "BROADPECT - BroadAspect",
    "30260": "NOBELLA - Nobel, Inc.",
    "30261": "VMC32 - Virgin Mobile Canada",
    "30262": "PTT- - High 5 Games",
    "30263": "COTNET - Cal-Ore Telephone Co.",
    "30264": "COLUMBIAPWS - Columbia Power and Water Systems",
    "30266": "A1COLO-COM - A1COLO.COM",
    "30267": "UEC-1350 - Universal Executive Centers",
    "30268": "CHKANET - CITY OF CHKA CHKANET",
    "30269": "OLDC-1 - ONLINE DOOR COUNTY",
    "30270": "GRIDWERKE - Gridwerke Corporation",
    "30271": "KLGATES - K&L Gates, LLP",
    "30273": "DIDL-1 - DreamWorks Studios",
    "30274": "MERITEL - Meritel Group Inc",
    "30275": "EIM - EIM",
    "30276": "GDCNET---GREEN-DOT-CORPORATION - Green Dot Corporation",
    "30277": "DFW-DATACENTER - DFW Datacenter",
    "30278": "EQUITYNET - Equity Residential",
    "30280": "TFCU - Teachers Federal Credit Union",
    "30281": "WHPOST - Washington Post",
    "30282": "-INAPCDN-OCY - Internap Network Services Corporation",
    "30283": "MOFO - Morrison & Foerster",
    "30284": "CITIGROUP-BANAMEX - Citigroup",
    "30285": "CITIGROUP-BANAMEX - Citigroup",
    "30286": "THM - ThreatMetrix Inc.",
    "30287": "ALON-USA - ALON USA, LP",
    "30288": "ANRO-INC - ANRO, Inc.",
    "30289": "ADVANCED-NETWORK-SOLUTIONS---AKRON-DATA-CENTER - Advanced Network SOlutions",
    "30290": "WOCO - Western Ohio Computer Organization",
    "30291": "DFMC - Delmarva Foundation for Medical Care, Inc.",
    "30292": "SB-PHX1 - SafeBackup",
    "30293": "SOUTHCO - Southco, Inc.",
    "30295": "2ICSYSTEMSINC - 2iC Systems Inc.",
    "30296": "YCMLLC - York Capital Management, LLC",
    "30297": "MAGMA-DESIGN-AUTOMATION",
    "30298": "COG-SEOVEC-ISP - COG-SEOVEC",
    "30299": "THE-MARTIN-AGENCY-HQ - THE MARTIN AGENCY",
    "30300": "BMLPROD - Bill Me Later",
    "30301": "INTRUST-WICHITA - INTRUST Bank, N.A.",
    "30302": "TBELUSA - Tractebel Energy Marketing",
    "30303": "OOMA - Ooma, Inc.",
    "30305": "LPS-1 - Lender Processing Services Inc",
    "30306": "AfOL-Sz-",
    "30307": "LAKE-REGION-MED - Lake Region Medical",
    "30308": "MACFCU - Mid-Atlantic Corporate Federal Credit Union",
    "30309": "IEXPOSURE- - Internet Exposure, Inc.",
    "30310": "MUT-AMERNY - Mutual of America Life Insurance Company",
    "30311": "DWS-LON - Disney Worldwide Services, Inc.",
    "30312": "NETGATE - Netgate",
    "30313": "IRS - Internal Revenue Service",
    "30314": "KAN-ED - Kansas Education Network",
    "30315": "N-THEPLANET-3 - ThePlanet.com Internet Services, Inc.",
    "30316": "ECEDI-N - EC/EDI, Inc.",
    "30317": "DEBTXS-NET - DebtXS",
    "30318": "WESTER-100 - WESTERN PETERBILT, INC.",
    "30319": "QMED-N - QMEDTRIX SYSTEMS INC.",
    "30320": "KMACAL - Kia Motors America, Inc.",
    "30321": "BURNINGMAN - Burning Man",
    "30322": "BIRCH-COV - Birch Communications Inc.",
    "30323": "OXFORDCOUNTY - The County of Oxford",
    "30324": "SKENER - SaskEnergy Inc.",
    "30325": "CP-ACES - Computer Pros, Inc.",
    "30326": "PNA - Pindar North America",
    "30327": "ALPARI-US - Alpari (US), LLC",
    "30328": "SAIC - State Auto Insurance Company",
    "30329": "SPARKPLUG-SOUTHWEST-LLC - Sparkplug Southwest, LLC.",
    "30330": "ARI-9000 - Automotive Rentals, Inc.",
    "30331": "ST-VINCENT - St. Vincent Hospital",
    "30332": "EBUS-GENET - Partylite Gifts, Inc.",
    "30333": "CD - CD",
    "30334": "PARK-NATIONAL-CORP - The Park National Corporation",
    "30335": "-WWU - Walla Walla University",
    "30336": "XITTEL- - Telecommunications Xittel inc.",
    "30337": "DELOITTE-US-N - Deloitte & Touche",
    "30338": "CFI-JOPLIN - Con-way Truckload Inc.",
    "30339": "DGLAW - Davis & Gilbert LLP",
    "30340": "-TIER - Tierpoint, LLC",
    "30341": "SCTA-N - South Central Telephone Association",
    "30342": "DISCOVERY - Discovery Networks International Inc.",
    "30343": "DFWCHECKPOINT - Check Point Software Technologies, Inc.",
    "30344": "FLEX-NETWORKS - FLEX NETWORKS INC",
    "30345": "CTRYWIDE-1340 - CountrWide Insurance Company",
    "30346": "TBD - Sumitomo Mitsui Banking Corporation",
    "30347": "IBERIABANKLFY - IBERIABANK CORPORATION",
    "30348": "UAP- - UAP Inc.",
    "30349": "CHART-54 - Charter Bridge Capital Management, L.P.",
    "30350": "REGION7-ESC - Region VII Education Service Center",
    "30351": "IIX-GCIIX-RS - IIX Corp.",
    "30352": "CPI-CORP-CLT - CPI Corp.",
    "30353": "IMB-SBC - International Mission Board of the Southern Baptist Convention",
    "30354": "DSS-9 - Distributed Systems Services, Inc.",
    "30355": "SFUP - Six Feet Up, Inc.",
    "30356": "NET-COM-ET - Network Equipment Technologies, Inc.",
    "30357": "WRIGLEYUSA - Wm. Wrigley Jr. CompaNY",
    "30358": "SHC-DIRECT-LLC - SHC Direct, LLC",
    "30359": "AVIDKC - Avid Communications, LLC",
    "30360": "N1 - RiverBirch Corporation",
    "30361": "SWIFTWILL2 - Swiftwill, Inc.",
    "30362": "HPT-N - Hawaii Pacific Teleport LP",
    "30363": "GLOBALRESPONSEUSA - Global Response Corporation",
    "30364": "TANMA - TanMar Communications, LLC",
    "30365": "SAB-CAPITAL-MANAGEMENT - SAB Capital Management",
    "30366": "-RHYTHMIC-NY - Rhythmic Technologies, Inc.",
    "30367": "STRATEGIC-VALUE-PARTNERS-LLC STRATEGIC VALUE PARTNERS LLC",
    "30368": "AAFP-NUMBER - AMERICAN ACADEMY OF FAMILY PHYSICIANS",
    "30369": "KEMI - Kentcuky Employers' Mutual Insurance",
    "30370": "QTI - Quiet Touch - Toronto",
    "30371": "NLAYER - nLayer Communications, Inc.",
    "30372": "SBS-NEWARK-CA - SIEMENS BUSINESS SERVICES",
    "30373": "BUSINESSONLYBROADBANDLLC - Business Only Broadband",
    "30374": "MODWEST - Blackfoot Telephone Cooperative, Inc.",
    "30375": "TEVA-NA - Teva Pharmaceuticals USA, INC",
    "30376": "COLLEGE-OF-ST-SCHOLTICA - College of St. Scholastica",
    "30377": "AISA-N - Amundi Investment Solutions Americas LLC",
    "30379": "14768 - O'Connor Davies, LLP",
    "30380": "IPOWER-2 - iPower, Inc.",
    "30381": "CRONUS-TECHNOLOGIES - cfactor Works Inc",
    "30382": "DICENET - Dice Corporation",
    "30383": "GENERAL-MOTORS-CORPORATION- General Motors Corporation",
    "30384": "GMBGP - Guild Mortgage Company",
    "30385": "PERDUE-FARMS-INCORPORATED - Perdue Farms Incorporated",
    "30386": "PM-SYSTEMS - PM Systems Corporation",
    "30387": "NIH-NET-NCCS - National Institutes of Health",
    "30388": "ELK-REGIONAL-HC - Elk Regional Health Center Inc",
    "30389": "CPI-CORP-CT - CPI Corp.",
    "30390": "IMERYS-UK-PARMOOR-NUMBER - Imerys Pigments",
    "30391": "ISCINT - ISC INTERNATIONAL, LTD.",
    "30392": "ADVISORY - The Advisory Board Company",
    "30393": "BMLCORP - Bill Me Later",
    "30394": "JENNISON - Jennison Associates LLC",
    "30395": "SAHS - SWEDISH AMERICAN HEALTH SYSTEM",
    "30396": "NORTH- - North Nova Cable Ltd.",
    "30397": "CHOICEDATA - CHOICEDATA",
    "30398": "-ADS - Automated Data Systems",
    "30399": "EGHS - Elkhart General Healthcare System",
    "30400": "ALTALINK - AltaLink LP",
    "30401": "SUIT-SHARED-SERVICES - Southern Ute Indian Tribe",
    "30402": "HARRIS - Harris Interactive Inc.",
    "30403": "EL-ROCHESTER-NY - Ellucian Company LP",
    "30404": "ADVANCED1 - Advanced Cable Communications",
    "30405": "CAIU-NET - Capital Area Intermediate Unit",
    "30407": "VELCOM - Rcp.net",
    "30408": "UNET - Arkansas State University",
    "30409": "SNCLAV- - SNC-Lavalin, Inc.",
    "30410": "FCSO1-N - First Coast Service Options, Inc.",
    "30411": "ARIZANT-N - ARIZANT HEALTHCARE INC.",
    "30412": "SABRAVA - Sabra Dipping Company, LLC",
    "30413": "BENEFITFOCUS - Benefitfocus.com, Inc.",
    "30414": "N-DTC - Digitcom Telecommunications Canada Inc.",
    "30415": "SCG-BGP01 - Sarasota County Government",
    "30416": "WCS - Wildlife Conservation Society",
    "30417": "BTIG-UK-LLP BTIG UK LLP",
    "30418": "SUMT-CMH - SumTotal Systems, Inc.",
    "30419": "MEDIAMATH-UKNETS MediaMath UK Ltd",
    "30420": "YCM - YORK CAPITAL MANAGEMENT (US) ADVISORS, L.P.",
    "30421": "SIGG- - The Signature Group",
    "30422": "LIBERTYSOURCE-01 - Liberty Source, LP",
    "30423": "AMEDI-3-N1 - Amedisys, Inc.",
    "30424": "WEST-JEFFERSON-MEDICAL-CENTER-LOUISIANA - West Jefferson Medical Center",
    "30425": "UTA-1 - Utah Transit Authority",
    "30426": "SCO-COM - SCO",
    "30428": "NET2PHONE-GLOBAL-SERVICES - IDT Corporation",
    "30430": "KPFNY - Kohn Pedersen Fox",
    "30431": "N - Devon Canada Corporation",
    "30432": "UBTANET - UBTANET",
    "30434": "LOEWS - LOEWS CORPORATION",
    "30435": "NEW-WORLD-PTA - New World Pasta Company",
    "30436": "ELITE-BROADBAND - Elite Broadband LLC",
    "30437": "GE-MS003 - General Electric Company",
    "30439": "MEMPHIS-DAILY-NEWS - Memphis Daily News",
    "30440": "XAPIENS - Xapiens Corporation",
    "30441": "SOUTHPOINT-1114-6TH-AVE - Southpoint Capital Advisors, LP",
    "30442": "EMERSON-RETAIL-SERVICES - Emerson Climate Technologies Retail Solutions, Inc.",
    "30443": "GOLDEN-STATE-OVERNIGHT-DELIVERY-SERVICE-INC - Golden State Overnight Delivery Service, Inc.",
    "30444": "OEU - Ocala Electric Utility",
    "30445": "RAD-2008 - City of Radford",
    "30446": "SERENA02 - Serena Software, Inc.",
    "30447": "INFB2- - InternetNamesForBusiness.com",
    "30448": "QTRADE-CAPITAL - QTrade Capital Partners LLC",
    "30449": "AZSTATE - Arizona State Government",
    "30450": "CITY-OF-LATHROP - City of Lathrop",
    "30451": "NET2EZ - Net2EZ",
    "30452": "FIRST-NATIONAL-TECHNOLOGY-SOLUTONS - First National Technology Solutions, Inc.",
    "30453": "PATRICK-SOLUTIONS-INC - PATRICK SOLUTIONS INC",
    "30454": "QVT-FINANCIAL - QVT Financial LP",
    "30455": "BC-LOS-ANGELES - NextGen MultiMedia Limited",
    "30456": "NHVILLE-COMPUTER-WEBHOSTING - Nashville Computer",
    "30457": "MEEMIC - Meemic Insurance Company",
    "30458": "NIUTECH-N - NiuTech",
    "30459": "FCLAW - Fennemore Craig",
    "30460": "DXMA01 - Dyax Corp",
    "30461": "QNACO-004 - QnA Consulting",
    "30462": "NEXGEN - NexGen Integrated Communications",
    "30464": "LPS-2 - Lender Processing Services Inc",
    "30465": "STATE-WIDE - STATE-WIDE MULTIPLE LISTING SERVICE,INC.",
    "30466": "CAXD - Cable Axion Digitel Inc.",
    "30467": "VONAGE-03 - Vonage Holdings, Inc.",
    "30468": "VONAGE-03 - Vonage Holdings, Inc.",
    "30469": "VONAGE-03 - Vonage Holdings, Inc.",
    "30470": "AEGIS-INET - Aegis Communications Group, Inc.",
    "30471": "MEDIALINK - Medialink",
    "30472": "ET-WEST-CENTER-HOUSINGNET - East-West Center",
    "30473": "ETHANALLEN - Ethan Allen Global, Inc.",
    "30475": "WEHOSTWEBSITES-COM - WeHostWebSites.com",
    "30476": "T2-CT-SHN - ThinkTech, Inc",
    "30477": "SHO - Shorenstein Realty Services",
    "30478": "AVT - Affinity VoIP Telecom, Inc.",
    "30479": "NCSERV-COM - NCServ, LLC.",
    "30480": "TIP2 - Turner Investment Partners",
    "30481": "CITIZENS-ISP - Citizens Internet Service",
    "30482": "PCAP-BOSTON - Parthenon Capital, LLC",
    "30483": "TEX-G-TRANSMISSION - TEX G TRANSMISSION, LLC",
    "30484": "PAHOUSEGOP - Pennsylvania House of Representatives, Republican IT Services",
    "30485": "PICKFORD-REALTY - Pickford Realty",
    "30486": "EZESOFT - Eze Castle Software LLC",
    "30487": "ANDERSON-HAY - Anderson Hay & Grain Co., Inc.",
    "30488": "SPRINGS - Springs Industries, Inc.",
    "30489": "MKPCAP - MKP CAPITAL",
    "30490": "ETHRN - Ethr.Net LLC",
    "30491": "CROWE - Crowe Chizek",
    "30492": "APPCORE - Appcore llc",
    "30493": "GOLDEN- - Goldenberg Hehmeyer",
    "30494": "FACTSET - FactSet Research Systems, Inc.",
    "30495": "LEXISNEXIS-MTS - REED ELSEVIER",
    "30496": "COLO4 - Colo4, LLC",
    "30497": "GTB - Global Telecom Brokers",
    "30498": "STRAND - STRAND BOOK STORE, INC.",
    "30499": "YSU- - Youngstown State University",
    "30500": "WOLFPAWSERVICES - Wolfpaw Services Inc.",
    "30501": "WFG-N - Williams Financial Group",
    "30502": "PROHCI-MIA - Hosting Consulting, Inc",
    "30503": "FPM-ATLANTA - FLORIDA PENINSULA MANAGERS, LLC",
    "30504": "PROFITABILITY - Profitability.net",
    "30505": "AT- - Applied Trust",
    "30506": "BLACKSUN-1 - Blacksun Technologies LLC",
    "30507": "GLWIZ - Gold Line Telemanagement,  Inc.",
    "30508": "SOC-TXDPS - Texas Department of Public Safety",
    "30510": "PHNS - PHNS",
    "30511": "MEDIPAN - Mediaspan Group, Inc.",
    "30512": "RIDGEVIEW-MEDICAL-CENTER - Ridgeview Medical Center",
    "30513": "DYNAMIC-INTERNET - DYNAMIC INTERNET",
    "30514": "MOCHIMEDIA - Mochi Media, INC",
    "30515": "USP - USP",
    "30516": "N-RISKMGMT - Risk Management Solutions, Inc.",
    "30517": "GREAT-LAKES-COMNET - Great Lakes Comnet, Inc.",
    "30519": "CANYONSRESORT - C Utah, LLC",
    "30520": "NUANCE-SOMERVILLE - NUANCE COMMUNICATIONS, INC",
    "30521": "IOI-1 - INTERLOGIC OUTSOURCING, INC.",
    "30522": "MNMC - Mount Nittany Medical Center",
    "30523": "BOK-FINANCIAL-CORPORATION - BOK Financial Corporation",
    "30524": "NEXGEN-NETWORKS - NEXGEN NETWORKS",
    "30525": "GLS - Global Linking Solutions",
    "30526": "NEPTUNO-NET - Neptuno Media, Inc.",
    "30527": "N-USMARCHON - Marchon Eyewear Inc.",
    "30528": "EICAT - E. I. Catalyst",
    "30529": "WIL-TOR- - Waterfront International Ltd.",
    "30530": "FMTC - Farmers Mutual Telephone Company",
    "30531": "TELINTA-1 - Telinta, Inc.",
    "30532": "3310-617INTERNET - Healthcare Realty Trust, Inc.",
    "30533": "THEBOE-30533 - The Boeing Company",
    "30534": "PWC0550 - Public Works Commission",
    "30535": "SPRING2-ARIN - The Springfield News-Leader",
    "30536": "CCR--01 - Circle Computer Resources, Inc.",
    "30537": "CAMBRIDGESOFT-CORPORATION - Cambridge Soft Corp.",
    "30539": "FLOWFINITY - Flowfinity Wireless Inc",
    "30540": "DEER-VALLEY-RESORT - Montage Hotels & Resorts",
    "30541": "OSPRAIE-NYC - Ospraie Fund",
    "30542": "PDC- - PREMIER DATA CORPORATION",
    "30543": "TVCC-5- - Treasure Valley Community College",
    "30544": "PFFCU- - People First Federal Credit Union",
    "30545": "FARMERSCOOPERATIVECOAMES - Farmer's Cooperative Company",
    "30546": "INTERNATIONAL-RECTIFIER - International Rectifier",
    "30547": "EDELMAN-SEA - Edleman Public Relat",
    "30548": "ARUBA - ARUBA NETWORKS, INC.",
    "30549": "LAKELAND-NETWORKS - Lakeland Networks",
    "30550": "HARLAND-FINANCIAL-SOLUTIONS - Harland Financial Solutions",
    "30551": "C-163-N01 - AK Steel Corporation",
    "30552": "SAINT-JOSEPHS-HOSPITAL-OF-ATLANTA - Saint Joseph's Hospital of Atlanta, Inc.",
    "30553": "CCH-TOR- - CCH Inc.",
    "30554": "LEVY-LFS-NET - Levy Restaurants",
    "30555": "FAUCET-DIRECT-NETWORK - Faucet Direct, Inc.",
    "30556": "HMH-30556 - Houghton Mifflin Harcourt Publishing Company",
    "30557": "AAUW - American Association of University Women",
    "30558": "LINCOLNELECTRIC - The Lincoln Electric Company",
    "30559": "NAVTECHWATERLOOOFFICE - Navtech Systems Support Inc.",
    "30560": "GE-MS001 - General Electric Company",
    "30561": "GE-MS002 - General Electric Company",
    "30562": "SCARSDALE-SCHOOLS - Scarsdale Schools District",
    "30563": "STRATACOM-GA-1 - Stratacom Communications, Inc.",
    "30564": "LSUS - Louisiana State University in Shreveport",
    "30565": "HOLMAN-NORTH - Mt. Laurel Ford",
    "30566": "WOLP-N - Whippoorwill Operations, L.P.",
    "30567": "AMEREXENERGY - Amerex Group of Companies",
    "30568": "VCS- - Virtacore Systems Inc",
    "30569": "CREIGHTON- - Creighton University",
    "30570": "AEPC- - Arizona Electric Power Cooperative, Inc.",
    "30571": "JACKHENRY-1 - Jack Henry & Associates, Inc.",
    "30572": "NYCB-NEW-YORK-COMMUNITY-BANCORP-INC - New York Community Bancorp Inc.",
    "30573": "OLDSECONDBANCORP - Old Second Bancorp",
    "30574": "BUSINESS-WIRE - Business Wire",
    "30575": "MSFT-30575 - Microsoft Corporation",
    "30576": "SAEN - San Antonio Express-News",
    "30577": "CITY-OF-BELLEVUE - City of Bellevue IT Dept",
    "30578": "NATURE-AMERICA-BO - NATURE AMERICA, INC",
    "30579": "CCHQ-1 - Corporate Computer, Inc.",
    "30580": "SKPO - SaskPower",
    "30581": "LAM-N - Lydian Asset Management LP",
    "30582": "HDS- - HITACHI DATA SYSTEMS",
    "30583": "QUANTUM - Quantum Communications LLC",
    "30584": "FANNIE-MAE-INTERNET-VPN - Fannie Mae",
    "30585": "HPES - Hewlett-Packard Company",
    "30586": "REYNWOOD - Reynwood Communications, Inc.",
    "30587": "TAI-GEORGETOWN - Toyota Tsusho America, Inc.",
    "30588": "NCSOFT - NCSoft Corp.",
    "30589": "ACTIVEHOST-WH-AVE - ActiveHost Corporation",
    "30590": "NSCM-NYC - 3G Capital, Inc.",
    "30591": "BPNSE - Defense Logistics Information Service",
    "30592": "WESTEC-SECURITY-INC - Westec Security, Inc.",
    "30593": "VORNADO-PUBLIC - Vornado Realty Trust",
    "30594": "NCSOFT - NCSoft Corp.",
    "30595": "URBANOUT - Urban Outfitters, Inc.",
    "30596": "KINGSWOOD - Kingswood-Oxford School",
    "30597": "AMBEST-N - A.M. Best Company",
    "30598": "CCL-N - CARNIVAL CRUISE LINES",
    "30599": "JACKHENRY-2 - Jack Henry & Associates, Inc.",
    "30600": "-CMN - Cinergy Metronet, Inc.",
    "30601": "LOBEL-FINANCIAL-CORPORATION - Lobel Financial Corporation",
    "30602": "-EDUCA-64 - Education Corporation of America",
    "30603": "BUSINESSVITALS - Business Vitals",
    "30604": "SPEEDY-4 - Speedy Cash",
    "30605": "JACKHENRY-3 - Jack Henry & Associates, Inc.",
    "30606": "BHSF - Baptist Health South Florida, Inc.",
    "30607": "302-DIRECT-MEDIA-N - 302 Direct Media LLC",
    "30608": "APTIM-N - Aptimus",
    "30610": "SERVICELINK - SERVICE LINK, INC.",
    "30611": "LUSCAR - Luscar Ltd.",
    "30612": "EAGLE-9- - Eagle Communications, Inc.",
    "30613": "CME-TESTLAB - Chicago Mercantile Exchange",
    "30614": "DELL DELL",
    "30615": "MITCHELL-INTERNATIONAL - Mitchell International",
    "30616": "NEEDCO - Needham & Company, LLC",
    "30617": "ROLLINS-INC - Rollins, Inc.",
    "30618": "LEEUNIV - Lee University",
    "30619": "TDM-",
    "30620": "CO-DATACENTER - APPLIED SYSTEMS, INC",
    "30622": "VENABLE - Venable LLP",
    "30623": "TNG - THE NAILCO GROUP, INC.",
    "30624": "CME - Chicago Mercantile Exchange",
    "30625": "AKERMAN-SENTERFITT - AKERMAN SENTERFITT",
    "30626": "EAMC-INET - East Alabama Medical Center",
    "30627": "EON-NET - Everyone.net, Inc.",
    "30628": "RRBUSINESSCINTI - Road Runner Business Cincinnati",
    "30629": "LCLARK - Lewis & Clark College",
    "30630": "REFUNDSTODAY - Refunds Today, Inc.",
    "30632": "SPSY - Spectra Systems Corporation",
    "30633": "LEEWEB-US - Leaseweb USA, Inc.",
    "30634": "CL - CompassLearning",
    "30635": "ANDJ--233W - &J Associates, Inc.",
    "30636": "INTERNAP-BLK6 - Internap Network Services Corporation",
    "30637": "-INAPCDN-AMS - Internap Network Services Corporation",
    "30638": "CITYOFHAMILTON-LIBRARY - Hamilton Public Library",
    "30639": "CMCFLEX - Computer Marketing Corporation",
    "30640": "ETHERIC - Etheric Networks, Inc.",
    "30641": "STATEOFDE - STATE OF DELAWARE",
    "30642": "ILFC001 - International Lease Finance Corp",
    "30643": "TTXCOM - TTX Company",
    "30644": "BOATRACS-LLC - Boatracs",
    "30645": "NETEY - Neteasy Technology Services Company",
    "30646": "CUDDYFEDER - Cuddy & Feder LLP",
    "30647": "USNX - U.S. NetworX, Inc.",
    "30648": "ERACA- - ELECTRONIC RECYLCING SOC",
    "30649": "PRINCIPALS - National Association of Secondary School Principals",
    "30650": "ALTA-RESOURCES - Alta Resources Corp.",
    "30651": "NEXTSOURCE-N - nextSource, Inc.",
    "30652": "JACKHENRY-4 - Jack Henry & Associates, Inc.",
    "30653": "EXOBIT - Exobit Networks Inc.",
    "30654": "KLSPAG-N - KLS Professional Advisors Group, LLC.",
    "30655": "ARE-N - Amster Rothstein & Ebanstein",
    "30656": "PUBLIC-SERVICE-MUTUAL-COMPANY- - PUBLIC SERVICE MUTUAL COMPANY",
    "30657": "GMS-PRIMARY - General Monitoring Services, Inc.",
    "30658": "BAKERD - Baker & Daniels LLP",
    "30659": "OCFL-COMPTROLLER - Orange County Comptroller",
    "30660": "PMBDC01 - FatWallet, Inc.",
    "30661": "TMXATRIUM - Atrium Network",
    "30663": "ISPEED-WIRELESS-INC - ISpeed Wireless Inc.,",
    "30664": "PHHTS - PHH Corporation",
    "30665": "JACKHENRY-5 - Jack Henry & Associates, Inc.",
    "30666": "XCHANGETELECOMCORP - Xchange Telecom Corp.",
    "30667": "WHEELERSLC - WHEELER MACHINERY CO.",
    "30668": "DATAMARK-CORP-1 - Datamark Inc.",
    "30669": "CAMDEN-NATIONAL - Camden National Bank",
    "30670": "COLONIAL-PROPERTIES-TRUST - Colonial Properties Trust",
    "30671": "ROTOR - HELICOPTER SOCIATION INTERNA",
    "30672": "30672 - QMACS",
    "30673": "MEDSETS-HSCA-N - MedAssets/HSCA",
    "30674": "BAYLORU - Baylor University",
    "30675": "AKAMAI- - Akamai Technologies, Inc.",
    "30676": "TUB - Tullahoma Utilities Board",
    "30677": "VALLEY-HEALTH-SYSTEM - valleyhealthlink.com",
    "30678": "STATEFARMINSCO-2 - State Farm Mutual  Automobile Insurance Company",
    "30679": "CPPNET - California State Polytechnic University - Pomona",
    "30680": "FISCOM-COLO5-JAX-FL - Fidelity National Information Services, Inc.",
    "30681": "JCU-N - John Carroll university",
    "30682": "ECOLLEGE-MONACO - eCollege.com, Inc.",
    "30683": "SOUTHMILL - Southern Mills, Inc.",
    "30684": "ESOLUTIONS-DATAFORTRESS - eSolutionsGroup Ltd.",
    "30685": "KITS-AKR-OH-DC1 - KIEHL IT SERVICES, LLC",
    "30686": "LVLT-30686 - Level 3 Communications, Inc.",
    "30687": "NWS-SOUTHERN-REGION-HEADQUARTERS - National Weather Service Southern Region Headquarters",
    "30688": "FTTRACK-NET- - FastTrack Communications Inc.",
    "30689": "FLOW-NET - FLOW",
    "30690": "SERVICEARGOS - SERVICE ARGOS INC",
    "30691": "LLDC - Lifeline Data Centers",
    "30692": "VERDE-REALTY - Verde Realty Operating Partnership, L.P.",
    "30693": "SERVERHUB-PHOENIX - Eonix Corporation",
    "30694": "KL-5527 - Keystone Systems, Inc.",
    "30695": "WALLSTREET-LTLN - Wall Street On Demand, Inc.",
    "30696": "TETN-I2 - Texas Education Agency",
    "30697": "NPBI- - National Penn Bancshares, Inc.",
    "30698": "BOSCH - Robert Bosch Corporation - North America",
    "30699": "CORRECTIONSCORP - Corrections Corporation of America",
    "30700": "KY-RON - Kentucky Regional Optical Network (KY-RON)",
    "30701": "ORACULAR - ORACULAR INC",
    "30702": "-DYMIN-SYSTEMS - Dymin Systems, Inc.",
    "30703": "SHSC-1- - SUNY Health and Science Center",
    "30704": "BIS01 - BOWMAN INTERNET SYSTEMS",
    "30705": "TELIRIS - Teliris Inc.",
    "30706": "EAMONTREAL - Electronic Arts, Inc.",
    "30707": "PATRICK-HENRY-COLLEGE - Patrick Henry College",
    "30708": "RAAPID-CORE - RAAPID Technical Services",
    "30709": "REVEAL - REVEAL SYSTEMS INC",
    "30710": "SPECT-19- - Spectrum Health",
    "30711": "2WIRE-CORP - 2Wire Inc.",
    "30712": "MDECA - MDECA",
    "30713": "YRDSB - York Region District School Board",
    "30714": "PHX-N - Axway Inc",
    "30715": "Q9--KML1 - Q9 Networks Inc.",
    "30716": "ROSEINT - Rose international",
    "30717": "GCPW-GREER-COMMISSION-OF-PUBLC-WORKS - Greer CPW",
    "30718": "SSI-WESTCOT - Survey Sampling International, LLC",
    "30719": "ARIESSYS - Aries Systems Corporation",
    "30720": "VWE-EXTRANET- VWE Extranet",
    "30721": "SATGATE SatGate LLC",
    "30722": "VODAFONE-IT-N Vodafone Omnitel N.V.",
    "30723": "FOTEXNET- Fotexnet Kft.",
    "30724": "WEB-BG web.bg autonomous system",
    "30725": "MICTD- Middle East Communication Co ( MICTD )",
    "30726": "WAVENET- PAGI - General Information Agency",
    "30727": "SYSLINK syslink operations AG, Basel, Switzerland",
    "30728": "UNITECH- JV \"UNITECH\"  NUMBER",
    "30729": "TRANSFERTTK- Transfer ltd.",
    "30730": "ZE-WROCLAW- EnergiaPro SA",
    "30731": "MAZUR- Uslugi informatyczne Wieslaw Mazur",
    "30732": "P Axel Springer Polska Sp. z o.o.",
    "30733": "GLOBUS- CJSC GLOBUS-TELECOM",
    "30734": "METISBILG- METIS BILGISAYAR SISTEMLERI SANAYI VE TICARET A.S.",
    "30735": "AGROUNION- TOV Corporation Argo-Soyuz",
    "30736": "EYSPEEDY- EasySpeedy Danmark ApS",
    "30737": "SAFETY- Safety Computing",
    "30738": "NETART- NetArt Group",
    "30739": "LENZING- Lenzing AG",
    "30740": "EXA-NETWORKS Exa Networks Limited",
    "30741": "DDO- DDO Organisation SARL",
    "30742": "BRITELINE- Bremen Briteline GmbH",
    "30744": "TOWER- Tower Semiconductor Ltd",
    "30745": "SITENETWORK- Site LLC",
    "30746": "ESGOB ESGOB LTD",
    "30747": "VOLSK- JSC Volgatranstelecom",
    "30749": "VOLOGDA- OJSC Rostelecom",
    "30750": "EUROCENTERUSA- EUROCENTER GAMES SARL",
    "30751": "EUROTEL MTS OJSC",
    "30753": "COMPOWER FHU \"COMPOWER\" Dariusz Krocz",
    "30754": "FI-PARLIAMENT- Parliament of Finland",
    "30755": "INTRACALL-CENTER- Intracall Center",
    "30756": "CENDANT- Travelport International Limited",
    "30757": "ICE- Icenetworks",
    "30758": "SCHLOTTERER-AT- Schlotterer Rolladensysteme",
    "30759": "ALCATEL-POLSKA- Alcatel Polska S.A  Autonomous System",
    "30761": "FR-INTERPOL International Criminal Police Organisation - INTERPOL",
    "30764": "PODA- PODA s.r.o.",
    "30765": "KT- Kish Telecom",
    "30766": "GGEWNET- GGEW net GmbH",
    "30767": "TAGILTELECOM- JSC \"TagilTelecom\"",
    "30768": "VOLVOX- VOLVOX CJSC",
    "30769": "BERKELEY- The Berkeley Group plc",
    "30770": "MOPO- Ministry of Public Order Greece",
    "30771": "CYCLE- PE Cycle-Plus",
    "30772": "LEONET LEO Pharma A/S",
    "30773": "MOBIVILLAGE- Mobivillage SA",
    "30774": "ESC-N ESC Network Autonomous System Number",
    "30775": "MKS- UAB \"Mokejimo korteliu sistemos\"",
    "30776": "CEMAISP- Ziggo B.V.",
    "30777": "ZPIX- Zaporozhye Internet Exchange",
    "30778": "KIELMAN-COM- Kielce University Of Technology",
    "30779": "INETKR- TRK Cable TV LLC",
    "30780": "HYPERION- Hyperion Solution Europe",
    "30781": "JAGUAR- Jaguar Network S",
    "30782": "TMONT- T-MONT Jerzy Grabski i Wspolnicy spolka jawna",
    "30783": "RSD Rased Maral Ava Jonoob JSC",
    "30784": "ISKRATELECOM- ISKRATELECOM ZAO",
    "30785": "RADIK- Radik B.V.",
    "30787": "JUMO Jumo GmbH & Co. KG",
    "30788": "INFOSVYAZ-RU-NET Infosviaz Ltd.",
    "30790": "ELLIPSE- Ellipse Ltd.",
    "30791": "ZA- za-internet GmbH",
    "30793": "GEMINI-ISTS-PL ISTS Sp. z o.o.",
    "30795": "INTRON- Koneo AB",
    "30797": "ACADEMTELECOM- Academtelecom CSJC",
    "30798": "TNNET- TNNet Oy",
    "30800": "INFOR-30800 Infor (Deutschland) GmbH",
    "30801": "OZONE- Ozone S",
    "30803": "TRIDENT-NET Trident Net  Limited",
    "30804": "TELENET- TELENET",
    "30805": "DIGITALBRAIN Editure Education Services UK LTD",
    "30806": "DATACT- DataCT v.o.f.",
    "30808": "VIKING- Viking Turizm",
    "30809": "DISISLERI DISISLERI BAKANLIGI",
    "30810": "KUPAVNA- Kupavna-Net Ltd",
    "30811": "EPiServer AB",
    "30812": "MARSU- State Educational Institution of Higher Professional Education Mari State University",
    "30813": "OSTROG-NET- Ostrog.Net J. Walega & M. Musiol s.j.",
    "30814": "CLUB-PRO-NET Club PRO NET",
    "30815": "DETAD Detecon Al Saudia Co. Ltd.",
    "30816": "KIRNET- Krajowa Izba Rozliczeniowa S.A.",
    "30817": "MEDIERVICE- TOV MediaService Ltd",
    "30818": "SKYRR- Advania hf.",
    "30821": "HM- H&M Hennes & Mauritz AB",
    "30822": "MAGEAL- Private Enterprise Mageal",
    "30823": "MNCNET- MNC Network",
    "30824": "MULTIMEDIA--2 Multimedia Polska S.A.",
    "30825": "SCHWARTAUER-WERKE- Schwartauer Werke GmbH & Co. KGaA",
    "30826": "KREDITPROMBANK Kreditprombank's",
    "30827": "XTRAORDINARY- Xtraordinary Networks Ltd.",
    "30828": "INTECHSERVICE- PE Intechservice-B",
    "30829": "INPI- INPI",
    "30830": "HSCG- CrossOver Data B.V",
    "30831": "MMK- OAO Magnitogorsk Iron and Steel works",
    "30832": "EYLAN-BG Easy-Lan Home Network",
    "30833": "TNC- Authonomous System for Technology & Networks Co",
    "30834": "GLOBALVOICE-DE euNetworks GmbH",
    "30835": "STECCOM- STEC.COM Autonomous System",
    "30836": "NET23- 23VNET Ltd.",
    "30837": "CDMS CDMS Ltd.",
    "30838": "TELPOL Jerzy Krempa \"Telpol\" PPMUE",
    "30839": "CCIPAU- CHAMBRE COMMERCE INDUSTRIE PAU BEARN",
    "30840": "PROBIL- PROBIL A.S",
    "30841": "IKB- Istarska Kreditna Banka Umag d.d.",
    "30842": "A-NET- \"A.Net\" LTD",
    "30844": "LIQUID- Liquid Telecommunications Ltd",
    "30845": "HTEL- M. Hofmann GmbH",
    "30846": "MAPFRE- MAPFRE INTERNET, S.A.",
    "30847": "LUNS- Lancaster University Network Services Limited",
    "30848": "IT-TWT- TWT S.p.A.",
    "30849": "HOST- Research-and-production company Host Ltd",
    "30850": "DESMIE- INDEPENDENT POWER TRANSMISSION OPERATOR - AMIE",
    "30851": "SILEMAN-RUDL- Sileman Sp. z o.o.",
    "30852": "VIS JSC VolgoInformNet",
    "30853": "METEOTELECOM Main Radio Meteorological Centre (MRMC)",
    "30854": "VELNET-1 VELNET, LLC",
    "30855": "TELE-PLUS- Tele-plus LLC",
    "30856": "RU-NTMK- OJSC \"EVRAZ Nizhny Tagil Metallurgical Plant\"",
    "30857": "CITC- Communications and Information Technology Commission (CITC)",
    "30858": "GLOBALNETWORKS- Papadopoulos Ioannis & SIA E.E. , GLOBAL NETWORKS",
    "30859": "FOZZYLTD- Fozzy-food ltd",
    "30860": "YURTEH- FOP Smirnov V'yacheslav Valentunovuch",
    "30861": "BMTRANS- Corporation BM Group",
    "30862": "ATOS-CH- Atos AG",
    "30863": "FX-NET- RCS & RDS SA",
    "30864": "EUROCONEX1- ELAVON FINANCIAL SERVICES LIMITED",
    "30865": "T-IX- T-IX NGO Center for interoperability data",
    "30866": "ECI-TELECOM-LTD ECI Telecom Ltd",
    "30868": "OLYMPUS-NSP- ZAO \"AKADO-Ekaterinburg\"",
    "30869": "RGOTUPS- State Educational Institution of Higher Professional Education \"Moscow State Railway University\"",
    "30870": "NETSHARK- TRANS-IX B.V",
    "30871": "MUNIC Municipalnoe kazennoe uchrezhdenie goroda Novosibirska \"Hozyaistvennoe upravlenie\"",
    "30872": "SIROCOM-UK Sirocom Ltd",
    "30873": "PTC-YEMENNET Internet Service Provider-The Gateway Of Yemen",
    "30874": "OYAKYATIRIM- Oyak Yatirim Menkul Degerler A.S.",
    "30876": "ONET-PL-2 Grupa Onet.pl S.A.",
    "30877": "ARIADNA Ariadna-Link CJSC",
    "30878": "NETDIRECT-SERVER Leaseweb Germany GmbH",
    "30879": "RAI- Rai Amsterdam B.V.",
    "30880": "SPACEDUMP- SpaceDump IT AB",
    "30881": "TENSOR- MTS OJSC",
    "30882": "BENEFIT The Benefit Company B.S.C. (C)",
    "30883": "MACROLOGIC- Macrologic SA",
    "30885": "BNR Banca Nationala a Romaniei,",
    "30886": "KOMITEX- PP KOM i TEX",
    "30887": "API-NET- \"API Internet\" P. Gubernat",
    "30888": "CTRNET- CTR Executiv S.A.",
    "30889": "WAYCOM- Waycom International SARL",
    "30890": "EVOLVA EUROLAN SOLUTIONS SRL",
    "30891": "N-IX- N-Ix LLC",
    "30892": "T-SYSTEMS-ELTEC T-Systems ITC Iberia S.A.U.",
    "30893": "GLSBILEN- INDIT HOSTING AB",
    "30894": "MBLOX- Mblox Ltd",
    "30896": "Iway-Network-",
    "30897": "PENTAGON-SYSTEMS Pentagon Development Systems Limited",
    "30898": "CRSR- DataCentrum",
    "30900": "WEBWORLD- Web World Ireland",
    "30902": "NEDA- neda rayaneh",
    "30903": "VTL--01 Ventelo Netherland BV",
    "30904": "KOZHALO- National Infocommunications Service Company Limited by Shares",
    "30905": "HRRBA- Raiffeisenbank Austria d.d.",
    "30906": "BROD- BROD-BG",
    "30907": "SAGE- SAGE",
    "30909": "FTVISION FastVision Limited",
    "30910": "RU-TAGNET- TAGNet Autonomous System",
    "30911": "ALTSTU- State Educational Institution of higher professional Education 'Altai state technical university after I.I.Polzunov'",
    "30912": "DCSNET-GLOBAL-TRANSIT- Bredband2 AB",
    "30914": "IOKO-  for ioko365 Ltd",
    "30915": "LIEBHERR Liebherr-IT Services GmbH",
    "30916": "NETWAY- NETWAY ISP  NUMBER",
    "30917": "BUDAPESTBANK- Budapest Hitel- es Fejlesztesi Bank Nyrt",
    "30918": "AGF- AGF",
    "30920": "MOBILON- Mobilom  LLC",
    "30921": "ERICSSON- Telefonaktiebolaget L M Ericsson",
    "30922": "SIBELTELECOM- OJSC \"MTS\"",
    "30923": "TVKTORUN- Mlodziezowa Spoldzielnia Mieszkaniowa",
    "30924": "KATHARSIS- OOO\"NPK Katharsis\"",
    "30925": "SPEEDXS- CBizz B.V.",
    "30926": "MAGIC-NET MAGIC Telekom d.o.o.",
    "30928": "RUBTSOVSK- ZAO Rubtsovsk",
    "30930": "LIFESCI- Life Science Communications",
    "30931": "IGINDEX-PLC IG Index PLC",
    "30932": "POLBITA- Polbita Sp.zoo",
    "30933": "COMCOLO-EU KDA Web Services Ltd. / 30933.net",
    "30934": "AARGAUBANK- Aargauische Kantonalbank",
    "30935": "DATATRANS-CH- Datatrans AG",
    "30936": "RENET-COM- RENET COM Autonomous System",
    "30937": "TISSAT-ES- Tecnologia E Ingenieria De Sistemas Y Servicios Avanzados De Telecomunicaciones, S.A.",
    "30938": "OMNIS- OMNIS",
    "30939": "ISDEFE- Ingenieria de Sistemas para la defensa de Espana sa",
    "30941": "BEUMER- BEUMER Maschinenfabrik GmbH & Co. KG",
    "30942": "ISAFE- iSAFE Zrt.",
    "30943": "UTRANSIT- Utransit International Carrier Limited",
    "30944": "DKD- Bendra Lietuvos, JAV ir Rusijos imone uzdaroji akcine bendrove \"DKD\"",
    "30945": "BELSOFT- NPP BELSOFT Inc.",
    "30947": "PLURICANAL- Pluricanal, SA",
    "30948": "RO-UNI S.C UNIMAT S.R.L",
    "30949": "EDEXCEL- Exponential-E Ltd.",
    "30950": "BREDBANDSALLIANSEN BKK Fiber",
    "30952": "KIT-FINANCE-TC- KIT FINANCE LTD",
    "30953": "PROC Procenter Ltd.",
    "30954": "RADIOKOM- Radio-Kom Ltd.",
    "30955": "UHT- UHT - Ukrainian High Technologies Ltd.",
    "30957": "EKOZEMPROEKT- Institute of Ecology, Landmanagement and Projecting LTD",
    "30958": "BCOM- BCOM S.p.a. - Bergamo",
    "30960": "TETRA- OOO Scientific-Production Center \"Tetra\"",
    "30961": "OPENMINDS- Openminds bvba",
    "30962": "COMTRANCE- comtrance GmbH",
    "30964": "INTROPRO- IntroPro Ltd.",
    "30966": "LINEL- LV7 Communication Ukraine Ltd",
    "30967": "SCN- Software Cellular Network Limited",
    "30968": "INFOBOX- Infobox.ru Autonomous System",
    "30969": "ZOL- Zimbabwe OnLine (Private) Ltd.",
    "30970": "TAONET- Taonet S.r.l.",
    "30971": "NICAT- nic.at Internetbetriebs- und Verwaltungsgmbh.",
    "30972": "M6WEB M6 WEB S.A.S.",
    "30973": "VIAMATMANAGEMENT- Via Mat Management AG",
    "30974": "NNTS- OJSC VolgaTelecom",
    "30975": "TKK Telewizja Kablowa Koszalin sp. z o. o.",
    "30976": "IT4WEB IT4WEB S.R.L.",
    "30977": "UGRATEL- Net By Net Holding LLC",
    "30978": "ATKOS- Itella Information Oy",
    "30980": "INTERC-",
    "30981": "HSS-CGN- Horizon Satellite Services Cologne Teleport",
    "30982": "CAFETG  de CAFE Informatique",
    "30983": "MARWAN-",
    "30984": "Metrong-",
    "30985": "IKATELNET",
    "30986": "SCANCOM",
    "30987": "ERITEL-",
    "30988": "ISInternetSolutions",
    "30989": "N N Inter-Global Networks Ltd. BGP Routing Policy",
    "30990": "ADJIB-",
    "30991": "SAHANNET Sahannet  Network",
    "30992": "MTN-NS-CAMEROON",
    "30993": "Egypt-Centers",
    "30994": "Galileo-Kenya",
    "30995": "CIBEG-",
    "30996": "WINROCK",
    "30997": "GIXA-",
    "30998": "NETCOM-AFRICA-",
    "30999": "EMTEL--AP",
    "31000": "N-FUJILINE Trade House \"Inet\" Ltd",
    "31002": "DATACOM- Datacom firma Ltd.",
    "31003": "IRON-MOUNTAIN-UK- Iron Mountain UK Ltd",
    "31004": "SBB-CFF-FFS Schweizerische Bundesbahnen SBB",
    "31005": "WORKZONE- Workzone , Norway",
    "31006": "SATNET- UAB Satnetas",
    "31007": "STIHL- ANDRE STIHL AG & Co. KG",
    "31008": "ENIN CJSC EN Telecom",
    "31009": "N-LEVI9UA Levi9 Ukraine LTD",
    "31010": "MYLOC- myLoc Managed IT AG",
    "31011": "UCTM- University of Chemical Technology And Metallurgy",
    "31012": "DCM- B.Net Hrvatska d.o.o.",
    "31013": "AIT-GR Athens Information Technology",
    "31014": "DELTTOCK- Delta Stock AD",
    "31015": "HILL-KNOWLTON Hill and Knowlton Strategies",
    "31016": "FTNET- PE Kovalkov Oleg Anatolyevych",
    "31017": "GMBNET GMB Computers SRL",
    "31018": "VIKENKOMTEK Viken KomTek",
    "31019": "MEANIE Meanie",
    "31020": "NEANETT- Neanett",
    "31021": "DIALOGUE-COMMUNICATIONS- Dialogue Communications Ltd",
    "31022": "GIV- Stichting Lancering Innovatieve Breedbanddiensten",
    "31023": "UNDP- United Nations Development Program",
    "31024": "MAVIATION- Malmo Aviation AB",
    "31025": "IAG- IAG-",
    "31026": "AESA- Autostrada Wielkopolska SA",
    "31027": "NIANET- Nianet A/S",
    "31028": "NOVOE-KTV- Novoe Kabelnoe Television Ltd.",
    "31029": "M-REAL M-REAL NET Ltd.",
    "31030": "CORONA Roman Hochuli",
    "31031": "TRANSNODE- Phibee Telecom SARL",
    "31032": "CALL-CENTER-POLAND- CALL CENTER POLAND S.A",
    "31033": "INVESTNET- InvestNet Italia S.p.A.",
    "31034": "ARUBA-N Aruba S.p.A.",
    "31035": "ISD- Corporation \"Industrial Union of Donbass\"",
    "31036": "NEWTELESYSTEMS New Telesystems - TV, Ltd.",
    "31038": "DTECH Data Tech SRL",
    "31039": "NETSTORAGE NET STORAGE SRL",
    "31042": "SERBIA-BROADBAND- Serbia BroadBand-Srpske Kablovske mreze d.o.o.",
    "31043": "ITCILO-N International Training Centre of the ILO",
    "31044": "DERGACHI- TOV DERGACHI.NET",
    "31045": "VTS VTS Sp. z o.o.",
    "31047": "TFXEURODC- TFX Holding GmbH",
    "31048": "FLEXEPRINT- Digital Evolutions Limited",
    "31049": "HYDAC-TECH- Hydac Technology GmbH",
    "31050": "CBB-RU-N Connexion by Boeing Eastern Europe, Ltd.",
    "31051": "ONLINE-TRAVEL ONLINE TRAVEL AG",
    "31052": "EXIGO exigo AG",
    "31053": "AMCS- AMCS.net Europe",
    "31054": "HELPAG- TUEV Rheinland i-sec GmbH",
    "31055": "CONSULTIX- Consultix GmbH",
    "31056": "PING-PRIMA- PING e.V. - Verein zur Foerderung der privaten Internetnutzung",
    "31058": "SEMPRA-ENERGY- RBS SEMPRA ENERGY TRADING HOLDINGS LIMITED",
    "31059": "AVELACOM- Avelacom Ltd.",
    "31060": "DOBA- DOBA Fakulteta",
    "31061": "UKRAVTO- PJSC \"Ukrainian Automobile Corporation\"",
    "31062": "TTCUA- TOV Transtelecom",
    "31064": "VIRTIX SABRI-BERISHA",
    "31065": "MCIT",
    "31066": "NEPTUNE-MULTIMEDIA- NEPTUNE MULTIMEDIA Network - Paris France",
    "31067": "SEAC- SEAC S.p.A.",
    "31069": "UNU-KHARKOV- Maxim Odinintsev",
    "31071": "AGI AutoGuard S.A.",
    "31072": "KCIC- Municipal Enterprise \"City Information Centre\"",
    "31073": "LIS-IX LIS-IX - Lisbon Internet Exchange",
    "31074": "ALPHABANK- Alpha Bank Romania SA",
    "31075": "N-SCTEL Sakhalin Coal Telecom",
    "31076": "TELIGO- NEXIN TECHNOLOGIES S.P.A.",
    "31077": "DIGIAREA LLC \"Universalna Merezheva Kompaniya\"",
    "31078": "NETSIGN Netsign Networks GmbH",
    "31079": "WIX- TER Sp. z.o.o.",
    "31080": "O2- o2 Sp. Z.o.o.",
    "31081": "RIIGIKONTROLL- National Audit Office of Estonia",
    "31082": "MCCTELECOM- MCCTELECOM, S.COOP.",
    "31083": "TELEPOINT Telehouse EAD",
    "31084": "MAGRATHEA-UK Magrathea Telecommunications Limited",
    "31085": "VIKINGNET- Viking Turizm ve Ticaret",
    "31086": "ORTHOFIX- Ortofix S.r.l.",
    "31087": "ENTERPRISE-IG-  for Enterprise IG Ltd.",
    "31088": "CHUDONET-LTD- Chudonet Ltd.",
    "31089": "SPEEDTELECOM- Speed Telecom",
    "31090": "ISVICRESIGORTA Isvicre Sigorta  Number",
    "31091": "LIGA-UA TOV Informational Analytical Center \"Liga\"",
    "31092": "TTI-TELECOM- T.T.I. Team Telecom International LTD",
    "31093": "ERNST-YOUNG ATAG ERNST-YOUNG AG",
    "31094": "TTKNET OJSC Rostelecom",
    "31095": "SPARIGT- Spar Slovenija d.o.o.",
    "31096": "SECURE- SECURE CONSULTING ENK.",
    "31097": "CORNER Corner Banca SA",
    "31098": "PEDI- Pedi GmbH",
    "31100": "SYNNET-WE synergetic AG",
    "31101": "ROCIS Complete i Solutions",
    "31102": "AT- TV Adler-Trading SRL",
    "31103": "KEYWEB- Keyweb AG",
    "31104": "UKRTELEPORT-N Ukr Teleport Ltd.",
    "31105": "GUGIK- Glowny Urzad Geodezji i Kartografii",
    "31106": "WPT- Wroclawski Park Technologiczny SA",
    "31107": "AKAMAI-NY Akamai International B.V.",
    "31108": "AKAMAI-VA Akamai International B.V.",
    "31109": "AKAMAI-LA Akamai International B.V.",
    "31110": "AKAMAI-SJC Akamai International B.V.",
    "31111": "BNPP- BNP Paribas LTD",
    "31112": "SIBTEL- Siberian Telecommunications Ltd.",
    "31113": "NEWIT- New information technologies",
    "31114": "NAC-LT- Nacionalinis atsiskaitymu centras",
    "31115": "INTRED- INTRED S.P.A. INTERNET PROVIDER",
    "31116": "DH- dhosting.pl Sp. z o.o.",
    "31117": "ENERGOTEL- Energotel, a.s.",
    "31118": "MININFRTR Ministerstwo Transportu, Budownictwa i Gospodarki Morskiej",
    "31119": "ITON- IT-On.Net GmbH",
    "31121": "WPWEB- WpWeb S.r.l.",
    "31122": "DIGIWEB- Digiweb Ltd.",
    "31123": "LBGRNWCH- Royal Borough of Greenwich",
    "31124": "SEFANET- Societe Electrique des Forces de l'Aubonne",
    "31125": "LINETEC- Linetec GmbH",
    "31126": "SODETEL- SODETEL SAL",
    "31127": "SATRO Satro, s.r.o.",
    "31128": "SHAZAM- Shazam Entertainment Limited",
    "31129": "MTP-POZNAN- Miedzynarodowe Targi Poznanskie Sp. z o.o.",
    "31130": "NMNET NM NET ApS",
    "31131": "GRUNDFOS- GRUNDFOS HOLDING A/S",
    "31132": "RESOMATIQUE CIENUM S",
    "31133": "MF-MGSM- OJSC MegaFon",
    "31134": "AMZS- AMZS d.d.",
    "31135": "CANADA-LIFE-GROUP-SERVICES-LTD Canada Life Group Services Limited",
    "31136": "IREC- IREC S",
    "31137": "NAKHODKATELECOM Nahodka Telekom Ltd",
    "31138": "PROEKT- Ltd IPTelecom",
    "31140": "BSE- Bulgarian Stock Exchange AD",
    "31141": "SWISSQUOTE- Swissquote Bank SA",
    "31142": "KLEYREXFFM- KleyReX Kleyer Rebstoecker Internet Exchange",
    "31143": "COSMOSTV- JCLL \"Cosmos TV\"",
    "31144": "WFP United Nations World Food Programme",
    "31145": "PU- State Higher Educational Institution 'Precarpathian National University of Vasyl Stefanyk'",
    "31146": "EBNER- Ebner Industrieofenbau Ges.m.b.H.",
    "31147": "INLINE- Inline Internet Online Dienste GmbH",
    "31148": "FREENET- Freenet Ltd.",
    "31149": "EXPRESSNIKOPOL- Multidisiplin Company Express Ltd",
    "31151": "PHG- Performance Horizon Group LTD",
    "31152": "ENGEL- Engel Austria GmbH",
    "31153": "BAKNET- Bakioglu Holding A.S.",
    "31154": "TMME- Toyota Motor Europe",
    "31155": "INTERHOUSE-LONDON Redbus Interhouse PLC London",
    "31156": "EST-UK- The Energy Saving Trust Ltd",
    "31157": "RELOADNETWORK-N Reload Network",
    "31158": "GARD- Asgard, LLC - RadioEthernet provider",
    "31159": "NETCATHOST- NetcatHosting",
    "31160": "OMCOMTEL- OOO \"Horizont-tour\"",
    "31161": "SCPEXIM SECO SEE d.o.o",
    "31162": "VERINT-LTD- Verint-Systems-LTD",
    "31163": "MF-KAVKAZ- JSC MegaFon",
    "31164": "LABESTEVE- LABORATORIOS DEL DOCTOR ESTEVE SA",
    "31165": "PGF-  of Polska Grupa Farmaceutyczna S.A.",
    "31167": "AXIONE- Axione S",
    "31168": "AIRACCESS- AirAccess GmbH",
    "31169": "NO-KAPITETSLAGET-SOGN Sognenett",
    "31170": "NEXENT- Knowledge Ltd TA Nexent",
    "31171": "COMSYS Comsys ltd.Bulgaria",
    "31172": "QFT- Q-Fast Telecom B.V.",
    "31173": "STM-NETWORKS- STM Networks LLC",
    "31174": "RBA- ZAO RAIFFEISENBANK",
    "31175": "SRISI- Network Federal agency on education",
    "31177": "STCVOIP- Saudi Telecom Co. (STC-Int'l-Comm. VoIP backhaul)",
    "31178": "CELEONET Celeonet",
    "31180": "ORT- ORT",
    "31181": "UFG- Ubezpieczeniowy Fundusz Gwarancyjny",
    "31182": "SB24- Bank Saman",
    "31183": "EMG- JSC \"European Media Group\"",
    "31184": "DE-MBNET-DUS- MB-NET -- Michael Bussmann EDV-Dienstleistungen",
    "31185": "TNPKO- OJSC Rostelecom",
    "31186": "GWS-HAMELN- Witte Buerotechnik GmbH",
    "31187": "UKRTEKHSTROY- Ukrtekhstroy Ltd",
    "31188": "UBER1337-ONLINE-GAMING- Uber1337OnlineGaming-London",
    "31189": "WESTTEL- Electron-M Ltd.",
    "31190": "SPAMHAUS- The Spamhaus Project",
    "31191": "NAUKANET2- LLC \"Nauka-Svyaz\"",
    "31192": "OT- CJSC \"Open Technologies 98\"",
    "31193": "VIATELE- VIA Teleport LLC",
    "31194": "BUSINESS-NETWORK-SERVICE BUSINESS NETWORK SERVICE DI MELI MAURO S.A.S",
    "31195": "MF-DV- OJSC MegaFon",
    "31196": "GLOBAL-MIX Global-MIX Multicast Service",
    "31197": "FNH- FNH media KG",
    "31198": "TELENOR-UK-LTD- Telenor UK Ltd",
    "31199": "EXPRO- Expro Sp. z o.o.",
    "31200": "NTK Novotelecom Ltd",
    "31202": "QUALCOMM Qualcomm Incorporated",
    "31203": "SHARQ-TELECOM The  of CJSC \"Sharq Telekom\"",
    "31204": "SUNCOMMUNICATIONS- JV \"Sun Communications\" Autonomous System",
    "31205": "MF-SIB- OJSC MegaFon",
    "31206": "NUFT- National University Of Food Technologies",
    "31207": "HRLINE- Harghita Line SRL",
    "31208": "MF-CENTER- OJSC MegaFon",
    "31209": "12CONNECT 12Connect",
    "31210": "DTEL-IX- Digital Telecom IX LLC",
    "31211": "SIGMATIC Sigmatic Oy",
    "31212": "INTERPAY- Interpay Nederland B.V.",
    "31213": "MF-NWGSM- OJSC MegaFon",
    "31214": "TIS-DIALOG- TIS-DIALOG Autonomous system",
    "31215": "PURH The Republic of Croatia, Ministry of Finance",
    "31216": "BSOCOM BSO Network Solutions S",
    "31218": "ALVATEC Alvatec Telecom SRL",
    "31219": "MENTHANET-HU- Beltav Ltd.",
    "31220": "CARRENZA- Carrenza Ltd",
    "31221": "EUCLYDE Pop Euclyde Sophia Antipolis",
    "31222": "N-FLYNET Terra S.p.a.",
    "31223": "EA- Electronic Arts Limited UK",
    "31224": "MF-UGSM- OJSC MegaFon",
    "31225": "OBLCOM- JSC Oblcom",
    "31226": "DN-SYSTEMS2 DN-Systems Enterprise Internet Solutions GmbH",
    "31227": "DUCTIL-STEEL Ductil Steel S.A.",
    "31229": "PL-BEYOND- E24 sp. z o.o.",
    "31230": "UNA-UA- UNA",
    "31231": "ZIVILA-KRANJ- Zivila Kranj d.d.",
    "31232": "MEKSA Meksa Yatirim A.S.",
    "31234": "KRAM- KRAM Ltd",
    "31235": "SKIWEBCENTER- SKIWEBCENTER SARL",
    "31236": "RVK- Reykjavik City Hall",
    "31237": "LONALO-IGS LOTERIE NATIONALE - NATIONALE LOTERIJ",
    "31238": "BURGO- Burgo Group S.p.A",
    "31239": "VIENNAWEB- Johann Baldermann",
    "31240": "OLD-HT-SYSTEMS- JSC Hosting Telesystems autonomous system",
    "31241": "P-BE- P.be SA",
    "31242": "TKPSA- TKP S.A.",
    "31243": "ST-ONELINE ST-oneline GmbH",
    "31244": "ETP- MY SERVER MEDIA SRL",
    "31245": "ATI-ISP",
    "31246": "NETBOX- SMART Comp. a.s.",
    "31247": "ARDIS- Torgoviy Dim Equip Electronics LLC",
    "31248": "MULTIA- CPUR Consorzio per le Applicazioni di Supercalcolo",
    "31249": "IEMPRESA-ES- Instituto de Empresa, S.L.",
    "31250": "OD- Online Direct Ltd.",
    "31251": "NETGUARD- Falco Networks B.V.",
    "31252": "STARNET- StarNet Moldova",
    "31253": "CTCLTD- Modern telecommunication systems LLP",
    "31255": "SEUK- SCHNEIDER ELECTRIC INDUSTRIES S",
    "31256": "WARWICKSHIRECC Warwickshire County Council",
    "31257": "ORIONNET-NET JSC \"Orion telecom\"",
    "31258": "JUGRA-BANK- Joint-Stock Commercial Bank JUGRA",
    "31259": "KOMSA- Komsa Group Network",
    "31260": "NEWCOM- LLC 'Santel'",
    "31261": "GARS- GARS Telecom",
    "31262": "EDICOM Intercambio Electronico de Datos",
    "31263": "MYNET- MNET s.r.l",
    "31264": "STIM-COMPUTING- Stim Computing",
    "31266": "INSTOLL- Instoll ltd.",
    "31267": "STROEER- Stroeer Polska Sp. z o.o.",
    "31268": "MF-GPRS- OJSC MegaFon",
    "31270": "FMN Fusion Media Networks Ltd",
    "31271": "RINGIER- Ringier AG",
    "31272": "WILDPARK- ISP WildPark, Ukraine, Nikolaev",
    "31273": "BISNET-LTD- Bisnet Ltd Main  Number",
    "31274": "TURKISHTREURY- Turkish Treasury",
    "31275": "SAMTELECOM- LLC Samtelecom",
    "31276": "HSPEED- Insoft EDV-Systeme und Handelsgesellschaft mbH",
    "31277": "NEWLINE- OOO \"New Line Telecom\"",
    "31278": "INMH Administratia Nationala de Meteorologie RA",
    "31280": "BPS-SA Bank Polskiej Spoldzielczosci SA",
    "31281": "BOFHNET Biuro Obslugi Firm Handlowych s.c. Jan Orzechowski, Maciej Orzechowski",
    "31282": "ATNR Atlas Telecom Network Romania S.R.L.",
    "31283": "FTHOST- Availo",
    "31285": "HSBC- HSBC Trinkaus & Burkhardt KGaA, Duesseldorf",
    "31286": "INTELSET- Television Radio Company \"TBT\" OJSC",
    "31287": "IPACCT- IPACCT Ltd.",
    "31288": "PMCS- PM Computer Services GmbH & Co KG",
    "31289": "NOSTRA- Joint Limited Company Nostra",
    "31290": "MURPHX-UK- Daisy Communications Ltd",
    "31291": "SKKNET- SKKNET LTD",
    "31292": "BLACKHAT- Peter Salanki",
    "31293": "QOSS- Quintessence Ltd.",
    "31294": "LANTECH- STIS Engineering Company Limited",
    "31295": "EXPERTLUWY- Expert Luwy",
    "31296": "MC21- MC-21 Security Systems Ltd.",
    "31297": "AXIAN-HU- Axian Kft.",
    "31298": "SSTECH--NUMBER Smart Software Technologies Ltd.",
    "31299": "MIND-SOFTWARE MIND SOFTWARE SRL",
    "31300": "FT-INTERNET Financial Times Ltd",
    "31302": "TSRV- TELECOMSERVIS Autonomous System",
    "31303": "NIOC- National Iranian Oil Company",
    "31304": "ESPOL- Espol Sp. z o. o.",
    "31305": "ALBA-ISP DKM Ltd",
    "31306": "N-INFONET-GZE Infonet-GZE Sp. z o.o.",
    "31307": "YKYATIRIM Yapi Kredi Yatirim Menkul Degerler A.S.",
    "31308": "NETWLAN Prespa-Bosilkov Ltd",
    "31309": "NMV- New Media Ventures BVBA",
    "31310": "PL-AXIT- Axit Sp. z o.o.",
    "31311": "VDO-X- Jet Stream B.V.",
    "31313": "STS Serviciul de Telecomunicatii Speciale",
    "31314": "DGS- Digital-Service LLC",
    "31315": "VWFSAG- VOLKSWAGEN BANK POLSKA S.A.",
    "31317": "VACHEV- Vachev Net Ltd.",
    "31318": "DATA-TECH- Data Technology",
    "31319": "ESTRACOM- ESTRACOM SPA",
    "31320": "WSMSIG- Wyzsza Szkola Menedzerska SIG",
    "31321": "STARTELECOMSPB- Startelecom Severo-Zapad JSC",
    "31323": "UNNET- United Networks Ltd.",
    "31326": "MTR-SVIAZ- JSC MTR-Sviaz",
    "31327": "TELESERVICIOS- FUNDOSA TELESERVICIOS S.A.",
    "31328": "SCHNEIDER- SCHNEIDER ELECTRIC INDUSTRIES S",
    "31329": "VECTRANET- VECTRA S.A.",
    "31331": "LINNEA Logica Norr AB",
    "31332": "INDUSTRIA-DE-TURBO-PROPULSORES- Industria de Turbo Propulsores S.A.",
    "31333": "VOLLMAR- vollmar.net GmbH",
    "31334": "KABELDEUTSCHLAND- Kabel Deutschland Vertrieb und Service GmbH",
    "31336": "TFRUSTEL- LLC Telecommunication Company Region Telecom",
    "31337": "ELEET- ELEET Networks",
    "31338": "MTU-INFORM MTS OJSC",
    "31339": "REACTIVE- Reactive Networks Ltd",
    "31341": "CAJAESPANA- Caja Espan~a de Inversiones, Caja de Ahorros y Monte de Piedad",
    "31342": "DE-CLANOTOPIA-DUS- Clanotopia IT-Service Ltd.",
    "31343": "INTERTELECOM Intertelecom Ltd",
    "31344": "IPPE- Federal State Unitary Enterprise 'State Scientific Center of Russian Federation Institute of Physics and Power Engineering of A.I. Leylunskiy'",
    "31345": "MAGISTRAL2- Business Network JV",
    "31346": "DDOL- Datadec Online S.A.",
    "31347": "PORTAONE- Porta One-Chernihiv Ltd",
    "31348": "NACURA- nacura it-SERVICE GmbH & Co. KG",
    "31349": "HAGEMEYER- Hagemeyer Autonomous System",
    "31350": "ITM- Private enterprise ITM",
    "31351": "INTERIP- INTERIP BV network",
    "31352": "MAINOVA- Mainova AG",
    "31353": "PTT- OJSC Rostelecom",
    "31354": "IWAVE- IWAVE SOLUTIONS SRL",
    "31356": "MIT-CH MIT Meyer Information Technology AG",
    "31357": "TOMICA- Tomsk Information and Consulting Agency",
    "31359": "FORATEC- OJSC \"Vimpelcom\"",
    "31360": "UITC- Private Joint-Stock Company \"INTER TV-CHANNEL\"",
    "31361": "UNIT-IT- unit-IT Dienstleistungs GmbH & Co KG",
    "31363": "DCNI- JSC \"Digital channels network\"",
    "31364": "INTELBI- Closed Joint-Stock Company \"Intelbi\"",
    "31365": "SGSTELEKOM SGS Telekom Autonomous System",
    "31367": "NEO-CUST Neo Telecoms Group",
    "31368": "TELNET- Astelnet Ltd.",
    "31369": "NSSI- National Social Security Institute",
    "31370": "MOSLINE- OOO Montaj Telecom Service",
    "31371": "WISSENSCHAFTSLADEN- Wissenschaftsladen Dortmund e.V.",
    "31372": "BEW BE&W Agencja Fotograficzna Sp. z o.o.",
    "31374": "BWCOM-AT EBE-EDV-Beratungs- und Entwicklungs-Gesm.b.H.",
    "31375": "RELOUFR- ANTOINE VERSINI",
    "31376": "SMART- Smart Telecom Limited",
    "31377": "AKAMAI-BOS Akamai International B.V.",
    "31378": "MEDIA-INET- Media Internet Technologies LTD",
    "31379": "FPF- Federal Agency for State Property Management",
    "31380": "CYBERSYSTEMS-HU- CYBER Hosting Kft",
    "31381": "WSIZ- Wyzsza Szkola Informatyki i Zarzadzania",
    "31382": "KAPSCH- Kapsch BusinessCom AG",
    "31383": "NEDERLANDNET- Computel Standby BV",
    "31386": "ATCANET- OCIACION TECNICA CAJ DE AHORROS, A.I.E",
    "31387": "BRIVARIS- FOP Zahvatkina Svitlana Mukolayivna",
    "31388": "NVPCONNECT NVP-Connect Ltd.",
    "31389": "IWNET- Oy IW-Net Ltd",
    "31391": "ISOC-IL- Israel Internet Association",
    "31393": "DK-INBODAN- IDdesign A/S",
    "31394": "NEMOX-NET- nemox.net",
    "31396": "FQDN-ORG fqdn.org",
    "31398": "NEC-EU- NEC Europe Ltd",
    "31399": "DAIMLER- Daimler Autonomous System",
    "31400": "ACCELERATED-IT Accelerated IT Services GmbH",
    "31401": "SICAMSERV Credito Agricola Servicos - Centro de Servicos Partilhados, ACE",
    "31402": "BLUESQUARE Blue Square Ltd",
    "31403": "INVA- IN.VA.'s Autonomous System",
    "31404": "LYCATEL- LYCATEL DISTRIBUTION UK LIMITED",
    "31407": "CACC- Cara Angy CRIS COMIMPEX SRL",
    "31408": "ORANGE-PALESTINE Orange Palestine Group Co. for Technological Investment Joint Stock Private Company",
    "31409": "SELTELECOM-NET Sel Telecom S.A.",
    "31410": "NWC- Network Communications ltd.",
    "31411": "ORG-ICGP1-RIPE- Irish Continental Group Plc data centre",
    "31412": "SMTVSAT-TRAL- STOWARZYSZENIE MILOSNIKOW TELEWIZJI SATELITARNEJ TRAL",
    "31413": "UNICER- Unicer Bebidas SA",
    "31415": "SVSCOMM- SVS Communication",
    "31416": "APPTEC-NETWORK Applied Technologies Co",
    "31417": "MIVTACH-SIMON- Mivtach Simon Insurance Agencies Ltd",
    "31418": "SOGECABLE-ES- SOGECABLE Autonomous System",
    "31419": "SATCOM-IT- SATCOM S.P.A.",
    "31420": "TERYST- Terasyst Ltd",
    "31421": "YUG-SVYAZ-SERVICE- Yug Sviaz Service Ltd",
    "31422": "AONUK- AON UK LIMITED",
    "31423": "PROMAX- Przedsiebiorstwo \"PROMAX\" Spolka Jawna Zofia Formanek-Mroczkowska Wieslaw Okroj",
    "31424": "NEXELLENT- nexellent ag",
    "31425": "FORATEC- OJSC \"Vimpelcom\"",
    "31426": "VISN Vision Internet Limited",
    "31427": "KHARTRON- TOV VTP Khartron Elektrosvyaz",
    "31428": "ALTADIS-ES- Altadis Distribution France S.A.S.",
    "31429": "SPYMAC- Clanotopia GmbH",
    "31430": "TEL-NET- Closed joint-stock company \"Telecommunication company TEL\"",
    "31431": "INTERCARS Inter Cars SA",
    "31432": "KEFFNET KeFF Autonomous System",
    "31434": "WINKOWSKI-NET-POLAND- 'QUAD/WINKOWSKI' sp.z o.o.",
    "31435": "MEDICOM-BG Medicom.BG, Sofia, Bulgaria",
    "31436": "PSTELECOM- LLC Telecom MPK",
    "31437": "PUIG LTD \"Persha Ukrainska informatsiyna gruppa\"",
    "31438": "SWMR- Citynet Marburg, Stadtwerke Marburg GmbH",
    "31439": "TTG- OOe Tourismus Technologie GmbH",
    "31440": "DSK- DSK Bank EAD",
    "31441": "GR- Gagnaveita Reykjavikur ehf",
    "31443": "BNB- Theodosios Rouselis & AFOI O.E.",
    "31444": "SEANET- SeaExpress Ltd.",
    "31445": "TTC- Top Systems LLC",
    "31446": "BETANDWIN2- bWin Interactive Entertainment AG",
    "31447": "SOFTRATING- Soft-Rating Consult ltd.",
    "31448": "NU-UA- Public organisation \"Fund of the regional initiatives \"GART\"",
    "31449": "31449 BELCENTER SPRL",
    "31450": "CCD1- Cortal Consors S.A.",
    "31452": "MTC-VB- MTC-Vodafone Bahrain",
    "31453": "LANWORX- Lothlorien Consulting Ltd",
    "31454": "FLANCO- FLANCO RETAIL SA",
    "31455": "INTRALINK- SC Intralink Srl",
    "31457": "EOS- EOS Data Systems GmbH",
    "31458": "SMARTTELECOM- Smart Telecom Autonomous System",
    "31459": "BBC-RD- BBC",
    "31460": "UNIKAL Unikal Ltd",
    "31461": "MORAVIA-IT- Moravia IT, a.s.",
    "31462": "ABSOLUTBANK- AKB \"Absolut Bank\" (ZAO)",
    "31463": "FOURD- 4D Data Centres Ltd",
    "31465": "ALMA-MEDIA-REGIONS- \"Complex Service Company\" LLC",
    "31466": "LANTAN-CS- JSC LANTAN-CS",
    "31467": "ARCGR- Arca SGR S.p.A.",
    "31468": "AVTOZAZ- ZAT Z Inozemnou Investiceu \"Zaporizkii Avtomobilebudivnii Zavod\"",
    "31469": "GOLSI- PE Vasylevych Olha",
    "31470": "CHEMK- OJSC Chelyabinsk Electric-Metallurgical Kombinat",
    "31471": "FINTEK- FINTEK Finansal Teknoloji Hizmetleri A.S.",
    "31472": "VOICEHOST VoiceHost Ltd",
    "31473": "BEARINGPOINT-MANAGED- Infonova GmbH",
    "31474": "MTV-UK- MTV Networks Europe",
    "31475": "METROCOM- Metrocom, Dnipropetrovsk, Ukraine",
    "31476": "MORVA- Morva System Company",
    "31477": "DUOCT- Duocast B.V.",
    "31479": "IPORIUM IPORIUM NETWORKS",
    "31480": "GLOBAL-TS- CJSC Global TeleSystems",
    "31481": "TOYOTA-TIS- TOYOTA Informations Systeme GmbH",
    "31483": "DELTA-TELECOM-URAL- Delta-Telecom Ltd.",
    "31484": "DIRECT-TELECOM- OOO Direct Telecom",
    "31485": "ALTTEL- ALTTEL, Moscow, Russia",
    "31486": "DJINN- Casa Djinn S.R.L.",
    "31487": "VARTECONLINE VarTec Telecom UK Ltd",
    "31488": "AIWAGULF Aiwagulf",
    "31489": "PIB- ProminvestBank",
    "31491": "OPTITEL- OptiTelecom, Moscow, Russia",
    "31492": "UZSCI- Uzbek Scientific & Education Network",
    "31493": "TWENTYTWENTYMEDIA- 2020Media.net.uk 31493",
    "31494": "INFOSETI- Autonomous System of Infoseti JSC",
    "31495": "TELERETE- Telerete Nordest s.r.l.",
    "31496": "ATNET- OJSC Rostelecom",
    "31497": "CMVM-PT- Comissao do Mercado de Valores Mobiliarios",
    "31498": "KAERCHER- Alfred Karcher GmbH & Co. KG",
    "31499": "YCC-",
    "31500": "GLOBALNET- JSC GLOBALNET",
    "31501": "SPBTELEPORT- SPB-TELEPORT Autonomous System",
    "31503": "NEWLINE New line, Ltd.",
    "31504": "NETSOFT- NETSOFT LTD",
    "31505": "DUNA- Przedsiebiorstwo Produkcyjno-Uslugowo-Handlowe 'Duna' Dunaj Piotr",
    "31506": "N-YS-IX Yuzhno-Sakhalinsk Internet eXchange",
    "31507": "SERVANET- ServaNet ISP Multihomed Internet Service",
    "31509": "W2NETWORKING W2 Networking Ltd",
    "31510": "IKB- Innsbrucker Kommunalbetriebe AG",
    "31511": "B-RAIL-BE- N.M.B.S. HOLDING N.V./ S.N.C.B. HOLDING S.A.",
    "31512": "LOGICA- JSC Logica",
    "31513": "TVTEL TVTEL - Grande Porto Comunicacoes SA",
    "31514": "INF-NET- LLC \"Multiscan\"",
    "31515": "INMARSAT INMARSAT GLOBAL LIMITED",
    "31516": "REG-PIEMONTE- Piedmont Regional Administration",
    "31517": "SKODA- SkodaAuto Deutschland GmbH",
    "31518": "NDR- Norddeutscher Rundfunk",
    "31519": "VOICECOM- SIA \"ECO NETWORKS\"",
    "31520": "ITSN- ARTAVIANA",
    "31521": "DOM- DOM Digital Online Media GmbH",
    "31522": "BTV-BG Balkan News Corporation EAD",
    "31525": "SATTI-ZHULDYZ- Satti Telecom Ltd.",
    "31526": "TEKOFAKS- TEKOFAKS",
    "31527": "TELEPOL- Telepol Security",
    "31528": "BOSBANK- Bank Ochrony Srodowiska SA",
    "31529": "DENIC-ANYCT- DENIC eG",
    "31530": "DWL-NET ISP-Solution Unternehmergesellschaft (haftungsbeschrankt)",
    "31531": "POINT- TOV Point",
    "31532": "SKYBET- Hestview Limited",
    "31533": "NUON-ETRM NV Nuon Energy Trade & Wholesale",
    "31534": "ING-BANK- ING Bank N.V. - Sofia Branch",
    "31535": "IDESTA- Idesta Solutions LTD",
    "31536": "DNISTER- JSC Selyanskyi Commercial Bank \"Dnister\"",
    "31537": "REFORMATORISCHDAGBLAD- Erdee Media BV",
    "31540": "AQUANET-PL Aquanet S.A.",
    "31541": "DIGITURK Krea Icerik Hizmetleri ve Produksiyon A.S",
    "31542": "OMEGAAUTO Trade Industrial Company Omega-Avtopostavka Ltd",
    "31543": "MYNET- myNET Internet Solutions",
    "31544": "RTC RTC Real Time-Center AG",
    "31545": "SLOVENICA- Adriatic Slovenica Zavarovalna druzba d.d.",
    "31546": "NORMA- \"NORMA TELECOM\" S.R.L.",
    "31547": "MCK-EUROPE- McKinsey & Company Inc United Kingdom",
    "31549": "RANA Aria Shatel Company Ltd",
    "31550": "DYCKERHOFF- Dyckerhoff AG",
    "31551": "F-DESIGN- SC F Design SRL",
    "31552": "PRONET- PRONET COM SRL",
    "31553": "EDPNETRU- Talessa SPRL",
    "31554": "ALTFEL SC Almsoft Computers SRL",
    "31555": "GROUPEMIT- Neo Telecoms S.A.S.",
    "31556": "ARCADAX- ARCADA-X Limited Company",
    "31557": "IGT-MOLD-NET- \"IGT Communications\" S.R.L",
    "31558": "ZGTK- ZhelGorTeleKom, Zheleznogorsk",
    "31559": "HORACKO Zdenek Soucek",
    "31560": "INSOURCE FOP Loginov Andrey Vyacheslavovich",
    "31561": "DATATEL- Data.tel LLC",
    "31562": "OPENMARKET OpenMarket Limited",
    "31563": "HNMS- National Meteorological Service",
    "31564": "HEXAGLOBE- HEXAGLOBE S",
    "31565": "SSSL- Symantec Limited",
    "31566": "SKYNETWORK SkyNetwork Ltd.",
    "31568": "ALVNET Alvnet Network",
    "31570": "BENTEC- Benind Spa",
    "31572": "PHOTONIUM- Photonium NetSolutions GmbH",
    "31573": "MM-LOGISTIK- ET Logistik Sp. z.o.o",
    "31574": "SE-BGC- Bankgirocentralen BGC AB",
    "31575": "MIET National Research University of Electronic Technology",
    "31576": "MOGEIX Association Gixe",
    "31577": "PRORED ProRed Comunicaciones Autonomous System",
    "31578": "MAGIC-SOFTWARE-IL- Magic-Software-Enterprises-Ltd",
    "31579": "SANDB- S&B Industrial Minerals S.A.",
    "31580": "MD-IX- Moldtelecom SA",
    "31581": "KOPINT- National Infocommunications Service Company Limited by Shares",
    "31582": "HOSTLINE ISP HOSTLINE",
    "31584": "CCO- Akzo Nobel Nederland B.V.",
    "31585": "N-COLTEL JSC \"Columbia-Telecom\"",
    "31586": "KDIS- XL Internet Services B.V.",
    "31587": "POSTELECOM SC POSTELECOM SA",
    "31588": "N-STKNET JSC SVYAZTELEKOM, Magnitogorsk, Russia",
    "31589": "ZSTAL- Zaporizhstal Integrated Iron & Steel Works JSC",
    "31590": "RACKHOSTING- Rackhosting.com ApS",
    "31591": "EDATIS- Edatis S",
    "31592": "KERNEN Kernen Consulting",
    "31593": "BLACKSEA TV Company \"Black Sea\" Ltd",
    "31595": "AWELL-WIRELESS- AwellConnected.Com",
    "31596": "WPPS- Ogilvy & Mather Deutschland GmbH",
    "31597": "TW-PRODUCTIONS- IT Complete BV",
    "31598": "TELECOMAX- FOP Savostin Oleg Lubobisch",
    "31599": "RIMCO Rimco Ryszard Slomczynski",
    "31600": "CERAMICA- Credit Ceramics autonomous system",
    "31601": "WIRTSCHAFTSBLATT- WirtschaftsBlatt Verlag AG",
    "31602": "RLE- Elisa Eesti",
    "31603": "TMVS TeleSpectrum Managed Voice Services",
    "31604": "INTERTELE- Intertele S.A.",
    "31605": "CANALS- Canal S SRL",
    "31606": "ARTRADE- TELEDATANET SRL",
    "31607": "MOBI- MobiMedia AG",
    "31608": "GAWEX- Gawex Media sp. z o. o.",
    "31609": "TELESON- SC Teleson SRL",
    "31610": "CUBIC SC CUBIC SRL",
    "31611": "ABILENE- Abilene Net Solutions S.r.l.",
    "31612": "AGFA- AGFA GEVAERT NV",
    "31613": "CLNEVA- JSC Comline-Neva",
    "31614": "ECB- European Central Bank",
    "31615": "TMO-NL- T-mobile Netherlands",
    "31616": "URALAUINVEST- JSC Ural-Austro Invest",
    "31617": "SALVIX- Salvix S.r.l.",
    "31618": "UTC- United Technologies International Operations Inc",
    "31619": "CITYSTARS-",
    "31620": "EXPOCENTR- JSC Expocentr",
    "31621": "QXL-NET-POLAND- Grupa Allegro Sp. z o.o.",
    "31622": "BRAIN- Berlin Research Area Information Network (BRAIN)",
    "31623": "WLNET WLnet Wiktor Roszkowski",
    "31624": "VFMNL- Verza Facility Management BV",
    "31625": "EXALIA- Exalia Ltd",
    "31626": "ZVITELECOM- OOO \"ZVI Telecom\"",
    "31627": "SERMEPA-ES- Servicios Para Medios De Pago SA",
    "31628": "ROBBO- Robbo Computer Net Robert Szamota",
    "31629": "LOREAL- LOREAL SA",
    "31630": "GENELEC-INET- Genelec Ltd.",
    "31632": "OAG- OAG Aviation WorldWide Limited",
    "31633": "LANTELECOM- PP Lan-Telecom",
    "31634": "HEMAB HEMAB ISP multihomed internet service",
    "31635": "SLIB- SLIB",
    "31636": "HENKEL-AT Henkel AG & Co. KGaA",
    "31637": "MECUK- WPP Group Technology Services",
    "31638": "N-LEPIDA Lepida S.p.A.",
    "31640": "CITYLIFELINE- City LifeLine Limited",
    "31641": "BYTEL- Bytel Ltd",
    "31642": "STADSNAT Regional Internet Exchange (RIX)",
    "31643": "GES- Gorodskaya elektronnaya svyaz Ltd",
    "31644": "NEAB-ETANET- CityNet Norrtelje Sweden",
    "31645": "TEKFENBANK- EUROBANK TEKFEN A.S",
    "31646": "N-WSHE Akademia Humanistyczno-Ekonomiczna w Lodzi",
    "31647": "TMSF- TARRUF MEVDUATI SIGORTA FONU",
    "31649": "RIPN-FDNS-RU-NYC Russian Backbone Network",
    "31650": "GVA Generalitat Valenciana",
    "31651": "INTERXION-BE-TRANSIT- Interxion Belgium NV.",
    "31652": "WEBHOSTS- Web Hosts Ltd",
    "31653": "FILNET- Filnet Serveis i Comunicacions, SL",
    "31654": "BTINTERNATIONAL- VODAFONE NET ILETISIM HIZMETLERI ANONIM SIRKETI",
    "31655": "N-GAMMATELECOM Gamma Telecom",
    "31656": "GIGA-URB-R ITS Ltd",
    "31657": "N-STEALTHNET StealthNet Ltd",
    "31658": "EURON Euron Sp. z o.o",
    "31659": "BELOW-ZERO Below Zero Hosting Ltd.",
    "31660": "PIXTEL- PIXTEL",
    "31661": "COMX ComX Networks A/S",
    "31662": "KNSURSELVA aurax connecta AG",
    "31664": "UNETCOM- PE Unetcom",
    "31665": "INVESCO- Invesco UK Ltd.",
    "31667": "FRESHACCESS- Fresh Access LTD",
    "31668": "RAPPAPORT EDV-Dienstleistungen Rappaport GmbH & Co KG",
    "31669": "ITSS- Riffle Media BVBA",
    "31670": "AUTOPREMIUM- Autopremium Sp. z o.o.",
    "31671": "AKTINFOSYS AKT Informationssysteme AG",
    "31672": "CONTROLCIRCLE-UK- Control Circle Ltd",
    "31673": "UNISERVER- Uniserver Internet B.V.",
    "31674": "VEDOP-II T.C. Maliye Bakanligi Gelirler Genel Mudurlugu",
    "31675": "AGE-CONCERN-ENGLAND  for Age Concern England",
    "31676": "EUROMETAL- Eurometal Management & Consulting SRL",
    "31677": "OBDURO- Obduro Network AB",
    "31679": "SLOVANET-MICRONET Slovanet a.s.",
    "31680": "SITEBYTES- sitebytes.nl Autonomous System",
    "31682": "DIOSOFT- DIOSoft Ltd.",
    "31683": "ZMPG- Zarzad Morskiego Portu Gdynia S.A.",
    "31684": "PROV-TORINO- Province of Turin Administration",
    "31685": "TIM- TOV Teleradiocompany \"TIM\"",
    "31686": "NETISON- netison di festa stefano e c. s.n.c.",
    "31687": "PPTUJ- Perutnina Ptuj d.d.",
    "31688": "SPLIO- Splio Developpement",
    "31689": "EMU- Eastern Mediterranean University",
    "31690": "GEOCOMMUNICATIONS- OOO GeoTelecommunications",
    "31691": "NETCORP- Netcorp Company",
    "31692": "SATURN-R- OOO Saturn-R",
    "31693": "WANAGAIN Wan Again Autonomous System",
    "31694": "GSCP General Secretary of Civil Protection (GSCP)",
    "31695": "IM- Limited Company \"Intermedia\"",
    "31696": "MTS- SC MTS Leasing SRL",
    "31697": "E-QUAL- e-Qual",
    "31698": "WEBHOST-  Number for WebHost.ie Ltd",
    "31699": "BANK-AL-JAZIRA- bank al jazira aut.name",
    "31701": "CONSULINTEL- Consulintel Autonomous System",
    "31702": "GRECO-INTERNATIONAL- GrECo International Holding AG",
    "31703": "INTERMAX- Mobil-group ltd",
    "31704": "ROBERTCOLLEGE- Private American Robert College",
    "31705": "EUMETSAT-OPS EUMETSAT",
    "31706": "ITALYCOM I-NetCom s.a.s.",
    "31707": "MATI- State Educational Institution of Higher Professional Education \"MATI\" Russian State University of Aviation Technology named after K.E. Tsiolkovsky.",
    "31708": "COREIX-UK- Coreix Limited",
    "31709": "COMPARE Cortex Consult A/S",
    "31710": "GIR- Grupul Industrial Roman GIR S.A.",
    "31711": "HYPO-SI- Hypo Leasing d.o.o.",
    "31712": "GIGTREAM- Gigastream plc",
    "31713": "GWCOMMS-MPLS Gateway Communication",
    "31715": "NETRINO- Hicap Networks Limited",
    "31716": "VGN VGN OD KOSOVSKA MITROVICA",
    "31717": "QUARTARETE- Quarta Rete S.p.a.",
    "31720": "ENGINET- CJSC ENGINET",
    "31721": "AZERCELL- Azercell Telecom",
    "31722": "COMSPE- tegut... Gutberlet Stiftung & Co",
    "31723": "WB-NET- Wittenberg-net GmbH",
    "31724": "SVYAZIST- Joint Stock Company Svyazist",
    "31725": "SHTORM- ISP Shtorm Ltd",
    "31726": "TELEFIBER Telefiber",
    "31727": "NODE4- Node4 Limited",
    "31728": "ADALE- ADALE SISTEMI SRL",
    "31729": "ITCS- ITCS Sp. z o.o.",
    "31731": "ADIX- ADIX B.V.",
    "31732": "IR-PARSUN Parsun Network Solutions, IR",
    "31733": "RYA- RYANAIR LIMITED",
    "31734": "STAGE- STAGE EXPERT SRL",
    "31735": "UNISERV- UNISERV GmbH",
    "31736": "SENSELAN- senseLAN GmbH",
    "31737": "DERBYNET DERBYNET",
    "31738": "NRCDE- Novosibirsk Regional Center of Distance Education",
    "31739": "ATL-INTERNET ATL INTERNET SL",
    "31741": "TOTSA TOTSA TOTAL OIL TRADING SA",
    "31742": "SOTACONNECT Sotaconnect Network",
    "31743": "IPGGIS-UK- Interpublic GIS (UK) Ltd",
    "31744": "MULTIBAND-NEWHOPE - Multiband",
    "31745": "SPIRETECH - Spire Technologies",
    "31746": "FANDM - Franklin and Marshall College",
    "31747": "BLACKROCK-FINANCIAL-MANAGEMENT-2 - BlackRock Financial Management, Inc.",
    "31748": "ALTERIAN - Alterian, Inc.",
    "31749": "FKNC- - Fort Knox National Company",
    "31750": "METHODIST-HEALTHCARE - Methodist Hospital of Memphis",
    "31751": "-MB-1 - The Market Builder, Inc",
    "31752": "UNITZ- - Unitz Online",
    "31753": "SEGOVIA - Segovia, Inc.",
    "31754": "NORTHWEST-FINANCIAL-CORP - Northwest Financial Corp",
    "31755": "VISKE-COMPANIES-INC-N - Viskase Companies, Inc.",
    "31756": "COLORADOSPRINGS-GOV - City of Colorado Springs",
    "31757": "N-VALLEYCREST - ValleyCrest Companies",
    "31759": "LARABIDA - La Rabida Hospital",
    "31760": "E-NOVATIONS - e-Novations ComNet Inc.",
    "31761": "TALISEN-TECH - Talisen Technologies Inc.",
    "31763": "BCIU - Berks County Intermediate Unit",
    "31764": "OAKLAND-USD-NET - OAKLAND UNIFIED SCHOOL DISTRICT",
    "31765": "FUNDSERV - FundSERV Inc.",
    "31766": "UPS-12-N - University of Puget Sound",
    "31767": "SSREBGP - SMITH SECKMAN REID, INC",
    "31768": "RAPID-RESPONSE - RAPID RESPONSE MONITORIN",
    "31769": "RAINBOW-BROADBAND - Rainbow Broadband, Inc.",
    "31770": "CMMC-I2 - Children's Memorial Medical Center",
    "31771": "N-CXA-SNTB-31771-CBS - Cox Communications Inc.",
    "31772": "OMEGABYTE-COMPUTER-CORPORATION - Omegabyte Computer Corporation",
    "31773": "-COREBTS-1 - Core BTS, Inc.",
    "31774": "TACONIC-CAPITAL-ADVISORS - Taconic Capital Advisors L.P.",
    "31775": "AMR- - Allegiance Marketing Resources, LLC.",
    "31776": "BUSINESS-WIRE-NY - Business Wire",
    "31777": "SPARCC- - Stark Portage Area Computer Consortium",
    "31778": "CCADE-MEDICAL-IMAGING - Cascade Medical Imaging",
    "31779": "DPV - Data Pangea LLC",
    "31780": "TRINITYPARTNERSWALTHAMCONNECTION - TRINITY PARTNERS",
    "31781": "CEPM-US - Corporate Express Promotional Marketing",
    "31782": "WLU - Wilfrid Laurier University",
    "31783": "SKRC-SOUTH01 - SkyRider Communications, Inc.",
    "31784": "ETCETERN - EMERGING TECHNOLOGY CENTER",
    "31785": "HBS- - Heartland Business Systems",
    "31786": "ELIETAHARI-N-01 - Elie Tahari",
    "31787": "WRIGHTMEDICAL - WRIGHT MEDICAL TECHNOLOGY",
    "31788": "VISTARCORPORATION - VISTAR Corporation",
    "31789": "DTC-PRD- - DELTELCO, INC.",
    "31790": "SANDC-CA - S&C Electric Canada Ltd.",
    "31791": "REGION16-ESC - Region 16 Education Service Center",
    "31792": "PHONEFACTOR-01 - PhoneFactor, Inc.",
    "31793": "BROADSTAR - Primecast",
    "31794": "CARIBANK - Caribbean Development Bank",
    "31795": "FRESH-EXPRESS - Fresh Express",
    "31796": "SNA-40 - Security Network of America",
    "31797": "GALAXYVISIONS - Galaxyvisions Inc",
    "31798": "KW-DATACENTER - KW Datacenter",
    "31799": "UMEDIA - uMedia",
    "31800": "DALNET - DALnet",
    "31801": "BHS-NET-LOU - Baptist Healthcare System",
    "31802": "CYPRESS-TELECOMMUNICATIONS - Cypress Telecommunications",
    "31803": "MMPLP - Magellan Midstream Partners, L.P.",
    "31804": "-BFC - Bissingers French Confections",
    "31805": "ANSWER-FINANCIAL - Answer Financial Inc.",
    "31807": "CLEARSURF01 - CLEARSURF BROADBAND",
    "31808": "ISCKY - Computer Mendtor LLC",
    "31809": "PROMERO-BGP - Promero Inc",
    "31810": "AOTL-",
    "31811": "MTCC - Manti Tele Communication Company",
    "31814": "FSI - FlightSafety International",
    "31815": "MEDIATEMPLE - Media Temple, Inc.",
    "31816": "NMDP - National Marrow Donor Program",
    "31817": "PSC - Progress Software Corp - CSG",
    "31818": "RIDGEWOODPOWER-NJ - Ridgewood Power",
    "31819": "PRAESES - Praeses Corporation",
    "31820": "PUGMARKS - PUGMARKS",
    "31821": "-RCS - Riverdale Country School",
    "31822": "CITY-UNIVERSITY-OF-NEW-YORK - City University of New York",
    "31823": "CALL-O-CALL-1 - Call-O-Call, Inc.",
    "31824": "HF-25B - HF Management Services, LLC",
    "31825": "STARWOOD-VO - Starwood Vacation Ownership",
    "31826": "NFBA - North Florida Broadband Authority",
    "31827": "BNT-NETWORK-ACCESS - Biz Net Technologies",
    "31828": "SHU--I2 - Seton Hall University",
    "31829": "HRV - Heruvim, Inc",
    "31830": "SPCORPNETS - Schering-Plough Corporation",
    "31831": "SIMONDSINTL - Simonds International Corporation",
    "31832": "N-MDT - Member Driven Technologies",
    "31833": "INTERNEX-SOLUTIONS - Internex Solutions LLC",
    "31834": "TELA-N - TELA, INC.",
    "31835": "CONTOUR-NETWORKS - Contour Networks",
    "31836": "USLI - United States Liability Insurance Group",
    "31837": "LION-BILLERICA - Lionbridge Technologies, Inc.",
    "31838": "OPNET - OPNET Technologies",
    "31839": "GORDIAN-HEALTH-SOLUTIONS - Onlife Health, Inc.",
    "31840": "HAVENS - Havens Advisors",
    "31841": "NKTC - NEW KNOXVILLE TELEPHONE COMPANY",
    "31842": "KHRONOS - Khronos LLC",
    "31843": "VERIZON-LIVESOURCE - Verizon LiveSource",
    "31844": "HOLDBROTHERS - Hold Brothers Online Investment Services, LLC",
    "31845": "INAP-LLC - iNAP",
    "31846": "DIGIPORT - Digiport",
    "31847": "REUTERS-NORTH-AMERICA - Reuters North America",
    "31848": "DVUSD - Deer Valley Unified School District #97",
    "31849": "PINNACLE - TGM Pinnacle Network Solutions llc",
    "31850": "AWECOMM - Awecomm Technologies, LLC",
    "31851": "101-WEB-HOSTING-SERVICE-LLC - 101 Web Hosting Services, LLC",
    "31852": "AAM-LLP Arden Asset Management",
    "31853": "EMS- - Express Messenger Systems, Inc.",
    "31855": "HPES - Hewlett-Packard Company",
    "31856": "CABS",
    "31857": "PRIORITY-TERABIT - Ptera Wireless Inc.",
    "31858": "MWNA-N - MARSHALL WACE NORTH AMERICA L.P.",
    "31859": "ANGELINA-COUNTY - ANGELINA COUNTY",
    "31860": "MACKAY-SHIELDS - MacKay Shields LLC",
    "31861": "CG-ADVANCED-DEVELOPMENT-CHI - Cap Gemini Ernst& Young U.S., LLC - ADC",
    "31863": "DACEN-2 - Dacentec, Inc.",
    "31864": "TRANSWAVE-COMMUNICATIONS-SYSTEMS-INC - Transwave Communications Systems, Inc.",
    "31865": "SWK - THE STANLEY WORKS",
    "31866": "NPCI-HOME - Nationwide Publishing Company, Inc",
    "31867": "NES1-ENT - NES National Enterprise Systems",
    "31868": "CAPECOMINC - Cape.Com, Inc.",
    "31869": "LL-BEAN - LL Bean",
    "31870": "AP-CA-BC-NW6 - AdPerfect Dynamic Advertising Solutions Ltd.",
    "31871": "GRACELANDUNIVERSITY - Graceland University",
    "31872": "ETERN-CENTER-FOR-ARTS-AND-TECHNOLOGY - Eastern Center for Arts and Technology",
    "31873": "UWF- - University of Wisconsin Foundation",
    "31874": "LPS-4 - Lender Processing Services Inc",
    "31875": "HPFMIA- - Hochheim Prairie Farm Mutual Insurance Association",
    "31876": "K2SHARE-TXRICVRC - K2Share LLC",
    "31877": "GPW - GEORGIA PUBLIC WEB, INC.",
    "31878": "JCVI- - J. Craig Venter Institute, Inc.",
    "31879": "PBM - PACIFIC BLUE MICRO, INC.",
    "31880": "NUGCA- - Nestle USA- Globe Center AMS",
    "31881": "MTNINC - MTN (Maritime Telecommunications Network)",
    "31882": "STRYK-1A - Stryker Endoscopy",
    "31883": "KANOODLE - Kanoodle.com",
    "31884": "VSBGP - Vining Sparks",
    "31885": "INFINITYSOFTWARE - Infinity Software Development",
    "31886": "UOGUELPH - University of Guelph",
    "31887": "CHEMAITSC - Mercy Health System",
    "31888": "FMT-WESTFIELD - First Mile Technologies",
    "31889": "REGUS - Regus Business Centres",
    "31890": "QUICKENLOANS - Quicken Loans Inc.",
    "31891": "BRIDGECOM-N - Broadview Networks, Inc.",
    "31892": "FLP-MSA - Forever Living Products",
    "31893": "MCKNIGHT-DATA - McKnight Dallas Real Estate, LP",
    "31894": "ORLANDO-CVB-DBA-VISIT-ORLANDO - OOCCVB, Inc.",
    "31895": "MISHCON-BGP - MISHCON DE REYA NEW YORK LLP",
    "31896": "FUTARIS - Futaris, Inc.",
    "31897": "SUMMACARE-HEALTH-PLAN-N - SummaCare Health Plan",
    "31898": "SAC-HERAKLES-01 - Oracle Corporation",
    "31900": "CITYOFTHORNTON - City of Thornton",
    "31901": "THECHIMES - The Chimes, Inc.",
    "31902": "OTS - Open Technology Solutions",
    "31903": "TEX-HEALTH-PARTNERS-N-1 - Texas Health Partners LLC",
    "31904": "NCWCD-80513 - Northern Water",
    "31905": "EGN-INET - Energen Corp",
    "31906": "CHARGE-ANYWHERE - Charge Anywhere LLC",
    "31907": "VONAGE-04 - Vonage Holdings, Inc.",
    "31908": "VONAGE-04 - Vonage Holdings, Inc.",
    "31909": "VONAGE-04 - Vonage Holdings, Inc.",
    "31910": "CORBIS-NYC - Corbis Corporation",
    "31911": "BSI-UBS - Blood Systems, Inc.",
    "31912": "MEDRISKNET - Medrisk, Inc.",
    "31913": "CPCHEM - Chevron Phillips Chemical Company LP",
    "31914": "HBNI - Hutterian Broadband Network Inc",
    "31915": "BLACKMOUNTAIN - Western WiMAX, LLC",
    "31916": "IMLNY - Isaac Morris Ltd.",
    "31918": "MEMEO-01 - Memeo Inc.",
    "31919": "BRMEMC - Blue Ridge Mountain Electric Membership Corporation - BRM EMC",
    "31920": "GEETEL- - Geetingsville Telephone Co., Inc.",
    "31921": "MALONE-N - Malone University",
    "31923": "ACG - AAA of Michigan",
    "31924": "NYBLOODCTR - New York Blood Center",
    "31925": "QUEBEC-RANDD-OFFICE - Taleo Corporation",
    "31926": "GLGROUP - Gold Line Telemanagement,  Inc.",
    "31927": "MPR-SOCIATES - MPR Associates",
    "31928": "JOHNSON-ENGINEERING - Johnson Engineering, Inc.",
    "31929": "GREATRIVERENERGY - Great River Energy",
    "31930": "ETSMTL - Ecole de technologie superieure",
    "31931": "HOOTSUITE - HootSuite Media Inc.",
    "31932": "AFS-KC - American Fiber Systems, Inc.",
    "31933": "AFS-CLEV - American Fiber Systems, Inc.",
    "31934": "ALLIANCEPL - Alliance Pipeline Ltd.",
    "31935": "APOGEE-KANS - Apogee Telecom Inc.",
    "31936": "REFLECTED-2 - Reflected Networks, Inc.",
    "31937": "VSP-N - Vision Service Plan",
    "31938": "UARTS - The University of the Arts",
    "31939": "DIRECPATH-ATL - DirecPath, LLC",
    "31940": "INTERNATIONAL-TELNET-INC - International Telnet Inc.",
    "31941": "ILS - The Nexus Group, Inc.",
    "31942": "SORIN-GROUP-USA - Sorin Group USA, Inc.",
    "31943": "IPS-8-9-10-11 - iPass Incorporated",
    "31944": "IPS-8-9-10-11 - iPass Incorporated",
    "31945": "IPS-8-9-10-11 - iPass Incorporated",
    "31946": "IPS-8-9-10-11 - iPass Incorporated",
    "31947": "SWANSON-HEALTH - Swanson Health Products Inc.",
    "31948": "RANDH - Rhythm and Hues, Inc.",
    "31949": "PIER1 - Pier 1 Imports",
    "31950": "-DANS - Data Network Solutions, Inc.",
    "31951": "NADSN- - NA Deep Space Network (DSN)",
    "31952": "CALAMOS- - Calamos Asset Management",
    "31953": "ACTIVESERVE- - ActiveServe INC",
    "31954": "HDG-N - Harvard Drug Group",
    "31955": "N-CONNEXUSENERGY - CONNEXUS ENERGY",
    "31956": "RONIN-BLK1 - Ronin Capital LLC",
    "31957": "EXCELLENCEINMOTIVATION - Excellence In Motivation Inc",
    "31958": "SOBONITO - Sobonito Investments ltd.",
    "31959": "TELETOUCH - Teletouch Communications, Inc.",
    "31960": "EMUNET",
    "31961": "IDC-WEB - International Data Corporation",
    "31962": "VIRTELA-CUST-VWEA1-DSC Virtela Communications",
    "31963": "VIRTELA-CUST-VTXDAL1-DSC Virtela Communications",
    "31965": "COYOTE-LOGISTICS - COYOTE LOGISTICS LLC",
    "31966": "CSAA-INSURANCE-EXCHANGE - CSAA Insurance Exchange",
    "31967": "FLTECH - Florida Institute of Technology",
    "31968": "AMA - AMA",
    "31969": "OUTERNOC - OuterNet Management L.P.",
    "31970": "LIVESTREAM-USA-1 - Livestream LLC",
    "31971": "ACORN - AppleOne",
    "31972": "EMGINECONCEPT-01 - Emagine Concept, Inc.",
    "31973": "WPS-1765DC - Wisconsin Physcians Service Insurance Corp.",
    "31974": "RIML-CORP--2 - Research In Motion Corporation",
    "31975": "SEWANEE - University of the South",
    "31976": "REDHAT-0 - Red Hat, Inc.",
    "31977": "RAILAMERICA-1 - Florida East Coast Railway LLC",
    "31978": "ADMAXMEDIA-COM - AdMax Media Inc.",
    "31979": "TERADYNE-BOSTON - Teradyne, Inc.",
    "31980": "PROMOTIONS-COM - Corsis Technology Group II, LLC",
    "31981": "BLUETOWERHOSTING-N - BlueTower Hosting LLC",
    "31982": "BRAHMAN-NY - Brahman Capital",
    "31983": "QUEENSU-KINGSTON - Queen's University",
    "31984": "AVIE-TECHNOLOGIES-INC - Asavie Technologies Inc.",
    "31985": "KCNAP-PRI-N - KC NAP, LLC",
    "31986": "BIMR-LN - Sanford-Burnham Medical Research Institute at Lake Nona",
    "31987": "SHUMWAY-CAPITAL - Shumway Capital",
    "31988": "N-NETSEER - Netseer INC",
    "31989": "ROGERSHARDIN-N - Rogers & Hardin LLP",
    "31990": "LSTECH- - Lightspeed Technologies Inc",
    "31991": "PRPA - Platte River Power Authority",
    "31992": "ORICOM - Rocler inc.",
    "31993": "AFS-SLC - American Fiber Systems, Inc.",
    "31994": "INTELEPEER-US - IntelePeer, Inc.",
    "31995": "KUEDINC - Globalscholar.com",
    "31996": "ETALKNETWORK - etalk Corporation",
    "31997": "ZONEALARM-COM - Check Point Software Technologies, Inc.",
    "31998": "BAYOFT-LLC - Bayasoft, LLC.",
    "31999": "BURRELLES-LUCE - Burrelles/Luce",
    "32000": "IMMEDIATE-SALES-AGENCY - Immediate Sales Agency Ltd.",
    "32001": "AAPA- - American Academy of Physician Assistants",
    "32002": "BSOCAP-N - Basso Capital Management, LP",
    "32003": "LITEWIRE-EV - LiteWire Internet Services, Inc.",
    "32004": "BIG-N - Business Information Group, Inc.",
    "32005": "THE-CHURCH-PENSION-GROUP - CHURCH PENSION GROUP SERVICES CORPORATION",
    "32006": "HBC - Hudson's Bay Company",
    "32007": "EQUINIX-RS-CHI - Equinix, Inc.",
    "32008": "CARDIONET-PHLDC - Cardionet, Inc.",
    "32009": "PERFECTSERVE-INC - PERFECTSERVE, INC.",
    "32010": "TSIS-LLC - Top Speed Internet Service, LLC",
    "32011": "JOHO-NYC - Joho Capital, LLC",
    "32012": "CCI - Corinthian College",
    "32013": "CATHOLIC-HEALTH-CARE-WEST - Dignity Health",
    "32014": "FTROOT - Steadfast Networks",
    "32015": "ONYXLIGHT - OnyxLight Communications, Inc.",
    "32016": "WCI - World Communications, Inc.",
    "32017": "SATCOM-MOZ",
    "32018": "MEGUIARS- - Meguiar's Inc.",
    "32019": "ADACORE - Ada Core Technologies, Inc.",
    "32020": "TRANSACT-BM-N - Transact Ltd.",
    "32021": "IDN- - INTERCOM DATA NETWORKS",
    "32022": "CHC- - Children's Hospital Colorado",
    "32023": "ANADARKO - Anadarko Petroleum Corporation",
    "32024": "ORGANIC-COM - Organic, Inc",
    "32025": "HBRO - Hasbro, Inc.",
    "32026": "VISTO-DCO-SEA - Visto Corporation",
    "32027": "POS-N - Port of Seattle",
    "32028": "32028 - CoastCom, Inc.",
    "32029": "IBS-2 - Internet Broadcasting Systems, Inc.",
    "32030": "PPI-MECH - Performance Pathways, Inc.",
    "32031": "BVUSD229 - BLUE VALLEY USD NO 229",
    "32032": "ORGILL- - Orgill, Inc.",
    "32033": "EXXON- Dummy aut-num object for 32033",
    "32034": "NEWCOM- NEWCOM mirror object from ARIN",
    "32035": "CCDT- - Telekenex Inc",
    "32037": "-ADDISON - Arbonne International, Inc.",
    "32038": "RIV01 - Riviera Hotel and Casino",
    "32039": "MGIC-MYERS-32039 - Myers Internet, Inc.",
    "32040": "TRENTON-TELEPHONE - Trenton Telephone Company",
    "32041": "UL - Underwriters Laboratories",
    "32042": "YEARONE - Year One, Inc.",
    "32043": "HERMON11 - Hermon School Department/HermonNet",
    "32044": "OCEANSEDGEINC - Oceans Edge",
    "32045": "1UWEB - 1U Web, INC.",
    "32046": "SULLCROM - Sullivan & Cromwell",
    "32047": "SULLCROM - Sullivan & Cromwell",
    "32048": "SULLCROM - Sullivan & Cromwell",
    "32049": "SULLCROM - Sullivan & Cromwell",
    "32050": "CUST__001 Customer",
    "32051": "SULLIVAN-CROMWELL- SULLIVAN & CROMWELL",
    "32052": "SULLCROM Sullivan & Cromwell",
    "32053": "SULLCROM - Sullivan & Cromwell",
    "32054": "ROTADYNE - Rotadyne",
    "32055": "CFLAW - Condon & Forsyth LLP",
    "32056": "SHAMROCKFOODS-INTERNET-01 - SHAMROCK FOODS COMPANY",
    "32057": "BRMHMRB - BLUEGRS REGIONAL MENTAL HEALTH-MENTAL RETARDATION BOARD, INC.",
    "32058": "SBG-1 - Sinclair Broadcast Group",
    "32059": "TRADESTATION-1 - TradeStation Securities, Inc",
    "32060": "SPORTSNETWORK - Computer Information Network",
    "32061": "KIMEL - Kimelman & Baird, LLC.",
    "32062": "ARMSTRONGWORLD-01 - Armstrong World Industries, Inc.",
    "32063": "MIMEDIA-01 - MiMedia, LLC",
    "32064": "AMU1 - American University",
    "32065": "VORTECH - Frontline Data Services, Inc",
    "32066": "JPMORGANCHE JPMorganChase",
    "32067": "32067 - Thomson Reuters U.S. LLC",
    "32068": "MEMPHISNETWORX - Memphis Networx",
    "32069": "N-ESPORTZ1 - Dover Web Services Ltd.",
    "32070": "TAMNET - TAM Network",
    "32071": "WKU- - Western Kentucky University",
    "32072": "STR-00 - STR",
    "32073": "MCPS-K12-MD-US - Montgomery County Public Schools",
    "32074": "PEI - Petz Enterprises, Inc",
    "32075": "FBL- - Iowa Farm Bureau Federation & Affiliated Cos.",
    "32076": "PXDNET - PIONEER NATURAL RESOURCES USA",
    "32077": "ULTISOFTN - ULTIMATE SOFTWARE GROUP",
    "32078": "SFFCU- - San Francisco Fire Credit Union",
    "32079": "AUTONATION-P3 - Autonation, Inc",
    "32080": "KN-ENGINEERING-INC - K&N ENGINEERING, INC.",
    "32081": "DIGITALRIVER-DC2 - Digital River, Inc.",
    "32082": "BSC-20041102 - Bridgewater State College",
    "32083": "OMNISPRING - Omnispring, LLC",
    "32084": "N-RPD - Reprints Desk, Inc",
    "32085": "ACE- - Broadband VI, LLC",
    "32086": "PSHP- - PACIFICSOURCE HEALTH PLANS",
    "32087": "DEDICATED-HOSTING-BIZ-INC - DEDICATED-HOSTING.BIZ INC",
    "32088": "WISCONSIN-REINSURANCE-CORP - Wisconsin Reinsurance Corporation",
    "32089": "SECTOR - Sector, Inc.",
    "32090": "UHAUL-INET3 - UHAUL INTERNATIONAL, INC.",
    "32091": "TRACF- - Tracfone Wireless",
    "32092": "ML37-N - Mycolo, llc",
    "32093": "TACCNET - University of Texas at Austin",
    "32094": "ERICYHOST - ERICSSON NORTH AMERICA MANAGED SERVICES",
    "32095": "ETSNET - ETS.net Inc.",
    "32096": "KUB-NET - Knoxville Utilies Board",
    "32097": "WII-KC - WholeSale Internet, Inc.",
    "32098": "TRANSTELCO-INC - Transtelco Inc",
    "32099": "NYSOAG- - New York State Office of the Attorney General",
    "32101": "N-KLYS - Kelly Supply Company",
    "32102": "MS-CONVENTION-CENTER-AUTHORITY - Massachusetts Convention Center Authority",
    "32104": "WELLMONT-TN - Wellmont Health System",
    "32105": "EVERN2 - Evernet Hosting",
    "32106": "CHECKPOINT - Check Point Software Technologies, Inc.",
    "32107": "WAVE-CABLE - Wave Broadband",
    "32108": "N-WSECU - WSECU",
    "32109": "BEACHN-22 - Beach Trading Co, Inc.",
    "32110": "URION-INSURANCE-CORPORATION - Asurion Insurance Services, Inc.",
    "32111": "CITIGROUP-JAPAN - Citigroup",
    "32112": "ODYSSEY-PRIME - Odyssey Communications Group Inc.",
    "32113": "-LEFRAK - The Lefrak Organization, Inc.",
    "32114": "WHAYNE-WALKER - Walker Machinery Company",
    "32115": "WSC-N - Water Street Capital, Inc",
    "32116": "YAHOO-4 - Yahoo!",
    "32117": "BERKSHIRE-HEALTH-SYSTEMS - Berkshire Health Systems",
    "32118": "-SMARTHEALTH - Smart Practice",
    "32119": "DATAFRAMELO - Dataframe Logistics, Inc.",
    "32120": "MHUMC-1-1 - Memorial Health University Medical Center",
    "32122": "SYNECTICSFMD2004 - Synectics for Management Decisions, Inc.",
    "32124": "CONTINENTALMILLS-EXT - CONTINENTAL MILLS",
    "32125": "WHEATON-COLLEGE - Wheaton College",
    "32126": "SFBCIC- - Southern Farm Bureau Casualty Insurance Company",
    "32127": "MRIC - Magnolia Road Internet Cooperative",
    "32128": "ANDIN-INTERNATIONAL - Andin International",
    "32129": "CITIZEN-WATCH-COMPANY - Citizen Watch Company Of America, Inc.",
    "32130": "BRIGHT-HORIZONS - BRIGHT HORIZONS.COM",
    "32131": "CALLWAY - Callway LLC",
    "32132": "INTEGRATEDSOLUTIONS - Integrated Computer Solutions",
    "32133": "JOHNSTONE-SUPPLY - Atwater Supply dba Johnstone Supply",
    "32134": "CG-US-1 - Cap Gemini America",
    "32135": "CINCINNATI-EQUITABLE-PUBLIC-NETWORK - Cincinnati Equitable Companies, Inc.",
    "32136": "FARMINGDALESTATE - Farmingdale State College",
    "32137": "PROVIDECOMMERCE - Proflowers Inc",
    "32138": "NETTEK01 - Nettek LLC",
    "32139": "OGDEN-PROJECTS - Covanta Projects, Inc.",
    "32140": "JEWELRY-TELEVISION - America's Collectibles Network",
    "32141": "REDROBIN-1 - Red Robin Gourmet Burgers",
    "32142": "D20 - Academy School District 20",
    "32143": "VNILESNET - The Village of Niles",
    "32144": "ADSSECURITY - ADS Security LP",
    "32145": "CAPENET - CapeNet LLC",
    "32147": "HMIC - Harleysville Mutual Insurance",
    "32148": "KCLS - King County Library System",
    "32149": "WEBTEAM - WEBTEAM, INC",
    "32150": "TUMMY-COM-LTD - tummy.com, ltd.",
    "32151": "POWERSPACE - POWERSPACE & SERVICES, INC.",
    "32152": "CCNBI-1 - CCNBI, Inc",
    "32153": "SHORTSTRAVELMGM - Shorts Travel Management",
    "32154": "NRC-LNK - National Research Corp.",
    "32155": "-MJM-CREATIVE-SERVICES-NY - MJM Creative Services",
    "32156": "HUMBER-COLLEGE - Humber College",
    "32157": "DC-UOIT-NET - DURHAM COLLEGE OF APPLIED ARTS AND TECHNOLOGY",
    "32158": "WRBC---BERKLEY-TECHNOLOGY-SERVICES - WR Berkley Technology Services",
    "32159": "CHECKVELOCITY1 - CheckVelocity, Inc.",
    "32160": "COMPUTERTECHNIQUESINC - Computer Techniques, Inc.",
    "32161": "CCBILL-N2 - CCBill",
    "32162": "CLIU21 - Carbon Lehigh Intermediate Unit 21",
    "32163": "BLIZ1 - BLIZZARD ENTERTAINMENT",
    "32164": "SECURED-SERVERS - SECURED SERVERS LLC",
    "32166": "TROUTMANSANDERS - TROUTMAN SANDERS",
    "32167": "OHPP-N1 - Oak Hill Platinum Partners",
    "32168": "WU - Vigo Remittance Corp.",
    "32169": "EBRARY - ebrary, Inc.",
    "32170": "SLVRMC - San Luis Valley Regional Medical Center",
    "32171": "TRIAN-FUND-MANAGEMENT-LP - Trian Fund Management L.P.",
    "32172": "RADICALMEDIA - @radicalmedia Inc.",
    "32173": "NETIP-LA - Network IP",
    "32174": "INTERNET-WEB-MODEL - Silicon Valley Bank",
    "32175": "TRANSIT - REGIONAL TRANSPORTATION DISTRICT",
    "32176": "32176 - Royal Bank of Canada",
    "32177": "XEEX-COMMUNICATIONS - Xeex",
    "32178": "SCC-N-31004 - Sinclair Community College",
    "32179": "-VITALIX - Vitalix Inc.",
    "32180": "ROCKET-SIRIUS - ROCKET SOFTWARE INC",
    "32181": "N-GIGENET - GigeNET",
    "32182": "GMCC - Grange Mutual Casualty Co.",
    "32183": "WINBEAM--1 - Winbeam",
    "32184": "ANY2-DENVER - CoreSite",
    "32185": "TRCOFMD - Transplant Resource Center of Maryland, Inc.",
    "32186": "FUJIFILM-HLUS - FUJIFILM Manufacturing USA, Inc",
    "32187": "WEMED - Wilson, Elser, Moskowitz, Edelman & Dicker",
    "32188": "JPFINANCIAL - JEFFERSON-PILOT LIFE INSURANCE COMPANY",
    "32189": "SAGRADO - Universidad del Sagrado Corazon",
    "32190": "ADPDS- - Automatic Data Processing, Dealer Services",
    "32191": "VITERRA-WINNIPEG - Viterra Inc",
    "32192": "EMPRISEBANK - EMPRISE BANK",
    "32193": "NY-PARK-INTERNET - American Media, Inc.",
    "32194": "N-PHOENIX-CHILDRENS - PHOENIX CHILDREN'S HOSPITAL",
    "32195": "ESI-EMR - Eisai Inc.",
    "32196": "DIRECTINS - Direct General Corporation",
    "32197": "MEGUIARS--PORT - Meguiar's Inc.",
    "32198": "MEGUIARS--NH - Meguiar's Inc.",
    "32199": "IPS-12 - iPass Incorporated",
    "32200": "PROTUSIPSOLUTIONS - Protus IP Solutions",
    "32201": "USATEC-MALVERN-PA - USA TECHNOLOGIES, INC.",
    "32203": "MSE-TA - MSE Technology Applications, Inc",
    "32204": "KPUNET - KPU Telecommunications",
    "32205": "RESISOFT-NETWORK-CHI - Resisoft, Inc.",
    "32206": "OBERTHURCS-USA - Oberthur Technologies of America Corp.",
    "32207": "MIDDLESEX-HOSPITAL - MIDDLESEX HEALTH SYSTEM, INC.",
    "32208": "SKL-SERVICES-N - SKL Services Inc",
    "32209": "PARUN - Parasun Technologies Inc.",
    "32210": "NTE-64-WHQNUM - NORTHERN TOOL & EQUIPMENT COMPANY, INC.",
    "32211": "ZINCVENTURES - Zinc Ventures",
    "32212": "HSB-EDGE - Hot Spot Broadband, Inc.",
    "32213": "BLANK-ROME-LLP - BLANK ROME LLP",
    "32214": "AGIO - Agio LLC",
    "32215": "SVVSD - SVVSD",
    "32216": "ANX-CERTIFIED-EXCHANGE-POINT - ANXeBusiness Corp.",
    "32217": "SCTIMES - St. Cloud Times",
    "32218": "GSIN-3-N - Gannett Healthcare Group",
    "32219": "SHS--1 - Sparrow Health System",
    "32220": "N-BELD - Braintree Electric Light Dept.",
    "32221": "BARONSERVICES - Baron Services",
    "32222": "ACCESSLINE-COM-2000 - AccessLine Communications Corp.",
    "32224": "EMPIRE - Empire Southwest",
    "32225": "MCGRAW-BCM - McGraw Communications",
    "32226": "MENARD-INC - Menard, Inc.",
    "32227": "MWLLP- - McGuireWoods LLP",
    "32228": "ISN - ISN Communications",
    "32229": "JSUMS-ARIN - Jackson State University",
    "32230": "PRESTIGEFINANCIAL1420 - Prestige Financial Services",
    "32231": "METABANK - METABANK",
    "32232": "IGLOBALNETWORKS - iGlobalNetworks.com, Inc.",
    "32233": "PERSONA - PERSONA COMMUNICATIONS INC.",
    "32234": "UD-ACA- - University of Dayton",
    "32235": "N-AAL - Antipodean Advisors, LLC",
    "32236": "MEXUS-27 - MEXUS GROUP L.P.",
    "32237": "GVPL- - Greater Victoria Public Library",
    "32238": "BAE-SYSTEMS-DETICA - Detica Solutions inc.",
    "32240": "ROUTERDOG - Proportal LLC",
    "32241": "ACPANA - Acpana Business Systems Inc.",
    "32242": "TCSN - TCS Capital",
    "32244": "LIQUID-WEB-INC - Liquid Web, Inc.",
    "32245": "CEY - CEY SECURITIES, LLC",
    "32246": "RMKR - Rainmaker Systems, Inc.",
    "32247": "SHAW-SATELLITE- - Shaw Satellite Services, Inc.",
    "32249": "TECHVAULT-VT - TECH VAULT, INC.",
    "32250": "NIAGARAC-N - Niagara College of Applied Arts and Technology",
    "32251": "BNP-PARIB-NEW-YORK - BNP PARIB NORTH AMERICA, INC.",
    "32253": "BECPL - Buffalo & Erie County Public Library",
    "32254": "KYNEX-1 - Kynex Inc.",
    "32255": "PPLNET- - PPL Corporation",
    "32256": "CYBERLINKP - CYBERLINK USA",
    "32257": "AETN-STAM-01 - A&E Television - Stamford",
    "32258": "SDNGLOBAL - SDN Global",
    "32259": "AREA-EDUCATION-AGENCY-267 - Area Education Agency 267",
    "32260": "N-HCPI - Health Care Property Investors, Inc.",
    "32261": "KSTREET - Kaminting Street Capital",
    "32262": "I-NET- - Industry I-Net, Inc.",
    "32263": "CATALYST-REPOSITORY-SYSTEMS-US - Catalyst Repository Systems, Inc.",
    "32264": "KMTELECOM - KMTelecom",
    "32265": "97130 - Cascade Networks Incorporated",
    "32266": "UNH-IOL - University System of New Hampshire",
    "32267": "BSE-OAK - BrightSource Energy, Inc.",
    "32268": "ARTISAN-PARTNERS-N - Artisan Partners Limited Partnership",
    "32269": "-WRP - Wechsler Ross & Partners Inc.",
    "32270": "LDTEL - LDtelecom Inc.",
    "32271": "TRAPP-ONLINE - Trapp Online, LLC",
    "32272": "UNWIRED-N - Unwired Broadband, Inc.",
    "32273": "LIRR - Long Island Rail Road",
    "32274": "LENAWEE-MONROE-TECHNOLOGY-CONSORTIUM - Lenawee-Monroe Technology Consortium",
    "32275": "UWH - Unified Webhosting, LLC",
    "32276": "EFFICIENT-CAPITAL-MANAGEMENT - Efficient Capital Management, LLC.",
    "32277": "TBAYTEL - TBayTel",
    "32278": "GETWIRELESS - Getwireless.net",
    "32279": "UBW-WAN",
    "32280": "THE-EWSCRIPPS - The E.W. Scripps Company",
    "32281": "CCT-LLC - CCT LLC",
    "32282": "CVNS48334 - COVANSYS",
    "32283": "RAGEFRAMEWORKS - RageFrameworks Inc",
    "32284": "CORP-BH-1 - Bashas' Inc.",
    "32285": "HFCC - Henry Ford Community College",
    "32286": "TRIPADVISOR - TripAdvisor, LLC",
    "32287": "SOLANA-CITIPLEX - Citigroup",
    "32289": "SWIFT-TRANSPORTATION-CORPORATION-INC - Swift Transportation Co. Inc.",
    "32290": "RUSTNET - RUST COLLEGE",
    "32291": "ANNEARUNDELMEDICALCENTER - ANNE ARUNDEL MEDICAL CENTER",
    "32292": "LOOP-ONE - Loop One, Inc.",
    "32293": "TCW--865 - Trust Company of the West",
    "32294": "CITY-OF-CHAMPAIGN-IL - City of Champaign, Illinois",
    "32295": "DESIGNCOLLECTIVE - Design Collective, Inc.",
    "32296": "METROFFICE - Metro Office Management, Inc.",
    "32297": "TEPN - Tucson Electric Power",
    "32298": "AMERICANAPPAREL - American Apparel (USA), LLC",
    "32299": "TELX-RS - Telx",
    "32300": "FTNFI-N - FTN Financial",
    "32301": "CITATION-PUBLISHING - Citation Publishing, INc.",
    "32302": "PBT-NET - The Private Bank",
    "32303": "RUBIOS - Rubio's Restaurants, Inc.",
    "32304": "ALLSCRIPTS-LV - Allscripts",
    "32305": "COOK-GROUP - COOK GROUP INC",
    "32307": "VIAERO-WIRELESS-GPRS - NE COLORADO CELLULAR INC",
    "32308": "8X8- - 8x8, Inc.",
    "32310": "PIONEER-WORLD - Pioneer Balloon Co.",
    "32311": "JKS-N - JKS Media, LLC",
    "32312": "TELECOMSYS-PUBLIC - Telecommunication Systems, Inc.",
    "32313": "NUMBERFORNEXTAG - Nextag Inc.",
    "32314": "JAGWIRED-BROADBAND - Jag Wire Enterprises, Inc.",
    "32315": "WJBTN- - The Western James Bay Telecom Network",
    "32316": "GREE-AMERICA - GREE International, Inc.",
    "32317": "HFCC - Henry Ford Community College",
    "32318": "CHSDC - Center for Hellenic Studies",
    "32319": "-MARQETA - Marqeta, Inc.",
    "32320": "WESTERN-STONE-AND-METAL-CORP - Western Stone and Metal",
    "32321": "BCGI- - Boston Communications Group Incorporated",
    "32322": "N-YUKONWALTZ - YukonWaltz",
    "32323": "EQUINIX-EDMA-CHI-N - Equinix, Inc.",
    "32324": "HPCC - Hensel Phelps Construction Company",
    "32325": "EJC-100 - James Campbell Company LLC",
    "32327": "ZAYOB-NE - Zayo Bandwidth NorthEast LLC",
    "32328": "ALCOM-IP-MANAGED-NETWORK - Alascom, Inc.",
    "32329": "MONKEYBRAINS - Monkey Brains",
    "32330": "TIEDEMANN-INVESTMENT-GROUP - TIEDEMANN INVESTMENT GROUP",
    "32331": "WINS-INTERNET-SERVICES - WINS, LLC",
    "32332": "IHC-MKE - Infinity HealthCare, Inc.",
    "32333": "FFVA - Florida Fruit & Vegetable Association",
    "32335": "N-T-TECHNOLOGY - N.T. Technology, Inc.",
    "32336": "IPS-2 - iPass Incorporated",
    "32337": "NOWCOM-BGP - Nowcom Corporation",
    "32338": "HOSTISERVER - Hostiserver Ltd",
    "32339": "ACTIVE-NA1 - The Active Network Inc.",
    "32340": "SPECIALTY-RETAILERS - Specialty Retailers",
    "32342": "GENEXSERVICES - Genex Services Inc",
    "32344": "CSD99 - Community High School District 99",
    "32347": "PRAN-N - Fleming College",
    "32348": "SYMPHONYSET - Symphony",
    "32349": "CI-GROUP- - CI-GROUP",
    "32350": "CANDIDCOLORSYSTEMS - Candid Color Systems, Inc.",
    "32351": "HAMPTON-PRODUCT - Hampton Product",
    "32352": "MGRC - MCGRATH RENTCORP",
    "32353": "CONCEPTCAP - Concept Capital",
    "32354": "UNWIRED - Unwired",
    "32355": "HBP- - Horsley Bridge Partners, LLC",
    "32356": "COMMUNITY-TEL-INC - Ronan Telephone Company",
    "32357": "STRUCTURED- - Structured IP services",
    "32358": "VENTURACOUNTY-01-N - County of Ventura",
    "32360": "MONROE-1-BOCES - Monroe #1 BOCES",
    "32361": "ULTRALIGHT - UltraLight",
    "32362": "SPHERIS- - MModal Services, Ltd",
    "32363": "KROLL_LDN_NET KROLL_LDN_",
    "32364": "SSHA-DC-N - eHealth Ontario",
    "32365": "SANDYNET - City of Sandy",
    "32366": "THE-BROOKINGS-INSTITUTION-1 - The Brookings Institution",
    "32367": "EDP-WDB-INET - Long Term Care Group",
    "32368": "MOUSER-ELECTRONICS - mouser electronics",
    "32369": "THEJOCKEYCLUB - The Jockey Club",
    "32370": "VONAGE-05 - Vonage Holdings, Inc.",
    "32371": "PROGRESSIVE-2 - Progressive Casualty Insurance Companies",
    "32372": "PRA- - PORTFOLIO RECOVERY SOCIATES",
    "32373": "AW1-WAYNE - AssetWorks, Inc.",
    "32374": "NUCLEARFALLOUT-LAX - Nuclearfallout Enterprises, Inc.",
    "32375": "HP-N - The Herald-Palladium",
    "32376": "PATIENT-FIRST - Patient First",
    "32377": "SCM-LP-1 - Stevens Capital Management LP",
    "32378": "WORTH-INET - The Worth Collection",
    "32379": "SOUTHERN-GRAPHIC-SYSTEMS-INC - Southern Graphic Systems, Inc",
    "32381": "WIDEVINE - Widevine Technologies",
    "32382": "ATOS-ORIGIN-INTERNET- - ATOS ORIGIN",
    "32383": "ROME-NET - ROME Sverdrup",
    "32384": "MILLERWELDSN01 - MILLER Electric Mfg. Co.",
    "32385": "INTELEPEER-US-BACKBONE - IntelePeer, Inc.",
    "32386": "FTNET-WIRELESS-LLC - Fastnet Wireless LLC",
    "32387": "HTS-CA - Honey Tek Systems",
    "32389": "BERKLEE- - Berklee College of Music",
    "32390": "SARATOGA-TECHNOLOGY-ACCELERATOR - Saratoga Technology Accelerator, LLC",
    "32391": "SRCACCESS - SANTA ROSA TELEPHONE COOPERATIVE INC",
    "32392": "OPENTRANSFER-ECOMMERCE - Ecommerce Corporation",
    "32393": "BDN - Brown Dog Networks",
    "32394": "G-BAR-LIMITED-PARTNERSHIP - G-Bar Limited Partnership",
    "32395": "DAKONA-N1 - Dako North America Inc.",
    "32397": "OCHIN-PDX - OCHIN",
    "32398": "REALNET-N-1",
    "32399": "ALORICA - ALORICA INC",
    "32400": "HWSERVICES-32400 - Hostway Services, Inc.",
    "32401": "H-MART - Grandsuper Center Inc",
    "32402": "TOWER-RESEARCH-CAPITAL TOWER RESEARCH CAPITAL LLC.",
    "32403": "THE-HERITAGE-FOUNDATION - The Heritage Foundation",
    "32404": "ACDIV01 - ACDI/VOCA",
    "32405": "OX-CHICAGO-39 - OptionsXpress, Inc.",
    "32406": "HOME-BUYERS-WARRANTY - Home Buyers Warranty Corporation",
    "32407": "FREEDOM-MORTGAGE - Freedom Mortgage Corporation",
    "32408": "SMHCOLOCATION - SMH Colocation",
    "32409": "T2COM - T2 Communications",
    "32410": "HMSTEINSGRP - Homesite Group Inc",
    "32411": "SURERX-HEALTH-CORPORATE - AssureRx Health, Inc.",
    "32413": "AEPRIOCOM-1 - Exigo Office, INC",
    "32414": "XEROX-ARS - Xerox Commercial Solutions LLC",
    "32415": "C3-LLC - C3",
    "32416": "NOVALIBRA - Nova Libra, Inc.",
    "32417": "ELONU- - Elon University",
    "32419": "BALDWIN-LYONS - Baldwin & Lyons, Inc.",
    "32420": "APTILO-US - Aptilo Networks Inc.",
    "32421": "BLCC - Black Lotus Communications",
    "32422": "LAWRE-N - LAWRENCE & MEMORIAL HOSPITAL, INC.",
    "32423": "GATEWAY-EDI-LLC - Gateway EDI, LLC",
    "32424": "SYMBIOTIC-NET - Network Connection",
    "32425": "SKB3-ARIN-BGP - Pixel Factory",
    "32426": "WV-SCHOOL-OF-OSTEOPATHIC-MEDICINE - WV School of Osteopathic Medicine",
    "32427": "AUNTMILLIES01 - Aunt Millie's Bakeries",
    "32428": "BELZ-INVESTCO - BELZ ENTERPRISES",
    "32429": "ATAENG - ATA Engineering, Inc.",
    "32431": "AIRCTLE - Aircastle Advisor LLC",
    "32432": "COFAN - Colleges of the Fenway, Inc.",
    "32433": "PALLFURNPARK - Palliser Furniture Upholstery Ltd.",
    "32434": "IH-SOLUTIONS - INTEGRATED HEALTHCARE SOLUTIONS, INC.",
    "32435": "DOTALLIANCE-ANYCT - DotAlliance",
    "32436": "FSRAD-1 - Radisphere National Radiology Group Inc",
    "32437": "CYBERTEK-ZA",
    "32438": "GRO-UCFUSM-1N - Michigan State University Federal Credit Union",
    "32439": "ALTOVA-BOS - Altova, Inc.",
    "32440": "LONI - Louisiana Board of Regents/Louisiana Optical Network Initiative (LONI)",
    "32441": "CGS-HOSTING-NETWORK - Advanced Training & Services Inc.",
    "32442": "USMNSTCMARCO01 - Marco Business Products",
    "32443": "SPERRY-MARINE - SPERRY MARINE INC.",
    "32444": "SAFELINK-JEROME1N - Safelink Internet",
    "32445": "XHOP - XHOP LLC",
    "32446": "HARBOR-CAPITAL-ADVISORS - Harbor Capital Advisors, Inc.",
    "32447": "MARTI- - MARTIN RESOURCE MANAGEMENT CORP.",
    "32448": "METROCT-1 - MetroCast Cablevision of New Hampshire, LLC.",
    "32449": "ALEXANDRA-INVESTMENT-MANAGEMENT - Alexandra Investment Management",
    "32450": "TESC-WEB - Thomas Edison State College",
    "32451": "SITE-B-DATA - Site B Data Services, LLC.",
    "32452": "JMP-SECURITIES-LLC - JMP Securities, LLC",
    "32453": "ICANETWORK - ICA Canada On-Line Inc.",
    "32454": "PRESIDENTIAL-PRAYER-TEAM - The Presidential Prayer Team, Inc.",
    "32455": "INTEGRAND-SURANCE-COMPANY - INTEGRAND Assurance Company",
    "32456": "WALBRIDGE-ALDINGER-CO-DTW - Walbridge Aldinger Company",
    "32457": "COH1 - City of Houston",
    "32458": "INDCONET - IND. CO. CABLE TV, INC.",
    "32459": "XIOCOM-PFN - CityNet LLC",
    "32460": "COPS-MONITORING - C.O.P.S. Monitoring",
    "32461": "ARSPL - ARE-East River Science Park, LLC",
    "32462": "TMARZETTI - T. Marzetti Company",
    "32463": "CAREMEDIC - Caremedic Systems, Inc.",
    "32464": "UICOMP- - University Of Illinois College Of Medicine At Peoria",
    "32465": "EMRYS-PARTNERS - Emrys Partners, L.P.",
    "32466": "HSMC-STOWE-VT - HOME SECURITY AND MANAGEMENT CO.",
    "32467": "SAKSINC-1 - Saks Incorporated",
    "32468": "CMSSTL - Correctional Medical Services",
    "32469": "PUBLIC-EMPLOYEES-CREDIT-UNION - Public Employees Credit Union",
    "32470": "N-RAZOR - RazorLine L.L.C.",
    "32471": "RCCW-GRX - Cellco Partnership DBA Verizon Wireless",
    "32472": "LEXIS2- - LEXIS-NEXIS",
    "32473": "EHTEL - Eh!Tel Networks Inc.",
    "32474": "PEERNYC - Peerless Clothing Inc.",
    "32475": "SINGLEHOP-INC - SingleHop",
    "32476": "MSFT-32476 - Microsoft Corporation",
    "32477": "ONLINE-TECH-INC - Online Tech Inc.",
    "32478": "ITVOCAL - IT Vocal LLC",
    "32479": "OPENBAND - OPENBAND MULTIMEDIA, LLC",
    "32480": "LLUMC - Loma Linda University Medical Center",
    "32481": "OSCEOLA - Osceola County",
    "32482": "CLEARREACH - Dash Carrier Services, LLC",
    "32483": "WCS-MAITLAND - WildCard Systems",
    "32484": "BAY-RADIOLOGY - Bay Radiology Associates",
    "32485": "ACMOORE - A.C. Moore Incorporated",
    "32486": "CBSBANK - CB&S Bank, Inc.",
    "32487": "CCPSL- - Cast & Crew Entertainment Services, LLC.",
    "32488": "CBMNYC - CBM Capital",
    "32489": "AMANAHA-NEW - Amanah Tech Inc.",
    "32490": "HI-SPEED - Hi-Speed US, LLC",
    "32491": "TUCOWS-3 - Tucows.com Co.",
    "32492": "DANA - DANA INNOVATION",
    "32493": "CUREMD - CureMD Corp.",
    "32494": "TCHSINET01 - Take Care Health Systems, LLC",
    "32495": "DNBWALTHAM - IMarket Inc.",
    "32496": "JMC- - JPMorgan Chase & Co.",
    "32497": "IODINCORPORATED-GBAY - iod incorporated",
    "32498": "NEFCU-N - New England Federal Credit Union",
    "32499": "AHCCCS - AHCCCS",
    "32501": "TUCSON-UNIFIED-SCHOOL-DISTRICT-1 - Tucson Unified School District #1",
    "32502": "SLCL-N - St. Louis County Library",
    "32503": "-PROVI-25 - Provider Solutions, Inc.",
    "32504": "INTELLETRACE - Intelletrace",
    "32505": "DWL-MAIN - DETEL WIRELESS, LLC",
    "32506": "ENL-17- - Experior Networks LLC",
    "32507": "RESOURCENATION-INC - Business.com Media Inc.",
    "32508": "GSINET - Granite State Long Distance, Inc.",
    "32509": "SEDGWICK-COUNTY- - Sedgwick County Information Services",
    "32510": "FOODLION1 - Food Lion, LLC",
    "32511": "ANTEHEALTHSYSTEM-1 - Asante Health System",
    "32512": "APHA-DC-1 - AMERICAN PUBLIC HEALTH SOCIATION",
    "32513": "BATTELLE-MEMORIAL-INSTITUTE - BATTELLE MEMORIAL INSTITUTE",
    "32514": "COMEDCOM - CoMedia Communications, Inc.",
    "32515": "JBSNET007 - JBS, Inc.",
    "32516": "IAM - IMPALA SET MANAGEMENT",
    "32517": "DOTINC-NET - Dot Internet Solutions Inc.",
    "32518": "R-MEGAPATH- - EXIDE TECHNOLOGIES",
    "32519": "E-VERGENT-COM-LLC - e-vergent.com LLC",
    "32520": "DIEBOLD-CHANNEL-1 - Diebold, Incorporated",
    "32521": "CNRL- - Canadian Natural Resources Limited",
    "32522": "MULTNOMAH-ESD - Multnomah Education Service District",
    "32523": "INFOSTREET - InfoStreet, Inc.",
    "32524": "GRUPO-SMS - Grupo-SMS USA, LLC",
    "32525": "UNDER-ARMOUR-PERFORMANCE-APPAREL - Under Armour, Inc.",
    "32526": "ANSW - Answers Corporation",
    "32527": "VARIOUS - FriendFinder Networks Inc",
    "32528": "ABBOTT Abbot Labs",
    "32529": "CGI-FEDERAL-N-1 - CGI Federal",
    "32530": "OPUS-1 - Opus Corporation",
    "32531": "FORDHAM-UNIVERSITY - Fordham University",
    "32532": "KMC-37-N - Kuakini Medical Center",
    "32533": "JMLS - The John Marshall Law School",
    "32534": "INSIGHTNY - Insight Partners",
    "32535": "GAW-N - GAW High-Speed Internet Inc",
    "32536": "4WEB-CA - 4WEB.CA",
    "32537": "XILINX - Xilinx Incorporated",
    "32538": "KOMATUSU-AMERICA-CORPORATION - Komatsu America Corporation",
    "32539": "WCMCQ-NET - Weill Cornel Medical College in Qatar",
    "32540": "HP-HOOD - HP Hood",
    "32541": "SAIRB- - Schulman Associates Institutional Review Board, Inc.",
    "32542": "JIGSAW-DATA-NETOPS01 - Jigsaw.com",
    "32543": "AWA-PLYMOUTH-MICHIGAN - Aisin World Corp of America",
    "32544": "FOTOKEM-INDUSTRIES - FotoKem Industries, Inc",
    "32545": "ALPINE-INTERNET-SOLUTIONS - Alpine Internet Solutions",
    "32546": "SMARSH - Smarsh Inc",
    "32547": "NYPR-1 - New York Public Radio",
    "32548": "PIXIUS-WICHITA- - Pixius Communications, LLC",
    "32549": "BUSIN-52-MIA - Businessnet Telecom Inc.",
    "32550": "EQUINIX-MA-NY9 - Equinix, Inc.",
    "32551": "KOHLBERG - Kohlberg & Co., L.L.C.",
    "32552": "ABGIL- - Alliance Benefit Group of Illinois",
    "32553": "AGILISYS-GRANDRAPIDS - Agilisys",
    "32554": "MCIU - Montgomery County Intermediate Unit",
    "32555": "CRIM--MTL - Centre de Recherche Informatique de Montreal",
    "32556": "TAHN - Titusville Area Hospital",
    "32558": "ZEUTER - Zeuter Development Corporation",
    "32559": "POINTONE- - PointOne",
    "32560": "BITXBIT - BIT BY BIT COMPUTER CONSULTANTS, INC.",
    "32561": "-CLAYT-3 - Clayton Group,INC",
    "32562": "SLACKER-1 - Slacker Inc.",
    "32563": "N-SRCMTL - Societe Radio Canada",
    "32564": "INTACT-FINANCIAL-CORPORATION - Intact Financial Corporation",
    "32565": "AFSCME-N - AFSCME",
    "32566": "DUNAVANT - Dunavant Enterprises, Inc.",
    "32567": "32567 - GameStop, Inc.",
    "32568": "TELAMON-INSURANCE-NETWORK - Marketing Associates Insurance Agency, Inc",
    "32569": "PRESSGANEYSOC - PRESS GANEY SOCIATES INC",
    "32570": "CANYONCOUNTRY - Canyon Country Communications, Inc.",
    "32571": "TLSNET-A - tls.net, Inc.",
    "32572": "AVENIR - Avenir Solutions Inc.",
    "32573": "TNE-GLOBAL-TELECOM-HART - TNE Global Telecom, LLC.",
    "32574": "AUTH - Symantec Inc",
    "32575": "COOPLABS - Cooplabs, Inc.",
    "32576": "LOANMART - 1-800LoanMart",
    "32577": "KROGER - The Kroger Co.",
    "32578": "KC-EURON-1 - Euronet Worldwide, Inc.",
    "32579": "ETG- - eVolution Technology Group, LLC.",
    "32580": "-YAK - Yak Communications (Canada) Corp",
    "32581": "FVTECH-1 - FVTech",
    "32582": "PEERINGPARTNERS-32582 - Peering Partners Communications, LLC",
    "32583": "LA-ENC-N1 - Life Alert Emergency Response, Inc.",
    "32584": "I-NETLINK - I-Net Link Wireless",
    "32585": "KSCM- - King Street Capital Management, L.P.",
    "32586": "NIAGARA-WIRELESS-INTERNET-COMPANY - Niagara Wireless Internet Co.",
    "32587": "NCH-FTWDC-01 - Frontier Communications of America, Inc.",
    "32588": "WINDERMERE-N-1 - Windermere Information Technology Systems",
    "32590": "VALVE-CORPORATION Valve Corporation",
    "32591": "KYNIKOSNY - Kynikos Associates. LTD",
    "32592": "HUNT-BROTHERS-OF-LOUISIANA-LLC - Hunt Brothers",
    "32593": "NO - Perspective, Inc.",
    "32594": "AUGUSTINE-GAMING-MANAGEMENT-CORP - AUGUSTINE GAMING MANAGEMENT CORP.",
    "32595": "BOARDER-MATRIXWEBS-COM - MATRIXWEBS.COM",
    "32596": "CAMBERCORP - CAMBER CORPORATION",
    "32597": "-NEWWAVENETCORP - NEW WAVE NET CORPORATION",
    "32598": "TRADER-CORPORATION - Trader Corporation",
    "32600": "AGILISYS-NORTHVILLE - Agilisys",
    "32601": "ACUNET-2 - Abilene Christian University",
    "32602": "CORP-HDQTRS - ROI Solutions, LLC",
    "32604": "COSCO-NJ-NA - China Ocean Shipping Company North America, Inc.",
    "32605": "BRAVESOFT- - BraveSoftTech Inc",
    "32606": "EBANKSYSTEMS - EBANK SYSTEMS, Inc.",
    "32607": "CANACCORD-GENUITY-INC - Adams Harkness & Hill",
    "32608": "MIDPLUS-INC - MIDPLUS INC.",
    "32609": "CNS - Cooperative Network Services, LLC",
    "32610": "XTRAMART- - Xtramart",
    "32611": "MERCE-15 - MERCEDES-BENZ USA, LLC",
    "32612": "LOC-01 - Lyric Opera of Chicago",
    "32613": "IWEB- - iWeb Technologies Inc.",
    "32614": "HDISS-NET - High Desert Internet Services",
    "32615": "ADVANTAGE-CELLULAR-SYSTEMS-INC - ADVANTAGE CELLULAR SYSTEMS, INC",
    "32616": "TCA-BGP - Take Charge America, Inc.",
    "32617": "STEAK-N-SHAKE - The STEAK N SHAKE Company",
    "32618": "ADKNO-KC - Adknowledge, Inc.",
    "32619": "SCHNUCKS - Schnuck Markets, Inc.",
    "32620": "NEKO - NEKO International Computers Inc.",
    "32621": "TCV-511 - Twin City VoIP, Inc.",
    "32622": "TWRS-PW - Towerstream I, Inc.",
    "32623": "TWRS-PW - Towerstream I, Inc.",
    "32624": "WESTEXCONNECTHQ - TELSTAR1 INTERNET SERVICES",
    "32625": "OFFSITE-1 - OFFSITE, LLC",
    "32626": "HOUSTON-AREA-LIBRARY-AUTOMATED-NETWORK-HALAN - Houston Area Library Automated Network ( HALAN )",
    "32627": "BIDS-TRADING - BIDS Trading L.P.",
    "32628": "WPOZ - Z 88.3 FM",
    "32629": "CITY-OF-CHARLOTTE-N - City of Charlotte",
    "32630": "PCI-GO - Patterson Companies, Inc.",
    "32631": "TBLEND - TeleBlend",
    "32632": "VAULT-NETWORKS - Vault Networks, Inc.",
    "32633": "SOFTSHARE - Softshare, Inc.",
    "32634": "FULL-SERVICE-NETWORK - Full Service Computing Corp",
    "32635": "CITYOFCLOVIS - City of Clovis",
    "32636": "TUCOWS-2 - Tucows.com Co.",
    "32637": "GM-ED-MULTILINE - General Mills",
    "32638": "TRENT-UNIVERSITY - Trent University",
    "32639": "MENDEL-HAYWARD - Mendel Biotechnology, Inc.",
    "32640": "RSKO-N - Richards Kibbe & Orbe LLP",
    "32641": "ARBINET-INTERNAL - ARBINET-THEXCHANGE, INC.",
    "32642": "ARBINET-LA-OPT-CUST - ARBINET-THEXCHANGE, INC.",
    "32643": "ARBINET-SF-RS - ARBINET-THEXCHANGE, INC.",
    "32644": "ARBINET-SF-OPT-CUST - ARBINET-THEXCHANGE, INC.",
    "32645": "PIVOT - FAIRPOINT COMMUNICATIONS, INC.",
    "32646": "LPC-N - Long Pond Capital, LP.",
    "32647": "CRUCIALWEBHOST - Crucial Web Hosting, Ltd.",
    "32648": "MNAT - Morris, Nichols, Arsht and Tunnel",
    "32649": "FE-DC-BGP - FRANKLIN ELECTRIC CO., INC.",
    "32650": "SANDHILLS-SW - SANDHILLS PUBLISHING",
    "32651": "COVENANT - Covenant Services Worldwide, LLC",
    "32652": "NAVTEQMARTCORE - HERE North America LLC",
    "32653": "ENETWORKS",
    "32654": "TWRS-CHI - Towerstream I, Inc.",
    "32656": "NUVEEN-NET01 - Nuveen Investments, LLC",
    "32657": "WRIWINDBER - WINDBER RESEARCH INSTITUTE",
    "32658": "EDELMAN-FINANCIAL - Sanders Morris Harris Group, Inc.",
    "32659": "CSCS-N - Commission scolaire de la Cote-du-Sud",
    "32660": "AVP-NORTH-AMERICA - AVENTIS PTEUR",
    "32661": "OLD-NATIONAL-BANCORP - Old National Bancorp",
    "32662": "GMCR - GREEN MOUNTAIN COFFEE ROTERS, INC.",
    "32663": "KCML-3-N - Knighthead Capital Management, LLC",
    "32664": "CLOUDNET-2 - Cloudnet, Inc.",
    "32665": "SOCALG-1 - Southern California Gas Company",
    "32666": "CWRU--1 - Case Western Reserve University",
    "32668": "SIMMONS-COMPANY - SIMMONS COMPANY",
    "32669": "WACOMT2004 - WACOM TECHNOLOGY",
    "32670": "PPAR-COS - Pikes Peak Association of REALTORS INC",
    "32671": "LEANLOGISTICS - LeanLogistics, Inc.",
    "32672": "TTIINC - TTI, Inc.",
    "32673": "SMGWORLD - SMG",
    "32674": "BLUE-HILL-DATA-SERVICES- - Blue Hill Data Services",
    "32675": "JEFF-PARISH-LA-SHERRIFF-OFFICE - Jefferson Parish Sheriff's Office",
    "32676": "-COSENTRY-COM-3 - COSENTRY.NET, LLC",
    "32677": "DKMC-BGP-DECATUR-GEORGIA-JUNE2004 - Dekalb Medical Center",
    "32678": "FIDALIA- - Fidalia Networks Inc.",
    "32679": "CRBERKSHIRES - CANYON RANCH",
    "32681": "SSD - Schlam Stone & Dolan, LLP",
    "32682": "-HTT - Home Town Telephone, LLC",
    "32683": "WAREHOUSE-DIRECT-OFFICE-PRODUCTS - Warehouse Direct Office Products",
    "32685": "ACM-N - Artis Capital Management, LP",
    "32686": "SMARTCITY-RELIANT-PARK - Smart City Networks, L.P.",
    "32687": "SKYTRON- - The KMW Group, Inc.",
    "32688": "GOLDEN1-CU-NET - GOLDEN 1 CREDIT UNION",
    "32690": "AEROFLEX-PLAINVIEW - Aeroflex Incorporated",
    "32691": "CSC - Corporation Service Company",
    "32692": "CHAMINADEUNIV-01 - Chaminade University of Honolulu",
    "32693": "CSBA - California School Boards Association",
    "32694": "HBCOMM - H&B Communications Inc.",
    "32695": "NEXECOMP-INC - NexeComp, Inc.",
    "32696": "TVD-EDISON-777 - Tri State Voice & Data, LLC",
    "32697": "ZINIO - Zinio Systems, Inc.",
    "32698": "PEORIANEXT- - Heartland Commerce & Economic Development Foundation",
    "32699": "FIRST-427 - Firstrade Securities Inc.",
    "32700": "HOMENET - Homenet Inc",
    "32701": "-VANGUARD - The Vanguard Group, Inc.",
    "32702": "MMCI - The Methodist Medical Center of Illinois",
    "32703": "IFN-NET - Indiana Fiber Network, LLC",
    "32704": "ORIONHEALTH - Orion Health Inc.",
    "32705": "WOODBRIDGEGROUP - The Woodbridge Group",
    "32706": "RHINO-XANADOO2 - JAB Wireless, INC.",
    "32707": "UHHS - University Hospitals Health System",
    "32708": "ADAR - Adar Investment Managment LLC",
    "32709": "1-JOINK - JOINK",
    "32710": "AGNICORP-N - AgniCorp Inc.",
    "32711": "WCGNC - Wake County Government",
    "32712": "TRIPWIRE-INC - Tripwire, Inc.",
    "32713": "GE-CI-LOUACCESS - General Electric Consumer Products",
    "32714": "COMPUTE",
    "32715": "ICCNET - ILLINOIS CENTRAL COLLEGE",
    "32716": "NORTHERNLAKESCOLLEGE1 - Northern Lakes College",
    "32717": "N-SNETANGOLA",
    "32718": "BPL-N - Boston Public Library",
    "32719": "BEPC- - Basin Electric Power Coop",
    "32720": "CANON-N - Canon USA Inc.",
    "32721": "WESBANCO - WesBanco Bank, Inc.",
    "32722": "BTLAW - Barnes & Thornburg",
    "32723": "-INF-001 - Infonexion Corp",
    "32724": "WEST-B2B-OMA - West Corporation",
    "32725": "WEST-B2B-SAT01 - West Corporation",
    "32726": "LIBERTY - Liberty University",
    "32728": "PALOMA-PARTNERS - Paloma Partners",
    "32729": "THE-ACTIVE-NETWORK-01 - The Active Network Inc.",
    "32731": "-CBTS - Code Blue Technology Solutions",
    "32732": "DCT-TELECOM - DCT Telecom Group, Inc.",
    "32733": "UD-RES- - University of Dayton",
    "32734": "2CONOC - 2checkout.com",
    "32735": "PEERMTL - Peerless Clothing Inc.",
    "32736": "INFORTECH-001 - Infortech Corporation",
    "32737": "SKYBEAM-32737 - JAB Wireless, INC.",
    "32738": "HYBRID-WIRELESS - Hybrid Wireless Inc",
    "32739": "CHRISTIANACARE--1 - Christiana Care Health Services, Inc.",
    "32740": "SLIQUA - Sliqua Enterprise Hosting, Inc.",
    "32741": "HPES - Hewlett-Packard Company",
    "32742": "4-RWEB - 4RWEB, Inc",
    "32743": "USCOLO-N - U.S. COLO, LLC",
    "32744": "MCCC - Montgomery County Community College",
    "32745": "UTI - UTi, United States, Inc.",
    "32746": "READYTECHS - ReadyTechs, LLC",
    "32747": "PLAYSPHERE - Atlantic Lottery Corporation",
    "32748": "STEADFT - Steadfast Networks",
    "32749": "POTPOURRI-GROUP-INC - Potpourri Group Inc",
    "32750": "GLEIM-N - Gleim Internet, Inc.",
    "32751": "NUCLEARFALLOUT-SEA - Nuclearfallout Enterprises, Inc.",
    "32752": "YCST- - Young Conaway Stargatt & Taylor, LLP",
    "32753": "GLOBEOP-FINANCIAL-SERVICES-NYC1 - GlobeOp Financial Services",
    "32754": "RANBAXYN-01 - Ranbaxy Pharmaceuticals, Inc.",
    "32755": "SRHS-205 - Spartanburg Regional Health Services District, Inc.",
    "32756": "CAMBRIANCOLLEGE - Cambrian College of Applied Arts & Technology",
    "32758": "TOTELCSI - TotelCSI",
    "32759": "INFENERGY - Infinite Energy, Inc.",
    "32760": "N-AURIS1 - Auris, LLC.",
    "32761": "WSE-NYC - Wasserstein & Co.",
    "32762": "SAULT-COLLEGE-N - Sault College of Applied Arts & Technology",
    "32763": "BS32BJB-HF - Building Service 32BJ Benefit Funds",
    "32764": "CIRL - CSN Support Services",
    "32765": "SENTCO - Sentco.net, LLC",
    "32766": "FIDELITY-BANK - Fidelity Bank",
    "32768": "MOBIUS-COMMUNICATIONS-NE - HEMINGFORD TELEPHONE",
    "32769": "MCFA - MITSUBISHI CATERPILLAR FORKLIFT AMERICA INC.",
    "32770": "CITYOF-294- - CITY OF PLEANTON",
    "32771": "DNSIMPLE - DNSimple",
    "32772": "MESTELNYC - Mestel & Company New York, LLC",
    "32773": "CC-N1 - Commstream Communications Inc",
    "32774": "NGK-SPARKPLUGS-USA - NGK Sparkplugs USA",
    "32775": "SMART-CITY-DALL - Smart City Networks, L.P.",
    "32776": "SMART-CITY-CHARLOTTE - Smart City Networks, L.P.",
    "32777": "SMART-CITY-FORT-WORTH - Smart City Networks, L.P.",
    "32778": "SMART-CITY-SANTA-CLARA - Smart City Networks, L.P.",
    "32779": "SMART-CITY-GRB-HOUSTON - Smart City Networks, L.P.",
    "32780": "HOSTINGSERVICES-INC - Hosting Services, Inc.",
    "32781": "DEFENDER-CLOUD-INTERNATIONAL-LLC - Defender cloud international llc",
    "32782": "NYC-PROD - Forex Capital Markets L.L.C.",
    "32783": "US-TROTTING-SOCIATION - U.S. Trotting Association",
    "32784": "MORTONINTL-1 - MORTON INTERNATIONAL, INC.",
    "32785": "BRTRADING - Rhino Trading, LLC",
    "32786": "FRONTIERFLYING - Frontier Flying Service, Inc.",
    "32787": "PROLEXIC-TECHNOLOGIES-DDOS-MITIGATION-NETWORK - Prolexic Technologies, Inc.",
    "32788": "XILOGIX-N - Xilogix, LLC",
    "32789": "FMD- - Fasken Martineau DuMoulin",
    "32790": "PACIOLAN-INC - Paciolan, Inc.",
    "32791": "CHIX- - Chi-X Canada ATS Ltd.",
    "32792": "TC-GTN - TransCanada Pipelines Ltd.",
    "32793": "CNS-11803NY - Computer Network Solutions LLC",
    "32794": "ICFG - International Church of the Foursquare Gospel",
    "32795": "HEARST-SERVICE-CENTER - HEARST CORPORATION",
    "32796": "VETERANS-TRANSPORTATION - Veterans Transportation Services Inc.",
    "32797": "BUCKRESEARCH- - Buckingham Research Group",
    "32798": "RYETEL- - The Rye Telephone Company",
    "32800": "MTELCO - Moundridge Telephone Co.",
    "32801": "REGAL - Regal Logistics Corp.",
    "32802": "BROCKTONHOSPITAL-ORG - Brockton Hospital",
    "32803": "IRES - International Rectifier",
    "32804": "PARANGON- - iWeb Technologies Inc.",
    "32806": "MARITIME-TELECOMMUNICATIONS-NETWORK - MARITIME TELECOMMUNICATIONS NETWORK, INC.",
    "32807": "N-INTERFACE-INC - INTERFACE INCORPORATED",
    "32808": "UTAHBROADBAND-1 - Utah Broadband LLC",
    "32809": "DRN- - Dickey Rural Networks",
    "32810": "GSM-N - Globe Specialty Metals, Inc.",
    "32811": "SMRSTWDS-MYMDU - MDU Communications (USA), Inc.",
    "32812": "N-SUNWESTFCU - Sunwest Federal Credit Union",
    "32813": "APS-N - American Payment Systems",
    "32814": "DATACONNECT - Data-Connect, LLC",
    "32815": "MOMA - MUSEUM OF MODERN ART",
    "32816": "WBGSEA - WB Games, INC",
    "32817": "NORTHERN-COLLEGE-ORION - Northern College of Applied Arts & Technology",
    "32818": "CSUOHIO- - Cleveland State University Computer Services",
    "32819": "DML-41-N - Dabroes Management LP",
    "32820": "NIPISSING - Nipissing University",
    "32821": "AD-CAT - ALTOONA AREA SCHOOL DIST.",
    "32822": "TEAMUCC - United Central Control, Inc.",
    "32823": "EVOLVER - Evolver, Inc.",
    "32824": "WWT-N1 - World Wide Technology, Inc.",
    "32825": "24-7--DEV-001 - 24/7 Customer, Inc.",
    "32826": "MARINER - Mariner Select, L.P.",
    "32827": "SEGAINC-ONLINE - Sega of America, Inc.",
    "32828": "WEN - Wyoming Community College Commission",
    "32829": "PORT-NETWORKS-BALTIMORE - Port Networks, LLC",
    "32830": "CCS-325-1 - Connecticut Computer Service, Inc.",
    "32831": "RPCI- - Roswell Park Cancer Institute",
    "32832": "ESDESIGN-COM - Environmental Systems Design, Inc.",
    "32834": "CHILDRENS-MEDICAL-CENTER - Children's Medical Center of Dallas",
    "32835": "TEX-NET - Valero Corporate Services",
    "32836": "LOGICAL-TELECOM-LP - Logical Telecom, L.P.",
    "32837": "WCL-50- - Williams & Connolly, LLP",
    "32838": "ZETRON-HQ-US - Zetron, Inc.",
    "32839": "AVANZADO-LLC - Avanzado LLC",
    "32840": "GRANDFIELD-DODD- - Grandfield & Dodd, LLC",
    "32841": "BOINGO--EC - Boingo Wireless, Inc.",
    "32842": "IBURST",
    "32843": "CITYOFHAYWARDCA - CITY OF HAYWARD",
    "32844": "COTEN-GDC- - Cotendo Inc.",
    "32845": "TEL-STAR - Tel-Star Cablevision Inc",
    "32846": "MDP - MDP",
    "32847": "LMGINC-ORL - LMG, Inc",
    "32848": "N-TRANS - TransFirst Holdings Inc.",
    "32849": "POWERSOUTH - PowerSouth Energy Cooperative",
    "32850": "MULTIPLAN-NY-MULTIPLAN-MD - Multiplan Corp.",
    "32851": "WAL-MART-2 - Wal-Mart Stores, Inc.",
    "32852": "THEPATRONSPRIITSCOMPANY - The Patron Spirits Company",
    "32853": "DMTN - Denso Manufacturing, Tennessee, Inc.",
    "32854": "PCTCU-N - Pinellas County Teachers Credit Union",
    "32855": "EMBARQ-NEBRKA - Embarq Corporation",
    "32856": "HSSCOREBGP01 - Haemonetics",
    "32857": "SPORTS-AUTHORITY- - The Sports Authority",
    "32858": "FG-1 - Frank Gates Service Company",
    "32859": "JEGS-HIGH-PERFORMANCE-N - JEGS",
    "32860": "CATS-NET-NETWORK",
    "32861": "MACQUARIE-HOLDINGS-USA-INC - Macquarie Holdings (USA) Inc.",
    "32862": "CAM-CAMSYS - Cambridge Systematics, Inc.",
    "32863": "NEWSPAPERCLIPS - NewspaperClips.com",
    "32864": "BOALN - Bedford Oak Advisors, LLC",
    "32865": "MONTANA-OPTICOM-32865 - Montana Opticom, LLC",
    "32866": "CJGAMESUS01 - CJ Games, Inc",
    "32867": "LLI-BLK1 - Long Lines Internet",
    "32868": "DS-DALL - Dataside, LLC",
    "32869": "SILVERSTAR-NET - Silver Star Telecom, LLC",
    "32871": "HACKER-GROUP-N-01 - The Hacker Group, Inc.",
    "32872": "SGRN2 - Spector Gadon & Rosen, P.C.",
    "32873": "COG-N - Children's Oncology Group",
    "32874": "SOCIATION-TECHNOLOGIES - Association Technologies, Inc.",
    "32875": "VIRPUS - DNSSLAVE.COM",
    "32876": "LYCOMING-COLLEGE - Lycoming College",
    "32877": "SKYWAYNETWORKS - Skyway Networks",
    "32878": "NWS-CR - National Weather Service",
    "32879": "CTG-NET - Clarity Technology Group, Inc.",
    "32880": "SMOOTHSTONE-IP-COMMUNICATIONS-CORP - Smoothstone IP Communications Corporation",
    "32881": "SERVERNORTH - Server North",
    "32882": "ADVENIAT-TELECOMMUNICATIONS - Adveniat",
    "32883": "LOGONIX - Logonix Corporation",
    "32884": "ALLSTON-TRADING-LLC - Allston Trading LLC",
    "32885": "IHS-N-27 - IOWA HEALTH SYSTEM",
    "32886": "NYC-INTERPUBLIC - THE INTERPUBLIC GROUP OF COMPANIES, INC.",
    "32887": "GEHA - GEHA",
    "32888": "SECURE-24-DCB - Secure-24, Inc.",
    "32889": "SOUTHWESTERN-WIRELESS - Southwestern Wireless, Inc.",
    "32890": "BTC--1 - Beehive Telephone Company, Inc.",
    "32891": "PRISMHEALTHNETWORK - Prism Network, Inc.",
    "32892": "DETRAD-01 - DE TRADING",
    "32893": "OGE - Oklahoma Gas & Electric Co.",
    "32894": "MCWANE - McWane, Inc.",
    "32896": "BORNEOUSA-1 - Borneo Management Services Limited, INC",
    "32897": "CCPUD-NETWORKS - Chelan County Public Utility District No.1",
    "32898": "DRMARTENS-NET - DR MARTENS AIRWAIR USA LLC",
    "32899": "BRESCOBROADBAND - Bresco Broadband",
    "32900": "QSL--01 - Quartet Service Ltd.",
    "32901": "CGNET-INTERNAP - CGNET Services International, Inc.",
    "32902": "WCIXNET - WCIX.Net, Inc.",
    "32903": "AMC2 - Atlantic Metro Communications",
    "32904": "SPOT-TRADING - Spot Trading LLC",
    "32905": "PARUS-HOLDINGS-INC - Parus Holdings, Inc.",
    "32906": "FM-INSURANCE F.M. INSURANCE COMPANY LTD",
    "32907": "STTHOM - University of St. Thomas",
    "32908": "TRIMBL-NUM - Trimble",
    "32909": "ROYALTY-CARPET-MILLS - Royalty Carpet Mills",
    "32910": "CONCENTRA-CDC - Concentra",
    "32911": "DEDIPOWERUSA - DediPower Managed Hosting",
    "32912": "PUBLIX-WEB-SERVICES - Publix Super Markets, Inc.",
    "32913": "TEXTURA-PLANSWIFT - PLANSWIFT  LLC",
    "32914": "HAL-N - Helios Advisors LLC",
    "32915": "KATTARE - Kattare Internet Services",
    "32916": "TRIPWIRE - Tripwire, Inc.",
    "32917": "SYNYGY-EUROPA SC SYNYGY EUROPA SRL",
    "32918": "THE-STAR-LEDGER - Star-Ledger",
    "32919": "ISP-PROMESA - Promesa Enterprises Inc.",
    "32920": "ITHAKA-SHAREDIT--1 - ITHAKA Harbors, Inc.",
    "32921": "ZSCALER-NEWYORK - ZSCALER, INC.",
    "32922": "ATCCOMMICATIONS - ATC Communications",
    "32923": "SILVERPNT-CT - SILVER POINT CAPITAL, L.P.",
    "32924": "GREENWAY-MEDICAL - Greenway Medical Technologies, Inc.",
    "32925": "HILMARCHEESE - HILMAR CHEESE COMPANY",
    "32926": "MSLC - Massachusetts State Lottery Commission",
    "32927": "CLECO-CORP - Cleco Corporation",
    "32928": "ITECHTOOL-N-LAH - ITechTool Incorporated",
    "32929": "BANTA-CORPORATION-MENHA-WI - Banta Corporation",
    "32931": "BUZNETCOM - BuzNet Communications",
    "32932": "GMDLWD11 - Guardian Mortgage Documents",
    "32933": "CERES-UNIFIED-SCHOOL-DISTRICT - Ceres Unified School District",
    "32934": "FACEBOOK - Facebook, Inc.",
    "32935": "32935 - XC Networks, Ltd.",
    "32936": "LAKEWOODCHURCH - Lakewood Church",
    "32937": "XOGROUP - XO Group, Inc.",
    "32938": "ACMCL404 - ATLANTA CAPITAL MANAGEMENT COMPANY, LLC",
    "32939": "ATLANTICBB-MIDDLETOWN - Atlantic Broadband Finance, LLC",
    "32940": "BROOKFIELD-HOMES-SOUTHLAND - Brookfield Homes Southland",
    "32941": "PYRSOFTWARE- - PYR Software Ltd.",
    "32942": "SCMN - Sandler Capital Management",
    "32943": "VOICEPULSE-NYC-01 - VOICEPULSE INC.",
    "32944": "FNIS - Fidelity National Information Services, Inc.",
    "32945": "TECONECTAMOS - Te Conectamos, LLC",
    "32946": "RPU-1892 - Rochester Public Utilities",
    "32947": "WEST-B2B-DEN01 - West Corporation",
    "32948": "LLS-HO- - LEUKEMIA & LYMPHOMA SOCIETY",
    "32949": "UNITED-REFRIGERATION - UNITED REFRIGERATION INC",
    "32950": "TOWNESTELECOMMUNICATIONS - Townes Telecommunications Services Corporation",
    "32951": "IPL-INTERNET1 - IPL",
    "32952": "-FTGX - FiberNet Telecom Group",
    "32953": "MHCV-1 - Mid-Hudson Cablevision, Inc.",
    "32954": "SG2-N - SG-2, LLC",
    "32957": "AVSL-32957 - Alpha Vision Services LLC",
    "32958": "HERITAGE-MEDICAL - Heritage Medical Associates, P.C.",
    "32959": "LITEUP - LiteUp, Inc.",
    "32960": "VONAGE-06 - Vonage Holdings, Inc.",
    "32961": "VONAGE-06 - Vonage Holdings, Inc.",
    "32962": "VONAGE-06 - Vonage Holdings, Inc.",
    "32963": "VONAGE-06 - Vonage Holdings, Inc.",
    "32964": "VONAGE-06 - Vonage Holdings, Inc.",
    "32965": "VONAGE-06 - Vonage Holdings, Inc.",
    "32966": "VONAGE-06 - Vonage Holdings, Inc.",
    "32967": "VONAGE-06 - Vonage Holdings, Inc.",
    "32968": "VONAGE-06 - Vonage Holdings, Inc.",
    "32969": "GLOBAL-CH-ACCESS - Global Cash Access, Inc.",
    "32970": "FNIS-6- - Fidelity National Information Services, Inc.",
    "32971": "HCC-N - Howard Community College",
    "32972": "CORPTAX-INC-1 - Corptax, Inc.",
    "32973": "BCL-N - Bracebridge Capital, LLC",
    "32974": "N-GHC - Group Health Cooperative",
    "32975": "TSH-NADC - Thomson Reuters Holdings Inc",
    "32976": "DRSLLC- - DRS LLC",
    "32977": "CBSITE-CHI-WEB - CareerBuilder, LLC",
    "32978": "NEUSTAR-2 - NeuStar, Inc.",
    "32979": "NEUSTAR-3 - NeuStar, Inc.",
    "32980": "NEUSTAR-5 NETWO336-ARIN",
    "32981": "NEUSTAR-4 - NeuStar, Inc.",
    "32982": "DOE-HQ - U.S. Department of Energy",
    "32983": "VISICUHQ - Visicu, Inc.",
    "32984": "RUELALA-INC - Rue La La Inc",
    "32985": "KCG-INC - Knowledge Consulting Group Inc.",
    "32986": "KEYDEV - Key Developments, LLC",
    "32987": "080780 - Clnetworks Inc",
    "32988": "VIRTELA-CUST-VCJC1-DSC Virtela Communications",
    "32989": "ARCSCALE-1 - Gig Avenue, LLC",
    "32991": "SPECUSA- - Spectrum Software Solutions Inc.",
    "32992": "ITECHTOOL-N-SF - ITechTool Incorporated",
    "32993": "N-ITS - ITS COMMUNICATIONS",
    "32994": "GALAXYBRANDS - Galaxy Brands, LLC",
    "32995": "NETFOR - Netfor, Inc",
    "32996": "AGRIBANK-STPAUL - AgriBank, FCB",
    "32997": "METROPCS-CORPORATE-DALL - MetroPCS Wireless, Inc.",
    "32998": "USVP - U.S. Venture Partners",
    "32999": "ECRI - ECRI",
    "33000": "WILDFIRE-33000 - Wildfire Broadband, LLC",
    "33001": "CRAVATH-SWAINE- Cravath Swaine and Moore",
    "33002": "BANDWIDTH-NOW-SD - Bandwidth Now, LLC",
    "33003": "TRI-COUNTY-CORE - The Tri-County Telephone Association, Inc.",
    "33004": "SUNY-ESC - Empire State College",
    "33005": "ELTOPIA - Eltopia.com, LLC",
    "33006": "LOGICALHOST - Logical Host, LLC",
    "33007": "KWIC- - NCS Technologies",
    "33009": "TKFT - TkFast Inc",
    "33010": "INTERCHURCH - The Interchurch Center",
    "33011": "BOXNET - Box.com",
    "33012": "VENTURIAN-HOSTING-LLC - Venturian Hosting LLC.",
    "33013": "AICPA - American Institute of Certified Public Accountants",
    "33014": "MARLINLEING - MARLIN LEING",
    "33015": "SILVER-EAGLE - Silver Eagle Distributors, L.P.",
    "33016": "2NDCITY - Second City Enterprises, Inc.",
    "33017": "MICROWORKS-OTT-NET - Kendall Lougheed and Associates Inc.",
    "33018": "GOGO6- - gogo6 Inc.",
    "33019": "WHEATONCOLLEGE - Wheaton College",
    "33020": "SAFENET - SAFENET",
    "33021": "PBVUSD - Panama-Buena Vista Union School District",
    "33022": "WELLESLEY-COLLEGE - Wellesley College",
    "33023": "MCCP- - Mahoney Cohen & Company, CPA, P.C.",
    "33024": "HWS - Harvard-Westlake School",
    "33025": "QE-N-01 - Quinn Emanuel Urquhart Oliver & Hedges LLP",
    "33026": "SHAKLEE1 - SHAKLEE CORPORATION",
    "33027": "NANO - Nanometrics, Incorporated",
    "33028": "THENEBULACLOUD - vexxhost",
    "33029": "OSAGE-MUNICIPAL-COMMUNICATIONS-UTILITY - Osage Municipal Communications Utility",
    "33030": "COLLEGE-OF-WOOSTER - College of Wooster",
    "33031": "INERAIL - Inerail",
    "33032": "AMI - American Megatrends, Inc.",
    "33033": "TELESPHERE-NETWORKS - Telesphere Networks Ltd.",
    "33034": "SITE-SAFE--1 - Crown Castle USA",
    "33035": "BAHAM-WIMAX - Bahamas WiMax",
    "33036": "PARLO--1 - Parlor.fm",
    "33037": "SAFELINK-BOISE1N - Safelink Internet",
    "33038": "XTT1 - XIT Rural Telephone Cooperative Inc.",
    "33039": "EDMC-INTERNET - Education Management Corporation",
    "33040": "ISNW- - ISN Wireless",
    "33041": "CONNECTION-TO-NPAC - Rogers Wireless Inc.",
    "33042": "MILLWA-US - Millward Brown, Inc.",
    "33043": "ELECTRONIC-ARTS-TIBURON - Electronic Arts, Inc.",
    "33044": "MEGAWIRE - Megawire Inc.",
    "33045": "HGST- - HITACHI GLOBAL STORAGE TECHNOLOGIES, INC.",
    "33046": "WFEC-COOPNET - Western Farmers Electric Cooperative",
    "33047": "INSTART - Instart Logic, Inc",
    "33048": "MARKWINS-NETWORK - Markwins International",
    "33049": "TELENAV2004 - TeleNav, Inc.",
    "33050": "REMAX-INTERNATIONAL - RE/Max International, Inc.",
    "33051": "SAN-YSIDRO-SCHOOL-DISTRICT - SAN YSIDRO SCHOOL DISTRICT",
    "33052": "VZUNET - Verizon Data Services LLC",
    "33053": "CLIPPER-MAGAZINE-NET - CLIPPER MAGAZINE",
    "33054": "MCCRACKENFS - McCracken Financial Software",
    "33055": "BCC-65-182-96-0-PHX - Brinkster Communications Corporation",
    "33056": "ABM-INTERGRATED-SOLUTIONS - ABM Integrated Solutions",
    "33057": "-ACTIV - ACTIV Financial Systems, Inc.",
    "33058": "PEGYSTEMS - Pegasystems Inc.",
    "33059": "MOMENTUM33059 - Momentum Telecom, Inc.",
    "33060": "PEERINGPARTNERS-33060 - Peering Partners Communications, LLC",
    "33061": "MOMENTUM33061 - Momentum Telecom, Inc.",
    "33062": "ALEXLEE-INC - ALEX LEE INC",
    "33063": "FREDCCHURCH - Fred C. Church, Inc.",
    "33064": "SNEI-SD - Sony Media Software and Services Inc.",
    "33065": "MEGATECHIE - Megatechie",
    "33066": "VISAL - Visalus, Inc.",
    "33067": "CLSICSOUTHCOMM - Classic South Communications, L.L.C.",
    "33068": "US1-HYPERSPEED - LIQUIDNET HOLDINGS INC.",
    "33069": "-BUSINESS-COMMUNICATIONS - BCI",
    "33070": "RMH-14 - Rackspace Hosting",
    "33071": "ISC-F- - Internet Systems Consortium, Inc.",
    "33072": "ISC-BCN1 Internet Systems Consortium, Inc.",
    "33073": "ISC-LCY1 Internet Systems Consortium, Inc.",
    "33074": "ISC-NBO1 Internet Systems Consortium, Inc.",
    "33075": "ISC-SCL1 Internet Systems Consortium, Inc.",
    "33076": "ISC-TGD1 Internet Systems Consortium, Inc.",
    "33077": "ISC-TRN1 Internet Systems Consortium, Inc.",
    "33078": "ISC-CAI1 Internet Systems Consortium, Inc.",
    "33079": "ISC-OSL1 Internet Systems Consortium, Inc.",
    "33080": "ISC-F- - Internet Systems Consortium, Inc.",
    "33081": "ISC-LCY2 Internet Systems Consortium, Inc.",
    "33082": "ISC-FRA1 Internet Systems Consortium, Inc.",
    "33083": "AXCELX-NET - AxcelX Technologies LLC",
    "33084": "DC-NET - DC-Net",
    "33085": "THE-MENS-WEARHOUSE - The Men's Wearhouse",
    "33086": "PARAADV - Para Advisors LLC",
    "33087": "AMCOI - AMCO Insurance Company",
    "33088": "COMPSYCH- - ComPsych",
    "33089": "XACCELNETWORKS - Xaccel Networks LLC",
    "33090": "ANDREWCORP-NOVA - Andrew Corp.",
    "33091": "U-CALGARY - University of Calgary",
    "33092": "QED-FINANCIAL-SYSTEMS-INC - QED Financial Systems, Inc.",
    "33094": "CREATIVE-SOCIATES-ARIN--NUMBER - Creative Associates International",
    "33095": "ALTERNATIVE-BANDWIDTH - Alternative Bandwidth, LLC",
    "33096": "HBT-1904 - Hills Bank and Trust Company",
    "33097": "VOLOCU - Volo Broadband",
    "33098": "TWRS-SP - Towerstream I, Inc.",
    "33099": "RDA-1 - RDA CORPORATION",
    "33100": "DHR-INTERNATIONAL - DHR INTERNATIONAL",
    "33101": "SOLIDTECHNOLOGY - Solid Technology",
    "33102": "PTI-1001- - PORTATIVE TECHNOLOGIES",
    "33103": "TECHRADIUM-INC - Techradium, INC.",
    "33104": "JELLYVISION - The Jellyvision Lab, Inc.",
    "33105": "ONE-CALL-MEDICAL - ONE CALL MEDICAL",
    "33106": "BCSOE - Supervisor of Elections",
    "33107": "EMSB-RISQ - English Montreal School Board",
    "33108": "CHEVRONTEXACO-FEDERAL-CREDIT-UNION - ChevronTexaco Federal Credit Union",
    "33109": "EQUINIX-RS-LAX - Equinix, Inc.",
    "33110": "-FIML-1 - Falcon Investment Management LLC",
    "33111": "NAVARRE-CORP - NAVARRE CORPORATION",
    "33112": "ACI-BGP - Arch Coal Inc",
    "33113": "CONETRIX - CONETRIX LLC",
    "33114": "CO-OP - Cu Cooperative Systems, Inc.",
    "33115": "AMARANTHNET - Amaranth Networks, Inc.",
    "33116": "N-WH-CO-VA-SCHOOLS - Washington County Schools",
    "33117": "STELLAR-SOCIATION - Stellar Association, LLC",
    "33118": "DAHC - Drive America Holdings Corp",
    "33119": "GLOBALTAP-HBURN - The Globaltap Corporation",
    "33120": "VIRGINIA-BEACH-CITY-PUBLIC-SCHOOLS - Virginia Beach City Public Schools",
    "33121": "INTERACTIVE-CHIC - Interactive Brokers LLC",
    "33122": "SPWL - Sun Prairie Utilities",
    "33123": "AUDANYCBGP4 - Auda Advisor Associates LLC",
    "33124": "PPGH01 - Palo Pinto General Hospital",
    "33125": "SPIRALIGHT - Spiralight Network, LLC",
    "33126": "KATONAH - Katonah Capital L.L.C.",
    "33127": "ISCORP-MEQUON - Integrated Systems Corp",
    "33128": "LONGACRE-NY - LONGACRE FUND MANAGEMENT, L.L.C.",
    "33129": "CITY-OF-GARDEN-GROVE - City of Garden Grove",
    "33130": "IL - Internet Access Solutions Ltd.",
    "33132": "FPL-FIBERNET - FPL FiberNet, LLC",
    "33133": "CNSI-01 - CopperNet Systems, Inc.",
    "33134": "KTCFV-USA - Kingston Technology Company",
    "33135": "NETNUMBER - NetNumber, Inc.",
    "33136": "-EDAP-209-92-155 - Edaptive Systems, LLC",
    "33138": "-NYPD - New York City Police Department",
    "33139": "CANACA-210 - Canaca-com Inc.",
    "33140": "SAN-ISABEL-TELECOM-INC - San Isabel Telecom, Inc.",
    "33141": "NOCSERVICES - NOC SERVICES CORP.",
    "33142": "OSWI-NET - Ultimate Internet Access, Inc",
    "33143": "INTELEPEER-US-DALL - IntelePeer, Inc.",
    "33144": "NAVIGANTCONSULTING - NAVIGANT CONSULTING",
    "33145": "N-BETHANYBCS - Bethany Christian Services",
    "33146": "TWGI-DC - THE WEINBERG GROUP INC",
    "33147": "COWLESPUBL- - Cowles Publishing Company",
    "33148": "TEX-STATE-UNIVERSITY-SYSTEM - Texas State University - San Marcos",
    "33149": "FFTFILL-INC - Ffastfill Inc.",
    "33150": "APTC - ANAHEIM PALMS TELECOM CENTER, LLC",
    "33151": "TRUSTWAVE-N - Trustwave Holdings, Inc.",
    "33152": "KCEC-N - Kit Carson Electric Cooperative, Inc",
    "33153": "SCAP- - SUNY College at Potsdam",
    "33154": "DQECOM - DQE Communications Network Services, LLC",
    "33155": "ATS-NET - ADVANCED TECHNOLOGY SERVICES INC.",
    "33156": "SSC - SecureSysCom, Inc.",
    "33157": "EQUINIX-EDMA-LAX-N - Equinix, Inc.",
    "33158": "DATA-SERVICES-INC - Data Services Incorporated",
    "33159": "NSPNET1 - Nature's Sunshine Products International",
    "33160": "OLDREPUBLICTITLE - OLD REPUBLIC NATIONAL TITLE INSURANCE CO.",
    "33161": "CHUMH-CINO-RESORT - Chumash Casino Resort",
    "33162": "CAPRIS-GROUP - Capris Group",
    "33163": "HEALTHPARTNERSPA - Health Partners of Philadelphia",
    "33164": "IRIS- Iristel Inc",
    "33165": "MISSOURI-NETWORK-ALLIANCE - Missouri Network Alliance, LLC",
    "33166": "ADP-FIS-01 - Automatic Data Processing, Inc.",
    "33167": "SWOCA-TWSIGNED - Southwest Ohio Computer Association",
    "33168": "INLANDIMAGING - INLAND IMAGING L.L.C.",
    "33169": "UDINET - Utherverse Digital Inc.",
    "33170": "MORGAN-STATE-UNIVERSITY - Morgan State University",
    "33171": "THE-RELIZON-COMPANY - THE RELIZON COMPANY",
    "33172": "MERIDIAN-LEING-CORPORATION - Meridian Leasing Corporation",
    "33173": "MYGN-US - Myriad Genetics Incorporated",
    "33174": "NEXXLINX - CustomerLinx of North Carolina, Inc.",
    "33175": "SCCB-N - South Coast Community Bank",
    "33176": "DTCCA - DTC Cable",
    "33177": "KALEI-2- - Kaleida Health",
    "33178": "CSINET - Cable Services, Inc.",
    "33179": "UDP - UDP Inc.",
    "33181": "OB--PAC - Bloomberg Financial Market",
    "33182": "DIMENOC - HostDime.com, Inc.",
    "33183": "BNC-BANK- - BNC National Bank",
    "33184": "MEDDATA-SEATTLE - Med-Data, Inc.",
    "33185": "TGLO-VGLO - THEGLOBE.COM, INC.",
    "33186": "DAVITTACLINK - DaVita, Inc.",
    "33187": "SHSU--1 - Sam Houston State University",
    "33188": "AUTOWC-01 - Auto Warehousing Company",
    "33189": "SOUTH-DAKOTA-RESEARCH-AND-EDUCATION-NETWORK - South Dakota Board of Regents",
    "33190": "KAZ - KAZ INCORPORATED",
    "33191": "IMEDGE - IMedge, LLC",
    "33192": "NAIB - National Aquarium in Baltimore",
    "33193": "RESERVOIR-NA - RESERVOIR CAPITAL PARTNERS, L.P.",
    "33194": "C-AUTONOMOUS-SYSTEM - Chemical Abstracts Service",
    "33195": "ROXIO - Rovi Corporation",
    "33196": "CONTROLPOINTE - Control Pointe LLC",
    "33197": "CROSSHARBORCP - Cross Harbor Capital Partners",
    "33198": "ATHER- - Atheros Communications Inc.",
    "33199": "EVO-N - EVO Merchant Services, LLC",
    "33200": "TELOGIS1 - Telogis, Inc",
    "33201": "TETF - Tilver Enterprises, LLC",
    "33202": "MOORE-VAN-ALLEN - Moore & Van Allen PLCC",
    "33203": "THE-ALDRIDGE-NETWORK - The Aldridge Company",
    "33204": "NCOMP-IMORTGAGE - NCompass, LLC",
    "33205": "DOSL-N1 - Data One Solutions, LLC.",
    "33206": "ZINPRO - ZINPRO",
    "33207": "CORNELL-PI1 - Cornell University",
    "33208": "SIGMAM- - Sigma Micro, LLC",
    "33209": "-INTERPLEX - Interplex",
    "33210": "1-800-HOSTING - 1-800-HOSTING, Inc.",
    "33211": "RISINGNET - RisingNet, LLC",
    "33212": "DAYSTARR- - Daystarr Communications",
    "33213": "BIN-NET - BIN 2 WAY RADIO",
    "33214": "TENAUTO-NA - Tenneco Automotive",
    "33215": "OVATI-10 - Ovation Travel Group, Inc.",
    "33216": "MAXIM - Maxim Integrated Products",
    "33217": "SCHNEIDER - Schneider National, Inc.",
    "33218": "ORION-CONSULTANTS-INC - Orion Consultants Inc.",
    "33219": "UMCC-2 - Ultimate Medium Communications Corp.",
    "33220": "OB--EU - Bloomberg Financial Market",
    "33221": "EGLUCK - E. Gluck Corporation",
    "33223": "GFI-GROUP-1 - GFI Group, Inc.",
    "33224": "TWRS-LA - Towerstream I, Inc.",
    "33225": "RPOINT-BOS-BGP-01 - Rockpoint Group, LLC.",
    "33226": "SUMMAHEALTH-N - Summa Health System",
    "33227": "BLUEBRIDGE-NETWORKS - Blue Bridge Networks",
    "33228": "ALPINEACCESSNET - Alpine Access, Inc.",
    "33229": "NEXTWAVE-CORP - Nextwave Telecom Inc.",
    "33230": "-CROSS - Cross Country TV Ltd",
    "33231": "IMTECH-GRAPHICS - Imtech Graphics, Inc.",
    "33232": "ERXNETWORK - eRx Network",
    "33233": "OECU-BGP1 - Oklahoma Employees Credit Union",
    "33234": "SJOBERGS-INC - Sjoberg's Inc",
    "33235": "SANJUAN - San Juan Unified School District",
    "33236": "DTBDS-1 - DTB Data Services, LLC",
    "33237": "SAVANTLTD- - Savant LTD",
    "33238": "ARGIN - iPacesetters LLC",
    "33239": "CIS-MSISAC - Center for Internet Security",
    "33240": "OPERA - Opera Solutions",
    "33241": "STREETLINE--1 - Streetline, Inc.",
    "33242": "LIGHTYEAR-NY - LIGHTYEAR CAPITAL LLC",
    "33243": "PEN-SQUARE - PEN SQUARE MANAGEMENT INC",
    "33244": "DEPM205 - Douglas Elliman Property Management",
    "33246": "BLC- - Bethany Lutheran College",
    "33247": "COTAL-BGP - COTAL TELCO SERVICES, INC.",
    "33248": "COE- - City of Evanston, Illinois",
    "33249": "HEIDMARUS Heidmar US",
    "33250": "RIOPL-COGE - Rioplex Wireless, Ltd.",
    "33251": "WINDSTEAM-HOSTED-SOLUTIONS-3 - Windstream Hosted Solutions, LLC",
    "33252": "BSPRO- - Bass Pro, Inc.",
    "33253": "OURAYNET - OurayNet",
    "33254": "OMERESA - Ohio Mid Eastern Regional Education Service Agency",
    "33255": "HAMDEN-N - Hampden-Sydney College",
    "33256": "QL-N-ROS - Qlogic Corporation",
    "33257": "WLC - Expert Service Providers LLC",
    "33258": "UGOTFILE - uGotFile, Inc.",
    "33259": "AV-101 - Coryn Group Inc.",
    "33260": "HOSTAURUS - Hostasaurus, Inc.",
    "33261": "SPECTRUM-GLOBAL-COMMUNICATIONS-INC-NETBLOCK - Spectrum Global Communications Inc.",
    "33262": "NVIAC - Fairfax Cable Access Corporation",
    "33263": "NEXTECLOUD-NETWORKS - NexteCloud L.L.C.",
    "33264": "YIPTEL - YIPTEL, L.L.C.",
    "33265": "-DESIGNORY-INC - The Designory, INC.",
    "33266": "CATAPHORA - Cataphora, Inc.",
    "33267": "BALLY-TOTAL-FITNESS - Bally Total Fitness",
    "33268": "TRUST - TRUST, LLC",
    "33269": "TELESPHERE-NETWORKS - Telesphere Networks Ltd.",
    "33270": "PMCSAZ - Preferred Medical Claim Solutions",
    "33271": "NPD-N-HQ-01 - Naperville Park District",
    "33272": "INTERLOCHEN-CENTER-FOR-THE-ARTS - Interlochen Center for the Arts",
    "33273": "SOFTARTISANS - Software Artisans, Inc.",
    "33274": "N-FAIRVIEWHEALTHSERVICES - Fairview Health Services",
    "33275": "KHS-N - Kennedy Memorial Hospitals - University Medical Center",
    "33277": "N1 - THE MEMBERS GROUP",
    "33278": "NSLC-ORG - National Student Clearinghouse",
    "33279": "EMPIRIX - EMPIRIX Inc",
    "33280": "-AFILI-MIA2 - Afilias Canada, Corp.",
    "33281": "BRIGHAM-YOUNG-UNIVERSITY-IDAHO - BRIGHAM YOUNG UNIVERSITY - IDAHO",
    "33282": "SOLUTIONWORKS-ACCENTURE - SOLUTION WORKS-ACCENTURE",
    "33283": "MCSERVICES - Imperial Technology, Inc.",
    "33284": "LBI-N - LBiSat, LLC",
    "33285": "SHENANDOAH-LIFE-INSURANCE-COMPANY - Shenandoah Life Insurance Company",
    "33286": "TURLOCK-IRRIGATION-DISTICT - Turlock Irrigation District",
    "33287": "COMCT-33287 - Comcast Cable Communications, Inc.",
    "33288": "LIQUIDPOINT-LLC - LiquidPoint, LLC",
    "33289": "BROADVOICE-TOY - Broadvoice, Inc.",
    "33290": "BROADVOICE-DCA - Broadvoice, Inc.",
    "33291": "BROADVOICE-ATL - Broadvoice, Inc.",
    "33292": "BROADVOICE-BOS - Broadvoice, Inc.",
    "33293": "BROADVOICE-LAX - Broadvoice, Inc.",
    "33294": "BROADVOICE-LON - Broadvoice, Inc.",
    "33295": "BROADVOICE-CHI - Broadvoice, Inc.",
    "33296": "BROADVOICE-MIA - Broadvoice, Inc.",
    "33297": "BROADVOICE-NYC - Broadvoice, Inc.",
    "33298": "MARVAMAIDNN - Marva Maid Dairy",
    "33299": "MH980 - Mission Hospitals, Inc.",
    "33300": "EDAN - Electricity Distributors Association",
    "33301": "CMCLNET - Finiti Group, LLC",
    "33302": "ONS-COS - Data 102, LLC",
    "33303": "METROBRIDGE-ORG - Metrobridge Networks USA Corporation",
    "33304": "RACETRAC - RaceTrac Petroleum, Inc.",
    "33305": "INFODIR - Info Directions, Inc.",
    "33306": "HANDI-FOIL - Handi-foil Corp.",
    "33307": "HNL- - Hightower Networks, LLC",
    "33308": "LOG-2008-GBW - Logicalis",
    "33309": "IMOBILE3- - iMobile3, LLC",
    "33310": "GLORB - Glorb Internet Services",
    "33311": "NET-TOPCON - TOPCON POSITIONING SYSTEMS INC",
    "33312": "FFBM-0049 - First Federal Bank of the Midwest",
    "33313": "WILCON - Wilcon",
    "33314": "VCC - Vancouver Community College",
    "33315": "FIRSTBANK-PUERTO-RICO - First BanCorp",
    "33316": "AV-INC - AeroVironment, Inc.",
    "33317": "FORESITEWIRELESS - Foresite Management, Inc.",
    "33318": "-AHC-80 - Agfa HealthCare Corporation",
    "33319": "PEC-NAPLES - Premier Executive Center",
    "33320": "IS3 - International Software Systems Solutions, Inc.",
    "33321": "BALTICORE - Balticore, LLC",
    "33322": "NDCHOST - Network Data Center Host, Inc.",
    "33323": "4WHEELPARTS - TransAmerican Auto Parts Company, LLC",
    "33324": "CHALLENGE-PRINTING - Challenge Printing",
    "33325": "BSYX-BIOSYNEXUS--BART-001 - Biosynexus Incorporated",
    "33326": "M2NET - MacLaren McCann Canada Inc.",
    "33327": "-PHIL - DigitalSpeed Communications",
    "33328": "NORTON-HEALTHCARE - Norton Healthcare",
    "33329": "IPCOMMUNICATIONS - IP Communications",
    "33330": "CLOUDRADIUM-USA-N - CloudRadium L.L.C",
    "33331": "FIRST-AMERICAN-FANDO - FIRST AMERICAN R.E. INFO SVCS.",
    "33332": "SUMNETLLC- - SUMNET, LLC",
    "33333": "LAFIBER - LAFiber, LLC",
    "33334": "SKYBEAM-ECCENTRIX - JAB Wireless, INC.",
    "33335": "2KDIRECT - 2KDirect, Inc.",
    "33336": "TIMEINC-TAMPA-N - Time Inc.",
    "33337": "TNS-NYCMVP - Transaction Network Services, Inc.",
    "33338": "TUALITY-HEALTHCARE - TUALITY HEALTHCARE",
    "33339": "NEMONT-CELLULAR - Nemont",
    "33340": "OI-NETWORKS - Outreach Internet, Inc.",
    "33341": "CUSD300-CARPENTERSVILLEIL - Community Unit School District 300",
    "33342": "QUALCOMM-AUSTIN - Qualcomm, Inc.",
    "33344": "PUBLIC- - American Petroleum Institute",
    "33345": "SIERRADATACENTERS - Sierra w/o Wires, Inc.",
    "33346": "MONSTERBROADBAND - Monster Broadband, Inc.",
    "33347": "ZIMBRICK-CORP - Zimbrick, Inc.",
    "33348": "PIERCE-COUNTY - Pierce County",
    "33349": "PERSHING - The Bank of New York Mellon Corporation",
    "33350": "APS---ARIZONA-PUBLIC-SERVICE-CORPORATION - Arizona Public Service Company",
    "33351": "NEW-GLOBAL-TELECOM-INC - New Global Telecom Inc.",
    "33352": "HNA-115 - Abrams Books",
    "33353": "GAIKAI - Gaikai, Inc.",
    "33354": "AIO-NS - All-In-One Network Solutions, Inc.",
    "33355": "NWR- - Northwest Research, Inc.",
    "33356": "CTWS - Eagle-Tech Systems",
    "33357": "DS-NET - GenRad, Inc.",
    "33358": "AE-CORPORATE-SERVICES-CO - AE CORPORATE SERVICES CO",
    "33359": "BNYB-SONIC - BNY Brokerage",
    "33360": "MRM-HQ - Maricopa Ready Mix LLC",
    "33361": "THEWIRE - THE WIRE INC.",
    "33362": "WIKTEL - Wikstrom Telephone Company, Incorporated",
    "33363": "BHN-TAMPA - BRIGHT HOUSE NETWORKS, LLC",
    "33364": "HCGHOSPITAL - HOWARD COUNTY GENERAL HOSPITAL",
    "33365": "CINFIN-N-01 - THE CINCINNATI INSURANCE COMPANY",
    "33366": "STONE-HARBOR-INVESTMENT-PARTNERS - Stone Harbor Investment Partners, LP",
    "33367": "FNFCO-BGP1 - FNF Construction, Inc.",
    "33368": "FXSERVER - Visual Trading Systems, LLC",
    "33369": "LIFEWATCH-SERVICES - LIFEWATCH SERVICES INC.",
    "33370": "-RIVCTY - City of Riverside",
    "33371": "WMA-BEVERLY-HILLS - William Morris Agency, Inc.",
    "33372": "SPARTAN- - Spartan Stores Inc.",
    "33373": "FHLBB-5 - Federal Home Loan Bank of Boston",
    "33374": "BON--001 - SOURCE INTERLINK COMPANIES",
    "33375": "ATHILON-NYC - ATHILON STRUCTURED INSURANCE ADVISORS, LLC",
    "33376": "CTLE-HARLAN - Castle Harlan",
    "33377": "FHLBC - Federal Home Loan Bank of Chicago",
    "33378": "N1 - ETERN BANK",
    "33379": "ACCELERATEBIZ - AccelerateBiz Inc.",
    "33380": "SSNC-OMR - SS&C Technologies, Inc.",
    "33382": "CRYPTICSTUDIOS-HQ - CRYPTIC STUDIOS, INC.",
    "33383": "HPES - Hewlett-Packard Company",
    "33384": "TEVA-NA - Teva Pharmaceuticals USA, INC",
    "33385": "QUOMATION - Quomation Insurance Services, Inc.",
    "33386": "EFRONTIER-0 - Efficient Frontier, Inc.",
    "33387": "DATHACK - DataShack, LC",
    "33388": "CSN - Community School of Naples, Inc.",
    "33389": "COLLEGEBOREAL - College Boreal",
    "33390": "READYTECH - READYTECH CORPORATION",
    "33391": "SECURITY-FINANCE - SECURITY FINANCE CORPORATION OF SPARTANBURG",
    "33392": "DAUPHIN-TELECOM - Dauphin Telecom",
    "33393": "MMMI - Michigan Millers Mutual Insurance Company",
    "33394": "SMH- - Seattle Mental Health",
    "33395": "TUSHAUS- - Tushaus Computer Services",
    "33397": "GENSOCIETYUTAH - Genealogical Society of Utah",
    "33398": "IMCLONE2005 - ImClone Systems, Inc.",
    "33399": "MTS-1 - Micro Technology Solutions, Inc.",
    "33400": "ATLANETBGP - American Theological Library  Association",
    "33401": "CPCC - Central Piedmont Community College",
    "33402": "BRIDGER-NYC1 - Bridger Management, LLC",
    "33403": "BROADCT-MUSIC-INC - BROADCT MUSIC, INC.",
    "33404": "DIRECTEDGE - Direct Edge",
    "33405": "HESS - Hess Corporation",
    "33406": "THOCC-N-1 - THE HOSPITAL OF CENTRAL CONNECTICUT AT NEW BRITAIN GENERAL AND BRADLEY MEMORIAL",
    "33407": "ITS-N - Internet Technical Services, LLC",
    "33408": "YPC-NET-N-65-215-76-0-167-206-212-0-24-YPC-NET - Yorktown Printing Corp.",
    "33409": "N-CBICI - CBI Connect Inc.",
    "33410": "MANDIANT-US2 - MANDIANT Corp",
    "33411": "BRIGHTPATTERNSC - Bright Pattern, Inc",
    "33412": "BAXACOBGP - Baxa Corporation",
    "33413": "BETA-OFFSHORE - Beta Offshore",
    "33414": "KENTCOUNTYMI - Kent County Information Systems",
    "33415": "PERKINSCOIE-N - Perkins Coie, LLP",
    "33416": "JMCGH-WTH-1950 - West Tennessee Healthcare",
    "33418": "HRNIT - HRN IT Co.",
    "33419": "TRIBAL-FUSION - Exponential Interactive, Inc.",
    "33420": "TCDI - Technology Concepts & Design, Inc.",
    "33421": "SEEDCO915 - SEEDCO",
    "33422": "NETC - New England Telehealth Consortium",
    "33423": "-SGT - SierraGem Technologies, LLC",
    "33424": "POWER-CORPORATION-DU-CANADA - Power Corporation du Canada",
    "33425": "MICROFINANCIAL - Timepayment",
    "33426": "AUTHORIA - AUTHORIA",
    "33427": "WSUTC - Washington State University",
    "33428": "NHS-39 - The New-York Historical Society",
    "33429": "NMT-DENVER - Newmont USA Limited",
    "33430": "VTSIL - Vantage Technologies Systems Integration, LLC",
    "33431": "JELLYDIGITAL - Jelly Digital",
    "33432": "INFB3- - InternetNamesForBusiness.com",
    "33433": "CLINICOMP - CLINICOMP INTERNATIONAL, INC.",
    "33434": "PEMPNAME01 - FEDERAL HOME LOAN BANK OF SEATTLE",
    "33435": "COMVERSE-WKF - Comverse, Inc.",
    "33436": "PARTNER-FUND-MANAGEMENT - Partner Fund Management, L.P.",
    "33437": "HOTNIC - Hotnic LLC",
    "33438": "HIGHWINDS2 - Highwinds Network Group, Inc.",
    "33439": "FZWL-NYC1LIB - Flemming, Zulack & Williamson, LLP",
    "33440": "WEBRULON-NETWORK - webRulon, LLC",
    "33441": "WIZTEL-N - Wiztel Inc.",
    "33442": "ZEBRA-TECHNOLOGIES-BGP--NUMBER - Zebra Technologies",
    "33443": "-NGENX - nGenX Corporation",
    "33444": "N-TAZEWELL-CO-VA-GOVT - Tazewell County",
    "33445": "YELP - Yelp! Inc.",
    "33446": "CP--TOR - Critical Path Inc.",
    "33447": "RPTCO-N-1 - RPT Consulting, Inc.",
    "33448": "OITNET-1 - Optimize I.T. Corp.",
    "33449": "ZINIO-PRD-01 - Zinio Systems, Inc",
    "33450": "EARTHMATRIX-N-01 - EARTHmatrix, LLC",
    "33451": "METACAPITAL-NYC - METACAPITAL MANAGEMENT, L.P.",
    "33452": "RW - Ridge Wireless",
    "33453": "FLUENTTRADE - Fluent API Development Inc",
    "33454": "HOLMESCORP- - HOLMES CORPORATION",
    "33455": "NORTHWESTERN-COLLEGE-STPAUL-MN - Northwestern College",
    "33456": "SITERRA-CORP1 - Siterra",
    "33457": "-VIRGIN-AMERICA - Virgin America",
    "33458": "PROLOGIS - ProLogis",
    "33459": "EVAULT- - EVAULT INCORPORATED",
    "33460": "WAUBONSEE-COMMUNITY-COLLEGE - Waubonsee Community College",
    "33461": "COMMUNITY-FOUNDATION-OF-NORTHWEST-INDIANA - COMMUNITY FOUNDATION OF NW INDIANA",
    "33462": "AER-LEXINGTON-MA - AER",
    "33463": "CITIGROUP-GLOBAL-ANYCT-DNS - Citigroup",
    "33464": "CITIGROUP-BACKBONE - Citigroup",
    "33465": "TSP-NET - Sensormatic Electronics Corporation",
    "33467": "SJRMC-NJ - St. Joseph's Medical Center",
    "33468": "EOJ1 - Locknet",
    "33469": "EDMUNDS-N - EDMUNDS.COM",
    "33470": "CANBYTELEPHONESOCIATION - Canby Telephone Association",
    "33471": "ARI-CUSTOMERS - Automotive Rentals, Inc.",
    "33472": "LATISYS-HBURN - Latisys-Ashburn, LLC",
    "33473": "MMC - Metalmark Capital LLC",
    "33474": "MSINET - Microset Systems, Inc.",
    "33475": "RSN-1 - RockSolid Network, Inc.",
    "33476": "TRADEWARE - TRADEWARE",
    "33477": "RTVI-1 - Overseas Media",
    "33478": "TECHOPS-N-2 - Live Nation Entertainment, Inc.",
    "33479": "CEENTA - Charlotte Eye, Ear, Nose and Throat Associates, P.A.",
    "33480": "WEBWERKS1 - Web Werks",
    "33481": "BELWAVE-COMMUNICATIONS - BELWAVE COMMUNICATIONS",
    "33482": "N-CARDTRONICS - CARDTRONICS USA INC",
    "33483": "INTERCARRIER-NETWORKS - InterCarrier Networks LLC",
    "33484": "BHS---SAN-ANTONIO-TX - Baptist Health System",
    "33485": "LCCC - Lehigh Carbon Community College",
    "33486": "ALKERMES - ALKERMES INCORPORATED",
    "33487": "WDNET-WHITEDELIVERY - WhiteDelivery",
    "33488": "WATECH-1 - Providence Park Medical Building Group, LLC",
    "33489": "COMCT-33489 - Comcast Cable Communications, Inc.",
    "33490": "COMCT-33490 - Comcast Cable Communications, Inc.",
    "33491": "COMCT-33491 - Comcast Cable Communications, Inc.",
    "33492": "CHOPPER-TRADING - Chopper Trading LLC",
    "33493": "HUDSON-VALLEY-FEDERAL-CREDIT-UNION - Hudson Valley Federal Credit Union",
    "33494": "IHNET - IHNetworks, LLC",
    "33495": "CCH-RW- - CCH Inc.",
    "33496": "ISC - ISC CONSTRUCTORS, LLC",
    "33497": "SEMO-COM - Semo Communications Inc",
    "33499": "LHP-NET - LHP Hospital Group Inc.",
    "33500": "WIS-INC - WAITEX INFORMATION SYSTEMS, INC.",
    "33501": "MTDIGITAL - Montana Digital, LLC.",
    "33502": "VRCT-AUR - SunGard VeriCenter Inc",
    "33503": "MCW-1- - Medical College of Wisconsin",
    "33504": "FNBP-2-HERM - FIRST NATIONAL BANK OF PA",
    "33505": "SIMPLEXINVESTMENTS - Simplex Investments, LLC",
    "33506": "CPINETWORKS- - COMMPUTERCATIONS",
    "33507": "DAXLLC - Sample Digital Holdings LLC",
    "33508": "SLN--CORE - Solstas Lab Partners, LLC",
    "33509": "CCADE-ACCESS-LLC-CA-ESTOR1 - Cascade Access, LLC",
    "33510": "-CSFLKAM14464 - C.S. du Fleuve-et-des-Lacs",
    "33511": "TEAMPRAXIS - TeamPraxis, LLC",
    "33512": "STORMWATER-MANAGEMENT - Stormwater Management, Inc.",
    "33513": "CANUSA-AUTOMOTIVE-WAREHOUSING - Canusa Automotive Warehousing Inc.",
    "33514": "EXCS - Executive Corporate, Inc.",
    "33515": "MONROE-GA - City of Monroe",
    "33516": "OMG-NA-636 - The Ogilvy Group, Inc.",
    "33517": "DYNDNS - Dynamic Network Services, Inc.",
    "33518": "INGENIX - Ingenix, Inc.",
    "33519": "BCU-PRIVATEN01 - Baxter Credit Union",
    "33520": "HUDSON-PRINTING - Hudson Printing Company",
    "33521": "MSLA-SCHOOLS - Missoula County Public Schools",
    "33522": "CPANEL-INC - cPanel, Inc.",
    "33523": "ROWANUNIVERSITY - Rowan University",
    "33524": "BT-ROC1-1 - BlueTie, Inc.",
    "33526": "IHSYSTEMS - IH Systems Inc.",
    "33527": "EWCREATIVE-1 - ETWEST CREATIVE",
    "33528": "MBSDEV- - MBS Dev Inc.",
    "33529": "PEAK-WEB-HOSTING - Peak Web Hosting Inc.",
    "33530": "HUBANK - Highlands Union Bank",
    "33531": "THE-NEWS-PRESS - News Press Publishing",
    "33532": "ZOOVY-DS3 - Zoovy, Inc.",
    "33533": "FAIRPLEX-INTERNET - Fairplex",
    "33534": "OTICONUS-COM - OTICON, INC.",
    "33535": "NYDN-33 - New York Daily News, L.P.",
    "33536": "COLOC8-INC--CO--PAGEBLOCKER-INC - COLOC8 INC.",
    "33537": "N-WF - WRIGHT & FILIPPIS",
    "33538": "VFGA-N - Vernon F. Glaser and Associates Inc.",
    "33540": "ALZHEI-N - Alzheimers Assoc.",
    "33541": "CCROUTE - ccROUTE Inc.",
    "33542": "COMCT-TELECOMM-3 - Comcast Telecommunications, Inc.",
    "33543": "NOBEL-NY - Nobel, Inc.",
    "33544": "WILINE - WiLine Networks Inc.",
    "33545": "BARDCOLLEGE - Bard College",
    "33546": "CITY-OF-CHICAGO---OEMC-TO-VZW - City of Chicago - Office of Emergency Management and Communications",
    "33547": "PSFCU-US01 - Polish & Slavic FCU",
    "33548": "UNWIRED-NOC - Unwired Broadband, Inc.",
    "33549": "BLACKBRIDGE - 1505694 Alberta Ltd.",
    "33550": "PJSC-N - Peter J. Solomon Company, L.P.",
    "33551": "SISTERS-OF-MERCY-HEALTH-SYSTEM - Sisters of Mercy Health System",
    "33552": "FLUIDHOSTING - Fluid Hosting LLC",
    "33553": "SOUNDTRANSIT - SOUND TRANSIT",
    "33554": "N-NEUTRAL-DATA - Neutral Data Centers Corp.",
    "33555": "STONEMARCHE - Stonemarche Network CoOp.",
    "33556": "HOME-TELEPHONE-N - Home Telephone Co.",
    "33557": "CLARION-CCA-128 - Clarion Corporation of America",
    "33558": "NRGNETWORKS - NRG NETWORKS",
    "33560": "LINCOLNINVESTMENTPLANNING - Lincoln Investment Planning, Inc.",
    "33561": "GREENHOUSE-WY - Green House Data, Inc.",
    "33562": "SURANT-MIA01INET - Assurant, Inc.",
    "33563": "THEMETHODISTHOSPITAL-HOUSTON - The Methodist Hospital",
    "33564": "CONRESPS - Continental Resources",
    "33565": "-HCLP - HomeField Capital, LP",
    "33566": "KNOXVILLE-UTILITIES-BOARD - Knoxville Utilies Board",
    "33567": "TELECOM-LESOTHO",
    "33568": "SLABLE - Slable",
    "33569": "ALLHOSTSHOP - ALLHOSTSHOP.COM",
    "33570": "AMNET-VOICE-AND-DATA-SYSTEMS - Amnet Systems, Inc.",
    "33571": "TEC-ELCAMINO-BGP - Vistage Worldwide, Inc.",
    "33572": "ELECTRONIC-ARTS-LOS-ANGELES - Electronic Arts, Inc.",
    "33573": "BAQMD-SF - Bay Area Air Quality Management District",
    "33574": "G4SMDC - G4S Monitoring and Data Services, Inc.",
    "33575": "TFINET-PUBLIC - The Franklin Institute Science Museum",
    "33576": "DIGICEL N-Digicel",
    "33577": "RFA- - Radio Free Asia",
    "33578": "ALTER-TRADING - ALTER TRADING COMPANY",
    "33579": "IMPERIAL-ONLINE",
    "33580": "COLMAC - Columbia Machine, Inc.",
    "33581": "PEOPLESBANK-NA - Peoples Bank, National Association",
    "33582": "BRANT-POINT - Brant Point Capital Management LLC",
    "33583": "IBC-FGIS - Isabella Bank Corporation",
    "33584": "NDAQ-OMX-FTENNY-33584 - THE NDAQ OMX GROUP, INC.",
    "33585": "CITYOFNEWPORTBEACH - City of Newport Beach",
    "33586": "RLPOLK-US - R. L. Polk & Company",
    "33587": "BRECKINRIDGE- - Breckinridge Capital Advisors",
    "33588": "BRESNAN- - Bresnan Communications, LLC.",
    "33589": "YS-ENGINEERING-LLC - YS Engineering, LLC",
    "33590": "LIONR-PR - LION RESOURCES, INC.",
    "33591": "MERITAIN- - Meritain Health, Inc.",
    "33593": "HARRIS-BANK - Harris Trust & Savings Bank",
    "33594": "GOVERNMENT-OF-THE-NORTHWEST-TERRITORIES - Government of the Northwest Territories",
    "33595": "STHS-TNN - Saint Thomas Health Services",
    "33596": "BRUNSWICKCORPORATION - Brunswick Corporation",
    "33597": "INFORELAY - InfoRelay Online Systems, Inc.",
    "33599": "RELIABLE-REPORTS-OF-TEX-INC - Reliable Reports of Texas, Inc.",
    "33600": "TNTECH - Tennessee Technological University",
    "33601": "ALACARE - Alacare Home Health & Hospice",
    "33602": "TELUQ - Tele-Universite",
    "33603": "DOMINOS-WRC-BLK01 - DOMINOS PIZZA, LLC",
    "33604": "BTNETWORK - Burlington Telecom",
    "33605": "BRO-ALP-INTER-PORT - Broder Bros",
    "33606": "TEKLINKS - TekLinks, Inc.",
    "33607": "WSC-PHILADELPHIA-PA - Weidenhammer",
    "33608": "HOOD-COLLEGE - Hood College",
    "33609": "W3DATA - Whitepages, Inc.",
    "33610": "THEPALMETTOBANK - PALMETTO BANK",
    "33611": "ELEPHANTENTERPRISES - SBJ MEDIA LLC",
    "33612": "TUMBLR - TUMBLR, INC.",
    "33613": "IAN-CENTURY - Asian Century Quest Capital, LLC",
    "33614": "SANNET - San Diego Data Processing Corp.",
    "33618": "SERVLET-LLC- - Servlet Internet Services Company LLC",
    "33619": "AMD-MARKHAM - Advanced Micro Devices, Inc.",
    "33620": "ALTRINSIC - Altrinsic Global Advisors, LLC",
    "33621": "ALLTEL-IT-N - Alltel Wireless",
    "33622": "DATAFRAMELO - Dataframe Logistics, Inc.",
    "33623": "ALHNVL-HAYNEVILLE-TELEPHONE - Hayneville Telephone Company",
    "33624": "DHHS-OIG - U.S. Dept. of Health & Human Services - Office of Inspector General",
    "33626": "OVERSEE-DOT-NET - Oversee.net",
    "33627": "VISTEON - VISTEON CORPORATION",
    "33629": "NKU-1 - Northern Kentucky University",
    "33630": "WCSR - WOMBLE CARLYLE SANDRIDGE & RICE, LLP",
    "33631": "PARC-N - Palo Alto Research Center Incorporated",
    "33632": "MSU-EAGLE - Morehead State University",
    "33633": "USG-CORPORATION - USG Corporation, Inc.",
    "33634": "INTER-380 - Internet Services Inc",
    "33636": "WOFFORD-COLLEGE - Wofford College",
    "33637": "N1 - Inside.Com Inc.",
    "33638": "SCOTTS- - CITY OF SCOTTSBURG",
    "33639": "CENTEX - Centex Service Company",
    "33640": "EXACTECH - Exactech Incorporated",
    "33641": "HEALTHLOGIC-SYSTEMS-CORPORATION - Healthlogic Systems Corporation",
    "33642": "NLETS - Nlets",
    "33643": "JELLYBELLY - Jelly Belly Candy Company",
    "33644": "OSUFCUN - OSU FEDERAL CREDIT UNION",
    "33645": "ODYSSEYRE - ODYSSEY RE HOLDINGS CORP",
    "33646": "SFH- - Sasser Family Holdings, Inc.",
    "33647": "YADTELNET - Yadkin Valley Telephone",
    "33648": "ELEPHANT - ColoFlorida / Elephant Outlook",
    "33650": "COMCT-33650 - Comcast Cable Communications, Inc.",
    "33651": "CMCS - Comcast Cable Communications, Inc.",
    "33652": "CMCS - Comcast Cable Communications, Inc.",
    "33653": "CMCS - Comcast Cable Communications, Inc.",
    "33654": "CMCS - Comcast Cable Communications, Inc.",
    "33655": "CMCS - Comcast Cable Communications, Inc.",
    "33656": "CMCS - Comcast Cable Communications, Inc.",
    "33657": "CMCS - Comcast Cable Communications, Inc.",
    "33658": "CMCS - Comcast Cable Communications, Inc.",
    "33659": "CMCS - Comcast Cable Communications, Inc.",
    "33660": "CMCS - Comcast Cable Communications, Inc.",
    "33661": "CMCS - Comcast Cable Communications, Inc.",
    "33662": "CMCS - Comcast Cable Communications, Inc.",
    "33663": "CMCS - Comcast Cable Communications, Inc.",
    "33664": "CMCS - Comcast Cable Communications, Inc.",
    "33665": "CMCS - Comcast Cable Communications, Inc.",
    "33666": "CMCS - Comcast Cable Communications, Inc.",
    "33667": "CMCS - Comcast Cable Communications, Inc.",
    "33668": "CMCS - Comcast Cable Communications, Inc.",
    "33669": "MEHARRY-I2 - Meharry Medical College",
    "33670": "NOVOUTHETERN - Nova University",
    "33671": "USBID-N - USBid, Inc.",
    "33672": "SMITHFIELD-INTERNET - SMITHFIELD FOODS",
    "33673": "NE-1 - MCN Online, LLC",
    "33674": "COGNEX-HQ - Cognex Corporation",
    "33675": "SURESCRIPTS - SURESCRIPTS, LLC",
    "33676": "TELX-MIAMI - Telx",
    "33677": "SIROTA-CONSULTING-LLC - Sirota Consulting",
    "33678": "NETWORTH-SERVICES - NetWorth Services, Inc",
    "33679": "-HFMA - Healthcare Financial Management Association",
    "33680": "TELEPERFORMANCE-USA - TELEPERFORMANCE USA",
    "33681": "COMPTRK - Competitrack Inc.",
    "33682": "WEBERHS - Weber Human Services Foundation",
    "33683": "UIWTX - University of the Incarnate Word",
    "33684": "MILBANK - MILBANK TWEED HADLEY MCCLOY",
    "33685": "THE-MADISON-HOTEL - The Madison Hotel",
    "33686": "SUNDOT-2005 - SUN DOT COMMUNICATIONS, LLC.",
    "33687": "HPES - Hewlett-Packard Company",
    "33688": "SUMMITEIS- - SummitEIS",
    "33689": "TILA - Astila Corporation",
    "33690": "ALLIANCE-N - ALLIANCE TECHNOLOGIES, INC.",
    "33691": "APPTIS-HQ-N1 - Apptis, Inc.",
    "33692": "MACALE - Macalester College",
    "33693": "REDANVIL - Red Anvil LLC.",
    "33694": "247REALMEDIA-HBURN - 24/7 Real Media, Inc.",
    "33695": "SCALEMATRIX - ScaleMatrix",
    "33696": "CREA- - Coventry Real Estate Advisors",
    "33697": "THEBOE-33697 - The Boeing Company",
    "33698": "SECURE-24-DCA - Secure-24, Inc.",
    "33699": "RUSSELL-MARKETING-RESEARCH - Russell Marketing Research, Inc.",
    "33700": "SMARTCITY-CINCINNATI - Smart City Networks, L.P.",
    "33701": "NEXUS-SYSTEMS - SEND TECHNOLOGIES, L.L.C.",
    "33702": "ENTERHOST - Enterhost",
    "33703": "HOFSTRA-UNIVERSITY - Hofstra University",
    "33704": "IFN-NET - Indiana Fiber Network, LLC",
    "33705": "DIGITAL-SHAPE-TECHNOLOGIES - Digital Shape Technologies Inc.",
    "33706": "GCS - Global Communications Services Inc.",
    "33707": "DGICBGP - Dreyer's Grand Ice Cream",
    "33708": "N1 - Independent Media Group",
    "33709": "WR-1 - WIREDRED CORPORATION",
    "33710": "CNLR-N - National Retail Properties, Inc.",
    "33711": "NEXTWAVE-NV2 - Nextwave Telecom Inc.",
    "33712": "NEXTWAVE-NV1 - Nextwave Telecom Inc.",
    "33713": "TPS - THE PARADIES SHOPS, INC",
    "33714": "HBCS-NC-1 - Hospital Billing and Collection Services",
    "33715": "ENFORME - Enforme Interactive, INC.",
    "33716": "UP-TIME-TECHNOLOGY-ISP-1 - Up Time Technology, Inc.",
    "33717": "CHT-GLOBAL - Chunghwa Telecom Global, INC",
    "33718": "APXINC-SJC - APX, Inc.",
    "33719": "SPE-IST - Sony Pictures Entertainment, Inc.",
    "33720": "LHTC - LAUREL HIGHLAND TELEPHONE COMPANY",
    "33721": "CCL-N2 - CARNIVAL CRUISE LINES",
    "33722": "CCCR- - Cache Creek Casino Resort",
    "33724": "BIZNESSHOSTING - VOLICO",
    "33725": "SITCO---OHARA-DC - SIT-CO, LLC",
    "33726": "GENEVACOLLEGE- - GENEVA COLLEGE",
    "33727": "HARBOR-FOOTWEAR-GROUP-LTD - Harbor Footwear Group Ltd",
    "33728": "UNITELINC - Unitel Inc",
    "33732": "EOR - Electronic On-Ramp, Inc",
    "33733": "MILLER-DAVIS-STUDIOS - MILLER DAVIS STUDIOS INC",
    "33734": "MPW-MACHLINK-NET - Muscatine Power and Water",
    "33736": "PILLARHOTELS-N - Pillar Hotels & Resorts, L.P.",
    "33737": "WEBROOT-N1 - Webroot Software, Inc.",
    "33738": "UNITED-STATES-HOLOCAUST-MEMORIAL-MUSEUM - United States Holocaust Memorial Museum",
    "33739": "MYSPACE - Myspace, Inc.",
    "33740": "TMGHEALTH-FTW - TMG Health, Inc",
    "33741": "AGANET - AGA Medical Corporation",
    "33742": "TELX-SFO - Telx",
    "33743": "HVW-ALB1 - Hudson Valley Wireless",
    "33744": "ANEW-TELECOM-DBA-CALL-AMERICA - CALL AMERICA INC",
    "33745": "GLSDC1 SIS  for North America GLSDC1",
    "33746": "TTEK- - TETRA TECH, INC.",
    "33747": "BGP-1 - Texas Industries, Inc.",
    "33748": "DSCI - DSCI Corporation",
    "33749": "ATMC - Atlantic Telephone Membership Corp.",
    "33750": "FTSIGNS-INTL - FTSIGNS International, Inc.",
    "33751": "BRH - Bartlett Regional Hospital",
    "33752": "MENTORGRAPHICS-ALM - Mentor Graphics Corporation",
    "33753": "WBMI - West Bend Mutual Insurance Company",
    "33754": "INDIANA-NEWSPAPERS-INC - Indiana Newspapers, Inc.",
    "33755": "OWI - Overland West Inc",
    "33756": "GETACTIVE-DC - GetActive Software, INC.",
    "33757": "GETACTIVE-BERKELEY - GetActive Software, INC.",
    "33758": "GOTRICOUNTY - TriCounty Communications, Inc.",
    "33759": "REGENERON - Regeneron Pharmaceuticals Inc.",
    "33760": "CLARIUM - Clarium Capital Management",
    "33761": "VDC-SCC - Vantage Data Centers",
    "33762": "WBS",
    "33763": "INCREDIBLE-TECHNOLOGY-HOLDINGS",
    "33764": "AFRINIC-ZA-JNB-",
    "33765": "TTCLDATA",
    "33766": "CYBERSMART-20071029",
    "33767": "TELECOM-LESOTHO",
    "33768": "TRANSNET",
    "33769": "IMANAFOODS",
    "33770": "KDN",
    "33771": "SAFARICOM-LIMITED",
    "33772": "BOL-CO-TZ-",
    "33773": "nic-mw-as1",
    "33774": "DJAWEB",
    "33775": "NITEL- Nigerian Telecommunication Limited",
    "33776": "STARCOMMS-N",
    "33777": "EGYPT-NETWORK",
    "33778": "Mantrac-Group-",
    "33779": "wataniya-telecom-as",
    "33780": "IGH-Accra",
    "33781": "OPQ",
    "33782": "BA-",
    "33784": "SYR-",
    "33785": "CITYNET",
    "33786": "KNet",
    "33788": "KANARTEL",
    "33789": "Internet2",
    "33790": "MEXCOM-",
    "33791": "TIX-N",
    "33792": "ESPACE Tamedia AG",
    "33793": "B4NET- UAB Acta iuventus",
    "33794": "MEGAROUTE- Mega Route - Kartoff Network",
    "33796": "BNAA- BoligNet-Aarhus",
    "33797": "TACSONIA-SERVICES UAB \"TACSONIA\"",
    "33798": "MEGACOM- Megacom ISP Autonomous System",
    "33799": "INTERNETNU- InternetNu BV",
    "33800": "TAB- TAB Austria Holding GmbH",
    "33801": "INTLSET-UK International Asset Management UK N",
    "33802": "SAFECHARGE- Safecharge ltd.",
    "33803": "AHINC- Adroit Holdings Inc.",
    "33805": "LIZARD- Rekah Corp Hosting",
    "33806": "COMARCH-DE- Comarch AG",
    "33807": "INTERSYS- Intersys Services sp. z o.o.",
    "33808": "ITENOS I.T.E.N.O.S. GmbH",
    "33809": "IKU- Istanbul Kultur University",
    "33810": "NIS- Mondi IT Services Barleben GmbH",
    "33811": "PIXELPARK- Pixelpark AG",
    "33812": "KELDYSH- M.V.Keldysh Institute for Applied Mathematics of Russian Science Academy",
    "33813": "COFIDIS-PT- COFIDIS",
    "33814": "TOGNUM- Tognum AG",
    "33816": "FFTW- FISCHER FRANCIS TREES & WATTS",
    "33817": "TELEGROUPUA- Subsidiary Enterprise Telegroup-Ukraine",
    "33819": "VVSU- Vladivostok State University of Economics",
    "33820": "REED-ELSEVIER- Reed Elsevier Group Plc",
    "33821": "BVB-N Bursa de Valori Bucuresti SA",
    "33822": "WEBDEAL-NORGE- Webdeal",
    "33823": "GEMENII PHOENIX TELECOM & MEDIA SERVICES SRL",
    "33824": "CONSOL- ConSol Consulting & Solutions Software GmbH",
    "33825": "BOR- Interimpex Ltd.",
    "33826": "ORBIS- Orbis S.A.",
    "33827": "EUROM-BANK Bank Leumi Romania SA",
    "33828": "IPTOX- iptoX GmbH",
    "33829": "RADCOM RADCOM SRL",
    "33830": "BKM- Bankalararasi Kart Merkezi",
    "33831": "RHC- Royal Hashemite Court",
    "33832": "DIGICOM-UA DigiCom Multiprotocol Network",
    "33833": "N-IMAGINIT IMAGIN IT Marcin Engelmann",
    "33834": "MINISAT SC MINISAT S.R.L.",
    "33835": "INFOSAT- INFOSAT TELECOM S.A.",
    "33837": "PRQ- PeRiQuito AB",
    "33838": "BETANET- BetaNET sp. z o.o.",
    "33839": "ALTAIR-NET- ALTAIR NET SRL",
    "33840": "STARTEL- JSC Startelecom-North",
    "33841": "FUNWOLD- S&T AG",
    "33842": "CROSSTEL- Cross Tel Ltd",
    "33843": "INTERSCHOLZ- interscholz Internet Services GmbH & Co. KG",
    "33844": "TDCRU- \"ZAO \"Investment Company \"Troika Dialog\"",
    "33845": "SWISSGOV Swiss Federation represented by FOITT",
    "33846": "DATAPORT- DATAPORT - Anstalt des oeffentlichen Rechts",
    "33847": "PI The Petroleum Institute",
    "33848": "PORSCHE- Dr. Ing. h.c. F. Porsche AG",
    "33849": "COMFONE- COMFONE AG",
    "33850": "UNIORSI- UNIOR Kovaska industrija d.d., Zrece",
    "33851": "EECS- East-European Communication Services Ltd.",
    "33852": "ORG-CCJS1-RIPE Cornet-AM Closed Joint Stock Company",
    "33853": "PROCREDITBANK-BG Procredit Bank Ltd",
    "33854": "HOSTIT--NN Nuco Technologies Ltd",
    "33855": "EMEDIA- Evolution Media Ltd",
    "33857": "N-METABOLI Metaboli SA",
    "33859": "TPP-HOSTING-NET The Portal Partnership Ltd.",
    "33860": "ICAP-UK ICAP Management Services Limited",
    "33861": "GAMBIT--NET Gambit Consulting GmbH",
    "33862": "VOCALNET-N SC VOCALNET SRL",
    "33863": "TER-ZG-POLAND- Aster Spolka z o.o.",
    "33864": "WDC- Wallonie Data Center Network",
    "33866": "ELAN Elan Ltd.",
    "33867": "AIRBALTIC AIR BALTIC CORPORATION",
    "33868": "PERFEKT-NET-POLAND- INEA S.A.",
    "33869": "TOSA-POLAND- INEA S.A.",
    "33870": "LOGILUNE Logilune SARL",
    "33871": "NORILSK-TELECOM- Norilsk-Telecom CJSC",
    "33872": "AMS- Alpha Medien Service GmbH",
    "33873": "ARVATO-SYSTEMS- arvato Systems GmbH",
    "33874": "VFM- Vodafone Malta International Gateway",
    "33875": "GOODNET GOODNET SRL",
    "33876": "DOMINIOS- Flesk Lda",
    "33877": "CUSIGORTA- Commercial Union Sigorta A.S",
    "33878": "ATFBANK- JSC ATFBank (UniCredit Group)",
    "33879": "FORTHS-PORTS-PLC Forth Ports Public Limited Company",
    "33881": "UZSCIENCE-NET Non-commercial science network of the Republic of Uzbekistan",
    "33882": "LONO- Notka IT-Service GmbH",
    "33883": "TRIONET-CZ- TRIOPTIMUM s.r.o.",
    "33885": "OWNIT Ownit Broadband AB",
    "33886": "STOCKHOLMIX- Stockholm Internet eXchange AB",
    "33887": "TELESET-NCHELNY OJSC Rostelecom",
    "33888": "NCPLG- Federal State Unitary Enterprise \"State",
    "33890": "PXPAT- wunderman pxp GmbH",
    "33891": "CORE-BACKBONE Core-Backbone GmbH",
    "33892": "SELS- The municipal enterprise \"Severskelektrosviaz\"",
    "33894": "RIKT- JSC \"RITC\"",
    "33895": "PL-TSYSTEMSPL T-SYSTEMS Sp. z o.o.",
    "33896": "SCHIEDEL- Schiedel GmbH & Co.",
    "33898": "TMOBILE- T-Mobile (UK) Limited",
    "33899": "CONTTEL JSC \"Contact Telecomm\"",
    "33900": "TPSA-MPLSNET- Telekomunikacja Polska S.A.",
    "33901": "CONNECTA- Connecta sp. z o.o.",
    "33902": "STARNET- ORG - Closed Joint Stock Company \"Star Networks\" (ORG-CJSC5-RIPE)",
    "33903": "CROC- Closed Joint Stock Company CROC incorporated",
    "33904": "INTELNET- Intelcom LLC, Moscow, Russia",
    "33905": "AKAMAI-AMS Akamai International B.V.",
    "33906": "EUROANSWER-RO- S.C. EuroAnswer S.R.L.",
    "33907": "ORNUS Ornus AB",
    "33908": "KIROVTELECOM ZAO Kirovtelecom",
    "33909": "RIALNET RIALNET Ltd.",
    "33910": "TRAMER- IGORTA BILGI MERKEZI",
    "33911": "BP BP OFFICE & SERVICE SRL",
    "33913": "RIATEK- RIATEK, JSC",
    "33914": "COMPS Compass Electro-Optical Systems Ltd",
    "33915": "TNF- Vodafone Libertel B.V.",
    "33916": "COMFLEX Comflex Networks ApS",
    "33917": "SPOE- Sozialdemokratische Partei Oesterreichs",
    "33918": "PRIMORSKE-NOVICE- Primorske Novice d.o.o. Koper, s.r.l. Capodistria",
    "33919": "DNET-CZ- D-NET,a.s.",
    "33920": "AQL (aq) Networks Limited",
    "33921": "LEBARA- Lebara limited",
    "33922": "NTT-LT- UAB Nacionalinis Telekomunikaciju Tinklas",
    "33923": "ART-COM ART-COM Sp. z o.o.",
    "33924": "PRONET-AL- Pronet sh.p.k.",
    "33925": "GLOBALIS- Global Internet Solutions SRL",
    "33926": "KAIAGLOBAL- Kaia Global Networks Ltd.",
    "33927": "SPECAVTOMATIKA- SpecAvtomatika LTD",
    "33929": "MICOM- Telemach d.o.o.",
    "33930": "INTRINSEC- INTRINSEC, France",
    "33932": "MINORISA- Minorisa de Sistemas Informaticos i de Gestion",
    "33933": "M2SOFT- M2Soft GmbH",
    "33934": "VOLGOGRADEC- OJSC Rostelecom",
    "33935": "FI-24ONLINE- 24 Online Oy",
    "33936": "SCAT7-  for Teleradio company SCAT-7",
    "33937": "SENORG-HU- SF Hungary Kft.",
    "33938": "DIGITALSAFE- ICT Concept BV",
    "33939": "GREENERY- The Greenery BV",
    "33940": "WICHMANN- Wichmann Internet Services GmbH",
    "33941": "GCONNECT Challenger Technology Ltd",
    "33942": "AGACTEL- AGACTEL S.p.a.",
    "33943": "CBEZDRAT- Cesky Bezdrat, s.r.o.",
    "33944": "FOKUS-SATCOM Fraunhofer FOKUS CC SatCom",
    "33945": "GDF- Gaz de France",
    "33946": "OTPBANK- OTP BANK ROMANIA SA",
    "33947": "WLA-NET-HU- WLA Interservices Ltd.",
    "33948": "REXNET- SC REXNET SRL",
    "33949": "DIGIDOC- DigiDoc B.V.",
    "33950": "LANXESS Lanxess AG",
    "33951": "FORWEB FORWEB",
    "33952": "MWISE- M-wise Ltd",
    "33953": "EXPERIAN- Experian International Ltd",
    "33954": "AHBRT- Allianz Hungaria Biztosito Zrt.",
    "33955": "PORTAVITA Portavita BV",
    "33956": "VOLLMAR2- vollmar.net GmbH",
    "33957": "KDS- Limited Liability Company \"KDS\"",
    "33958": "GSCF Global Supply Chain Finance AG",
    "33959": "METRO-HU- Metro C&C",
    "33960": "YAFINANS- Asya Katilim Bankasi A.S.",
    "33961": "TELCOR- TELCOR COMMUNICATIONS SRL",
    "33962": "EUROCOM- Eurocom CJSC",
    "33964": "SOGEI-N Sogei Societa' Generale d' Informatica S.p.A.",
    "33965": "LITECOM 33965 is operated by:",
    "33966": "INGENIUM- SC Ingenium NET SRL",
    "33967": "GB-LANCSCC Lancashire County Council",
    "33968": "INTERNETENGINEERING Internet Engineering Limited Main",
    "33969": "CTCTVER OJSC \"RT Labs\"",
    "33970": "OPENHOSTING M247 Ltd",
    "33971": "BANCPOST- Bancpost S.A",
    "33972": "INFORMCENTER- InformCenter autonomous system",
    "33973": "EPAM- Epam Systems FLLC",
    "33974": "ALIANCE \"Aliance Plus\" Ltd.",
    "33976": "AFTONBLADET-SE aftonbladet.se",
    "33977": "BALEANU-SERV- Baleanu Servcom S.R.L.",
    "33978": "YAPIC- Collective Production Enterprise Yapic.Net",
    "33980": "PAF Frobbit Ab",
    "33981": "TSYS- Total System Services Processing Europe Limited",
    "33982": "KARUPA- Karupa s.p.a.",
    "33983": "ARTMOTION- National IP network of ARTMOTION.Net",
    "33984": "SURFPLANET- Surfplanet GmbH",
    "33985": "NEUSIEDLER- Neusiedler Ybbstal AG",
    "33986": "REDDER- Redder Telco srl",
    "33987": "NETWAY- Netway ltd",
    "33988": "TEAMIX Teamix GmbH",
    "33989": "STTK-ABAK- SibTransTelecom  (Abakan City)",
    "33990": "PROKOM- Asseco Poland SA",
    "33991": "SKALA- Company Skala, Ltd",
    "33992": "MSRESPONSE- Mass Response Service GmbH",
    "33993": "ELSITE- Elsite network",
    "33994": "VONAGE Vonage Holdings Inc",
    "33995": "SKYLINK SkyLink Data Center GmbH",
    "33996": "PEKAOLIF- Pekao Leasing Sp z o.o.",
    "33997": "DARLICS- Tidikom ltd.",
    "33998": "REPOWER- Repower AG",
    "33999": "VALIDIO- MIIK Ltd.",
    "34000": "FR-RR-CG13 Conseil General des Bouches-du-Rhone",
    "34001": "LIV-NET- LIV NET",
    "34002": "INTERXION-FR-TRANSIT- Interxion France S.A.",
    "34004": "IE-THOMSON-N Thomson Corporation",
    "34005": "COSMO-BG Cosmo.Net Ltd., Sofia, Bulgaria, Internet Service Provider",
    "34006": "VEEPEE-N Veepee S",
    "34007": "PROQUOTE Proquote Ltd",
    "34009": "BIFAB- Franz Cornelsen Corporate Services GmbH",
    "34010": "YAHOO-IRD Yahoo! Europe",
    "34011": "DOMAINFACTORY domainfactory GmbH",
    "34012": "VELLANCE- Vellance B.V.",
    "34013": "MAZNET- Hotels Online International Ltd",
    "34014": "METEOMEDIA- Meteomedia GmbH",
    "34015": "GEW-RHEINENERGIE- GEW Rheinenergie AG",
    "34016": "UHT-KHARKIV- UHT - Ukrainian High Technologies Ltd.",
    "34017": "CNET- Geology and Nature Management Institute of Far Eastern Branch of Russian Science Academy",
    "34018": "LVBALTICOM-2 JSC BALTICOM",
    "34019": "HIVANE Hivane",
    "34021": "MULTI-VISP-N Multi-vISP Network / SECR",
    "34022": "INGRO- ING BANK NV AMSTERDAM BUCHAREST BRANCH",
    "34023": "CITYLINE- PE Shattah Zia G.Naman",
    "34024": "INFOHIT- Infohit Computer d.o.o.Ljubljana",
    "34025": "PETABIT- Kontilint Data AB",
    "34026": "BUCKSNET Bucks Net Services Ltd",
    "34027": "OFIR OFIR DANMARK A/S",
    "34029": "IBXNORDIC- IBX Group AB",
    "34030": "BORTELECOM- Closed Joint-Stock Company \"Management Company \"Business Technologies and Communications\"",
    "34031": "JD- Jesta Digital GmbH",
    "34033": "S2116- OOO SALON 2116 Electronic Post Office",
    "34034": "ARCTEL- LLC \"Nasha Set\"",
    "34035": "IP-TEL- IP-TEL CJSC",
    "34037": "VARD-LT- VARD.LT, UAB",
    "34038": "COMTEL-TMN- OJSC \"Vimpelcom\"",
    "34040": "CZTTNET- TTNET Czech Republic",
    "34041": "BMA-ORG-UK The British Medical Association",
    "34042": "MTTELECOM- \"MT-Telecom\" LLC",
    "34043": "RISS Internet Security Systems SRL",
    "34044": "PRIMSERVIS- Prim-Servis Ltd.",
    "34045": "MCXSYSTEMS- MCX Serwis Sp.z o.o sp.k.",
    "34046": "SHIELD- ShieldTelecom, Ltd.",
    "34047": "DGROUP- Bystrov Dmitriy Sergeevich",
    "34049": "HDATA- H-data, spol. s r.o.",
    "34051": "AMADEUS-TN- Amadeus Data Processing GmbH",
    "34052": "LOGIKA- OOO NPP LOGIKA",
    "34056": "KIEVNET Kiev Optic Networks Ltd.",
    "34057": "LGNET- S.C. LG Network S.R.L.",
    "34058": "TELIT Limited Liability Company \"Astelit\"",
    "34059": "SPAR-HU- SPAR Magyarorszag Kereskedelmi Kft",
    "34060": "TCCFR- SC Telecomunicatii CFR SA",
    "34061": "GEDOMAX- SC Gedomax Pro 2003 SRL",
    "34063": "VNIINM- OAO High-technological Scientific-Research Institute of Inorganic Materials of A.A. Bochvar",
    "34064": "ING-FR- ING DIRECT N.V.",
    "34065": "NORMA-PLUS- TOV Norma-Plus",
    "34066": "TELAPPLIANT- TelAppliant Ltd.",
    "34067": "STCNET Standard Telecomunicatii SRL",
    "34068": "INGOK- Ingulets Ore-Dressing Plant",
    "34069": "RADIOGDANSK- Radio Gdansk SA",
    "34070": "DATIN- DATin internet s.r.o.",
    "34071": "E-WRO-TRANSIT Miejskie Sieci Informatyczne Wroclaw",
    "34072": "QNET- Qnet Srl",
    "34074": "IBS-BG- IBS Bulgaria EOOD",
    "34075": "LEXISNEXIS LexisNexis Polska Sp. z o.o.",
    "34076": "ZETO-NET Zaklad Elektronicznej Techniki Obliczeniowej w Olsztynie spolka z ograniczona odpowiedzialnoscia",
    "34077": "AIKOTECH- Aikotech LTD",
    "34078": "STREAMDOOR- Streamdoor Ltd",
    "34079": "EDUSERV- Eduserv Internet UK",
    "34080": "MIRAMO- Autonomous  of MIRAMO",
    "34081": "INCUBATEC- incubatec GmbH - Srl",
    "34082": "YAHOO-AMA Yahoo! Europe",
    "34083": "ORG-AL161-RIPE Aranea LLC",
    "34085": "NICO-BANK- JSC NICO-BANK",
    "34086": "SCZN- T-Systems International GmbH",
    "34087": "NTE-BREDBAND NTE Bredband, Norway",
    "34088": "BELLAXA- Bellaxa Networks GmbH",
    "34090": "PAYSAFE-AT- paysafecard.com Wertkarten AG",
    "34092": "TVCOM- TVCOM Ltd.",
    "34093": "PLUSLINE- NWT a.s",
    "34094": "AGRICOLE- JSC \"Credit Agricole Bank\"",
    "34095": "KTVPREROV- NejTV a.s.",
    "34096": "ALPHABANKSERBIA- Alpha Bank Srbija a.d.",
    "34097": "KNUST- Knust, Ghana",
    "34098": "ZENIT-BANK- OJSC Bank ZENIT",
    "34099": "ROAD-TECH-COMPUTER-SYSTEMS Road Tech Computer Systems Ltd.",
    "34100": "STORTINGET- Stortinget",
    "34101": "ABN-AMRO- ABN AMRO Bank N.V.",
    "34102": "AWANTI- Awanti Ltd.",
    "34103": "CALLAX Callax Telecom Holding GmbH",
    "34104": "GLOBAL- Global Iletisim Hizmetleri A.S.",
    "34105": "ARIAVESATCOM- Ariave Satcom ltd",
    "34106": "TELEGRAAF- TMG Online Media B.V.",
    "34108": "BREEDBANDDELFT Stichting Breedband Delft",
    "34109": "34109 Tilaa V.O.F.",
    "34110": "NETWORK-IE- Vu2Vu Ireland Limited",
    "34112": "ILCA ILCA Internet (ILCA, JSC)",
    "34114": "ZONA-FRANCA-CADIZ- Consorcio de la Zona Franca de Cadiz",
    "34115": "NAVTEQ- Navteq (DE) GmbH",
    "34117": "OYAKYATIRIM Oyak Yatirim Menkul Degerler A.S.",
    "34118": "PELENG- Peleng Ltd.",
    "34119": "WILDCARD- Wildcard UK Ltd",
    "34120": "VT-N Verslo Tiltas UAB",
    "34121": "RUSAL- Subsidiary company of CJSC 'RUSAL Global Management BV'",
    "34122": "IFAP- IFAP - Instituto Financiamento Agricultura e Pescas",
    "34123": "NETORN- Netorn LLC",
    "34124": "TRUST TRUST International Hotel Reservation Services GmbH",
    "34125": "BECHTLEFN- Bechtle GmbH & Co. KG, IT-Systemhaus FN",
    "34126": "AROBE- Arobase, Cote d'Ivoire",
    "34127": "MUNICH-AIRPORT- Flughafen Muenchen GmbH",
    "34128": "CG- SC Connexion Group SRL",
    "34129": "LEGATEL- Legatel Telecom Srl",
    "34130": "ERB- ERB Retail Services IFN S.A.",
    "34131": "POSTANSKA- Banka Postanska Stedionica A.D.",
    "34132": "DIGITALPARK- DIGITAL PARKS DATA CENTER SERVICES S.L.",
    "34133": "NETIT- NetIT Internet Solutions in Sweden AB",
    "34134": "FREECLIX FreeClix Ltd",
    "34135": "RENESYS Renesys Corporation",
    "34136": "UA-LINIYA- \"Telecom of Ukraine\" Ltd.",
    "34137": "RUAMUR- OJSC Rostelecom",
    "34139": "TSINET- CJSC TSI Service",
    "34140": "NECC- Acer Computer GmbH",
    "34141": "IN2IP- in2ip B.V. i.o.",
    "34142": "MGLINE- FOP Kuskivskiy Igor Volodymyrovich",
    "34143": "IHOME- Freenet Ltd.",
    "34144": "EUSIP-RACK66 EUSIP bvba",
    "34145": "TOMTEL LLC TOMTEL",
    "34146": "ISP-SOLUTIONS- ISP Solutions SA",
    "34147": "PROMEK-BANK- Rusfinance Bank Ltd.",
    "34149": "ALION- Alion Technology",
    "34150": "RADIONETSPB- \"Radionet\" Co. Ltd",
    "34154": "CONFIGO- Configo Systems Gesellschaft fuer Systemloesungen mbH",
    "34155": "EL-LOGISTIK- EL-Logistik",
    "34156": "BAHN--BLN DB Systel GmbH",
    "34157": "FTIRAQNORTH FastIraq, LLC",
    "34158": "BBC-RD-NONUK- British Broadcasting Corporation, R&D Projects, Non-UK",
    "34160": "TRANSTRUM Transtrum BV",
    "34161": "FSD-FFM- Frankfurter Societaets-Druckerei GmbH",
    "34162": "ARK-TR Arkas Holding A.S",
    "34164": "AKAMAI-LON Akamai International B.V.",
    "34165": "LOGIQIT-APS Logiqit.com ApS",
    "34166": "ELECOM- Electronic Communication Systems Ltd",
    "34167": "EUROPOOL- Euro Pool System International B.V.",
    "34168": "ELCOM-ISP- OJSC Rostelecom",
    "34169": "MEDIA-COM-TYCHY Media-Com Sp. z o.o.",
    "34170": "AZTELEKOM Azerbaijan Telecomunication ISP",
    "34171": "INTERDOTNET-LIG- Inter.Net Germany ligado operation",
    "34172": "ELK-BAWUE- Evangelische Landeskirche Wuerttemberg",
    "34173": "MAILCLUB- Mailclub S",
    "34174": "MCNOLIA McNolia.com B.V.",
    "34175": "JARMUS- UAB \"Jarmus\"",
    "34176": "AUTOROM- ITH Management Office SRL",
    "34177": "CELESTE- CELESTE - Internet services provider",
    "34178": "QINETIQ Qinetiq Limited",
    "34179": "EGRAD- Limited company EGRAD",
    "34180": "INKO-NET- ISP INKO-NET LTD",
    "34181": "N-UAC-DE IP-NETWORK",
    "34182": "FUTURELAB futureLAB AG",
    "34183": "BMGAT- Bundesministerium f. Gesundheit",
    "34184": "BT BANCA TRANSILVANIA SA",
    "34185": "ITL-VL- Information Technology Laboratory Ltd",
    "34187": "RENOME- LLC Renome-Service",
    "34188": "OPO- Elisa Oyj",
    "34190": "MICROCOM-UA- Microcom Ltd.",
    "34191": "THALESISNUE-DE- Thales IS Nuernberg",
    "34192": "TRANSITEC ZAO Transitec",
    "34193": "EQUINUX- equinux AG",
    "34194": "NETGLOBE-COMUNICATII Netglobe Comunicatii",
    "34196": "KATOEN-NATIE- S.O.N.J.A. NV",
    "34197": "SHRD- Saint Honore Recherche et Developpement SARL",
    "34198": "ROL Rol Online Network S.A.",
    "34199": "EFL- Europejski Fundusz Leasingowy SA",
    "34200": "DATAINTEGRATION Data Integration Ltd",
    "34201": "PADICOM PADICOM SOLUTIONS SRL",
    "34202": "ALFACOM- Alfa Communications Inc.",
    "34204": "KHUST- FOP Michail Mandryk",
    "34205": "MRBD- OJSC Rostelecom",
    "34207": "IBS-DF IBS Systems Integration Limited",
    "34208": "ZMP-GDANSK- Zarzad Morskiego Portu Gdansk S.A.",
    "34209": "PLIXDC- PLIX Sp. z o.o.",
    "34210": "GLOBAL-CONNECT Global Connect BV",
    "34211": "LANPORT- Lanport-S LLC",
    "34212": "PL-KULCZYKTR- Volkswagen Group Polska Sp. z o.o.",
    "34213": "INFOR-2 Infor (Deutschland) GmbH",
    "34214": "IPMG- TOV \"IP Media Group\"",
    "34215": "ATINET @Inet Technology Consultancy BV",
    "34216": "TRENITALIA SPA",
    "34217": "ALFATEL- Alfatelcom JSC RU",
    "34218": "H3GIE Hutchison 3G IE core network autonomous system",
    "34219": "ARCHE- Arche AG",
    "34220": "NITEL-  for Nigeran Telecommunication Ltd.",
    "34221": "QL- JSC QUICKLINE",
    "34222": "ZONER- ZONER software, a.s",
    "34223": "N-REGION ZAO N-Region",
    "34224": "NETERRA- Neterra Ltd.",
    "34225": "SPEEDPARTNER SpeedPartner GmbH",
    "34226": "RUBICOM-HU- RubiCom Ltd.",
    "34228": "SERVERA- Martin & Servera AB",
    "34229": "VAKUSHAN- Anton Vakushin",
    "34230": "FTEL- FasTel LLC",
    "34231": "DUSTING- SC DUSTING ELECTRONIC SRL",
    "34232": "PULNET Pulnet Ltd",
    "34233": "SUPERIOR- Superior B.V.",
    "34234": "DEPENDIT- Dependit",
    "34235": "PSERVEUR- PSERVEUR",
    "34236": "IDEA-VMI Vaddo Media Information IS AB",
    "34237": "POL- POL SARL",
    "34239": "INTERAMERICAN Interamerican Hellenic Life Insurance Company SA",
    "34240": "MANITU manitu GmbH",
    "34241": "NCT- OOO New Communication Technologies",
    "34243": "WEBAGE Web Age Ltd",
    "34244": "TELESERVICE Teleservice Bredband Skane AB",
    "34245": "MAGNET- Magnet Networks",
    "34246": "RU-FORTUM JSC \"TGC-10\"",
    "34247": "TSI-DDM- T-Systems DDM GmbH",
    "34248": "VELTON-TC- VELTON.TELECOM Ltd",
    "34249": "TNKBP- OAO TNK-BP Management",
    "34250": "UZTELECOM- \"Uzbektelecom\" Joint-Stock Company",
    "34251": "IMC- IMC LLC",
    "34252": "CELESTYNET- Chodkiewicz Krzysztof Edward EDMIRA",
    "34253": "WPP-EMEA- WPP 2005 Limited",
    "34254": "HORNET- HOR.NET Polska Sp. z o.o.",
    "34255": "I- ITUR Seguros y Reaseguros, S.A.",
    "34256": "NEMUNET- Betriebsgesellschaft Freizeit- und Sportzentrum Halberstadt mbH",
    "34257": "SIDEX ISPAT Sidex SA",
    "34258": "EUROBANK-EFG Eurobank a.d.",
    "34259": "VAUSH Privately owned Enterprise Testeshnikov Vladislav Jurievich",
    "34261": "BUHLERGROUP Buhler AG",
    "34262": "BIOTEVA- TEVA Magyarorszag Zrt.",
    "34263": "MPYNET- Mikkelin Puhelin OYj",
    "34265": "SILVERTELECOM- SilverTelecom Ltd",
    "34266": "UWC-NET- Autonomous System of Uralwestcom  CJSC",
    "34267": "DEBRYANSK--1 OJSC Rostelecom",
    "34268": "AINET OOO Ainet",
    "34270": "INETC Internet Connections Ltd",
    "34272": "ACTAVIS- Actavis EAD",
    "34273": "FISBS- Atos IT Solutions and Services Oy",
    "34274": "ELBMULTIMEDIA ELB MULTIMEDIA",
    "34275": "GHNET- TER Sp. z.o.o.",
    "34276": "RABOBANK Cooperatieve Centrale Raiffeisen-Boerenleenbank B.A.",
    "34277": "ALFA-LTD- Alfa Ltd.",
    "34278": "UA-ISP- V. LHKARYOV INSTITUTE OF SEMICONDUCTOR PHYSICS of The National Academy of Sciences of Ukraine",
    "34279": "TELETRANS Teletrans SA",
    "34280": "INTELCOM- Intelcom Ltd.",
    "34281": "NETDISH- ANTECH S.P.A.",
    "34282": "UKNOC- UKNOC",
    "34283": "KEPLER-ROMINFO Kepler Rominfo SA",
    "34284": "SECOBS-CPDL Asseco Business Solutions S.A.",
    "34285": "JJAA- Sociedad Andaluza para el Desarrollo de las Telecomunicaciones S.A.",
    "34286": "AJL- Aberdeen Journals Ltd",
    "34287": "VOLGOGRAD-GSM- CJSC Volgograd-GSM",
    "34288": "34288 EDU-ZG-CH - Public Schools in the Canton of Zug",
    "34289": "WEBART- WebArt Internet Services GmbH und Co. KG",
    "34290": "EBU Union Europeenne de Radio-Television",
    "34291": "CINVB- JOINT-STOCK INVESTMENT BANK OF CHELYABINSK \"CHELYABINVESTBANK\"",
    "34292": "PETRANET- Petra NET Autonomous System",
    "34293": "JSTEL J.S.tel s.r.o.",
    "34294": "ACCENTURE- Accenture SL",
    "34295": "ETA-BG-N Eta BG Ltd.",
    "34296": "MILLENICOM- MILLENI.COM",
    "34297": "SKH-IX- OJSC Rostelecom",
    "34298": "AXPL- Audatex Polska Sp. z o.o.",
    "34299": "TREZOR- Uprava za trezor, Ministarstvo finansija",
    "34300": "SPACENET- JSC Internet-Cosmos",
    "34301": "KFNETRO KFNET COM SRL",
    "34302": "WSCNET WinSoft Company, s.r.o.",
    "34303": "BELTELECOM ZAO \"Sviaz Telecom\"",
    "34304": "TEENTELECOM Teen Telecom SRL",
    "34305": "BEIP Base IP B.V.",
    "34306": "MOBIUS- MOBIUS TECHNOLOGY",
    "34307": "NL-IX-RS Broadband Hosting B.V. trading as NL-ix",
    "34308": "RIEDEL-NETWORKS Riedel Networks GmbH & Co. KG.",
    "34309": "LINK11 Link11 GmbH",
    "34310": "PENTANET- Penta Consulting SA",
    "34311": "LG- LG CNS Europe B.V",
    "34312": "ARMNET- FOP Boyko Oleg Mikhaylovich",
    "34314": "ESNET- ES Net Ltd.",
    "34315": "MAXNET- MAXNET Maxprogres, s.r.o.",
    "34317": "CLEARWIRE- Clearwire Ireland Ltd",
    "34318": "MINNIBERGER- Flashnet GmbH",
    "34319": "DOTRO DOTRO Telecom",
    "34320": "MNW- MNW Co Ltd",
    "34321": "LDK- Institute of strategic marks",
    "34322": "VIKMTER- VIK Master Ltd",
    "34323": "IPCOM- IP-Com Ltd",
    "34324": "NETLINK- NetLink sp. z o. o.",
    "34325": "PROFILINE- PROFILINE Sp. z o.o.",
    "34326": "CSC- SIA \"CSC TELECOM\"",
    "34327": "MTER-TELECOM OOO Master-Telecom",
    "34328": "TYPOHEADS- Typoheads GmbH",
    "34329": "INFONET-LV- SIA \"InfoNet Sistemas\"",
    "34330": "GSG- Gornoslaska Spolka Gazownictwa Sp. z o.o.",
    "34331": "KIEVNET- TOV \"KS PLUS\"",
    "34332": "TYCO- Tyco Health Care",
    "34333": "NERYUNGRITELECOM- NeryungriTelecom Ltd.",
    "34336": "GECFRU1- CJSC GE Money Bank",
    "34337": "ELPOS Cable TV Elpos Ltd.",
    "34339": "POLFIN- Centrum Przetwarzania Danych Ministerstwa Finansow",
    "34340": "BNT- Bulgarian National TV",
    "34341": "NCEM Namvaran Consulting Engineers and Managers",
    "34342": "KRDC- KRDC Sp. z o.o",
    "34343": "NL-EWEKA-USENET- Eweka Internet Services B.V.",
    "34344": "THE-PORT-OF-TILBURY-LONDON-LTD Port Of Tilbury London Ltd",
    "34345": "MMP- MMP BV",
    "34346": "KIEVLINE- Kievline LLC",
    "34347": "CNH- Stadtwerke Hall in Tirol GmbH",
    "34349": "KUNTSEVONET- SITS Ltd",
    "34350": "MANGROUP Man Investments Limited",
    "34351": "INTER-TELECOM- MTS OJSC",
    "34352": "MCN- MarComNet",
    "34353": "NETEX Netex Consulting S.R.L.",
    "34354": "SKATVIS- SIA \"SkaTVis\"",
    "34355": "INFOSFERA-UA- Chernigivtelecom LLC",
    "34356": "DIRECTEDI_UA DirectEDI UA network",
    "34357": "URBANMEDIA- Urban Media Communication Verlags GmbH",
    "34358": "CLAXTELECOM CLAX TELECOM SRL",
    "34359": "UA-LINK- NPF LINK Ltd.",
    "34360": "SISCO- Sisco Autonomous System",
    "34361": "LINKBG- LinkBG Ltd.",
    "34362": "VOLJATEL-HR- Terrakom d.o.o.",
    "34363": "STENUNGSUND- Stenungsunds Kommun",
    "34364": "TATAISNEFT- LLC TatAISneft",
    "34365": "JOHN_DEERE_WATER- John Deere Water Ltd.",
    "34366": "TELECABLE- KTV&Telecable Ltd.",
    "34367": "BSI- Banka Slovenije",
    "34368": "THEZONE \"Zonata - Natskovi & Sie\" Ltd.",
    "34369": "SHATELIX SHATEL Internet Exchange",
    "34370": "CSC CSCBank SAL",
    "34371": "AICOM-NET Metropolitni s.r.o.",
    "34372": "VEGYSTEMS- VegaSystems GmbH & Co. KG",
    "34374": "PROMETEY- remote department",
    "34376": "TELECOM-GROUP- Telecom Group Ltd",
    "34378": "RUG- OJSC Razgulay Group",
    "34379": "TNS-2 OOO \"Telecomunikacionnye Nezavisimye Systemy\"",
    "34380": "AMDOCS AMDOCS (ISRAEL) LTD",
    "34381": "METRO-RU- Metro C&C",
    "34382": "SYRUS-SRL- Assyrus Srl Maintainer",
    "34383": "TELOISE- Teloise",
    "34384": "WLANNET- LANWorld Finland Oy",
    "34385": "TRIPNET Tripnet AB",
    "34386": "SGL-CARBON-EU- SGL Carbon GmbH",
    "34387": "NETCREW Netcrew ry",
    "34388": "MAYANET Maya Iletisim Ticaret Limited Sirketi",
    "34389": "RU-ITS-NET Closed Joint-Stock Company \"Information Technologies and Communications\"",
    "34390": "NPLAY--TECHLAB NPLAY Sp. z o.o",
    "34391": "AXELCOM-01- PARITEL OPERATEUR SU",
    "34392": "ISKNET- Interaktywne Studio Komputerowe",
    "34393": "SYSTEL- Systel Systemy Teleinformatyczne M. Linscheid Spolka Jawna",
    "34395": "CYBCOM-NET--BG Cybercom Ltd",
    "34396": "GAMER- 5 Point AG",
    "34397": "CYBERIA-RUH Cyberia Riyadh Autonomous System",
    "34398": "ETSTUR- Ersoy Turistik Servisleri A.S.",
    "34399": "NEXUS- NEXUS Ltd.",
    "34400": "N-ETTIHADETISALAT Ettihad Etisalat",
    "34401": "EMIMUSICGROUP- EMI Group Limited",
    "34402": "INFOPLUS- INFOPLUS Joanna Operacz Leszek Chwalinski s.c.",
    "34403": "INGBANKTR- ING BANK ANONIM SIRKETI",
    "34404": "DELTA-M Delta M d.o.o.",
    "34405": "ANCITEL-N Ancitel S.p.A.",
    "34406": "VANCO-UK-2 Reliance Globalcom Ltd. (formerly Vanco Ltd)",
    "34407": "WAVECREST-01 Wavecrest (UK) Ltd",
    "34409": "GRATKA- Polskapresse sp. z o.o.",
    "34410": "VANILLA-TELECOMS-LTD-MALTA- Vanilla Telecoms Ltd",
    "34412": "ACTIV- SC Computers Activ SRL",
    "34413": "MATRIX Calyx Managed Services Limited",
    "34414": "NOKIA-CHINA NOKIA Corporation",
    "34416": "FDX- Full Duplex SRL",
    "34417": "BALTIKUMS- Komercbanka Baltikums",
    "34418": "GLOBAL-NET- Global Bilgi Pazarlama ve Cagri Hizmetleri A.S.",
    "34419": "ON- Vodafone Group Services GmbH",
    "34421": "34421 Telecom Media Systems JLLC",
    "34422": "NIV2- Alionis",
    "34423": "NEW-LAN- ATW Internet Kft.",
    "34424": "PGNIG- Polskie Gornictwo Naftowe i Gazownictwo SA",
    "34425": "AIRBITESBG- Air Bites Bulgaria Network",
    "34426": "SHABAKAHNET-N Autonomus System number for Shabakah Net",
    "34427": "COMSENSO Comsenso BV",
    "34429": "BSP BSP GROUP INFORMATIK",
    "34430": "QORE- Connect Data Solutions",
    "34431": "OPTEAM- OPTEAM S.A.",
    "34432": "PHH- Profihost AG",
    "34433": "UTEL- UTEL S",
    "34434": "RU-SCX- Server-Center JSC",
    "34435": "EVERNET- Tomasz Tomaszewski EVERNET",
    "34436": "PDP-NET- E-Government Network of Provicia di Padova",
    "34437": "CALLCOMM04 Vyke Telecoms Limited",
    "34438": "PROFZONE Erich Hohermuth",
    "34439": "GFD- OBI Smart Technologies GmbH",
    "34440": "SPEICHER- Speicherzentrale GmbH & Co. KG",
    "34441": "SIBNK- Siberian Internet Company",
    "34442": "AMATISNETWORKS Xifos Ltd",
    "34443": "PABK- Postova banka a.s.",
    "34444": "EUTELSAT-BACKBONE- EUTELSAT S.A.",
    "34446": "RTLTD- Ready Technology (UK) Limited",
    "34448": "SNTUA- S&T UKRAINE",
    "34449": "MORDOVIA- OJSC Rostelecom",
    "34450": "WDC- WORLDNET DATA COMUNICATII SRL",
    "34451": "BROM- BANCA ROMANECA SA MEMBRA A GRUPULUI NATIONAL BANK OF GREECE",
    "34452": "WIMAXRU JSC Start Telecom",
    "34454": "EXCLUSIV- SC Business IT Telecom SRL",
    "34455": "OPEN-NET- SC OPEN NETWORK MANAGEMENT SRL",
    "34456": "RIALCOM- Rial Com JSC",
    "34457": "AMB-GENERALI Generali Deutschland Informatik Services GmbH",
    "34459": "FARITOM FARITOM LTD",
    "34460": "PHOENIX- PHOENIX Pharmahandel GmbH & Co KG",
    "34462": "DITEC- DITEC, a.s.",
    "34463": "SSPORT- Super Sport d.o.o.",
    "34464": "ZEISS- Power and communication of construction CJSK",
    "34467": "SOTCOM- Sotcom ISP",
    "34469": "CONNETRO-  for the connet-ro network",
    "34470": "PTKOM- PortTelekom Autonomous system",
    "34471": "EXCOM- Free Technologies Excom S.L.",
    "34472": "ROSENERGOBANK- Commercial Bank 'ROSENERGOBANK' (ZAO)",
    "34473": "VISUALRADIO- Visual Radio  Number",
    "34474": "KEBA-AG KEBA AG",
    "34478": "UEKAE- TUBITAK Ulusal Elektronik ve Kriptoloji Arastirrma Enstitusu",
    "34479": "TSC- High Current Electronics Institute",
    "34480": "GSC- Nanotekh Ukraine Ltd",
    "34482": "CIRQUE Cirque Bredband A/S",
    "34483": "WOLFSKIN- Jack Wolfskin Ausruestung fuer Draussen GmbH & Co. KGaA",
    "34484": "TIETOTALO- Tietotalo Infocenter Oyj",
    "34485": "ELECTROSVIAZ- Euroset-Retail LTD",
    "34486": "IP2 2ML it solutions bv",
    "34488": "BANK-AUSTRIA-LJUBLJANA- UNICREDIT BANKA SLOVENIJA d.d.",
    "34489": "AIRPLANET- Pannon Pipics Ltd.",
    "34490": "TSC- JSC Tomskkosmossviaz",
    "34491": "BULSTRAD- Zastrahovatelno Akcionerno Druzhestvo \"Bulstrad Viena Insurance Group\" AD",
    "34492": "PRIMANET- Prima Net Consult EOOD",
    "34493": "OCCTERRA- OCCTERRA S",
    "34494": "BAIT-PL- Bait Sp. z o.o.",
    "34496": "PLANET-SCHOOL- Planet-School Webhosting Leslie Schnee e.K.",
    "34497": "2E2_1 Logicalis Guernsey Ltd",
    "34499": "JN- Editura Intact, JURNALUL NATIONAL,",
    "34500": "CTSPI CTSPI Company",
    "34501": "ABSI- Advanced Business Solutions International SRL",
    "34502": "XLINK- Multikom Austria Telekom GmbH",
    "34504": "INTERPROM- Joint Stock Commercial Bank Interprombank CJSC",
    "34505": "VISTATEC-  Number for Vistatec Limited",
    "34506": "SUPERGROS SuperGros a/s",
    "34507": "OPG Mediq NV",
    "34508": "PORTTEL- OAO Komstar-OTS",
    "34509": "BMJ- P.P.H.U. \"BMJ\" Sp.J. W.Baran J.Pogonowski",
    "34510": "AFONE- AFONE",
    "34511": "F-INTEGRA- Fundacion Integra Autonomous System",
    "34512": "ARIANET- Rutil Ltd.",
    "34513": "TSTONLINE- TSTonline co.",
    "34514": "FUTURECOM Futurecom Interactive AG, Zurich, Switzerland",
    "34516": "ARX-NET ARX.NET SA",
    "34517": "MAXNET- MaxNET SRL",
    "34518": "FATUM- LLC \"Fatum-3\"",
    "34519": "VJESNIK- Vjesnik d.d.",
    "34520": "DFG- Deutsche Forschungsgemeinschaft",
    "34521": "ATOS-SK- Atos IT Solutions and Services s.r.o.",
    "34522": "MORH Ministry of Defense of Republic of Croatia",
    "34523": "EMAILSYSTEMS Webroot Services Ltd",
    "34524": "DIGICOM- Digital Communications Ltd.",
    "34525": "KOBA- KoBa Konrad Baranowski",
    "34526": "WIMORE WiMORE s.r.l.",
    "34527": "NETFORT- Netfort, Moscow, Russia",
    "34530": "CK-ZETO- Centrum Komputerowe ZETO S.A.",
    "34531": "BIOS B.I.O.S. Technologies Ltd",
    "34532": "BRUETSCH-RUEGGER Bruetsch-Ruegger AG",
    "34533": "ESAMARA- CJSC \"ER-Telecom Holding\"",
    "34534": "PAVIANETWORK- Linea Com Srl",
    "34535": "IXIS IXIS Autonomous System",
    "34536": "NEWEL- Newel Informatique Autonomous System",
    "34537": "GIPPNET Solidtango AB",
    "34538": "NANKABEL- Mode3h CATV & Internet division",
    "34540": "AGROKOR- mStart telekomunikacije d.o.o.",
    "34541": "ONLINESOLUTIONS- Online Solutions Hosting Services",
    "34542": "FORUM-TELECOM- \"International Commercial Alliance\"",
    "34543": "BCR Banca Comerciala Romana SA",
    "34544": "PL--3PL 3.PL s.c.",
    "34546": "DFQS- Dom Finansowy \"QS\" Sp. z o.o.",
    "34547": "TELESMART- Telesmart Telekom DOO",
    "34548": "KNV- Koch, Neff & Volckmar GmbH",
    "34549": "LAXIN- Laxin IT-Services GmbH & Co. KG",
    "34550": "INTERCON- Intercon JSC",
    "34551": "IF-CFR- INFORMATICA FEROVIARA SA",
    "34552": "TKURAL- OJSC MegaFon",
    "34554": "ANTANET Antares Kommunikationstechnik AG",
    "34555": "CCS-LEEDS-N C.C.S. (Leeds) Ltd",
    "34556": "NETCAMP-SE Availo NetCamp AB",
    "34557": "TACOM- Tacom",
    "34558": "TELEMAIL Ozone Limited",
    "34559": "MEDIACOM- SC MEDIACOM NET SRL",
    "34560": "SOFTEX- SC Softex SRL",
    "34561": "FONNET Fonnet Ltd.",
    "34562": "PROIP- Synssans B.V.",
    "34563": "MICROSEC- Microsec Szamitastechnikai Fejleszt Kft.",
    "34564": "GOTHAER- Gothaer Versicherungen",
    "34568": "CONNECTINGBYTES- ConnectingBytes GmbH",
    "34569": "NETWORX-BG Networx-Bulgaria Ltd.",
    "34570": "CSAT- Dataline LLC",
    "34572": "HELIANTIS- Heliantis S",
    "34573": "OBERON-N Oberon Plus LLC",
    "34574": "REKSOFT- Reksoft Co. Ltd.",
    "34575": "CNIX-ROUTE-SERVER Cork Neutral Internet Exchange",
    "34576": "REGIONSKANE-SE Skane Lans Landsting",
    "34577": "SKATTV- SKAT TV Ltd.",
    "34578": "BEDAG Bedag Informatik",
    "34579": "SOYUZ- Soyuz LTD",
    "34580": "UNITLINE_MSK_NET1 Close Company MediaSeti",
    "34581": "QUINSY- Quinsy B.V.",
    "34582": "PLGATE- Polo Ltd.",
    "34583": "ALVARION ALVARION LTD",
    "34584": "KHBDSV OJSC Rostelecom",
    "34586": "DR-EUROPE element5 GmbH",
    "34587": "HLM2- Hillside (New Media) Limited",
    "34588": "FIBERNET-HU- Invitel Tavkozlesi Zrt.",
    "34589": "IFAO-BG- i:FAO Bulgaria EOOD",
    "34590": "NEOLINK CJSC \"ER-Telecom Holding\"",
    "34592": "AMARD Amard Ltd",
    "34593": "QAVR- QAVR-",
    "34594": "OT- OT - Optima Telekom d.d.",
    "34595": "GLOBAL-2 Global Germany",
    "34598": "EZFACE EZFace Ltd",
    "34599": "CONCRET- SC Concret Network Srl",
    "34600": "CENTAUR- Prioritel Ltd",
    "34601": "INTERCOM- Intercom Factory S.L.",
    "34602": "STARLINK- Media Ltd",
    "34603": "MZTM- JSC \"Mariupol factory Heavy Machinery\"",
    "34604": "PULMAN-COM- Institute of Soil Science and Plant Cultivation",
    "34605": "LINET- Linet LTD",
    "34606": "N-BBBELL BBBell s.r.l. - Telecommunication Services",
    "34607": "SKEKRAFT Skelleftea Kraft Elnat AB",
    "34608": "MARAFON Bookmaker Company Marathon Ltd",
    "34609": "34609 Internet Master Co Ltd",
    "34610": "RIKSNET",
    "34612": "IMATRIX MATRIX PC bv.",
    "34613": "LYNK- Lynk srl",
    "34616": "AMEUROPE-NET Multi Corporation BV",
    "34617": "SOFTWAREONE- SoftwareONE AG",
    "34618": "PROMETEO- Prometeo S.p.A.",
    "34619": "CIZGI Cizgi Telekomunikasyon Hizmetleri Sanayi Ve Ticaret Limited Sirketi",
    "34620": "MIKRONET_LTD- Mikronet SIA",
    "34621": "SUNTELECOM- SUN Telecom RTS SRL",
    "34622": "BIKAB- Bredband i Kristianstad AB",
    "34623": "NETEGRAL Astutium Limited",
    "34624": "MEGPACE- Megaspace Internet Services GmbH",
    "34625": "INX- OSHS Ltd",
    "34627": "OPENLINK- HOSTWAY ROMANIA SRL",
    "34629": "ORNRU- \"Resurs-Svyaz\" Ltd.",
    "34630": "AMBRA- AMBRA srl",
    "34632": "ARIELCOMMS Ariel Communications Ltd",
    "34633": "UKRINDEX- UkrIndex LLC",
    "34634": "KLIMRTS- Digit One LLC",
    "34635": "LIBERTY- Liberty Poland S.A.",
    "34636": "LNDN- Laser Networks  Number",
    "34637": "BZE- ENION S.A",
    "34638": "ALTERNET Alternet SA",
    "34639": "TOTEL- Totel LTD",
    "34641": "IQ-NET- IQ-NET SRL",
    "34642": "DIG-IMAGE MG & V Ltd.",
    "34644": "EXTEL- OJSC \"VimpelCom\"",
    "34645": "BABILON- I.C.S \"BOOM-INFO\" S.R.L.",
    "34646": "STEINKAMM Arne Steinkamm",
    "34647": "PROSYGMA-  FOR AKILAO PROSYGMA",
    "34648": "BCIT- Unicredit Tiriac Bank SA",
    "34649": "HOST365 HOST365 LIMITED",
    "34650": "ADB- A.D.B. Analisi Dati Borsa S.p.A.",
    "34651": "KOYTO-PL- koYto.pl",
    "34652": "KID-  number for KID ltd.",
    "34653": "FOCUS-NUNTI Focus Nunti Ltd.",
    "34654": "IONIC- Ionic Information Limited",
    "34655": "DOCLER- DoclerWeb Kft.",
    "34656": "COMPENSA- COMPENSA S.A.",
    "34657": "TAWAMANNET TAWA MANAGEMENT LTD",
    "34658": "RAKITA-TELEKOM-KLIMOVSK- Limited Company Rakita-telekom",
    "34659": "KEYYO KEYYO SA",
    "34660": "IDAQ- Idaq Ltd",
    "34661": "BREEZE-NETWORK TOV TRK \"Briz\"",
    "34662": "MMBANK- Bank of Moscow OJSC",
    "34663": "BELTINGDIENST Belastingdienst/Centrum voor Infrastructuur en Exploitatie",
    "34664": "NEVKA-SPB- OOO Nevka SPb",
    "34665": "AIRABA- AirABA Sarajevo D.O.O.",
    "34666": "GLB1- \"Global-Erty\" JSC",
    "34668": "ORBITAUA- Join Stock Company \"Scientific & Production Enterprise \"ORBITA\"",
    "34669": "TELESYS- Telesys Ltd.",
    "34670": "COREWARE- Coreware Ltd",
    "34671": "TOMSKNEFTEHIM- Tomskneftehim Ltd.",
    "34672": "ELHIM- MIPS Group LLC",
    "34673": "SUEDKURIER- Suedkurier GmbH",
    "34674": "NETWAVE- NetWave Ltd.",
    "34675": "PIH-UK Prima Internet Holdings Limited",
    "34676": "STAVCOM- \"Stavropol'skie Kommunikacii\" OOO",
    "34677": "UA-INIT- ACT-COMBI Ltd",
    "34678": "TOLVUN- Tolvun Autonomous system",
    "34679": "VELOX Connexions4London Ltd",
    "34680": "FALCON- FALCON COMPUTERS SRL",
    "34682": "YAUZA-TELECOM- LLC Yauza Telecommunication Company",
    "34683": "NETLINE Netline S.A. Internet Services Provider",
    "34684": "YKS- Yapi Kredi Sigorta A.S.",
    "34685": "XOVO- X.OVO MediaNetworks GmbH",
    "34686": "AFFV- Affarsverken Karlskrona AB",
    "34687": "KOLBI- Fastnet LLC",
    "34688": "PL-MAVERICK- Marcin Pietrucha as \"Maverick\"",
    "34689": "IPI-GROUP- IP Infrastructures Ltd",
    "34690": "SVAOIX- Netorn-TK LLC",
    "34691": "CISCOM- Centralizovannie informationie systemy i communicacii Ltd",
    "34692": "FREEBONE-CZ Freebone s.r.o.",
    "34694": "STWW- Stadtwerke Woergl GmbH",
    "34695": "E4A- E4A s.r.l.",
    "34696": "AINE- Aine",
    "34697": "EMERSON-EMA- Emerson",
    "34698": "MOLCOM- JV Molcom Ltd.",
    "34699": "MINISTERO-ESTERI- Ministero degli affari esteri",
    "34700": "CITYNET- Maxnet Autonomous System",
    "34701": "WITZENMANN- Witzenmann GmbH, Pforzheim",
    "34702": "WAVECOM- WaveCom",
    "34703": "PRTNET- LTD Pokrovsky radiotelefon",
    "34704": "SAVEHO Saveho SARL",
    "34705": "SYDFYN Sydfyns-Intranet A/S",
    "34706": "RACKSENSE-N Rack Sense Ltd",
    "34707": "KEMSU- State Educational Institution of higher professional Education 'Kemerovo State University'",
    "34708": "GRD Gulf Research & Development Company",
    "34709": "ALTEGROSKY- CJSC Settelecom",
    "34710": "PUREHOSTING- Happy Hosting",
    "34711": "DIGINET- DIGINET SA",
    "34712": "SEAC2- Seac Spa",
    "34714": "OPTICNET OPTICNET - SERV S.R.L.",
    "34715": "AMRON- \"Radio station \"Radio set\" Ltd",
    "34716": "ANIX ANIX Limited Hosting",
    "34717": "SID- SID bank d.d. Ljubljana",
    "34718": "TPSUZ- ISP \"TPS\" - BGP N of \"TEXNOPROSISTEM\" Ltd",
    "34719": "PL-4EVERNET- 4EverNET Sp.z o.o.",
    "34720": "CHUMAK- Chumak plc",
    "34722": "RKU rku.it GmbH",
    "34723": "RNT- Real Network and Tel SRL",
    "34724": "PANON- Panon Net d.o.o. Subotica",
    "34725": "NETCOM- Netcom S.R.L.",
    "34726": "SALTAR Anders Telecom Ltd.",
    "34728": "CINVEN Cinven Services",
    "34729": "SILBERAUTO Aktsiaselts Silberauto",
    "34730": "BGK- Bank Gospodarstwa Krajowego",
    "34731": "ARCHIMEDIA- Archimedia SRL",
    "34732": "FRIKI- Friki Com SRL",
    "34733": "SAVOLA-NET The Savola Group",
    "34734": "COMNED-RG2 Network Management Development Organisation BV",
    "34735": "LKW-WALTER-AG LKW Walter Internationale Transportorganisation AG",
    "34736": "TOYOTA-TR TOYOTA OTOMOTIV SANAYI TURKIYE A.S.",
    "34737": "QINETIQ-ISP QinetiQ Ltd",
    "34738": "STERLING- Sterling Fluid Systems IP BV",
    "34739": "ES- Electronic Shield Ltd",
    "34740": "PCHARDWAREWEB PC Hardware SRL",
    "34741": "BOB Bank of Beirut S.A.L",
    "34742": "SATLINE- CJSC SatLine",
    "34743": "NHNET- NashNet Ltd",
    "34744": "GVM S.C. GVM SISTEM 2003 S.R.L.",
    "34745": "TELEWARE TeleWare plc -  number",
    "34746": "EATONKAYE AXA Insurance UK plc",
    "34747": "ISI- OJSC \"Vimpelcom\"",
    "34748": "PORTUS- H1 Telekom d.d.",
    "34749": "GLBP-N Global Service Provider",
    "34751": "AXPERIA Axperia",
    "34752": "DOCTISSIMO LAGARDERE ACTIVE DIGITAL S",
    "34753": "CSC-BG- CSC Bulgaria",
    "34754": "TELNET- Telnet Limited",
    "34755": "TOBB Turkiye Odalar Borsalar Birligi",
    "34756": "N-GVRH Infostrada Connect B.V.",
    "34757": "SIBSET-NSK- Sibirskie Seti Ltd.",
    "34758": "INTERPLANET-IT Interplanet S.r.l.",
    "34759": "N-BANCADITALIA Banca d'Italia",
    "34760": "N2000- Neptuno 2000 Servicios en Red S.L.U:",
    "34761": "XTS-TELECOM KERTEL FRANCE OUTRE MER",
    "34762": "COMBELL- Combell group NV",
    "34763": "VIRGINRADIO Ipercast Network",
    "34764": "FISDE- Maurice Funke",
    "34765": "AIRCLUB- Centrum Podrozy Air Club Stanislaw Modlinski",
    "34767": "STONERICH- Otto M. Steinmann e.U.",
    "34768": "MARVEL-COMMUNICATIONS- Marvel Communications SA",
    "34769": "ORANGE LuXcommunications S.A.",
    "34770": "ELITSAT- Elit Sat Net Ltd.",
    "34771": "MEGETI- Megaseti Ltd.",
    "34772": "NEOTEL--MK NEOTEL-MKD Autonomous System",
    "34774": "HON-EU Honeywell Europe Services S",
    "34775": "ANALYTIC-NET FOP Koval Andriy Olegovych",
    "34776": "NAU- National Aviation University",
    "34778": "MENTOR-GRAPHICS- Mentor Graphics (Ireland) Ltd.",
    "34779": "T-2- T-2, d.o.o.",
    "34780": "VILLAGE-ROADSHOW- Village Roadshow Operations Ellas S.A.",
    "34781": "SIMA-LAUSANNE- Service Multimedia",
    "34782": "ELEVEN-NET2 eleven - Gesellschaft zur Entwicklung und Vermarktung von Netzwerktechnologien mbH",
    "34783": "IPSLA- IP SLA Internet Protocole Service Leval Agreement S",
    "34784": "RUSAT-  a Satellite Teleport RuSat",
    "34785": "STW- N Stadtwerke Klagenfurt AG",
    "34786": "VNET- OOO NPO Intermet",
    "34787": "LYAKH- PF \"Volodymyr Lyakh\"",
    "34788": "NMM- Neue Medien Muennich GmbH",
    "34789": "COMP- Asseco Poland S.A.",
    "34790": "WAVEWORKS- Waveworks Internet Network",
    "34791": "STV- Rozhlas a televizia Slovenska Ipo",
    "34792": "FSS- Finance Communication Service, Ltd",
    "34793": "NORDGEAR- Getriebebau NORD GmbH & Co. KG",
    "34794": "LIBRABANK- Libra Bank SA",
    "34795": "INMR- Ipsos Interactive Services SRL",
    "34796": "QTEL-IXP-1 Ooredoo Q.S.C.",
    "34797": "EGRISI- Egrisi JSC.",
    "34798": "MCIX- MCIX - Manchester Commercial Internet Exchange",
    "34799": "COLIBRI- Lugalink Ltd",
    "34801": "KT- JSC \"Key-Telecom\"",
    "34802": "RCCF Commercial Bank \"Renaissance Capital\" LLC",
    "34803": "BGL Broadband Gibraltar Ltd",
    "34804": "EUROTELECOM- LLC \"Eurotelecom\"",
    "34805": "COMDREV- Comdrev Internet Service Provider",
    "34806": "RUVA-NET RUVA Networks",
    "34807": "STEDAC- Rainer Lillge",
    "34808": "SRR Societatea Romana de Radiodifuziune",
    "34809": "SANEF- numero  de SANEF TELECOMS",
    "34810": "MANSION- Mansion (Gibraltar) Limited",
    "34811": "PIRE Aspire Internet Ltd",
    "34813": "CAPITALCITYSERVICE Capital City Service Limited",
    "34814": "DYTYNETS- Osnova-Internet LLC",
    "34815": "IE-GEC- Dublin Entrprise & Technology Centre Limited",
    "34816": "AEG AEG Europe",
    "34817": "LHSYSMUC Lufthansa Systems AG",
    "34818": "BAGIMSIZ_GAZETECILER_YAYINCILIK Bagimsiz Gazeteciler Yayincilik A.S",
    "34820": "DANNAX-SK- DANNAX spol. s.r.o.",
    "34821": "PCSNN- Information & Computing Center, Ltd.",
    "34822": "MEDIANETWERK Media Netwerk",
    "34823": "DBNET- Danish Broadband a/s",
    "34824": "SAMARVYAZINFORM-CJSC- SAMARVYAZINFORM CJSC",
    "34826": "BLUEMEDIA- Blue Media Sp. z o.o.",
    "34829": "NAUKAVIDNOE LLC \"Nauka-Svyaz\"",
    "34830": "FCPL-LD1- FCP Internet LTD",
    "34832": "NOVOSYSTEM- NOVOSYSTEM Ltd.",
    "34833": "BUSTC- Business Telecom Ltd",
    "34834": "QUIPU- QUIPU GmbH",
    "34835": "POLIVEKTOR Polivektor JSC",
    "34836": "RCS-SPB- CJSC \"Ruscentrosvyaz\"",
    "34837": "VANAELECTRIC Vana Electric Co. Ltd.",
    "34838": "ALFAINS- JSC \"AlfaInsurance\"",
    "34839": "SWP- Suedwest Presse Online-Dienste GmbH",
    "34841": "BALCHIKNET Lafy EOOD",
    "34842": "RCS-LT AB City Service",
    "34843": "SPBREALTY- Managing company \"Realty of Petersburg Ltd\"",
    "34844": "ELART Elart Stanislaw Zakrzewski",
    "34845": "BILLBIRD- Billbird S.A.",
    "34846": "CCORE- Centrecore",
    "34847": "PROFGROUP- PROFGROUP SRL",
    "34848": "COMENDO- Comendo A/S",
    "34849": "RUDN- Federal State Institution of Higher Professional Education \"Peoples Friendship University of Russia\"",
    "34850": "AKAMAI-MUC Akamai International B.V.",
    "34851": "FSS- Fund of social insurance of Russian Federation",
    "34852": "AYALON_INSURANCE_LTD AYALON INSURANCE COMPANY LTD",
    "34853": "SUNNYDAY Sunny Day Design",
    "34854": "IRADEUM- Iradeum Trading Ltd.",
    "34856": "COMFORT- TOV Comfort Ltd.",
    "34857": "TELELAN- Telelanas ISP, Klaipeda, Lithuania",
    "34858": "ENERGY- JSC Energy",
    "34859": "M2M- m2m Wholesale Ltd",
    "34860": "ERENIS Societe Francaise du Radiotelephone S.A.",
    "34861": "INFA-UK- Informatica Software Ltd.",
    "34862": "IRE- Institution of Russian academy of sciences Kotel'nikov Institute of Radio Engineering and Electronics of R",
    "34863": "HEXANET HEXANET S",
    "34866": "MTERIT Master IT Ltd.",
    "34867": "COSMONOVA- Cosmonova LLC",
    "34868": "ANYCT- wasted.io Ltd.",
    "34869": "EKANET- Ekanet Limited Liability Company",
    "34870": "INTERFAX- News Agency Interfax-Ukraine Ltd",
    "34871": "UZDUNROBITA FE Uzdunrobita Ltd",
    "34872": "HVB Unicredit Global Information Services S.C.P.A.",
    "34873": "IGIF- ACSS - Administracao Central do Sistema de Saude, I.P.",
    "34874": "LINKY- ZAO Linky Autonomous System",
    "34875": "YANFES OJSC \"Rostelecom\"",
    "34876": "SMART-SYSTEMS \"SMART SISTEMZ TECHNOLOJI\" MMM",
    "34877": "PROCREDITBANK- ProCredit Bank Public Joint Stock Company",
    "34878": "KIT Karlsruhe Institute of Technology (KIT)",
    "34879": "CCT- NGENIX",
    "34880": "SOLVENIUS-GMBH Solvenius GmbH",
    "34883": "FH-JOANNEUM FH JOANNEUM Gesellschaft mbH",
    "34885": "EDSBG- Erzdioezese Salzburg",
    "34886": "IDC- The Interdisciplinary Center Hertzeliya",
    "34887": "CIRT- GU Center of Information Technologies RT",
    "34888": "PSV- SC PETROMSERVICE SA",
    "34889": "INTERAMBITION- InterAmbition.com B.V.",
    "34890": "TCU-COM- Territorial Control Centre of Communications Ltd.",
    "34891": "UM-WARSZAWA- Urzad Miasta Stolecznego Warszawa",
    "34892": "INFOLINK- Infolink",
    "34893": "INSTITUT-STRAUMANN Institut Straumann AG",
    "34894": "ATEL- OJSC \"Vimpelcom\"",
    "34895": "HOSTNET-DE- hostNET Medien GmbH",
    "34896": "VTELECOM- Vostoktelecom Telephone Company LLC",
    "34898": "SYMBIOS- DTS LLC",
    "34899": "NEWCOLO- NewColo GmbH",
    "34900": "NYMEX- CME Operations Limited",
    "34902": "ENERGIAPRO- EnergiaPro SA",
    "34904": "GEDERAMI- SC GEDERAMI SRL",
    "34905": "BWT- BWT AG",
    "34906": "AVIANET AVIANET Network Management GmbH",
    "34908": "-VALOR-KH LLC \"TC Valor\"",
    "34909": "MAXCOM- Maxcom Ltd.",
    "34912": "IFN- INTERFUSION INET",
    "34913": "RENTABILIWEB Rentabiliweb Telecom",
    "34914": "SYNTEC- Syntec LTD",
    "34915": "METROSERV- Metropolitan Services SRL",
    "34916": "DNET- SC Digital Construction Network SRL",
    "34917": "ORLANDONET- Orlandonet Ltd",
    "34918": "IR-PISHGAMAN-ICP Pishgaman Kavir Yazd",
    "34919": "MONTAN-NET Montan Telecom AG",
    "34920": "BSQ Simply Transit Ltd",
    "34921": "BELTVR National State Teleradio Company of the Republic of Belarus",
    "34922": "NETNAMES NetNames Operations Limited",
    "34925": "CHICS- CJSC Chelyabinsk Interactive Cable Networks",
    "34926": "COTELEM- Cotelem",
    "34928": "REGIOITAACHEN regio iT aachen GmbH",
    "34929": "HOSTWAY Hostway France SARL",
    "34930": "BAA BAA Airports Ltd",
    "34931": "AWARESOFT Awareness Software Limited",
    "34932": "FUZION Fuzion is a Danish Internet Service Provider",
    "34933": "IPSGRP- PP Aleksandr Tatarets",
    "34934": "UKFT UKfastnet Ltd",
    "34936": "NYM- nym networks",
    "34937": "OTVK- Stowarzyszenie Olawska Telewizja Kablowa",
    "34938": "VANDEROEST Arjan van der Oest",
    "34939": "SPLINE- Company Spline network",
    "34940": "NUX Eros Computer System Ltd t/a NUX",
    "34941": "CYBERCOM- CyberCom & YT AB",
    "34942": "VIVOR- Vivor B.V.",
    "34943": "SPINTERNET- Poste Srpske a.d.",
    "34944": "VESATEL- Vesatel SRL",
    "34945": "QF-N Qatar Foundation for Education, Science and Community Development",
    "34946": "WETTERNET- Jonkoping Energi AB",
    "34947": "COPPERNET- Coppernet, Zambia",
    "34948": "TYPHON- Typhon",
    "34949": "INTERPC- IDLINE S",
    "34950": "N-SOS SYSteam Outsourcing Services Linkoping AB",
    "34951": "POLICOLOR- POLICOLOR SA",
    "34953": "RELAIX RelAix Networks GmbH",
    "34954": "SAINSBURYS-NET Sainsbury's Supermarkets Ltd",
    "34955": "VICENIK Martin Vicenik",
    "34956": "NATEXISMETALS- NATEXIS COMMODITY MARKETS LIMITED",
    "34957": "CEGETEL-LA-REUNION- SOCIETE REUNIONNAISE DU RADIOTELEPHONE SCS",
    "34958": "FAMIPOW- Look a Box SPRL",
    "34959": "CAMIS- Camis Menkul Degerler",
    "34960": "NETCETERA-AG- Netcetera AG",
    "34961": "GNTLT- UAB GNT Lietuva",
    "34962": "INFODATA- SC InfoData Telecom SRL",
    "34963": "ALLYNNT Allyn International Services Inc.",
    "34964": "RIPE-AT- Ripe-NetWorks e.U.",
    "34965": "IDEON- Ideon Center AB",
    "34966": "RALFBENDER- Ralf Bender",
    "34967": "DRD- DRD Communication Plc",
    "34968": "IUNXI Trixit Holding B.V.",
    "34969": "PJONET- Pasjo.Net Sp, z o.o.",
    "34970": "DIATEM DIATEM SARL",
    "34971": "PDDA- Prometeus di Daniela Agro",
    "34972": "ROBINAXIS- SC BINAXIS SRL",
    "34973": "CALVAEDI- CalvaEDI S.A.S.",
    "34974": "KAMCHATKA- OJSC Rostelecom",
    "34975": "AZIMUTR- Azimut-R ltd. Autonomus System",
    "34976": "CNI Regione Toscana",
    "34977": "PROCONO- PROCONO S.A.",
    "34978": "GLOBAL-MOBILE-VISION Global Mobile Vision",
    "34980": "ESTAT mediametrie-eStat",
    "34981": "ROLINK- SC Link Explore SRL",
    "34982": "_ESAG ELMOS Central IT Services GmbH",
    "34983": "UT- Ltd. Univer-telekom",
    "34984": "TELLCOM- TELLCOM ILETISIM HIZMETLERI A.S.",
    "34985": "NETING- NETING Sp. z o.o.",
    "34986": "KPWIG KOMISJA NADZORU FINANSOWEGO",
    "34987": "BTNET-AND-EXPERT-TRAINING-SYSTEMS BTnet and Expert Training Systems",
    "34988": "EWS DB Schenker Rail (UK) Ltd.",
    "34989": "SERVETHEWORLD- ServeTheWorld",
    "34990": "SKYINET- TOV SkyInet",
    "34991": "WNS- Wireless Network Solutions Ltd.",
    "34992": "PGI-FR-TC- Premiere Global Services",
    "34993": "ODISO- ODISO",
    "34994": "LVBP- SIA \"BALTIC PRO\"",
    "34995": "SYSTEM-LTD- System Ltd",
    "34996": "ANADOLUSIGORTA- Anadolu Anonim Turk Sigorta Sirketi",
    "34997": "ALIONIS Alionis",
    "34998": "SDM- Commercial Bank \"SDM-BANK\" OJSC",
    "34999": "PROINTERNET- Pro-internet Sp. z o.o.",
    "35000": "PROMETEY Prometey Ltd. Autonomous System"
}